﻿* Encoding: UTF-8.

* *** This syntax file is designed to take the raw SPSS data from the RAAAP-3 Qualtrics questionnaire and process it in order to, as per the RAAAP-3 Data Analysis Plan:
3.	Data Identification - Removal of “non-data” (eg “click here to agree” = all are 1)
4.	Systematic review of each variable - is it the correct type?
5.	Data Cleansing - (eg -99  system missing)
6.	Data Correcting - (eg missing response options backfilling based on free text (eg if a US state was missing from the choices this could be backcoded based on other responses))
7.	Data Anonymising  (removal/redaction of any text that might give rise to identification)
8.	Data Recoding - for clearer analysis [eg 8 (=1 year as a research admin) recode to 1]
9.	Data Rationalisation (eg “years in research administration” into 5 year bands)
10.	Data Consolidation (eg merging of data fields where appropriate [3 “other” into 1] [optional step]
11.	Data Fusion (eg merging of two independent fields into a complex variable [eg Gender and Age into Gender-Age] for more insightful analyses) [optional step]
11A            Data splitting and saving - to aid anonynimity, eg separating free text from multichoice responsese
Other steps from the data analysis plan are not conducted in this SPSS file, but elsewhere

* *** file created and developed by Simon Kerridge (SK), Madhuri Dutta (MD), Melinda Fischer (MF), Cristina Oliveira (CO)
    
* *** Background
* *** This is the third survey in the RAAAP series of surveys, RAAAP-1 was conducted in 2016 and RAAAP-2 in 2019
* *** See: https://inorms.net/activities/raaap-taskforce/ for more information.

* *** Version History.
* *** 18th May 2022 - initial version: SK, MD, MF, CO
* *** 25th May 2022 - v2 - first full version: SK, MD, MF, CO
* *** 12th July 2022 - v3 - includes fix for left over values labels for academic qualification level: SK, MF
* *** 7th August 2022 - v4 - includes anonymising syntax: SK, MF, based on work of SK, MD, MF, CO
* *** 1st May 2023 - v5 - includes additional anonymising syntax: SK, based on work of SK, MD, MF, CO in cross checking results from v4

* *** Overview of data
* *** The main RAAAP-3 data were collected by Qualtrics 
* *** So the RAAAP-3 Main with 5,608 responses and 414 initial datapoints
* *** However, not all of those were completed survey responses: 3,431 are marked as complete, 2,177 incomplete.
* *** A decision needs to be made about the incomplete responses - should they be included or not?  Perhaps just some of them?
    * *** AGREED approach
    * *** 1 (one) response that did not consent (and hence could not progress) - will be deleted
    * *** 3 (three) preview responses will also be deleted
    * *** 528 "spam" (as determined by Qualtrics) will also be deleted - Note that these at most had got only to question 1 YearsEmployed, so any actual dataloss is minimal.

* *** This syntax file will systematically check the data and cleanse and anonymise it
* *** See XXXXX for details

* *** In Summary this SPSS Syntax file is:
* *** To cleanse and anonymise the data ready for analyses

* *** new for SPSS v26 need to have this to show the syntax in the output window.
SET PRINTBACK=LISTING.

* Open the raw data.
* *** CHANGE THIS FILEPATH to that actual data for the real analyses.
CD 'C:\Users\srk\Dropbox\RAAAP-3 HIBARMA\HIBARMA\RAAAP-3 Analysis'.

* *** open the data file.
GET
  FILE='C:\Users\srk\Dropbox\RAAAP-3 HIBARMA\HIBARMA\RAAAP-3 Analysis\RAAAP-3 HIBARMA_May 18, '+
    '2022_06.26 encrypted.sav'
    PASSWORD='2R:B7J<K;v>{>r5z'.
DATASET NAME MainData3 WINDOW=FRONT.

DATASET ACTIVATE MainData3.

* *** Delete the non consenting response.
SELECT IF    (Consent_1 = 1).
EXECUTE.

* *** Delete the 3 preview responses and the 528 "spam", in effect just keep those listed as "IP Address" 0].
SELECT IF    (Status = 0).
EXECUTE.

* *** So now we have 5,076 responses.

* This section removes the unwanted variables - ie those that contain no data - they are either just question text or unretrieved data.
DELETE VARIABLES Status.
* DELETE VARIABLES Progress. ** for RAAAP-3 Data we keep this as we have retained some data from incomplete responses.
DELETE VARIABLES Duration__in_seconds_. 
DELETE VARIABLES Finished.
DELETE VARIABLES RecordedDate.


* ResponseId.
* This is the unique id for a response - no changes needed. - This variable does not relate the the variable of the same name in the RAAAP-1 or RAAAP-2 dataset.
* that is - there is no tracking between surveys.  So the same repondent would have a different ResponseId for RAAAP-1, RAAAP-2, and RAAAP-3.
* Similarly, in the unlikely case where a ResponseId is the same from RAAAP-1 to RAAAP-2 or RAAAP-3 it does not indicate that this is the same respondent.
DELETE VARIABLES DistributionChannel.

* Consent_1.
* Is the consent marker - not needed, as all consented (after we deleted the one that did not)
* Note that Consent_1. is the statement of consent - this is not retained as all respondents had to selected "Agree" in order to take the survey.
DELETE VARIABLES     Consent_1.

* UserLanguage - retain.  There are 5 languages (Note that French one was partial). English, Spanish, French, Chinese, and Portuguese were the languages.

VARIABLE LABELS StartDate "0. Start Date".
VARIABLE LABELS EndDate "0. End Date".
VARIABLE LABELS Responseid "0. Response Id".
VARIABLE LABELS UserLanguage "0. User Language".
VARIABLE LABELS Progress "0. Progress".

* YearsEmployed.
* Qualtrics codings already match RAAAP-1/2  *** HOWEVER there is more granularity... and we would need to create.
* *** YearsEmployedGrouped to exactly match the RAAAP-1/2 Data... AND/OR we could maybe use the even more granular data from RAAAP-1/2 to match the RAAAP-3 data!.
* *** in any case these should be ordinals.
MISSING VALUES YearsEmployed (-99).
VARIABLE LABELS YearsEmployed '1. Approx Years as a Research Administrator'.
VARIABLE LEVEL YearsEmployed(ORDINAL).
FORMATS YearsEmployed(f8.1).
ADD VALUE LABELS YearsEmployed -99 "No Response".
EXECUTE.

* *** created the 5 year banded YearsEmployedGrouped to match RAAAP-1/2.
RECODE YearsEmployed
    (0.0 = 0)
    (0.5, 1.0, 2.0, 3.0, 4.0 = 2)
    (5.0, 6.0, 7.0, 8.0, 9.0 = 7)
    (12.0 = 12)
    (17.0 = 17)
    (22.0 = 22)
    (27.0 = 27)
    (28.0 = 28)
    (32.0 = 32)
    (37.0 = 37)
    (40.0 = 40)
    (-99=SYSMIS)
    (ELSE=Copy)
INTO YearsEmployedGrouped.
FORMATS YearsEmployedGrouped(f8).
ADD VALUE LABELS YearsEmployedGrouped 0 "Never" 2 "<5" 7 "5-9" 12 "10-14" 17 "15-19" 22 "20-24" 27 "25-29" 28 ">=10 (China)" 32 "30-34" 37 "35-39" 40 ">=40" -99 "No Response".
VARIABLE LABELS YearsEmployedGrouped "1a. Approx Years (Banded) as a Research Administrator".
VARIABLE LEVEL YearsEmployedGrouped (ORDINAL).
MISSING VALUES YearsEmployedGrouped (-99).
EXECUTE.

* *** in RAAAP-3 we asked about First Role Level as well as Current Role Level in the same question, in RAAAP-2 FirstRoleLevel was Q16.
* *** FirstRoleLevel.
RENAME VARIABLES FirstAndCurrentRoleL_First = FirstRoleLevel.
MISSING VALUES FirstRoleLevel (-99).
VARIABLE LABELS FirstRoleLevel "2(R216)f. Define your first RA role".
ADD VALUE LABELS FirstRoleLevel -99 "No Response".
VARIABLE LEVEL FirstRoleLevel (NOMINAL). /* perhaps should be ORDINAL - but this matched CurrentRoleLevel in RAAAP-1/2.
EXECUTE.

* *** CurrentRoleLevelR3.
RENAME VARIABLES FirstAndCurrentRoleL_Current = CurrentRoleLevelR3. /* because in RAAAP-3 we also asked about First Role Level so the name from Qualtrics did not match RAAAP-1/2.
MISSING VALUES CurrentRoleLevelR3 (-99).
VARIABLE LABELS CurrentRoleLevelR3 "2R3. Define your current RA role extended".
ADD VALUE LABELS CurrentRoleLevelR3 -99 "No Response".
VARIABLE LEVEL CurrentRoleLevelR3 (NOMINAL). /* perhaps should be ORDINAL - but this matched RAAAP-1/2.
EXECUTE.

* *** and here we need to add in the back coding, so that CurrentRoleLevel is correctly computed afterwards.
* *** backcoding from CurrentRoleLevelDetails -> CurrentRoleLevelR3 - MD. **** TO CHECK ***.
IF (ResponseId="R_2S6u2i8AFVXQt0I") CurrentRoleLevelR3=3.
IF (ResponseId="R_3QLRdiFD5ce3hp2") CurrentRoleLevelR3=2.
IF (ResponseId="R_3p9HmDdYWIhU5Sd") CurrentRoleLevelR3=2.
IF (ResponseId="R_2b0FovA5slJZHip") CurrentRoleLevelR3=2.
IF (ResponseId="R_27g9CcEX32aYP1e") CurrentRoleLevelR3=3.
IF (ResponseId="R_C4AtDLsuhlEG2zv") CurrentRoleLevelR3=1.
IF (ResponseId="R_1k0NfstcLl36mo4") CurrentRoleLevelR3=2.
IF (ResponseId="R_D30mtuevPAysInL") CurrentRoleLevelR3=2.
IF (ResponseId="R_2uR4jydtSYrh3yX") CurrentRoleLevelR3=3.
IF (ResponseId="R_yKP3Hz8L9s3PN7z") CurrentRoleLevelR3=1.
IF (ResponseId="R_2PuRzKvRpa5ABTg") CurrentRoleLevelR3=2.
IF (ResponseId="R_rkCTsKPT0dCuk3n") CurrentRoleLevelR3=2.
IF (ResponseId="R_ah3srgKl4RhZCwh") CurrentRoleLevelR3=3.
IF (ResponseId="R_28P5zeoC0gjDXEz") CurrentRoleLevelR3=2.
IF (ResponseId="R_3GeabuOZKRLWctX") CurrentRoleLevelR3=1.
IF (ResponseId="R_2ZDpveJgnEKpf3i") CurrentRoleLevelR3=2.
IF (ResponseId="R_3e4cQClU1aCXIPt") CurrentRoleLevelR3=1.
IF (ResponseId="R_OpvtmCaaxeiltgB") CurrentRoleLevelR3=1.
IF (ResponseId="R_2anKY1A9dCleuIq") CurrentRoleLevelR3=3.
IF (ResponseId="R_XCam2lxqXIKwybv") CurrentRoleLevelR3=2.
IF (ResponseId="R_1LCh3EbQ2doOxjs") CurrentRoleLevelR3=3.
IF (ResponseId="R_3jYTryWR9JkGLQW") CurrentRoleLevelR3=1.
IF (ResponseId="R_1Ijfjq6CYBwXOl7") CurrentRoleLevelR3=1.
IF (ResponseId="R_2w0Q9QtWwwiRkOd") CurrentRoleLevelR3=3.
IF (ResponseId="R_Wds8fEcKVh8Vf9L") CurrentRoleLevelR3=3.
IF (ResponseId="R_1PcqOTv8IOyrV64") CurrentRoleLevelR3=3.
IF (ResponseId="R_1llz9vuusTFc7xn") CurrentRoleLevelR3=3.
IF (ResponseId="R_3gYPnP1GcPHlVBw") CurrentRoleLevelR3=3.
IF (ResponseId="R_25QNmshvWmX0kMB") CurrentRoleLevelR3=2.
IF (ResponseId="R_3O2jSdrxjC3POMi") CurrentRoleLevelR3=3.
IF (ResponseId="R_2z75HDt7hxbaw7K") CurrentRoleLevelR3=1.
IF (ResponseId="R_3rHCznLAmdtINNA") CurrentRoleLevelR3=3.
IF (ResponseId="R_263zbwxFEOIKa1V") CurrentRoleLevelR3=1.
IF (ResponseId="R_1pxkBduauyiEJFq") CurrentRoleLevelR3=3.
IF (ResponseId="R_3dRZOO3DG0Jt5Z1") CurrentRoleLevelR3=4.
IF (ResponseId="R_2tKdV9KrCjm7lNs") CurrentRoleLevelR3=2.
IF (ResponseId="R_1BYua97H96X3Pk3") CurrentRoleLevelR3=3.
IF (ResponseId="R_C77yYb41UXEwNW1") CurrentRoleLevelR3=3.
IF (ResponseId="R_2CwVGF06BlkRvYA") CurrentRoleLevelR3=1.
IF (ResponseId="R_3EtkhxHDmmmc14c") CurrentRoleLevelR3=2.
IF (ResponseId="R_22LdLNAv2S53LTZ") CurrentRoleLevelR3=3.
IF (ResponseId="R_3PYPtjBfJbSgvhQ") CurrentRoleLevelR3=1.
IF (ResponseId="R_d4fs0bFfXXtJ6tb") CurrentRoleLevelR3=3.
IF (ResponseId="R_1MYSAUCsfSS1n3Z") CurrentRoleLevelR3=2.
IF (ResponseId="R_3F3cYDpJBIAeJ7k") CurrentRoleLevelR3=2.
IF (ResponseId="R_1BYl2J6I226fZde") CurrentRoleLevelR3=3.
IF (ResponseId="R_3j3bsevBT04VYHB") CurrentRoleLevelR3=4.
IF (ResponseId="R_a33zxb8gqO0ZB29") CurrentRoleLevelR3=3.
IF (ResponseId="R_3hthFRgsvCZD8Sg") CurrentRoleLevelR3=2.
IF (ResponseId="R_2CIm9hxkFikvd2m") CurrentRoleLevelR3=1.
IF (ResponseId="R_3iCmKeb1b94BJO6") CurrentRoleLevelR3=2.
IF (ResponseId="R_27QBdgT49HN0sjR") CurrentRoleLevelR3=2.
IF (ResponseId="R_oXHqWi7nV3KZICR") CurrentRoleLevelR3=2.
IF (ResponseId="R_3GpTrNGAo3J4OLE") CurrentRoleLevelR3=3.
IF (ResponseId="R_1ewuX7VyCblwxBI") CurrentRoleLevelR3=3.
IF (ResponseId="R_2yjciEFYIuHjlAC") CurrentRoleLevelR3=3.
IF (ResponseId="R_1QGw9hB3FSnoNSH") CurrentRoleLevelR3=1.
IF (ResponseId="R_27HZ60nT80ayCDt") CurrentRoleLevelR3=3.
IF (ResponseId="R_2xYtxZZp3oVr7d5") CurrentRoleLevelR3=3.
IF (ResponseId="R_1Sbze3aJDnoMXBL") CurrentRoleLevelR3=1.
IF (ResponseId="R_3FWdYOvvXV5eWc4") CurrentRoleLevelR3=4.
IF (ResponseId="R_xcnODB1iMt3rYMF") CurrentRoleLevelR3=2.
IF (ResponseId="R_12A63h4w7epyX84") CurrentRoleLevelR3=2.
IF (ResponseId="R_3dSq9RmeZWzBYNU") CurrentRoleLevelR3=1.
IF (ResponseId="R_WwZiDAEZe4GrjZn") CurrentRoleLevelR3=2.
IF (ResponseId="R_21zZ4qC1DV5Bzye") CurrentRoleLevelR3=3.
IF (ResponseId="R_3n5Uys0A30ttG0p") CurrentRoleLevelR3=1.
IF (ResponseId="R_1gCrI58a9Ogn1Be") CurrentRoleLevelR3=1.
IF (ResponseId="R_2wAABRcId8iWvqx") CurrentRoleLevelR3=3.
IF (ResponseId="R_3HtstTEgJAQKqGA") CurrentRoleLevelR3=1.
IF (ResponseId="R_3Hp13RIVqIIJLmC") CurrentRoleLevelR3=3.
IF (ResponseId="R_2SBpO2uGZTqcuVf") CurrentRoleLevelR3=2.
IF (ResponseId="R_2Yh2S9HEAIWzDXM") CurrentRoleLevelR3=1.
IF (ResponseId="R_20Ms8lkvsXpylXP") CurrentRoleLevelR3=1.
IF (ResponseId="R_2PhB1m4RcOw1DrY") CurrentRoleLevelR3=1.
IF (ResponseId="R_3Kp9A4bV4RSZcll") CurrentRoleLevelR3=1.
IF (ResponseId="R_pghFx2PJAYFve2B") CurrentRoleLevelR3=2.
IF (ResponseId="R_1QsbWag6k5q3xss") CurrentRoleLevelR3=2.
IF (ResponseId="R_3oMEG7e9Htlgk6R") CurrentRoleLevelR3=2.
IF (ResponseId="R_xrZzQyvX7H25Sw1") CurrentRoleLevelR3=2.
IF (ResponseId="R_1kGEeZeXEVCLVez") CurrentRoleLevelR3=3.
IF (ResponseId="R_2cuVx71RAETTNVq") CurrentRoleLevelR3=3.
IF (ResponseId="R_41ssSbaZavylRJv") CurrentRoleLevelR3=2.
IF (ResponseId="R_soQMjSUfIoUmziV") CurrentRoleLevelR3=3.
IF (ResponseId="R_1rJmXBDrLe9cqMA") CurrentRoleLevelR3=2.
IF (ResponseId="R_rfJWhO0kZCjkbSx") CurrentRoleLevelR3=3.
IF (ResponseId="R_2DTWhRItDmrFZTG") CurrentRoleLevelR3=3.
IF (ResponseId="R_e2QBxBmOTKhrKiB") CurrentRoleLevelR3=1.
IF (ResponseId="R_voSw84irNP4aL5L") CurrentRoleLevelR3=1.
IF (ResponseId="R_1QopVY5Iuk6gLPV") CurrentRoleLevelR3=9.
IF (ResponseId="R_1oj0zhiThUvA6i1") CurrentRoleLevelR3=1.
IF (ResponseId="R_6SiG3rbgrq8J7QR") CurrentRoleLevelR3=1.
IF (ResponseId="R_PNW4uKbHq36T5Wp") CurrentRoleLevelR3=3.
IF (ResponseId="R_2rpS09awfSqqyj7") CurrentRoleLevelR3=3.
IF (ResponseId="R_ZKJflKzKZG0T44x") CurrentRoleLevelR3=1.
IF (ResponseId="R_2rj8ldrauMQu8mg") CurrentRoleLevelR3=1.
IF (ResponseId="R_1LAnfgk8gNavoE6") CurrentRoleLevelR3=1.
IF (ResponseId="R_3oQSXwx32X0aOSw") CurrentRoleLevelR3=2.
IF (ResponseId="R_2CfDUrbbqfSvQw2") CurrentRoleLevelR3=2.
IF (ResponseId="R_3J4Ocq8jGIcQcBP") CurrentRoleLevelR3=1.
IF (ResponseId="R_3M9xi401ZhGbeii") CurrentRoleLevelR3=1.
IF (ResponseId="R_2bVlHQLn5x6rptB") CurrentRoleLevelR3=4.
IF (ResponseId="R_3qDlUdDlW2M9Za8") CurrentRoleLevelR3=2.
IF (ResponseId="R_32WSgtdowXcbycT") CurrentRoleLevelR3=1.
IF (ResponseId="R_2S02qa5lIcYmgEP") CurrentRoleLevelR3=1.
IF (ResponseId="R_3FPRP0cJZkN7Atq") CurrentRoleLevelR3=2.
IF (ResponseId="R_RVLGMZhX2A4S0yB") CurrentRoleLevelR3=3.
IF (ResponseId="R_vSUpUBcSR658bnz") CurrentRoleLevelR3=3.
IF (ResponseId="R_tLIFes3rdw1gGel") CurrentRoleLevelR3=1.
IF (ResponseId="R_1Fwu9PMbwqC4ySv") CurrentRoleLevelR3=3.
IF (ResponseId="R_33rGKffN1fnnpHE") CurrentRoleLevelR3=1.
IF (ResponseId="R_10ufhpEKdm9YXGB") CurrentRoleLevelR3=1.
IF (ResponseId="R_30ovYDAQVLneC2X") CurrentRoleLevelR3=3.
IF (ResponseId="R_3O33wx9HHJR8QaS") CurrentRoleLevelR3=1.
IF (ResponseId="R_1kXEQ6YerEhpt6y") CurrentRoleLevelR3=1.
IF (ResponseId="R_r6LPvk4B1eoH98R") CurrentRoleLevelR3=2.
IF (ResponseId="R_2Se7cNW8QP9c5mA") CurrentRoleLevelR3=9.
IF (ResponseId="R_2Bxm2BKXPVFpYax") CurrentRoleLevelR3=2.
IF (ResponseId="R_2uP5ESbTvaGlC2v") CurrentRoleLevelR3=3.
IF (ResponseId="R_2uVwahxlpUgkfPT") CurrentRoleLevelR3=3.
IF (ResponseId="R_2EglAdI1pmP86Vz") CurrentRoleLevelR3=3.
IF (ResponseId="R_2b3jR1FBRQepHay") CurrentRoleLevelR3=1.
IF (ResponseId="R_5cGLLSpmeTevd2V") CurrentRoleLevelR3=2.
IF (ResponseId="R_2pK3jEQ51Tgsbma") CurrentRoleLevelR3=3.
IF (ResponseId="R_RVpNKskjLCD58PL") CurrentRoleLevelR3=1.
IF (ResponseId="R_1oiOLa3oTzK0Drj") CurrentRoleLevelR3=3.
IF (ResponseId="R_2YmELMKI0MriITl") CurrentRoleLevelR3=2.
IF (ResponseId="R_27VbtFWMHVxwgQ2") CurrentRoleLevelR3=4.
IF (ResponseId="R_doH6YjwXjSVbJRL") CurrentRoleLevelR3=9.
IF (ResponseId="R_1doin7WMoB7t98G") CurrentRoleLevelR3=2.
IF (ResponseId="R_2zzK85dNlYOI9JR") CurrentRoleLevelR3=2.
IF (ResponseId="R_1gtlID2BTPCZ4b4") CurrentRoleLevelR3=1.
IF (ResponseId="R_eRwd1N34foTlzP3") CurrentRoleLevelR3=3.
IF (ResponseId="R_tSTwmScHgvo2V69") CurrentRoleLevelR3=3.
IF (ResponseId="R_3nc7O837Zf7TXlx") CurrentRoleLevelR3=2.
IF (ResponseId="R_3JdOPoANtlA9jkR") CurrentRoleLevelR3=3.
IF (ResponseId="R_3EG60OQ0joq7YAt") CurrentRoleLevelR3=2.
IF (ResponseId="R_3kvogHuIGT3t1ko") CurrentRoleLevelR3=3.
IF (ResponseId="R_p4cl4GFpzOUkOs1") CurrentRoleLevelR3=1.
IF (ResponseId="R_4HK1ZuF3v4ec9kR") CurrentRoleLevelR3=1.
IF (ResponseId="R_3O2oZ32UKQSSGLX") CurrentRoleLevelR3=3.
IF (ResponseId="R_2QLIAnZ5yA4R212") CurrentRoleLevelR3=4.
IF (ResponseId="R_3nk3gO9cpww5k8F") CurrentRoleLevelR3=1.
IF (ResponseId="R_1mzorHpn32dB5eE") CurrentRoleLevelR3=3.
IF (ResponseId="R_1dsMiOsF4jWamsP") CurrentRoleLevelR3=3.
IF (ResponseId="R_1mFxj6qAch2WuA0") CurrentRoleLevelR3=3.
IF (ResponseId="R_3JyH0aNGiQHkWnV") CurrentRoleLevelR3=1.
IF (ResponseId="R_ALnIIbAqWHChnJT") CurrentRoleLevelR3=3.
IF (ResponseId="R_8euIwnjGcyp96GB") CurrentRoleLevelR3=4.
IF (ResponseId="R_2QK9pvwf9RaFrTy") CurrentRoleLevelR3=3.
IF (ResponseId="R_1FRfZObpeZRC69L") CurrentRoleLevelR3=2.
IF (ResponseId="R_2B8rPwGV16NTYpY") CurrentRoleLevelR3=3.
IF (ResponseId="R_2AKyTzVDYG7tiII") CurrentRoleLevelR3=1.
IF (ResponseId="R_2SrwGNygBfnwoUc") CurrentRoleLevelR3=3.
IF (ResponseId="R_1dvtALjUvwt2COA") CurrentRoleLevelR3=9.
IF (ResponseId="R_31GGBQUbOqmXEH6") CurrentRoleLevelR3=3.
IF (ResponseId="R_1cTjMZZ1sgz7ub0") CurrentRoleLevelR3=3.
IF (ResponseId="R_2DZexN8TvNvD76W") CurrentRoleLevelR3=2.
IF (ResponseId="R_RzCZO5qHW13Fx4J") CurrentRoleLevelR3=2.
IF (ResponseId="R_2YgZzXWW9qTmccl") CurrentRoleLevelR3=1.
IF (ResponseId="R_2uHEp1xP3YHqEWV") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_7aLBTwt7m8bMmJ3") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_6qULFEYneEE6bF7") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1dMETYhndbSQTuJ") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2xPDIkYpk1xXxPM") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3rVzCPENCdVMILR") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_22xZop7kYc5BCln") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3kH5stvLcVrUlb6") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_9Y9mifM4Qa2m4lr") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_pJJmbgjAoJJnprb") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3EMzleWVMTrCLfN") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3g1OvUCvnGbGXOC") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3L78kHvhdoqxy6c") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2qmlwzXMSCuKi5d") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3D1I9XxsQ0u7JLu") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2Se5HKlZ6bXsNQx") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2f9tYVABsHIbLmz") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3iCQbLACysURDO2") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3Oi7fOZF83D3Aad") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3KYYMIIlEkI1YFl") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2c8FGKQkTlMqZh7") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1NDlkL8jUmUkrwN") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2q2VANlBknxfKWP") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1DBi7oPkmAFIjmt") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_10MbN2vezwwUfJC") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_RfD7ZTonC0On8Nb") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1lAiRqp1Y0vCy5g") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1dFtonqBzFGDU3C") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_37MniwNWhi8FvnH") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_u8hSu2LYU0zWH1D") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_bC1n5E0YcgELbSF") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2v5Iba9IWowpAKC") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_23aBnzBSVSNDxyn") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_exjdKts3aPmAyNH") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2wb3DfMf0ODw9tz") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_8dJX4lqQDB1ExFf") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1od5gkOdq6XIXGj") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_pxSB4whKd01xJPr") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1ODK8yo4TlG7xDg") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_pxQPumBJiE8BThv") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_6m7ZCoLYWEp0blv") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3GcRDfuSWK76ZGI") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2rGUOh83XFs4O1H") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3fHr0yLa4Lzr2Zm") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2zYAegpEF1hj8T0") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1FS0MxTV17guDyN") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_2P7pUY4x51tWoWm") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3fBrfJ4uyfeUWxh") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3lQYcaB5EvujRpm") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3r2nJz2rum29T3O") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3Jsf8NE7mvZ2e6v") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_32Ld70W5i3w8Z30") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_VWPSKBOqk9JFWBH") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_24O8rlFKOjLJlTa") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1oeaBqIJrVBsB62") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_24eECozlkbOX7WY") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1LC0LjQJZVBIzbu") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_1JXzQrHDuvc47zD") CurrentRoleLevelR3=FirstRoleLevel.
IF (ResponseId="R_3CKoccZV04rYgrW") CurrentRoleLevelR3=FirstRoleLevel.
EXECUTE.

* *** CurrentRoleLevel. 
* *** NOTE that in RAAAP-3 we allowed "Assisting" for CurrentRoleLevel.. and so for backwards compatability we combine operational and assisting into operational.
RECODE CurrentRoleLevelR3
    (1 = 1)
    (2 = 2)
    (3,4 = 3)
    (9 = 9)
    (-99=SYSMIS)
    (ELSE=Copy)
INTO CurrentRoleLevel.
FORMATS CurrentRoleLevel(f8).
ADD VALUE LABELS CurrentRoleLevel 1 "Leader" 2 "Manager" 3 "Operational" 9 "Other" -99 "No Response".
VARIABLE LABELS CurrentRoleLevel "2. Define your current RA role".
VARIABLE LEVEL CurrentRoleLevel (NOMINAL).
MISSING VALUES CurrentRoleLevel (-99).
EXECUTE.

* FirstRoleLevelDet. This is not new for RAAAP-3, but in RAAAP-2 it was Q16,.
RENAME VARIABLES FirstRoleLevelDet=FirstRoleLevelDetails.
VARIABLE LABELS FirstRoleLevelDetails "2fd. Details of first RA role".
MISSING VALUES FirstRoleLevelDetails ("").
VALUE LABELS FirstRoleLevelDetails "" "No Response".
EXECUTE.
* *** >1,000 responses - should cross check with CurrentRoleLevel/FirstRoleLevel to ensure consistency?.
* *** 94 CurrentRoleLevels had "Other", of these 71 gave some text -could be worth looking at these to see if backcoding is possible.
* *** Note that no missing responses to Level gave details - so no possibility to recode for those.

* *** backcoding from FirstRoleLevelDetails -> FirstRoleLevel - MD. **** TO CHECK ***.
IF (ResponseId="R_3QLRdiFD5ce3hp2") FirstRoleLevel=3.
IF (ResponseId="R_O6F21eHhkWL2Uil") FirstRoleLevel=3.
IF (ResponseId="R_7aLBTwt7m8bMmJ3") FirstRoleLevel=3.
IF (ResponseId="R_2QmJYirdD1hdVi2") FirstRoleLevel=2.
IF (ResponseId="R_C4AtDLsuhlEG2zv") FirstRoleLevel=1.
IF (ResponseId="R_1k0NfstcLl36mo4") FirstRoleLevel=9.
IF (ResponseId="R_31Kj0G27irK3W9w") FirstRoleLevel=1.
IF (ResponseId="R_20UVbiYPR51GzTi") FirstRoleLevel=3.
IF (ResponseId="R_Y5IOdkRQPQ3Y1wt") FirstRoleLevel=3.
IF (ResponseId="R_3PpJZnB9hjFuu1q") FirstRoleLevel=1.
IF (ResponseId="R_2xPDIkYpk1xXxPM") FirstRoleLevel=1.
IF (ResponseId="R_vMM7kERlfufJqZX") FirstRoleLevel=2.
IF (ResponseId="R_1GxGrohAhDxixDr") FirstRoleLevel=3.
IF (ResponseId="R_1q24IVMwGOfpFpW") FirstRoleLevel=3.
IF (ResponseId="R_W7Lqt7k1h6dhR9D") FirstRoleLevel=3.
IF (ResponseId="R_wZ7umEFrgKF809P") FirstRoleLevel=3.
IF (ResponseId="R_1nVn0QxmCyZD9UH") FirstRoleLevel=9.
IF (ResponseId="R_3e4cQClU1aCXIPt") FirstRoleLevel=3.
IF (ResponseId="R_vCbHrEJKxRsLRnz") FirstRoleLevel=4.
IF (ResponseId="R_pJJmbgjAoJJnprb") FirstRoleLevel=3.
IF (ResponseId="R_OpvtmCaaxeiltgB") FirstRoleLevel=4.
IF (ResponseId="R_3mkptFxSt38AUaY") FirstRoleLevel=4.
IF (ResponseId="R_pDTFVv8uW2FG9bz") FirstRoleLevel=3.
IF (ResponseId="R_1okbnqSE5JbDlxr") FirstRoleLevel=3.
IF (ResponseId="R_2fARTLTEkxjs4QW") FirstRoleLevel=2.
IF (ResponseId="R_2CfRaQfZFWRFv7y") FirstRoleLevel=2.
IF (ResponseId="R_VVa2YQQjZvYdKuZ") FirstRoleLevel=4.
IF (ResponseId="R_XCam2lxqXIKwybv") FirstRoleLevel=3.
IF (ResponseId="R_1kXliHVGWNYAIKJ") FirstRoleLevel=9.
IF (ResponseId="R_30ugLQzRIp30YBV") FirstRoleLevel=3.
IF (ResponseId="R_1Ijfjq6CYBwXOl7") FirstRoleLevel=9.
IF (ResponseId="R_3G0p0HjNduHmSLP") FirstRoleLevel=3.
IF (ResponseId="R_31opFOfS2Vj6GQn") FirstRoleLevel=1.
IF (ResponseId="R_1PcqOTv8IOyrV64") FirstRoleLevel=3.
IF (ResponseId="R_10q0ajNQPd5nQII") FirstRoleLevel=3.
IF (ResponseId="R_uh2Kn1WtoHbLq6Z") FirstRoleLevel=4.
IF (ResponseId="R_1242u9ffz8z4Ven") FirstRoleLevel=2.
IF (ResponseId="R_3ptosj7zagNJmNn") FirstRoleLevel=3.
IF (ResponseId="R_qUBTumtu8k3TXPP") FirstRoleLevel=3.
IF (ResponseId="R_3gYPnP1GcPHlVBw") FirstRoleLevel=3.
IF (ResponseId="R_25QNmshvWmX0kMB") FirstRoleLevel=9.
IF (ResponseId="R_cZtud1WOYMKjlQZ") FirstRoleLevel=9.
IF (ResponseId="R_sulPsQzji7pBtHb") FirstRoleLevel=2.
IF (ResponseId="R_3rHCznLAmdtINNA") FirstRoleLevel=3.
IF (ResponseId="R_263zbwxFEOIKa1V") FirstRoleLevel=3.
IF (ResponseId="R_3KBlXf1pDysQbqz") FirstRoleLevel=9.
IF (ResponseId="R_3dRZOO3DG0Jt5Z1") FirstRoleLevel=2.
IF (ResponseId="R_1riFnY269ovi1gu") FirstRoleLevel=3.
IF (ResponseId="R_2tKdV9KrCjm7lNs") FirstRoleLevel=3.
IF (ResponseId="R_zT2eNBT6YR3Iuw9") FirstRoleLevel=3.
IF (ResponseId="R_3R3Z0iphXeHKg85") FirstRoleLevel=3.
IF (ResponseId="R_D66c81EeN69XZ5f") FirstRoleLevel=9.
IF (ResponseId="R_10GItYjdO8Ruu10") FirstRoleLevel=3.
IF (ResponseId="R_3D1I9XxsQ0u7JLu") FirstRoleLevel=3.
IF (ResponseId="R_2Se5HKlZ6bXsNQx") FirstRoleLevel=3.
IF (ResponseId="R_2xVPoQVzGJKJyLi") FirstRoleLevel=3.
IF (ResponseId="R_1GDETSQJrt3Q29j") FirstRoleLevel=9.
IF (ResponseId="R_22RI1ta8YJoJ4ZH") FirstRoleLevel=4.
IF (ResponseId="R_3F3cYDpJBIAeJ7k") FirstRoleLevel=2.
IF (ResponseId="R_3j3bsevBT04VYHB") FirstRoleLevel=4.
IF (ResponseId="R_2dmckexWA9ZuCEu") FirstRoleLevel=9.
IF (ResponseId="R_3iCmKeb1b94BJO6") FirstRoleLevel=3.
IF (ResponseId="R_1NDlkL8jUmUkrwN") FirstRoleLevel=4.
IF (ResponseId="R_oXHqWi7nV3KZICR") FirstRoleLevel=4.
IF (ResponseId="R_1jAENrpiFgBRvMi") FirstRoleLevel=3.
IF (ResponseId="R_3EQYk10uOO6BPln") FirstRoleLevel=4.
IF (ResponseId="R_1ewuX7VyCblwxBI") FirstRoleLevel=3.
IF (ResponseId="R_2q2VANlBknxfKWP") FirstRoleLevel=4.
IF (ResponseId="R_12Pw3jJiN9Qeccu") FirstRoleLevel=2.
IF (ResponseId="R_Wvq1MReCP24u6Y1") FirstRoleLevel=2.
IF (ResponseId="R_O2yjCJOBC0l9ncB") FirstRoleLevel=3.
IF (ResponseId="R_1QGw9hB3FSnoNSH") FirstRoleLevel=4.
IF (ResponseId="R_1IAFJYc1Kg6l7rr") FirstRoleLevel=4.
IF (ResponseId="R_1rvmroBhdIZU74K") FirstRoleLevel=3.
IF (ResponseId="R_3RrNZgDbPWkgd8x") FirstRoleLevel=4.
IF (ResponseId="R_1FyXEWie3tisXln") FirstRoleLevel=9.
IF (ResponseId="R_10MbN2vezwwUfJC") FirstRoleLevel=4.
IF (ResponseId="R_1Sbze3aJDnoMXBL") FirstRoleLevel=4.
IF (ResponseId="R_bpE3dpg5d71L7R7") FirstRoleLevel=4.
IF (ResponseId="R_1E3XSookHdo4bz9") FirstRoleLevel=2.
IF (ResponseId="R_12A63h4w7epyX84") FirstRoleLevel=4.
IF (ResponseId="R_3dSq9RmeZWzBYNU") FirstRoleLevel=3.
IF (ResponseId="R_2YA33rlbf14GLRx") FirstRoleLevel=4.
IF (ResponseId="R_2CjL36XMuqFlYHV") FirstRoleLevel=3.
IF (ResponseId="R_11hbMxg2htTYHqM") FirstRoleLevel=3.
IF (ResponseId="R_30vrQBcc4JUkTCp") FirstRoleLevel=3.
IF (ResponseId="R_2wAABRcId8iWvqx") FirstRoleLevel=3.
IF (ResponseId="R_1NChrXKZ8BR3vku") FirstRoleLevel=3.
IF (ResponseId="R_cRYDiBF5b0lGHiF") FirstRoleLevel=3.
IF (ResponseId="R_3EuHdBgKOlgfloL") FirstRoleLevel=4.
IF (ResponseId="R_3lVSOfiAxQ5XztL") FirstRoleLevel=9.
IF (ResponseId="R_33C31RQ3ntmZTZi") FirstRoleLevel=4.
IF (ResponseId="R_AtdVRAD7BdtiA25") FirstRoleLevel=3.
IF (ResponseId="R_RwBuZxLt8U8DeLf") FirstRoleLevel=9.
IF (ResponseId="R_216ZT74s6CsCLq0") FirstRoleLevel=9.
IF (ResponseId="R_20Ms8lkvsXpylXP") FirstRoleLevel=9.
IF (ResponseId="R_3phS4xmzNaxZsod") FirstRoleLevel=3.
IF (ResponseId="R_cvaIOcmlQNn2D0l") FirstRoleLevel=3.
IF (ResponseId="R_3Kp9A4bV4RSZcll") FirstRoleLevel=2.
IF (ResponseId="R_QnLT4RVVhYUs3iF") FirstRoleLevel=2.
IF (ResponseId="R_2CH8MUawoezxvXy") FirstRoleLevel=4.
IF (ResponseId="R_41ssSbaZavylRJv") FirstRoleLevel=3.
IF (ResponseId="R_e2QBxBmOTKhrKiB") FirstRoleLevel=3.
IF (ResponseId="R_XoeES5Lz2HRTKLv") FirstRoleLevel=2.
IF (ResponseId="R_25F5zLXXxnOtaV0") FirstRoleLevel=2.
IF (ResponseId="R_1oj0zhiThUvA6i1") FirstRoleLevel=4.
IF (ResponseId="R_3O33fV1HjZKRHJf") FirstRoleLevel=9.
IF (ResponseId="R_ZKJflKzKZG0T44x") FirstRoleLevel=2.
IF (ResponseId="R_2zwN977t3aMC0Sd") FirstRoleLevel=3.
IF (ResponseId="R_2rj8ldrauMQu8mg") FirstRoleLevel=2.
IF (ResponseId="R_1LAnfgk8gNavoE6") FirstRoleLevel=2.
IF (ResponseId="R_3iKZ28MbWHjpiNS") FirstRoleLevel=4.
IF (ResponseId="R_3oQSXwx32X0aOSw") FirstRoleLevel=2.
IF (ResponseId="R_ddpN1F5ocM1Atxf") FirstRoleLevel=4.
IF (ResponseId="R_Q4cWFfmRzScWZ8t") FirstRoleLevel=3.
IF (ResponseId="R_6m7ZCoLYWEp0blv") FirstRoleLevel=4.
IF (ResponseId="R_3J4Ocq8jGIcQcBP") FirstRoleLevel=4.
IF (ResponseId="R_3GcRDfuSWK76ZGI") FirstRoleLevel=3.
IF (ResponseId="R_2rGUOh83XFs4O1H") FirstRoleLevel=3.
IF (ResponseId="R_VIoqmzMr3Rv1cIh") FirstRoleLevel=3.
IF (ResponseId="R_3qDlUdDlW2M9Za8") FirstRoleLevel=1.
IF (ResponseId="R_vVIpFmPBu1PiPh7") FirstRoleLevel=4.
IF (ResponseId="R_2S02qa5lIcYmgEP") FirstRoleLevel=1.
IF (ResponseId="R_1kUeptyDkVNfHPs") FirstRoleLevel=3.
IF (ResponseId="R_ZL7W18wTaNOZTmV") FirstRoleLevel=4.
IF (ResponseId="R_vSUpUBcSR658bnz") FirstRoleLevel=3.
IF (ResponseId="R_2zSZqYsF9O5qFa2") FirstRoleLevel=4.
IF (ResponseId="R_3hs608KMrrMKCCJ") FirstRoleLevel=9.
IF (ResponseId="R_tLIFes3rdw1gGel") FirstRoleLevel=4.
IF (ResponseId="R_1FJJMwUcr5jqE0Y") FirstRoleLevel=2.
IF (ResponseId="R_33rGKffN1fnnpHE") FirstRoleLevel=2.
IF (ResponseId="R_2aQ5YCASVXk1lEM") FirstRoleLevel=3.
IF (ResponseId="R_30ovYDAQVLneC2X") FirstRoleLevel=3.
IF (ResponseId="R_3O33wx9HHJR8QaS") FirstRoleLevel=2.
IF (ResponseId="R_1kXEQ6YerEhpt6y") FirstRoleLevel=2.
IF (ResponseId="R_cI4DtszRbjYx5jH") FirstRoleLevel=4.
IF (ResponseId="R_2pJGdvK3bbDil9H") FirstRoleLevel=4.
IF (ResponseId="R_2Se7cNW8QP9c5mA") FirstRoleLevel=1.
IF (ResponseId="R_2PBEXsUtmIlp8wy") FirstRoleLevel=2.
IF (ResponseId="R_3hGdFb45YpJwmqS") FirstRoleLevel=9.
IF (ResponseId="R_2uP5ESbTvaGlC2v") FirstRoleLevel=4.
IF (ResponseId="R_094o1d3jDFerpER") FirstRoleLevel=4.
IF (ResponseId="R_1BQkQ8HgSjsszc1") FirstRoleLevel=4.
IF (ResponseId="R_1LbS33yRGVdDScZ") FirstRoleLevel=4.
IF (ResponseId="R_5cGLLSpmeTevd2V") FirstRoleLevel=9.
IF (ResponseId="R_3hbDWYTuJYjDP2T") FirstRoleLevel=3.
IF (ResponseId="R_2pK3jEQ51Tgsbma") FirstRoleLevel=4.
IF (ResponseId="R_RVpNKskjLCD58PL") FirstRoleLevel=3.
IF (ResponseId="R_3p0fSiZVGh6ME2B") FirstRoleLevel=3.
IF (ResponseId="R_1oiOLa3oTzK0Drj") FirstRoleLevel=4.
IF (ResponseId="R_00uMLrzodaYIYSd") FirstRoleLevel=1.
IF (ResponseId="R_VWPSKBOqk9JFWBH") FirstRoleLevel=2.
IF (ResponseId="R_2YmELMKI0MriITl") FirstRoleLevel=9.
IF (ResponseId="R_27VbtFWMHVxwgQ2") FirstRoleLevel=4.
IF (ResponseId="R_doH6YjwXjSVbJRL") FirstRoleLevel=9.
IF (ResponseId="R_32XUD8rstuOKBZ8") FirstRoleLevel=2.
IF (ResponseId="R_2zzK85dNlYOI9JR") FirstRoleLevel=3.
IF (ResponseId="R_1igkUHIn5CNXpyJ") FirstRoleLevel=3.
IF (ResponseId="R_3dFlaYeWLef5SXQ") FirstRoleLevel=3.
IF (ResponseId="R_2YttDtML7wMR7Px") FirstRoleLevel=2.
IF (ResponseId="R_1gtlID2BTPCZ4b4") FirstRoleLevel=1.
IF (ResponseId="R_eRwd1N34foTlzP3") FirstRoleLevel=4.
IF (ResponseId="R_3hhAQQwIPn4dUG8") FirstRoleLevel=3.
IF (ResponseId="R_3nc7O837Zf7TXlx") FirstRoleLevel=4.
IF (ResponseId="R_3EG60OQ0joq7YAt") FirstRoleLevel=3.
IF (ResponseId="R_p4cl4GFpzOUkOs1") FirstRoleLevel=2.
IF (ResponseId="R_3O2oZ32UKQSSGLX") FirstRoleLevel=3.
IF (ResponseId="R_3EXp3KpPUDwMa6E") FirstRoleLevel=9.
IF (ResponseId="R_1oeaBqIJrVBsB62") FirstRoleLevel=3.
IF (ResponseId="R_1dsMiOsF4jWamsP") FirstRoleLevel=4.
IF (ResponseId="R_3JyH0aNGiQHkWnV") FirstRoleLevel=3.
IF (ResponseId="R_3pms37v9J3jA3dW") FirstRoleLevel=9.
IF (ResponseId="R_qDQKG4goXHDbJu1") FirstRoleLevel=1.
IF (ResponseId="R_2EGZQZvwbQRm40u") FirstRoleLevel=9.
IF (ResponseId="R_wReflsFjWw6ED2V") FirstRoleLevel=3.
IF (ResponseId="R_8euIwnjGcyp96GB") FirstRoleLevel=3.
IF (ResponseId="R_rqLofWAGJNffIlj") FirstRoleLevel=3.
IF (ResponseId="R_1FRfZObpeZRC69L") FirstRoleLevel=3.
IF (ResponseId="R_sj4X1yKadHXjAg9") FirstRoleLevel=3.
IF (ResponseId="R_2AKyTzVDYG7tiII") FirstRoleLevel=2.
IF (ResponseId="R_2SrwGNygBfnwoUc") FirstRoleLevel=3.
IF (ResponseId="R_27WMCpuZQ5jlX18") FirstRoleLevel=1.
IF (ResponseId="R_Tvme9hSPtpxLt3r") FirstRoleLevel=1.
IF (ResponseId="R_215RjoH4v0GyDkg") FirstRoleLevel=4.
IF (ResponseId="R_12s46xwvn344aOJ") FirstRoleLevel=3.
IF (ResponseId="R_1cTjMZZ1sgz7ub0") FirstRoleLevel=2.
IF (ResponseId="R_1JXzQrHDuvc47zD") FirstRoleLevel=3.
IF (ResponseId="R_RzCZO5qHW13Fx4J") FirstRoleLevel=3.
IF (ResponseId="R_1llOY5GFSrFD9nS") FirstRoleLevel=9.
IF (ResponseId="R_2YgZzXWW9qTmccl") FirstRoleLevel=4.
IF (ResponseId="R_3dRZouDuPsI27NI") FirstRoleLevel=3.
IF (ResponseId="R_2pKqXWG04hmk9bM") FirstRoleLevel=3.
IF (ResponseId="R_1OK61Dhm7URPjGq") FirstRoleLevel=3.
EXECUTE.

* *** anonymising FirstRoleLevelDetails - CO.
IF (ResponseId="R_2TZBSjgeZPtUPrm") FirstRoleLevelDetails="Head of (creater of) departmental research support office in a university medical center. Managed ~XXXX team members supporting ~XXXX researchers, reporting directly to dept chair.".
IF (ResponseId="R_2sYIgG54Y94iEDt") FirstRoleLevelDetails="General manager, Centre of Excellence for XXXX".
IF (ResponseId="R_3hA8wjAehsm7vfc") FirstRoleLevelDetails="Jefe de Laboratorios y Talleres de Ingenieria Industrial de la XXXX, base para el desarrollo de Investigación Tecnológica y Soporte a los cursos de las Escuelas Profesionales de Ingenieria".
IF (ResponseId="R_3NHT1j3rde9I4Ll") FirstRoleLevelDetails="Asistente de supervisión de proyectos de investigación en la Oficina de Investigación y Desarrollo - Vicerrectorado Académico - Universidad XXXX".
IF (ResponseId="R_2QmJYirdD1hdVi2") FirstRoleLevelDetails="Soy gestora de proyectos del Instituto de Investigación (XXXX) de la Universidad de XXXX".
IF (ResponseId="R_3qOe9q9wSeTMKkN") FirstRoleLevelDetails="Research Service Analyst at XXXX University. Cradle to Grave operations for multiple units.".
IF (ResponseId="R_9AA2wk0LV8zEh21") FirstRoleLevelDetails="Grants Manager for $XXXXM FIPSE FITW grant at a college.".
IF (ResponseId="R_3DkA3HV4oJ8jTJF") FirstRoleLevelDetails="Working at a R01 University where annual federal funding to the unit was more than $XXXXM and operationally more than $XXXXM.".
IF (ResponseId="R_cOpwDQP2aQNCdTb") FirstRoleLevelDetails="I was the XXXX research support employee in a comprehensive cancer centre".
IF (ResponseId="R_2xWbOUDcs23xWdA") FirstRoleLevelDetails="I was essentially the PI (not a term I knew at the time) of XXXX USAID-funded grants (with cost share!  also not a term I knew at the time) as a Peace Corps Volunteer.".
IF (ResponseId="R_3CV0q6Y2Kreiw2y") FirstRoleLevelDetails="I am a team member in the Open Science and XXXX team (XXXX is the name of our university's research information system)".
IF (ResponseId="R_24Bjpai6ncwx1PW") FirstRoleLevelDetails="Brussels liaison for XXXX national universities".
IF (ResponseId="R_3GeabuOZKRLWctX") FirstRoleLevelDetails="I was an Awards Administrator at the XXXX, processing applications under various panels. ".
IF (ResponseId="R_3mkptFxSt38AUaY") FirstRoleLevelDetails="Monitora en un XXXX".
IF (ResponseId="R_ewCOL6JpvypYH4t") FirstRoleLevelDetails="Processing of grant applications and organisation of assessment processes for a regional funding agency in Germany (XXXX).".
IF (ResponseId="R_2wconplnDXCKssP") FirstRoleLevelDetails="Worked with EU's FP3-FP4, COST and other international programmes in the Ministry of Research XXXX. Danish XXXX member during FP4, COST Senior Official.".
IF (ResponseId="R_2AGP92KlyBh0BB7") FirstRoleLevelDetails="Research Development Manager for Global Challenges Research Fund at XXXX University of XXXX".
IF (ResponseId="R_3jYTryWR9JkGLQW") FirstRoleLevelDetails="Apoyo desde el MINISTERIO DE XXXX a los términos de referencia de las convocatorias y seguimiento, ejecución y cierre a los proyectos financiados. ".
IF (ResponseId="R_233imbivLyO6MQB") FirstRoleLevelDetails="Fui Gestor de proyectos de innovación en la Universidad XXXX".
IF (ResponseId="R_3L7ryEfemk50oRV") FirstRoleLevelDetails="Research Manager at a UKRI-recognised IRO in the UK XXXX sector".
IF (ResponseId="R_D934SCyhR3vYpQ5") FirstRoleLevelDetails="Operational coordinator for international development project on Coastal Zone Management, with university partners in XXXX.".
IF (ResponseId="R_2eQkvsOQVTQQDSI") FirstRoleLevelDetails="XXXX de la oficina de internacionalización de Colciencias a cargo de la implementación del programa de Diáspora Altamente Calificada, financiado con recursos del Banco Mundial.".
IF (ResponseId="R_1mymfUfw7rl436U") FirstRoleLevelDetails="I was a Research Coordinator for the XXXX Institute for Research on Sustainability after completing my PhD".
IF (ResponseId="R_4VkuOdH5WE1foad") FirstRoleLevelDetails="Research Support Officer with line management of one person. There were only the XXXX of us in the office at that time (XXXX)".
IF (ResponseId="R_2SvlClSZBL7W7l9") FirstRoleLevelDetails="Associate Portfolio Manager at EPSRC (UK) looking after the sub-portfolio of XXXX".
IF (ResponseId="R_2aaECc37WOETzqG") FirstRoleLevelDetails="Member of staff at the Wellcome Trust, XXXX. Duties included managing funding competitions, arranging peer-review, managing committees, managing funded Centres and mentoring. ".
IF (ResponseId="R_1eqjMBJrOarx73P") FirstRoleLevelDetails="Program Manager for large NIH XXXX grant".
IF (ResponseId="R_3GcFGhQZDDOOhHd") FirstRoleLevelDetails="I was a Research Officer at XXXX University.".
IF (ResponseId="R_PTfsfqQmCwEQtzz") FirstRoleLevelDetails="Desarrollar estrategias para mejorar los procesos y resultados de investigación de una escuela academica de la XXXX Colombia".
IF (ResponseId="R_1BYua97H96X3Pk3") FirstRoleLevelDetails="Research Finance Team Lead at XXXX".
IF (ResponseId="R_3KZOEwXOAfmrPm4") FirstRoleLevelDetails="I management XXXX Intergovernmental Scientific Award (No.XXXX). Scientific Collaboration Grant No. XXXX (http:// dknii.gov.ua).".
IF (ResponseId="R_C232faXbcox97gJ") FirstRoleLevelDetails="".
IF (ResponseId="R_78SeBk3AfhawxUt") FirstRoleLevelDetails="I was the XXXX employee in a research administration department of a small U.S. university".
IF (ResponseId="R_2tchnU0EKlxDrQE") FirstRoleLevelDetails="XXXX Grant Manager for the division of Geriatric,  extreme amount of learning, everything i thought I knew, I didn't.  ".
IF (ResponseId="R_1NwPCaYYopx75g7") FirstRoleLevelDetails="Head of administration, coordinator for Centre of Excellence with an annual turnover of approx XXXX MNOK - External project portfolio of approx XXXX projects".
IF (ResponseId="R_1hX1oFfkT78HkkV") FirstRoleLevelDetails="RAE XXXX Coordinator".
IF (ResponseId="R_RIfiKrEdH2RxC6t") FirstRoleLevelDetails="Manager for an ESRC funded Research Centre at XXXX University".
IF (ResponseId="R_2E06juupc514Q82") FirstRoleLevelDetails="I was recruited to support the RAE XXXX 50% and be the centre administrator for a large XXXX-funded grant, 50%".
IF (ResponseId="R_2Sp1BK4Q9CkGVY0") FirstRoleLevelDetails="University Research Administrator at the University of XXXX".
IF (ResponseId="R_2qwO1ST9fc86VZP") FirstRoleLevelDetails="My first role was in a College of Nursing research office at the University of XXXX on the XXXX campus. Provided pre-award support. ".
IF (ResponseId="R_2q4zRCl5mUhPU34") FirstRoleLevelDetails="Responsible for pre- and post-award for an R-13 NIH grant for a small non-profit organization focused on an XXXX.".
IF (ResponseId="R_2YFjp0KDtvUY7Qk") FirstRoleLevelDetails="I was first a Medical Department Manager, then School of Medicine Finance & Administration Associate Director at XXXX University, and returned to a lower Research Administrator role. ".
IF (ResponseId="R_3qJV14SQCCiQPYe") FirstRoleLevelDetails="I started as an Administrative Officer for the XXXX Centre (XXXX) for Metabolic Diseases.".
IF (ResponseId="R_a9ICAbmyDH5uNZD") FirstRoleLevelDetails="Research Funding Assistant- providing pre-award and costing support at XXXX University ".
IF (ResponseId="R_1Nggafyom3ohKVd") FirstRoleLevelDetails="Manager of Centre for XXXX, XXXX Centre, Institute of Education".
IF (ResponseId="R_2CvSAlAKMC2y9cK") FirstRoleLevelDetails="I am the Grant Specialist for XXXX Texas. I work with faculty on grant purchasing, hiring and close out.".
IF (ResponseId="R_1I6L1PLGu3PTmC2") FirstRoleLevelDetails=".I was working at a funding agency at XXXX and was manging 55 projects in terms of quarterly disbursement off finds monitor Scientific progress and utilization of funds.".
IF (ResponseId="R_1LnwYqGTD0VA5dr") FirstRoleLevelDetails="Gestora de proyectos internacionales en la Universitat de XXXX".
IF (ResponseId="R_3G39HpWUtefem5c") FirstRoleLevelDetails="Research and Eternal Affairs Manager, Faculty of Arts and  Humanities, University of XXXX".
IF (ResponseId="R_2bWyIZGtcVgCD9Z") FirstRoleLevelDetails="Receptionist for U of XXXX CMRR facility. Monitored security procedures, prepared patient stipend payments, Checked in study participants, maintained grant files. ".
IF (ResponseId="R_24hGeKAxTWgPNAh") FirstRoleLevelDetails="Coordinador Ejecutivo del Observatorio de Ciencia y Tecnología de la Universidad del XXXX".
IF (ResponseId="R_3MlLSrypqIl2oth") FirstRoleLevelDetails="Research Officer for the administration of the Global Challenges program at XXXX. Doing research management tasks within a team.".
IF (ResponseId="R_1F4dTCiTtGjsaTT") FirstRoleLevelDetails="Head of Administration and Services at XXXX-Institute".
IF (ResponseId="R_2bOft500H8gk0zF") FirstRoleLevelDetails="Project Leader for XXXX and XXXX".
IF (ResponseId="R_1goxfDPomPcu1t3") FirstRoleLevelDetails="research administrator, School of Education, XXXX University, XXXX.".
IF (ResponseId="R_O2n02BxC6cT7Bvz") FirstRoleLevelDetails="Grants Development Officer in the Office of Research at XXXX".
IF (ResponseId="R_1g6YWdozwwq9oUc") FirstRoleLevelDetails="Legal Advisor of Research Services Division at University of XXXX".
IF (ResponseId="R_3EQifCFqNA5tmo0") FirstRoleLevelDetails="My first RMA role was just advise the XXXX of the FCT, manage calendars and plan events".
IF (ResponseId="R_1q7B42kCMem5b12") FirstRoleLevelDetails="I was supporting Prof. XXXX to implement FP6/XXXX  project".
IF (ResponseId="R_2VvGqQbVu363AHI") FirstRoleLevelDetails="Research admin assistant at XXXX Uni in Melbourne, Australia.".
IF (ResponseId="R_dhj37VMR8aBDw2t") FirstRoleLevelDetails="Research & Innovation Administrator, XXXX University".
IF (ResponseId="R_3MMbLJqwlPuooG6") FirstRoleLevelDetails="I was a grants administrator at XXXX - the commercial grants arm of the University of XXXX in 2005".
IF (ResponseId="R_pH2v25XLcKqA6FH") FirstRoleLevelDetails="Research Office Coordinator at XXXX Uni of Technology. Very much a support role to the Associate Dean Research of the Business School. ".
IF (ResponseId="R_216ChyS6xkADwHm") FirstRoleLevelDetails="XXXX within the national research excellence assessment in New Zealand".
IF (ResponseId="R_DtTxhMtXYHyAZTb") FirstRoleLevelDetails="I was responsible for the research management of XXXX clinical studies for a pharmaceutical company in a country organization.".
IF (ResponseId="R_1EYAfTfVOjqC99M") FirstRoleLevelDetails="University XXXX".
IF (ResponseId="R_UfpmrbsgXUUG5a1") FirstRoleLevelDetails="I was international project officer in charge of the development of scientific and higher education cooperation between France and XXXX  at the french embassy.".
IF (ResponseId="R_bDaYj0VSUAq2nJv") FirstRoleLevelDetails="Faculty Collaborations Coordinator to networking with STEM faculty regarding grantsmanship with XXXX minority serving institutes (MSI), Department of XXXX, and Research I universities.   ".
IF (ResponseId="R_3M0vSuDkCbGtUka") FirstRoleLevelDetails="First was research assistance, but first proper RMA was assisting with ethics processes at XXXX Uni. ".
IF (ResponseId="R_Ojyf5qCdETGFViV") FirstRoleLevelDetails="XXXX, XXXX, Royal Australian College of General Practitioners".
IF (ResponseId="R_8df1v4nZoNjCBax") FirstRoleLevelDetails="Research Support Officer at the University of XXXX".
IF (ResponseId="R_2CdfXYbZyNlBTKi") FirstRoleLevelDetails="Head of the XXXX University Australia Research Office".
IF (ResponseId="R_7V8Br1O0nYc9ia5") FirstRoleLevelDetails="Postgraduate research officer in the Faculty of Arts Arts Research office at the University of XXXX".
IF (ResponseId="R_3M9xi401ZhGbeii") FirstRoleLevelDetails="From a previous stint in private industry (Federal Contract Managment), I entered my first 'official' RMA position in 1993 at XXXX State University as a Sponsored Programs Administrator. ".
IF (ResponseId="R_1ePjZimq5QXf6BJ") FirstRoleLevelDetails="Education and Public Engagement Manager at the XXXX Society (London, UK)".
IF (ResponseId="R_2dTsCkujv7RfmeK") FirstRoleLevelDetails="Coordinadora de diagnostico de los jóvenes en alto riesgo en el marco del proyecto XXXX con un equipo de 2 sociólogos a cargo ".
IF (ResponseId="R_vDhpmafYbTbOapX") FirstRoleLevelDetails="I worked at XXXX (a major R1 institution) in a department and assisted with proposals. At that time, it was typing them on a typewriter, making copies, and shipping them in paper ream boxes.".
IF (ResponseId="R_2Se7cNW8QP9c5mA") FirstRoleLevelDetails="Chefe de Departamento de Imunologia do XXXX".
IF (ResponseId="R_2uP5ESbTvaGlC2v") FirstRoleLevelDetails="XXXX grant assistant entry level grant admin supporting dept level grants".
IF (ResponseId="R_2WHXjCUudGJTJLO") FirstRoleLevelDetails="Scientific Programme Manager - XXXX international".
IF (ResponseId="R_2f0P9dZGr5fhLpD") FirstRoleLevelDetails="I work for a research department at XXXX. I am responsible/oversee pre and post award administration/fiscal aspects of current and pending awards at a departmental level.".
IF (ResponseId="R_32Ld70W5i3w8Z30") FirstRoleLevelDetails="Directora del Secretariado de XXXX".
IF (ResponseId="R_eKviY03SM54zToZ") FirstRoleLevelDetails="Management Information Analyst at the University of XXXX".
IF (ResponseId="R_2D5fFFgqwhsm1Rz") FirstRoleLevelDetails="Grant accountant for about XXXX NSF grants in the Department of Mathematics at the University of XXXX.".
IF (ResponseId="R_eyus19fdMG1cxJn") FirstRoleLevelDetails="REF Research Impact Coordinator at the University of XXXX, working on panels C and D.".
IF (ResponseId="R_1i4Xxb9KtdFtlbX") FirstRoleLevelDetails="Project manager at a specific Ec funded project (XXXX).".
IF (ResponseId="R_3pms37v9J3jA3dW") FirstRoleLevelDetails="When I was Ph.D student, I did research work on XXXX under guidance of Prof. XXXX, who is an academician of China.".
IF (ResponseId="R_1hMTDVgLcgrAsa9") FirstRoleLevelDetails="Project Manager, University of XXXX".
IF (ResponseId="R_1r9qvEs2Kd7n2G0") FirstRoleLevelDetails="Federal Program Officer for the National XXXX Resources Division.".
IF (ResponseId="R_27WMCpuZQ5jlX18") FirstRoleLevelDetails="Director Innovation and Internationalization XXXX, supporting  research funding from Gov of India , BIRAC, Newton Fund , Chevening fund and Fulbright ".
IF (ResponseId="R_Tvme9hSPtpxLt3r") FirstRoleLevelDetails="Directrice administrative et financière d'un laboratoire de recherche du CNRS (XXXX personnes). Responsable de l'équipe administrative (XXXX personnes)".
IF (ResponseId="R_86AnaGJ2r51FeCt") FirstRoleLevelDetails="Administration assistant of the XXXX University XXXX Project - a clinic education unit supporting research in wrongful conviction. ".
IF (ResponseId="R_1DV8NObhROXDKzO") FirstRoleLevelDetails=CONCAT("Research manager of the Faculty of Health and Social Care, XXXX University, UK.  The Faculty was not",
" research-intensive and so despite the title, I worked one on one with researchers to support the application process for research funding.").
IF (ResponseId="R_26nn8nNjiQcjcw6") FirstRoleLevelDetails=CONCAT("Gestora de proyectos en la Vicerrectoría de Investigaciones de la Universidad de XXXX. Apoyaba la ge",
"stión de becas de estudiantes doctorales y búsqueda de fuentes de financiación, capacitaba a Estudiantes de doctorado y profesores nuevos en estrategias para la consecución de financiación a sus proye",
"ctos de investigación.").
IF (ResponseId="R_1F2LBqxhyel8W6j") FirstRoleLevelDetails=CONCAT("When I first began working at the research department, I was responsible for providing research supp",
"ort to staff at XXXX that are doing research whether it is their master's degree, doctoral degree with processing and screening their application for research development leave, research grant funding",
" to attend a conference and research ethics to conduct a research project. I would also capture support staffs research publications. I would administer support staffs research requirements.  ").
IF (ResponseId="R_XYPQGspT06FbZHr") FirstRoleLevelDetails=CONCAT("grants manager at XXXX. responsible for supporting the financial and administrative management of a ",
"portfolio of sponsored awards. Duties included: Provide continuous monitoring of revenue and expenditures on federal and non-federal research grant.s Develop monthly budget and expenditure reconciliat",
"ion, financial projections, financial reports, and maintain working knowledge of basic fund information (e.g., terms and award dates). Continuously ensure expenditures are in line with award terms and",
" prepare adjustments to the general ledger on grant-level activity, as necessary. Strategize with Principle Investigators (PIs) on resource/personnel allocations, including initiating and processing r",
"equired forms and documentation. Assist  faculty with the submission of grant proposals, as needed. Provide guidance to the faculty and other research program staff to ensure compliance with universit",
"y and sponsored research policies").
IF (ResponseId="R_1QL9yXWmXFaqCm0") FirstRoleLevelDetails=CONCAT("El Vicerrectorado de Investigación, se creo en mi universidad a fines del XXXX. Soy asistente Técnic",
"o del Vicerrectorado de Investigación desde el XXXX. A partir de allí hemos gestionando las iniciativas en CTI de mi universidad, primero estableciendo los marcos normativos, políticas y procesos. Lue",
"go se desarrollo un plan de Infraestructura y equipamiento (XXXX). Ahora estamos en proceso de brindar mejores condiciones para que los docentes se orienten a la investigación.").
IF (ResponseId="R_2Qm4AWDBP855uls") FirstRoleLevelDetails=CONCAT("Joined XXXX 1999 as research officer in the central administration and the division of education and",
" research (UFO). Was responsible for research related tasks at the university board and faculty board. Coordinator for the research administration and the administrative support to the boards of facul",
"ties, Deputy head of division XXXX, Substitute EU Liaison officer XXXX, Substitute director of postgraduate studies XXXX, Substitute head of division XXXX.  Was research coordinator at currently the s",
"chool of innovation, design and engineering (XXXX) between 2005 and 2016. Between 2010 and 2016 he was head of XXXX (Division of Research Coordination). XXXX he was Regional Contact point for FP7. Amo",
"ng his main duties as research coordinator was to promote the participation in FP7, Horizon 2020, ECSEL and EUREKA and to coordinate the participation in the European Technology Platforms (ETP) and Pu",
"blic Private Partnerships (PPP). He was also Member of the Professional Development Working Group in the European Association of Research Managers and Administrators (EARMA) XXXX. Between XXXX and XXX",
"X he coordinated the XXXX project XXXX.").
IF (ResponseId="R_vMM7kERlfufJqZX") FirstRoleLevelDetails=CONCAT("XXXX. Research and Project Manager 'XXXX Intergovernmental Scientific Project: (XXXX). Scientific Co",
"llaboration Grant No. XXXX (http://XXXX).   XXXX : Chief operating officer, Project Manager, The XXXX of Ukraine, Ukraine  Stimulation of fundamental and applied scientific researches in the field of ",
"Natural Sciences; establishing of the scientific and technical cooperation between scientific institutions, higher education institutions and representatives of the manufacture and service sectors; pr",
"omotion of the production-oriented (branch) scientific institutions by organizing competitions at the request of central executive bodies or other customers, provided that such central bodies of execu",
"tive power or the customers of the corresponding funds are allocated.  Thanks to the work of my team in the field of 'XXXX', XXXX in Ukraine, a competition for grants for research within the framework",
" of the competition 'XXXX' was successfully held.   In XXXX as a member of international team that includes groups from Ukraine, the United Kingdom, Spain and Italy, I contributed to the proposal 'XXX",
"X” for a grant under umbrella of the European Union’s Horizon 2020 research and innovation program under the XXXX. The proposal was evaluated positively and got funding. I was selected as the Chief Re",
"search Supervisor of the project from Ukrainian side.   In XXXX and XXXX I attracted funding from Erasmus+ program 'Key action 1 – Mobility for Learners and Staff – Higher Education Student and Staff ",
"Mobility”. for internships of students at the Faculty of Mathematics of XXXX University (XX). I was selected as a Program Supervisor and Manager from the Ukrainian side.  From January XXXX to December",
" XXXX, I was Manager of the grant of the Ministry of XXXX of Ukraine (Grant: XXXX) 'XXXX.'    ").
IF (ResponseId="R_3fkjzJYupDKFe3M") FirstRoleLevelDetails=CONCAT("During my time at the TTO of the Italian XXXX - XXXX, Italy (XXXX), I administrated and executed mor",
"e than 100 projects at the European, national and local levels in the Biotech field. Under the leadership of the director, I carried out assigned tasks in a timely and effective manner and I worked to",
"gether with other team members to support the definition of the Unit's overall work programme results as well as their dissemination. As Innovation Manager, I managed more than 100 projects at nationa",
"l and European level. My largest project with XXXX partners (XXXX SMEs, XXXX universities and XXXX research centres) with a budget of € XXXX million to create a regional cluster in the XXXX (www.XXXX)",
". ").
IF (ResponseId="R_bIpQQm2XujkUdFL") FirstRoleLevelDetails=CONCAT("RMA del Framework Contract XXXX de la DG de XXXX. Gestión de contratos específicos con diferentes De",
"legaciones de la UE para diseñar, implementar o evaluar proyectos de cooperación internacional y desarrollo de la UE. ").
IF (ResponseId="R_Y6zInFx3eVhitaN") FirstRoleLevelDetails=CONCAT("I supported the XXXX of Research for the Department of XXXX. XXXX is/was one of several departments ",
"within the School of Medicine, which is one of 7 'schools' at a major, R1 university on the East coast of the United States. I worked with the researchers to prepare their grant applications - back th",
"en, everything was submitted via US mail or package service, and multiple copies were required.").
IF (ResponseId="R_1q24IVMwGOfpFpW") FirstRoleLevelDetails=CONCAT("Research administrator in an externally funded research centre based at a XXXX University and operat",
"ing across a number of different universities. Responsible for providing support for all types of research related activities including: financial control, travel arrangements, new bids, events and ca",
"pacity building activities, publications, meetings, funder reporting, data management, institute network activities, Director support.").
IF (ResponseId="R_1OH0jNm5IhkpRa2") FirstRoleLevelDetails=CONCAT("After my 1st post-doc I was recruited by a UK private consultancy company to write FP6 proposals (XX",
"XX - SME instrument). It was a steep leaning curve: submit a new and a resubmission in 10 weeks. Job qualified as an 'internship'. I was finally recruited by this company a year later. I was hired to ",
"manage a large project and build a partnering internal service.").
IF (ResponseId="R_27QBC4GxIb8NblY") FirstRoleLevelDetails=CONCAT("I was XXXX of a victim-witness office staffed by myself and volunteers.  The office was part of the ",
"County Prosecuting Attorney's Office.  I wrote and administered all grants that supported and helped to expand the office.").
IF (ResponseId="R_3GiBhcw3NP3gc0Z") FirstRoleLevelDetails=CONCAT("XXXX las Convocatorias Nacionales (MinCiencias, Banco de la República e ICETEX), así como las Convoc",
"atorias de financiación interna y Apoyo a convocatorias internacionales. Administración del proyecto XXXX.  Gestionar y administrar los permisos de investigación y servicios de consultoría en Biodiver",
"sidad: Permisos de recolección de especies biológicas, Contratos Acceso al Recurso Genético y sus Productos Derivados, Parques Naturales Nacionales, Exportación e importación de especímenes biológicos",
" entre otros").
IF (ResponseId="R_7Vhfy6dUdehydYR") FirstRoleLevelDetails=CONCAT("Comencé como profesional operativo a cargo de respaldar a tres coordinadores de grupos de inevstigac",
"ión de XXXX, en las labores administrativas, financieras, logísticas, de medición y clasificación, de gestión de medios de publicación científica. Igualmente, al mismo tiempo, brindé apoyo al jefe del",
" Centro de Investigación, al que están adscritos los grupos, para el diseño, implementación, seguimiento y evaluación de iniciativas para el mejoramiento de la capacidad investigativa, de gestión de p",
"royectos, de gestión del conocimiento y de apropiación social. Tenía responsabilidades frente a algunas iniciativas, pero mi labor principal era apoyar, articular y asesorar la toma de decisiones de g",
"rupos e investigadores. ").
IF (ResponseId="R_24IBH6b6mJHDFrV") FirstRoleLevelDetails=CONCAT("Academic Manager (2/3 time with the rest of the 1/3 as a postdoc) at a Danish Centre XXXX (Centre ba",
"sed jointly in Denmark and the XXXX; role was primarily based in Denmark). Responsible for budget management, research centre communications (internal and external), contributions to governance, fundi",
"ng application support for both the institution and individuals, event management, strategic advice to centre leader").
IF (ResponseId="R_1hXZE2GdXVD7p6A") FirstRoleLevelDetails=CONCAT("I was hired as a temp at XXXX Univeristy to work in pre-award research administration and budgeting.",
" The position was in a statellite office to the central OSP office. It was a hybrid role where I worked directly with some faculty members and in some cases worked with departmental administrators. I ",
"was hired as a permanent employee three months later. ").
IF (ResponseId="R_2471V3AxhmfhKeq") FirstRoleLevelDetails=CONCAT("I was a project assistant at University of XXX and had a variety of administrative responsibilities.",
" I was asked to contribute to preparation of pieces of funding proposals, starting with things like biosketches and other support documents. Gradually, I took on more responsibility and was preparing ",
"larger sections of the proposals and working closely with the department administrator to coordinate submission.").
IF (ResponseId="R_1eY7EXhVStLmylu") FirstRoleLevelDetails=CONCAT("My role began after being asked to track financials and write reports for a large DoD grant received",
" in response to a 9-11 prompted RFA that was awarded to XXXX.  I worked as the Admin Coordinator in the Emergency Department and was told to 'manage this grant' which was a subagreement at the time.  ",
"I had no formal training and barely understood what a grant was, muchless the compliances a the time.  There was no mentoring process, no training provided, and no resources at the time, really, to se",
"arch for information online.").
IF (ResponseId="R_Uih4OBHmwLoAefn") FirstRoleLevelDetails=CONCAT("My first RMA role was as XXXX of a large research program at a major US Federal funding agency (the ",
"NSF). The position was complex, as my daily leader was the program's scientific coordinator, but his department head at the university where the office was physically located was also my staff manager",
". I also referred directly to the Program Officer at the NSF as well as to the Executive Board of the program. Welcome to the real world.").
IF (ResponseId="R_2nuCteJU2a0c2PL") FirstRoleLevelDetails=CONCAT("I was part of a small team (3 people) managing an EU Horizon XXXX grant where my employer acted esse",
"ntially as a funding body (giving grants for researcher mobility). At first I assisted the team but later on became the main responsible interacting with applicants for our mobility grants and organiz",
"ing the entire application process.").
IF (ResponseId="R_1r7bv4XFqiJPiXs") FirstRoleLevelDetails=CONCAT("Head of science management of Research area (XX research groups) within larger research institute. E",
"nabling decision processes among group leaders, supervising & building RMA team, organizing and documenting PI recruitments and scientific meetings, supporting public outreach, reporting for evaluatio",
"n of institute & research groups").
IF (ResponseId="R_32XAJO6z1fUV9t6") FirstRoleLevelDetails=CONCAT("awards administrator at Canada's XXXX research intensive institution. I started as a temp and applie",
"d for a permanent position when it became available. I supported large institutional and strategic grants in the central office").
IF (ResponseId="R_2xJWNpVMNta7uMU") FirstRoleLevelDetails=CONCAT("I began my career in research development as a Research Development Specialist in the Office of the ",
"Vice Provost for Research at XXXX University in 2009. I was responsible for assisting faculty, centers, institutes, and other units with all aspects of proposal development, including funding searches",
", proposal writing and editing, organization, timelines, and interfacing with IU's Office of Research Administration and partners.").
IF (ResponseId="R_2eWmzCm2TVHPMoV") FirstRoleLevelDetails=CONCAT("Secretaria de Programa de Medicina Molecular del Institut de Recerca de biomèdica de XXXX.  Tareas a",
"dministrativas y logísticas, asistencia al coordinador de programa.  Vínculo entre programa y administración central.  Organización de seminarios, apoyo a la ejecución del programa de doctorado, etc..",
" ").
IF (ResponseId="R_D66c81EeN69XZ5f") FirstRoleLevelDetails=CONCAT("Worked for a non-profit that held a contract with the State XXXX Board.  We funded community-based p",
"rograms.  I reviewed reports, completed site visits, and completed other administrative duties.").
IF (ResponseId="R_10GItYjdO8Ruu10") FirstRoleLevelDetails=CONCAT("Apoyar todos los procesos de investigación de los programas académicos ofrecidos en la ciudad de XXX",
"X por parte de la Universidad XXXX. Promover la creación de grupos de investigación y producción académica de los docentes. Impulsar y dirigir semilleros de investigación y supervisar los trabajos des",
"arrollados. Presentar propuestas de convocatoria interna y socializar las convocatorias nuevas y revisar el cumplimiento de los términos de los trabajos presentados. Asistir a reuniones relacionadas c",
"on la investigación a nivel regional.").
IF (ResponseId="R_25So3JfZpA5fOEY") FirstRoleLevelDetails=CONCAT("Worked as Research manager in XXXX Translational Cancer Research Centre XXXX from XXXX till XXXX.  •",
" Grant administration including collating proposal documents and submitting grant applications, preparation of annual reports for the Institute • Financial administration including preparation of budg",
"ets and monitoring & recording of research expenses (salaries, consumables, equipment, office material, travel and meetings, miscellaneous) • Material and inventory management including overseeing pur",
"chase of relevant equipment (lab & IT ) and consumables and pre-purchase functions like organizing vendor bidding exercise liasoning with the XXXX Materials & Bio-medical teams and vendor interaction ",
"and evaluation and maintaining and recording various stock levels as required. • Personnel management; including preparation of a draft Human Resources (HR) policy for the research institute; working ",
"with HR department for advertisement of research positions, conducting interviews and coordination of personnel appointment ; coordination of annual appraisals of research staff; and liaison with HR r",
"egarding  research staff attendance and leave • Overall responsibility for health & safety affairs of the Research Institute in coordination with health & safety officers  ; including organizing  trai",
"ning sessions and regular lab induction • Coordination of interactions with invited experts, external research groups and institute guests, including arrangements of talks, meetings, sessions with res",
"earch staff and local hospitality requirements • Coordination and monitoring of infrastructure requirements for operation of the research institute, including completion of the institute build and equ",
"ipping of the facility ").
IF (ResponseId="R_3iCQbLACysURDO2") FirstRoleLevelDetails=CONCAT("Liderar la Dirección de Investigaciones de una Universidad privada en XXXX (Colombia), planear, coor",
"dinar y realizar seguimiento a los grupos de investigación, investigadores y estudiantes con dedicación a la realización de proyectos de investigación internos y externos  ").
IF (ResponseId="R_1GDETSQJrt3Q29j") FirstRoleLevelDetails=CONCAT("Encargado de fomentar la cultura investigativa y el desarrollo del sistema de Ciencia y tecnología d",
"e la XXXX Nacional. Hacer seguimiento a las áreas y líneas para el fomento de la investigación y el desarrollo tecnológico en la comunidad XXXX. Promover y orientar la ejecución de proyectos de invest",
"igación y desarrollo tecnológico en las Facultades, las Áreas de investigación de las Escuelas de Formación, los comités de investigación de las Direcciones de la XXXX, los comités de investigación de",
" las Regiones de XXXX y los comités de investigación de las XXXX. Apoyar y estimular a las facultades, las áreas de investigación de las escuelas de XXXX, los comités de investigación de las Direccion",
"es, los comités de investigación de las Regiones de XXXX y los comités de investigación de las XXXX en la conformación de redes y grupos de investigación.").
IF (ResponseId="R_3fTC8yYgPicY3vw") FirstRoleLevelDetails=CONCAT("Dirección de investigación e innovación de la XXXX, bajo la responsabilidad y liderazgo de la Vicerr",
"ectoría Académica de la Sede. Desde la Dirección se gestiona el proceso de investigación de la Universidad -según los lineamientos y criterios establecidos en el estatuto orgánico, la política naciona",
"l de investigación de la Universidad, así como la política del SNCYTel. Desde este cargo se direcciona los planes, proyectos, programas y actividades de formación para la investigación y para la inves",
"tigación en sentido estricto, en el marco de un sistema institucional de investigación mutlicampus, que busca focalizar los esfuerzos de todas las sedes y seccionales (talento humano, recursos financi",
"eros, infraestructura, relacionamientos) para la identificación y solución de problemáticas pertinentes.").
IF (ResponseId="R_z7hhCxB67DqDO9P") FirstRoleLevelDetails=CONCAT("I was hired by a general internal medicine division in the department of medicine at a large urban a",
"cademic medical center on the XXXX. My role was to hire, train, and oversee a team of research project managers, research assistants and coordinators who provided support to 5-7 clinical research facu",
"lty at various career stages (striving for K to launching first U's). I oversaw a portfolio of NIH, Foundation and gifts that initially started around $5M total costs to over $35M during my tenure tha",
"t lasted 7 years. I was also responsible for managing spending of all awards and addressing under/over spending accordingly. For my area I also worked closely with the Department Administration and Ch",
"ief to discuss our strategic focus and direction of the group.").
IF (ResponseId="R_Q01xWm9Sxsa61tT") FirstRoleLevelDetails=CONCAT("I started as an administrative assistant for the central office at the University of XXXX. I did sch",
"eduling, reports, requested higher approvals and served as a liaison between upper management and pre award teams. ").
IF (ResponseId="R_1rkcl61rOSVw3iN") FirstRoleLevelDetails=CONCAT("• Conduct initial and continuing review of human participant research protocols as per the approved ",
"Standard Operating Procedures (SOPs) developed and approved by the XXXX Management Board. • Monitoring of approved protocols as per the terms of approval and take appropriate steps to address any brea",
"ches of the terms of approval. The breaches will be addressed following procedures set out by the University of XXXX guidance on allegations of research misconduct. • Contribute to the effectiveness a",
"nd service and management of the XXXX Ethics Board by implementing recommendation put forth by the board. • Ensure institutional adherence to the University of XXXX Ethics Policy and its associated pr",
"ocedures. • Ensure the continuing education of committee members to enable them to be abreast of new developments, policies and regulations concerning research ethics and integrity.  • Report (includi",
"ng financial reports) on annual basis to (XXXX)  • Develop clear systems and mechanisms for managing payments and charges for ethical review. ").
IF (ResponseId="R_3jdK7DKNO0jBAsO") FirstRoleLevelDetails=CONCAT("I worked as part of the team of Research Development Officers at the University of XXXX who were res",
"ponsible for the pre and post award services. i was the focal person for some colleges and then became the schedule officer for the international mobility programmes. ").
IF (ResponseId="R_2cisAHkkz2Adn13") FirstRoleLevelDetails=CONCAT("I am currently in my first RMA role. I work as a grant specialist for over XXXX divisions in the Dep",
"artment of Medicine at XXXX University XXXX. I handle the 'pre-award' side of grants as they come in to us from our PIs, from conception to submission. Our PIs submit both federal and non-federal gran",
"ts, and I am versed in a variety of different foundations in addition to standard NIH/DoD submission types.").
IF (ResponseId="R_2c9OiCraCkmYXRL") FirstRoleLevelDetails=CONCAT("Research Manager for a newly established unit (XXXX) in Faculty of Science. Responsibilities: Centre",
" Management and Administration, Budgeting, Research Event Coordination, Liaison with Faculty and School Senior Management, Website Maintenance, Communications, Recruitment, Stakeholder Engagement, Gra",
"nt Management.").
IF (ResponseId="R_1FyXEWie3tisXln") FirstRoleLevelDetails=CONCAT("Knowledge Exchange Manager at XXXX University working on the XXXX Creative Technology Network, a lar",
"ge Research England funded research project to promote creative technology across the XXXX of England.").
IF (ResponseId="R_e9BjHcgAYawMfVD") FirstRoleLevelDetails=CONCAT("Executive Director and Project Manager for an International Consortium of three Universities: -XXXX ",
"-Center for XXXX Studies founded by  University of XXXX (Italy), University of XXXX (Spain) and XXXX University (USA). I was in charge to find external research funding activities and manage all funde",
"d projects. ").
IF (ResponseId="R_3J2SVGKbG2HSguB") FirstRoleLevelDetails=CONCAT("employee of XXXX branch office XXXX; responsible for programmes concerned with the promotion of Germ",
"an as a foreign language at Polish HEI as well as counselling on study-, research and funding opportunities for Polish researchers and students in Germany").
IF (ResponseId="R_ApaiXusMHk2RSIV") FirstRoleLevelDetails=CONCAT("Research Assistant – XXXX NHS Foundation Trust; - Administrative tasks and secretarial support, such",
" as arranging meetings, minute taking, producing agendas, site initiation meetings, dealing with internal and external stakeholders. Promotion and education of patients and Trust staff about clinical ",
"trials with posters, information leaflets and power point presentations.  During the Team Leader’s adoption leave, I negotiated with many departments within the hospital and across the Trust, and with",
" other trusts, exchanging good practice, to complete the necessary tasks for trial opening as efficiently as possible.  ").
IF (ResponseId="R_2axXhAiOznn1Koc") FirstRoleLevelDetails=CONCAT("The primary task were: • Manager TRDP of NRF including all administration such as grant holder linke",
"d bursaries. • Develop new NRF programme based on niche areas. • Secretariate for the Research Sub-Committee of the XXXX Committee: agenda, minutes, follow-up correspondence, monitoring the budget. • ",
"Deal with all questions related to the availability of internal funding (except M & D bursaries). • Link between researchers, research sub-committee and finance. • Assist with the administration of po",
"st-doc bursaries. • 'Research at XXXX” – refer/answer questions. • Link between RM and faculty officers (M & D students graduating/enrolled). • Manager RA system. ").
IF (ResponseId="R_3PcrUBXAkYbIIft") FirstRoleLevelDetails=CONCAT("I was nominated to be XXXX of New Media Institute, XXXX University of China in year XXXX. I had been",
" in charge of the research, innovation and collaboration work of this insitute as an interdisciplinary research team and postgraduate education institution within the framework of XXXX University of C",
"hina.").
IF (ResponseId="R_wWW9wcNSm0pKpH3") FirstRoleLevelDetails=CONCAT("Project Manager at the Center for XXXX. It is my role to help projects progress through the evaluati",
"on process. I'm also responsible for making sure contracts with other research institions are in place. I'm also involved in the working groups revolving around the project submission process and how ",
"it can be optimized.").
IF (ResponseId="R_2QlVW3JpIvFqfzx") FirstRoleLevelDetails=CONCAT("I entered the world of research management becoming the personal assistant to a professor of the Aus",
"trian Academy of Sciences, which I haven't even heard of before. Organizing his daily life as a leading scientist in XXXX, I quickly learned about funding for science: publications, projects applicati",
"ons and reporting. There was also an international team and a beamline at a synchrotron to manage. I did a couple of courses to add specific funding knowledge to my already existing soft skills. ").
IF (ResponseId="R_2v5Iba9IWowpAKC") FirstRoleLevelDetails=CONCAT("This started when I was involved in the first inter-universiity research collaboration coordinated b",
"y the Inter-University Council for XXXX (XXXX). It gave me the initial role of academic writing and research mentoring of PhD, MSc/MA), and undergraduate students from multiple disciplines until now. ").
IF (ResponseId="R_3iJYkTgeo1OjDaO") FirstRoleLevelDetails=CONCAT("I was a Post Award Assistant at the XXXX State Foundation. I would assist the Post Award Analyst and",
" Post Award Manager with issuing subawards, invoicing, reviewing travel and expense reimbursements, setting up new awards, closing out awards, assisting with audit, etc.").
IF (ResponseId="R_RtrtB6YPq8ShQjL") FirstRoleLevelDetails=CONCAT("Served XXXX interdisciplinary centers at a R1 (Carnegie rating) in US. Found funding, prepared budge",
"ts & justifications, reviewed proposal documents, created application sites and uploaded documents, contacted sub-awards and program managers, prepared and routed proposals in internal systems, revise",
"d budgets, assisted in report preparation, and created no-cost extension justifications.").
IF (ResponseId="R_XoeES5Lz2HRTKLv") FirstRoleLevelDetails=CONCAT("• Edited grant proposals, drafted grant budgets, shepherded grants through university approval proce",
"ss, submitted final proposals • Managed 4 federally-funded projects with budgets ranging from $80,000 to $192,000 per year involving multiple subcontracts • Monitored project budgets; Tracked project ",
"metrics (data usage, presentations, website statistics); Drafted sections of proposals and technical reports; Coordinated website development and maintenance; Coordinated staff working on current proj",
"ects;  • Maintained contact with project participants, including farmers and ranchers as well as an interdisciplinary group of researchers from two consortia (XXXX Consortium (XXXX), and Consortium fo",
"r Site Specific Resource Management (XXXX)) • Planned and coordinated local and national workshops and conferences • Developed educational materials for use by K-12 teachers aiming to integrate GPS, G",
"IS, and remote sensing into classroom teaching • Planned and led 4-day GIS training workshops for elementary and secondary education teachers throughout Montana, training over 90 teachers").
IF (ResponseId="R_1KexTuXEk2VneNu") FirstRoleLevelDetails=CONCAT("I was recruited to assist the Portuguese Delegates appointed to the Horizontal Priorities of the XXX",
"X EC Framework Program for Research and Development. My functions included support to call dissemination (emailling and info days), analysing and preparing information on the national participation on",
" such programmes to be used by the National Delegates and NCPs, gathering comments on work programmes.").
IF (ResponseId="R_voSw84irNP4aL5L") FirstRoleLevelDetails=CONCAT("At XXXX National Lab, I served as a research assistant to an interdisciplinary team of researchers w",
"orking on decision science. I soon rose up in the ranks to manage a project to develop a decision tool to help DOE make decisions about projects to reduce human health risks caused by environmental co",
"ntaminants.").
IF (ResponseId="R_2zr6Wv7XhMSRI0f") FirstRoleLevelDetails=CONCAT("Research assistant at a Max Planck Institute in XXXX/DE ‣ Support of the cooperation partners such a",
"s kindergartens, school nurseries and parents ‣ Acquisition of volunteers ‣ Coordination of student assistants and interns ‣ Support and conduction of behavioural child studies ‣ Guided tours and lect",
"ures on the work of the department ‣ Encoding, digitalisation and transcription of video material ‣ Organisation of department events ‣ Design of information material").
IF (ResponseId="R_10PFeVVGJFYjYZw") FirstRoleLevelDetails=CONCAT("Research Development Officer for 2 Schools (Physical and Biological sciences) at XXXX. Was a new off",
"ice, consisting of me and an administrative assistant. Later grew to encompass central research development and all STEM Schools.").
IF (ResponseId="R_1d072mTPfQb7vUo") FirstRoleLevelDetails=CONCAT("I was working at the secretarial office of Research Ethics Committee(EC) of University of XXXX, grad",
"uate school of Medicine. Through reviewing the application from to the EC, I consulted medical and health researchers how to design their research protocols in align with guide lines.").
IF (ResponseId="R_2VfI8miujZiMMbG") FirstRoleLevelDetails=CONCAT("XXXX years ago, I began my career in research administration working for one of Australia’s national",
" funding agencies, the XXXX (now the Australian Research Council). I provided secretariat support to the XXXX sub-committee, one of eight sub-committees. The entire College of Experts was about 20 peo",
"ple, and the secretariat was about 11 people. ").
IF (ResponseId="R_2aQ5YCASVXk1lEM") FirstRoleLevelDetails=CONCAT("Actually I'm working on projects since 1988. At that time and until 2008 I managed the projects (oft",
"en more than one at the same time) as researchers but did all the administrative work myself. Starting from 2015 I was an actual RMA at the institute of XXXX, at the central level (contracts, check fi",
"nancial reporting, assist with audits, budget prognosis). No team").
IF (ResponseId="R_2SwTWYjsADfDlZE") FirstRoleLevelDetails=CONCAT("My first role was at XXXX in Wash DC. I was hired only because I spoke XXXX and they needed someone ",
"with this skill to support 9 offices located in the former XXXX. My role was to provide support with any questions or issues offices might have, help expats with understanding Russian ways of making b",
"usiness, review of monthly expense reports with all receipts that were in XXXX, approve or disapprove some expenses, enter expenses in Quickbooks, and once a year travel to my offices to check complia",
"nce with cash on hands and bookkeeping. ").
IF (ResponseId="R_C2fPRrRyBAcFCHT") FirstRoleLevelDetails=CONCAT("• Perform pre/post-award sponsored research required for submission, acceptance, management and clos",
"ing of certain sponsored activities.  • Accept, draft and process change requests for amendments.  • Review and submit/accept no-cost extensions, budget revisions, and amendments to sponsored programs",
" projects.  • Process incoming material transfer agreements that conform to establish a uniform biological materials transfer agreements (UBMTA) template AND review all other material transfer agreeme",
"nts terms and conditions to be negotiated with sponsors. • Follow up with principal investigators and sponsors regarding the status of pending actions.  • Oversee completion of all transactions to ens",
"ure timely execution of all sponsored programs transactions.  • Work with university units to determine necessary elements of deliverables and reports and ensure required deliverables and reports meet",
" compliance with university policies and sponsor requirements.  • Guide the office of sponsored programs administrative assistants as needed.  • Implement, draft and assist faculty with 'XXXX' asserti",
"ons following proposal and/or award requirements, IP waivers, and other sponsored award-related documents. • Process monthly and quarterly performance reports as required.  • Redline grants and contra",
"cts for terms the university cannot accept.  • Validate/process compliance requirements with XXXX policies including IACUC, IRB, export control, and others.  • Participate in federal government regula",
"tion policy training and office Improvement planning. • Create reports.  • Quality assurance on process flow. ").
IF (ResponseId="R_2qkQnwHZyBn3Uy8") FirstRoleLevelDetails=CONCAT("Profesional de apoyo a grupos encargados de varias facultades de la universidad XXXX en temas de apo",
"yo en la gestión de la información de la producción para convocatorias de medición de minciencias ").
IF (ResponseId="R_RXHqGdnUCCSDWM1") FirstRoleLevelDetails=CONCAT("Research Assistant - supporting research supervisor and research division, (ie admin coordinator, de",
"partment coordinator for research) for  the XXXX Coordinating Center - an academic clinical contracting full service center.").
IF (ResponseId="R_1mFxj6qAch2WuA0") FirstRoleLevelDetails=CONCAT("My first job was an administrative assistant I in the Clinical psychology Training program at XXXX. ",
" I had a direct supervisor who gave me administrative task to do in support of the training program.").
IF (ResponseId="R_1rvv8r4UQp9UrdT") FirstRoleLevelDetails=CONCAT("In my first RMA, I worked at a Research Office in a Language Studies Institute, in XXXX. I did the a",
"ctivities of the secretary who was on vacation. Among the tasks, I performed project accountability and gave support to researchers in whatever was necessary for the development of research.").
IF (ResponseId="R_2DLXJLJ7yadfwge") FirstRoleLevelDetails=CONCAT("Innovation consultant working with pre-award and  industri collaborations and later as University Re",
"search Administrator URA at XXXX University in Japan with resposibilities for research support through pre-award and coordination of research collaborations, especially with the US and northern Europa",
".").
IF (ResponseId="R_8bJk4Vb64Yhm6Ln") FirstRoleLevelDetails=CONCAT("During my first role at XXXX University, I was responsible to assist the institution's designated au",
"thority with administration of grants, particlurly post-awards. My duties included: a) liaision with funders on post-awards matters b) compliance c) Students support d) progress reporting e) adjustmen",
"ts f) recordkeeping and data management g) networking ").
IF (ResponseId="R_33DabAtP1c3U0Gp") FirstRoleLevelDetails=CONCAT("• Promote Intellectual Property (IP) awareness, Office of Technology Transfer (OTT), and encourage I",
"P creation within the Council for XXXX (XXXX). • Support divisions and units in activities that promote the development of Intellectual Property. • Evaluate new invention disclosures. • Develop and up",
"date IP Policy, standard operating procedure, guidelines, and processes • Develop intellectual property strategies for the XXXX technologies. • Manage the patent prosecution process and maintenance of",
" the intellectual property portfolio. • Assist Researchers to apply grassroots and commercialisation funding and grants • Ensure compliance with the Intellectual Property Rights from Publicly Financed",
" Research and Development Act, 2008 (Act No. 51 of 2008), and the regulations • Build and maintain relationships with internal and external stakeholders, including relevant departments, funders/invest",
"ors (public and private), collaborators, entrepreneurs, and government entities. • Facilitate all logistics of the Technology Transfer Office operations, such as travel arrangements; meetings; worksho",
"ps & trainings • Ensuring a proper online and hardcopy system of record keeping on all activities of the Technology Transfer Office. • Draft reports, submissions, motivations, and memos ").
IF (ResponseId="R_1H6H6aOpJlfyvro") FirstRoleLevelDetails=CONCAT("I was the Research Manager of the National XXXX Research Institute. Managing research strategy, rese",
"arch students, writing grants, monitoring research and undertaking some project and program management. I also did the majority of the marketing and communications.").
IF (ResponseId="R_1llOY5GFSrFD9nS") FirstRoleLevelDetails=CONCAT("Over 14+ years of Leadership, Training and Management experience possessing good track record of wor",
"king on training programs. Managed and supervised technical and professional development courses for university faculty & admin personnel. As Senior Program Officer, XXXX University XXXX, I am respons",
"ible for keeping liaison & building coalition with senior management of sister institutions/organizations at various levels to launch need based trainings. I have been carrying out TNAs, developing Mo",
"Us, training materials/ modules, preparing follow up monitoring systems and assisting for changes of desired results in the client departments for improved performance. This has helped me sharpening m",
"y issue-based networking and partnership skills. Above all I have hands on experience of drafting quality report of each training and keeping record thereof for follow up actions on lessons learnt. Be",
"sides, I have been involved in making Vlogs to disseminate information about different departments of XXXX to parents and students. Links are enclosed: https://XXXX https://XXXX  https://XXXX https://",
"XXXX https://XXXX").
EXECUTE.

* CurrentRoleLevelDet.
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES CurrentRoleLevelDet=CurrentRoleLevelDetails.
VARIABLE LABELS CurrentRoleLevelDetails "2a. Details of current RA role".
MISSING VALUES CurrentRoleLevelDetails ("").
VALUE LABELS CurrentRoleLevelDetails "" "No Response".
EXECUTE.
* *** >1,000 responses - should cross check with CurrentRoleLevel/FirstRoleLevel to ensure consistency?.
* *** 73 CurrentRoleLevels had "Other", of these 58 gave some text -could be worth looking at these to see if backcoding is possible.
* *** Note that no missing responses to Level gave details - so no possibility to recode for those.

* *** anonymising for CurrentRoleLevelDetails - MF.
IF (ResponseId="R_2UVlF7TvawLfcFO") CurrentRoleLevelDetails="Funding advisor for personal grants at University Medical Center (XXXX Medical Center XXXX)".
IF (ResponseId="R_O6F21eHhkWL2Uil") CurrentRoleLevelDetails="Cradle to Grave Research Administration at XXXX University.  Process proposals, manage the awards, closeout the awards.".
IF (ResponseId="R_3NHT1j3rde9I4Ll") CurrentRoleLevelDetails="Asistente de supervisión y monitoreo de proyectos de investigación en el Instituto de Investigación - Vicerrectorado de Investigación - Universidad Nacional de XXXX".
IF (ResponseId="R_3hxRe2kcDSAwOs8") CurrentRoleLevelDetails="Director Nacional de XXXX ".
IF (ResponseId="R_1QaBA3JzgqDiMxj") CurrentRoleLevelDetails="Revisor de revistas internacionales e investigador senior de la XXXX".
IF (ResponseId="R_sG9ye2Yfv3maL7j") CurrentRoleLevelDetails="Senior Advisor, Research Tenders University in XXXX, Australia".
IF (ResponseId="R_ODXwSvbCy2bzS37") CurrentRoleLevelDetails="Senior manager for the  graduate research school at XXXX University,  leading the team that handles all aspects of graduate research administration from applications to examinations.".
IF (ResponseId="R_3qOe9q9wSeTMKkN") CurrentRoleLevelDetails="Senior Administrator at University of XXXX. Pre-award only. No management or supervisory. Highly respected unit on campus. ".
IF (ResponseId="R_2ANIRO5kcbsGyhi") CurrentRoleLevelDetails="Managing director of the XXXX Institute - XXXX Iceland As the head of the institute I participate in many aspects of research management".
IF (ResponseId="R_2wsjO9QVQCnS96z") CurrentRoleLevelDetails="Coordino el equipo de profesionales que gestiona oportunidades de investigación con financiación nacional e internacional para la Universidad Nacional de XXXX, la más importante del país.".
IF (ResponseId="R_uqAbvE1qBDisM4p") CurrentRoleLevelDetails="I am now Head of the College of XXXX and Veterinary Medicine at the University of XXXX".
IF (ResponseId="R_2AGP92KlyBh0BB7") CurrentRoleLevelDetails="Research Development Manager in the Faculty of Social Sciences at the University of XXXX".
IF (ResponseId="R_233imbivLyO6MQB") CurrentRoleLevelDetails="Soy profesional especializado gestiono entre otros temas las convocatorias públicas distritales de investigación, actualmente en la Gerencia de CTI de XXXX ".
IF (ResponseId="R_2fvpymJ9rWF4Muq") CurrentRoleLevelDetails="Associate Director of Research, XXXX".
IF (ResponseId="R_11jT1bi4QcrTOIl") CurrentRoleLevelDetails="Head of the XXXX Research Support Office".
IF (ResponseId="R_2eQkvsOQVTQQDSI") CurrentRoleLevelDetails="Coordianadora de la Unidad de Enlace de la Vicerrectoría de Investigación de la Universidad XXXX, responsable entre otros de las alianzas estratégicas a nivel de CTeI".
IF (ResponseId="R_1mymfUfw7rl436U") CurrentRoleLevelDetails="I am Head of Research Funding at XXXX University, leading the Pre Award service for the institution.  ".
IF (ResponseId="R_2SvlClSZBL7W7l9") CurrentRoleLevelDetails="Director of the XXXX Research Partnership".
IF (ResponseId="R_3GcFGhQZDDOOhHd") CurrentRoleLevelDetails="I am a Research Administrator at XXXX State University.".
IF (ResponseId="R_1BYua97H96X3Pk3") CurrentRoleLevelDetails="Research Finance Manager at XXXX and previously Acting Faculty Research Manager at XXXX".
IF (ResponseId="R_2CvbbqbBnKpXJ7l") CurrentRoleLevelDetails="Gestión del Servicio de Investigación de la XXXX, supervisión de las actividades de investigación de la Universidad.".
IF (ResponseId="R_RIfiKrEdH2RxC6t") CurrentRoleLevelDetails="Director, Research and Innovation at XXXX University".
IF (ResponseId="R_1OUGTPdWJyk39o2") CurrentRoleLevelDetails="Research Metrics Analyst - Research & Enterprise Services, University of XXXX".
IF (ResponseId="R_2nJ0qiuJ4bC3JCx") CurrentRoleLevelDetails="Head of Faculty Research Support (Engineering), University of XXXX".
IF (ResponseId="R_1FyXEWie3tisXln") CurrentRoleLevelDetails="Innovation Manager at XXXX University working on XXXX a large UKRI SIP funded research project to promote screen-based innovation across XXXX and XXXX".
IF (ResponseId="R_e9BjHcgAYawMfVD") CurrentRoleLevelDetails="Currently I work at University of XXXX in Special Research Service, after three years at Univeristy of XXXX with at IAdministrative Department International Research.".
IF (ResponseId="R_a9ICAbmyDH5uNZD") CurrentRoleLevelDetails="Research Development and Support Officer, providing both pre and post award support to externally funded project at XXXX University".
IF (ResponseId="R_1Nggafyom3ohKVd") CurrentRoleLevelDetails="Maternity Cover, Centre for XXXX (XXXX) Department of Economics, XXXX".
IF (ResponseId="R_eE6Otw0aFAy4gPn") CurrentRoleLevelDetails="Director of Research for the social work school at XXXX University.".
IF (ResponseId="R_1LnwYqGTD0VA5dr") CurrentRoleLevelDetails="Gestora de proyectos en pre-award departamento en XXXX".
IF (ResponseId="R_3G39HpWUtefem5c") CurrentRoleLevelDetails="Head of Research Support, XXXX University".
IF (ResponseId="R_24hGeKAxTWgPNAh") CurrentRoleLevelDetails="Coordinador Ejecutivo del Observatorio de Ciencia y Tecnología de la Universidad del XXXX".
IF (ResponseId="R_1F4dTCiTtGjsaTT") CurrentRoleLevelDetails="Knowledge and Technology Transfer at XXXX Institute".
IF (ResponseId="R_22nUz6tb66EvRpp") CurrentRoleLevelDetails="Vice Chair for Investigator Development Dept. of Medicine XXXX University".
IF (ResponseId="R_2zBVjJVSnqJG1uV") CurrentRoleLevelDetails="Director, Office of Research Integrity and Ethics, XXXX University ".
IF (ResponseId="R_1g6YWdozwwq9oUc") CurrentRoleLevelDetails="Legal Advisor of Research Services Division at University of XXXX".
IF (ResponseId="R_uq4mndSbAJTJkxX") CurrentRoleLevelDetails="I am European Projects adviser in the teacher education department of Norway's XXXX university".
IF (ResponseId="R_1q7B42kCMem5b12") CurrentRoleLevelDetails="I am project Coordinator of the XXXX Projects Support Centre ".
IF (ResponseId="R_3MMbLJqwlPuooG6") CurrentRoleLevelDetails="I am grant manager at XXXX University Clinical Research Unit - which is part of The University of XXXX, and am responsible for grants across our entire programme in XXXX, XXXX and XXXX. ".
IF (ResponseId="R_1E08SeDy3giP0Qd") CurrentRoleLevelDetails="Head of the PMO Researche centre XXXX".
IF (ResponseId="R_3r3fIdp4j3wz6Ku") CurrentRoleLevelDetails="Almost the same, but now I am responsible for the EU grants in XXXX (The XXXX is a thematic programme of the Ministry of XXXX), INTERREG... at XXXX University.".
IF (ResponseId="R_vZecJ9Jxy0eGezL") CurrentRoleLevelDetails="Gestor de proyecto europeo MSCA XXXX convocatoria financiada en 2019".
IF (ResponseId="R_3pgaq2b6bfcwkfN") CurrentRoleLevelDetails="Assistant Director of Research Development at  largest XXXX institution in New Jersey.".
IF (ResponseId="R_Xn5DHooROr9JIoF") CurrentRoleLevelDetails="Head of research and development at University of XXXX".
IF (ResponseId="R_10PFeVVGJFYjYZw") CurrentRoleLevelDetails="Currently CEO and Principal Consultant of a research development consulting firm. Have been Director of RD at XXXX, and Associate Vice Chancellor for Research at XXXX.".
IF (ResponseId="R_Ojyf5qCdETGFViV") CurrentRoleLevelDetails="Director, Research Grants and Development, XXXX University".
IF (ResponseId="R_8df1v4nZoNjCBax") CurrentRoleLevelDetails="Research Funding Officer at the XXXX Institute of Science and Technology".
IF (ResponseId="R_2qDfMgnYuBNCIK2") CurrentRoleLevelDetails="XXXX director ".
IF (ResponseId="R_UinLUENpRJfZuo1") CurrentRoleLevelDetails="Senior Interdisciplinary Funding Specialist, XXXX College XXXX".
IF (ResponseId="R_7V8Br1O0nYc9ia5") CurrentRoleLevelDetails="Manager, Graduate Research, Faculty of Business and Economics (University of XXXX)".
IF (ResponseId="R_3M9xi401ZhGbeii") CurrentRoleLevelDetails="I am now the Assistant VP for Research Administration and the Director of Sponsored Programs for the University of XXXX. ".
IF (ResponseId="R_1ePjZimq5QXf6BJ") CurrentRoleLevelDetails="Coordinator of the Communications and Outreach Office at XXXX (XXXX, Portugal)".
IF (ResponseId="R_3O33wx9HHJR8QaS") CurrentRoleLevelDetails="My current role is of Head Technology Transfer at one of the Institute of XXXX. Besides tech trasfer i support r research support office on Industry projects and negotiations.".
IF (ResponseId="R_2Se7cNW8QP9c5mA") CurrentRoleLevelDetails="Coordenador do Laboratório de Referência em XXXX do XXXX".
IF (ResponseId="R_3PB7BNnBuRvIyLQ") CurrentRoleLevelDetails="Research Strategy Development Manager at School of Life Sciences, University of XXXX".
IF (ResponseId="R_2WHXjCUudGJTJLO") CurrentRoleLevelDetails="Science and Strategy Manager, University of XXXX".
IF (ResponseId="R_eyus19fdMG1cxJn") CurrentRoleLevelDetails="Impact Development Manager at XXXX University, managing the research impact of half of the HEI's faculties (Health, Social Care and Education, and XXXX School of Arts).".
IF (ResponseId="R_3pms37v9J3jA3dW") CurrentRoleLevelDetails="When I came to XXXX University of Finance and Economics, I, together with my colleagues, have been working computational finance.".
IF (ResponseId="R_1hMTDVgLcgrAsa9") CurrentRoleLevelDetails="Faculty Funding Officer, University of XXXX".
IF (ResponseId="R_1NrC6SvzRWg7OAs") CurrentRoleLevelDetails="I am currently a consultant at XXXX, working in their research enterprises services division, providing interim research administration staffing services. ".
IF (ResponseId="R_oXfO0DrMcswPf1f") CurrentRoleLevelDetails="Now I am head of financial affairs for XXXX (XXXX) Research contracts".
IF (ResponseId="R_8bJk4Vb64Yhm6Ln") CurrentRoleLevelDetails="Currently and I serve as the Deputy Director for the XXXX University Postgradaute Office, with a key specialisation in Postgraduate Funding (scholarships and bursaries) ".
IF (ResponseId="R_1H6H6aOpJlfyvro") CurrentRoleLevelDetails="Current role is Manager of Major Awards at XXXX University. This is quite a new role and is mainly administrating large entity grants at the University.". 
IF (ResponseId="R_1DV8NObhROXDKzO") CurrentRoleLevelDetails=CONCAT("Grants and Contracts Manager, XXXX University, Australia.  I manage a 24-strong team of research adm",
"inistrators supporting the entire lifecycle and discipline spread of XXXX University.  This involves pre- and post-award support.").
IF (ResponseId="R_26nn8nNjiQcjcw6") CurrentRoleLevelDetails=CONCAT("Coordinadora de Gestión de Proyectos de Impacto Regional en la Facultad de Ingeniera de la Universid",
"ad del XXXX. Busco generar alianzas entre la Facultad de Ingeniera y entidades externas para el desarrollo de proyectos de investigación, desarrollo tecnológico e innovación. Responsable del proceso d",
"e formulación y aplicación a convocatorias del Sistema General de Regalías (XXXX) y proyectos de Beneficios Tributarios (XXXX) Responsable del XXXX Horizonte Europa para XXXX.").
IF (ResponseId="R_1F2LBqxhyel8W6j") CurrentRoleLevelDetails=CONCAT("Currently I not only screen support staff's applications for research development leave, research fu",
"nding to complete their master's or doctoral degree, attend a conference to present their research paper and research ethics certificate for a research project, I also prepare training programs like w",
"orkshops and information session for support staff. I also implement strategies to increase research publications by providing publication training. I implement strategies to raise awareness at XXXX t",
"o increase support staff's research needs. My work function has increased from providing administration support to support staff to advising, procedure writing, creating training programs, increasing ",
"marketing and communication awareness, creating a strategy plan to increasing research publications.      ").
IF (ResponseId="R_XYPQGspT06FbZHr") CurrentRoleLevelDetails=CONCAT("Director, Sponsored Projects Administration at XXXX State University. responsible for overseeing the",
" Compliance and Post-Award Operations portions of the sponsored projects lifecycle ($25M in external funding annually and $70M open sponsored projects portfolio). ensure contractual, financial, and pr",
"ogrammatic management of all funded awards are in compliance with federal and state statutes, policies, and procedures. provide leadership and decision-making in regards to electronic management, spon",
"sored projects workflow, and policies and procedures; maintain a culture of compliance in research administration. ").
IF (ResponseId="R_D30mtuevPAysInL") CurrentRoleLevelDetails=CONCAT("I am currently a Research Coordinator and and my duties include the following:  v Manage, monitor, a",
"nd report on research activities: - Establish and maintain the research related information system (research publications, Network membership, seminars, symposia, writing retreats) as day-to-day activ",
"ities.  - Working with individuals and thrust to collate information and liaise with Marketing Department to ensure that the school research website reflects all submitted projects and is up to date. ",
"- Act as a secretariat for the School Research Committee and assist Chairperson to compile and develop research outputs report for the submission to the Faculty of Humanities.  v Coordinating and Mana",
"ging Research Outputs matters: - Present the research outputs status/progress of the school at the School Research Committee and to all staff.  - Collate and accurately capture all research outputs on",
" Research XXXX System (XXXX). This include data collection and management. - Maintaining quality assurance for the captured research outputs. Ensuring that all supporting documents, such as compliant ",
"of peer review letters etc. are submitted with the research outputs if required.  - Work closely with the School Finance Officer and assist in managing XXXX money from the Research outputs are allocat",
"ed to rightful publishers.  - Ensure that updated research policies are adhered to by all academics, postgraduates, researchers, and visiting scholars. - Monitor and evaluate all research activities i",
"n the school. - Assist the Research Committee Chairperson compile Parliamentary Research report for submission to the Assistant Dean Research.  v Funding: - Source and circulate relevant calls proposa",
"ls and information on behalf of the XXXX and School Research Committee on funding opportunities.  - Assist in developing and writing funding proposals.  - Assist in collating contractual documents for",
" compliance to calls requirements.  - Keep track of new funders and new collaborators from national and international institutions.  - Assist PhD students with funding opportunities. - Work closely wi",
"th research clusters of the school to able to identify funding related to the cluster mandate.  v Provide Support for school writing retreats/workshops for proposal and funding writing, PhD writing, a",
"rticle writing etc.: - Organize capacity development training for staff and PhD students. This include, but not limited to, grant proposal writing, Manuscript writing, research report writing etc.  - ",
"Provide support in planning, coordinating and assist with logistical arrangements for the school periodic writing retreats. - Identity and communicate the dates with relevant stakeholders. - Monitor e",
"valuation reports from the writing retreats. v Administration and event coordination: - Partake in the School Research Committee meetings and prepare minutes. - Coordinate and support PhD and Postdoct",
"oral admin related activities in conjunction with the PhD coordinator. This involves, but not limited, assessing new PhD applications using ORACLE: People’s Soft. - Facilitate, and coordinate and atte",
"nd PhD proposal presentations/defend, as well as corresponds PhD related enquiries from students and prospective students. - Assist Head of School and Executive members with Strategic partnerships, co",
"ordination, and collaborations. Develop tracking tools of strategic partnership with the school. - Provide the efficient procurement support for the research related purchases and arrangement, within ",
"the confinement of Universities policies.   ").
IF (ResponseId="R_2Qm4AWDBP855uls") CurrentRoleLevelDetails=CONCAT("Lead proposal work and coordination activities of running projects, initiate a large set of proposal",
"s every year. Support researchers and other PM. Lead a PM team, not officially an office, but instead included in a lab. Currently coordinate the European XXXX-project XXXX and co-coordinate the Horiz",
"on 2020 ICT project XXXX. Also lead a set of other H2020 and domestic projects as local PI. ").
IF (ResponseId="R_vMM7kERlfufJqZX") CurrentRoleLevelDetails=CONCAT("Since August 2021 I coordinate implementation of the Ministry XXXX of Ukraine grant aimed at the lon",
"g-term development of the science direction 'XXXX' at the XXXX University of XXXX. I supervise team of one hundred and fifty people. • I coordinate implementation of the project 'XXXX” within Horizon ",
"2020 research and innovation program from XXXX University of XXXX side. I supervise four people within the project. • January XXXX – December XXXX I coordinated implementation of the project of the Mi",
"nistry of XXXX of Ukraine 'XXXX”. I supervised team of twenty-seven people. I planed, designed, conducted and reported on studies of XXXX within a project of the Ministry of XXXX of Ukraine 'XXXX”. • ",
"I plan, design conduct and report on long-term theoretical and experimental research on the XXXX project on investigation of XXXX. • I process and analyze obtained data, write scientific publications.",
" • I write quarterly and annual reports on investigated problems.  • I supervise PhD and Master students. • I review scientific papers in the following peer-reviewed journals: Chinese Journal of XXXX,",
" XXXX Journal, Journal of XXXX, Journal of XXXX, and Ukrainian Journal of XXXX. ").
IF (ResponseId="R_0vmcqonbhTBpAHf") CurrentRoleLevelDetails=CONCAT("Research Manager, Institute  § Oversee pre-award process, post-award prior approvals, review and app",
"roval of award terms, review and approval of unfunded agreements § Provide team daily guidance, instruction and training in all aspects of research administration § Collaborate with Institute leadersh",
"ip, central administrators, team, and faculty to ensure compliance in all grant activities § Serve as primary contact for Principal Investigators, and administrative staff throughout the life cycle of",
" all sponsored awards, providing support, guidance, education and training § Directly manage an assigned portfolio of faculty proposals and awards § Institute representative on XXXX Council (XXXX) and",
" XXXX (XXXX). Served on XXXX Process subcommittee for two years § Provide training forums to Institute trainees and administrators on various research administration topics").
IF (ResponseId="R_2BbmY2ntz5BX59r") CurrentRoleLevelDetails=CONCAT("Actualmente, como Vicerrector de Investigaciones, tengo la responsabilidad de fortalecer a la Instit",
"ución en la que me encuentro vinculado dentro del Sistema Nacional de XXXX – XXXX, de desarrollarla en concordancia con indicadores de nivel internacional, y gestionar recursos para las áreas de gener",
"ación de conocimiento, investigación creación, innovación y transferencia, editorial y difusión, formación en investigación-innovación.").
IF (ResponseId="R_bIpQQm2XujkUdFL") CurrentRoleLevelDetails=CONCAT("Gestión del proyecto XXXX (H2020 SwafS) y contribución a la implementación de otros proyectos con fi",
"nanciación europea: ECIU University XXXX (H2020 SwafS) , XXXX (EIT HEInnovate Initiative) ").
IF (ResponseId="R_2QibIJZYaBvfAAM") CurrentRoleLevelDetails=CONCAT("Research Administrator II:  • Review, analyze, and submit proposals and budgets for 3-departments’ f",
"aculty:   ENTOM, MICRO, and XXXX • Train 3-departmental RAs assistants as my replacements • Assists administrative staff and faculty in assessing funding opportunities. • Provides pre-award support wh",
"ich includes reviewing requests for proposal (RFP) and identifying the specific requirements and policies are met while ensuring the policies are within or consistent with those of UF; prepares accura",
"te budgets for each proposal • Assists with the development, management, authorization and transmittal of proposals to federal, state, and private funding agencies. • Reviews proposals for compliance ",
"with sponsor and University terms and rules, and review, negotiation and acceptance of resulting grant awards • Confer with investigators and campus administrators to ensure that changes or correction",
"s are made as needed. • Enter and update data on projects in XXXX system (XXXX Integrated Research Support Tool) cradle-to-grave.  • Create forms and tools for faculty and staff to assist in the devel",
"opment of proposals through awards. • Assists Division of Sponsored Programs (DSP) with proposals, agreements, and awards. • Respond to the concerns of 3-chairs • Assists with the reports, as needed f",
"or 3-department chairs  ").
IF (ResponseId="R_2zOV63ErbS5zBQt") CurrentRoleLevelDetails=CONCAT("Ejecución de estrategias de alcance nacional y departamental. Gestión ante XXXX. Gestión ante Mincie",
"ncias. Actividades de cooperación internacional. Busqueda de oportunidades de financiacion. Gestión de publicaciones científicas. ").
IF (ResponseId="R_3qIoWq2EOuGkq4r") CurrentRoleLevelDetails=CONCAT("I work as an alumni coordinator at XXXX University of XXXX. My role is: * to develop strategy of alu",
"mni services including online and offline PR & marketing,  * build and follow up partnerships of the university * organize projects related to alumni between faculties and units. * build fundraising s",
"trategy and manage fundraising.").
IF (ResponseId="R_3kOk9btNNygLXFf") CurrentRoleLevelDetails=CONCAT("I work at XXXX as a Research Programmes Manager where I manage a large research Centre, supporting t",
"he operational, strategy and development aspects. This involves creating and managing processes, reporting, handling finances, identifying opportunities, contributing to grant writing etc. ").
IF (ResponseId="R_1hXZE2GdXVD7p6A") CurrentRoleLevelDetails=CONCAT("Work as a department level employee in a 'XXXX' at the XXXX University where we serve three schools ",
"(School of Medicine, School of Engineering, and Applied Sciences, and the School of Nursing). I am still in a pre-award role and work very independently, often advising or mentoring my colleagues. I h",
"ave experience with most federal funding agencies and many foundations. I work with contracts, sub-awards, and some corportate entities.").
IF (ResponseId="R_2471V3AxhmfhKeq") CurrentRoleLevelDetails=CONCAT("I am the Senior Grants Manager for a lab at XXXX. I manage a team of three and am responsible for ma",
"naging specific grants as well as developing and managing overall budgets and long term financial plans for our unit. ").
IF (ResponseId="R_7O6eJj89Q89k7g5") CurrentRoleLevelDetails=CONCAT("I am a pre-award research administrator at XXXX State. I manage my own portfolio and occasionally tr",
"ain department-level research administrators, but overall do not have a managerial role. ").
IF (ResponseId="R_2rONMq9T3mvmWV3") CurrentRoleLevelDetails=CONCAT("I am executive director of the Research Development Office (RDO) at the University of XXXX, a major ",
"public R1 university in the US. The 8-person RDO team supports institutional research goals through a broad array of activities: intra- and inter-institutional collaboration and large grant developmen",
"t support; management of intramural funding competitions, limited submission selection, and a T32 trainee tracking system; as well as facilitation of faculty development and campus strategic initiativ",
"es.  I am also a very active member of the National Organization of Research Development Professionals (NORDP). ").
IF (ResponseId="R_2xJWNpVMNta7uMU") CurrentRoleLevelDetails=CONCAT("I am currently Director of Proposal Development for XXXX's Institute for International Business in t",
"he XXXX School of Business. This is an international development unit situated within a business school. In this role, I carry out all of the duties of a research development specialist, but in additi",
"on, I am on the senior team of the institute and participate in discussions about the institute's strategy and tactics on a regular basis. I have also designed and currently maintain a proposal librar",
"y, as well as a library of proposal development resources. In addition, I have created a database of all proposals and awards for the unit since its establishment that we use to run reports on current",
" and historical proposal activity. Recently, I have also taken on monitoring and evaluation and other data-related duties.").
IF (ResponseId="R_2eWmzCm2TVHPMoV") CurrentRoleLevelDetails=CONCAT("Senior Advisor en la Oficina de Proyectos Internacionales de la Universidad XXXX de XXXX.  Promoción",
" de oportunidades de financiación europea e internacional en el ámbito de las ciencias sociales y las humanidades. Asesoramiento integral en fase de elaboración de propuesta y negociación hasta firma ",
"de contrato e inicio de proyecto ").
IF (ResponseId="R_zT2eNBT6YR3Iuw9") CurrentRoleLevelDetails=CONCAT("In the XXXX my role, moved to the Graduate School and reduced my hours to 0.6fte, and I was no longe",
"r a Management Account, but became Finance Manager - PGR Studentships. Over the intervening years, my role has become FT and I have continued to act as the Grant Manager for all Training Grants.  I wa",
"s solely responsible for all Studentships on UKRI Training Grants (including the Matched Funds), Wellcome Trust PhD Programmes, Charity funded and our own Centrally funded studentships in April XXXX a",
" new post was recruited to and I have responsibility for Training and managing the workload of a Finance Co-ordinator although I do not line manage the post.").
IF (ResponseId="R_3KZOEwXOAfmrPm4") CurrentRoleLevelDetails=CONCAT("Since XXXX, I have been the chief manager of the Ministry XXXX of Ukraine grant aimed at the long-te",
"rm development of the science direction 'XXXX' at the XXXX University of XXXX (XXXX) , Ukraine (I supervise team of 54 people).").
IF (ResponseId="R_25So3JfZpA5fOEY") CurrentRoleLevelDetails=CONCAT("Working as Academic coordinator & IRB Secretariat in XXXX Medical Center XXXX from XXXX Feb till dat",
"e. 1.Academics:  My job responsibility is to work as a team under XXXX Academic division and coordinating different  administrative work for the ongoing following academic courses: i)National Board of",
" Examination in Medical Sciences (DNB/DrNB/FNBCOURSES) recognized 8 courses;  ii)IIT Kharagpur recognized 4 MSc , integrated PhD ;  iii)Paramedical 5 courses 2.Institutional Review Board (IRB)  I work",
" as a part of XXXX IRB Secretariat office and following are my responsibilities being a part of the IRB team: i)Keeping documentation for the Protocols with corrections, Protocol Termination, CIOMS, S",
"USARS, EC Notifications for the ongoing IRB approved studies ii)Conducting regular trainings of the IRB members iii)Coordinating with DCGI regarding the pharma trials related serious adverse events iv",
")Handle and Coordinate with XXXX Quality team for the yearly internal audit  v)Handle and Coordinate with NABH audit and also IRB NABH related work vi)Handle and update the IRB SOPs vii)Handle archiva",
"l procedure for the closed studies with XXXX  ").
IF (ResponseId="R_2tchnU0EKlxDrQE") CurrentRoleLevelDetails=CONCAT("This role is the job of a super administrator.  I'm the Administrator for the XXXX Center, Systems a",
"nd Computation Biology and The XXXX Institute.  and The grant admin. for: emergency medicine and anesthesiology .  ").
IF (ResponseId="R_voRnmOMGPrbxo09") CurrentRoleLevelDetails=CONCAT("In July of 2021 my boss took another position at XXXX. I quickly assumed some of her responsibilitie",
"s which includes directing our training programs and educational activities. I do work alongside our faculty lead with his input. I am responsible for our the administrative duties. We did hire a coor",
"dinator who is assuming many of my previous responsibilities.").
IF (ResponseId="R_2c9OiCraCkmYXRL") CurrentRoleLevelDetails=CONCAT("Platform Manager for a new centrally supported team (XXXX Data Analytics Platform). Responsibilities",
": People management, Operations, Budgeting, Research Event coordination, Liaison with stakeholders across the University, Website Maintenance, Communications, Recruitment.").
IF (ResponseId="R_pQX16rTVaMVrZYZ") CurrentRoleLevelDetails=CONCAT("I am the director of research administration and financial operations for the Dept. of Internal Medi",
"cine where I've worked for 31 years (42 total at Univ. of XXXX).  I'm responsible for pre and post award administration, space and equipment as well as all other funds related to the total operation o",
"f the department.  We have &gt;350 FTE of faculty totaling about $80M per year.").
IF (ResponseId="R_3PcrUBXAkYbIIft") CurrentRoleLevelDetails=CONCAT("I have been acting as Vice Director of Collaborative Innovation Center and Executive Board Member of",
" XXXX Lab for Media Convergence and Communication, XXXX University of XXXX since the year of XXXX. I am in charge of scientific research and innovation management, international and domestic collabora",
"tion management, and scientifi research infrustructure building of the XXXX Lab and Collaborative Innovation Center, which is the integration of 27 research institutes and key labs , and flagship of s",
"cientific research work of the university. ").
IF (ResponseId="R_1FRFo84oRCkggVH") CurrentRoleLevelDetails=CONCAT("Current role is 70% Research Administration and 30% Academic/Administrative support. Provide EECS fa",
"culty with financial and research administrative support,  with research hiring, cost centre oversee and grant administration;  provide back up support to the undergraduate program during peak  period",
"s, administrative support to the Department Curriculum  Committees, and general administrative support to the department.  Review and assists EECS Principal Investigators (PI’s) in the completion  of ",
"all relevant forms including claims for reimbursement (hard copy  and/or electronic), personal advance clearing, cheque requisitions,  and purchase order requisitions (hard copy and/or electronic). Ch",
"eck  for proper authorization, mathematical accuracy, completeness and  accuracy of fund, cost center, and general ledger account.  Confirm eligibility of expenditures against agency guidelines and XX",
"XX University policies and procedures.  Review e-Reports to ensure that sufficient funds are available before  processing expenditure claims, cheque requisitions, invoices, journal  entries, and Emplo",
"yee Transaction Forms (ETF’s).  Review assigned cost centers with PI’s by accessing e-Reports to ensure  sufficient funds are available for charges.  Identify cost centre overspends and communicates t",
"hese to the  appropriate PI and Prepares correcting journal entries as required.  Prepare accurate and timely ETF’s as directed, ensuring that contract  end dates do not exceed the grant end dates and",
" prepares revised  ETF’s when required. Provides information on payroll and timesheet  processes as required.  Ensure proper record keeping and documentation retention practices  to facilitate audits ",
"by granting agencies and internal audits.  Forwards financial reports, such as form 300’s, received from Research  Accounting to PI’s and/or designates and obtain approval signatures  before returning",
" to Research Accounting by the stipulated deadline  date.  Prepares requests for invoices where applicable and sends to Research  Accounting.  Assists in gathering and preparing information required f",
"or on demand  audits both external and internal.  Assists PI’s in the procurement of research goods and services to ensure  compliance with Procurement policies and procedures; ensures proper  complet",
"ion of procurement forms including cost center information.  Maintain original receipts/documentation in a well-organized filing  system consistent with XXXX University policy.  Reallocate expenditure",
"s charged with a purchasing card to  appropriate cost centres as necessary. Obtains sign off purchasing  card statement from the appropriate PI.  Handle inquiries from graduate students and direct the",
"m to resources  for processing expenses.  (Provide ongoing support and in particular back up support during  peak periods (beginning of terms: Fall, Winter, Summer).  Process various forms in consulta",
"tion with Program Support Assistant  and Undergraduate Vice Chairs including deferred standing  agreements, letters of permission (LOP’s), grade change notifications  and request/petition to enroll la",
"te forms; issues permissions to enroll.  Provides support to maintain up to date student files including grades  and course performance summary forms (CPS). Provide administrative support to the Depar",
"tment Curriculum  Committees: schedules committee meetings, reserves meeting rooms;  establishes committee meeting agenda in consultation with the Vice  Chairs, compiles and distributes agenda materia",
"ls, attends committee  meetings, minute-taking; liaisons between Curriculum Committees  (gathering and distributing information)  Support curriculum management processes by preparing  documentation fo",
"r course and program changes and updates.  Support faculty search, Tenure and Promotion (T&P)").
IF (ResponseId="R_2EFubkvxmhui357") CurrentRoleLevelDetails=CONCAT("Since end of 2021, Director of Sponsored Research at XXXX University in XXXX, Canada. Leading the of",
"fice,  made of 3 teams: preaward (including submission of proposals and negotiation of funding agreements and contracts/postaward / institutional data and stats). 32 staff members.").
IF (ResponseId="R_3iJYkTgeo1OjDaO") CurrentRoleLevelDetails=CONCAT("I'm the Financial Research Account Manager at XXXX's Office of Sponsored Programs. I oversee the Fin",
"ancial Research Accountants and work with our Associate Director of Financial Compliance in audits, SEFA reporting, HERD reporting, etc.").
IF (ResponseId="R_21BpQWuBf05Vfdu") CurrentRoleLevelDetails=CONCAT("The Research Hub Coordinator providing a full range of operational support and project management to",
" the Director of the ARC XXXX Research Hub (ARC XXXX), including but not limited to the management of financial and KPI reporting, project tracking, human resources, and communications and provides hi",
"gh level support to the Research hub Director by contributing to the development of plans and reports for research projects; actively managing a diverse range of strategic and marketing functions that",
" impact research; financial reporting and ensuring compliance with relevant legislation including work health and safety and risk management requirements.").
IF (ResponseId="R_wZem8cP1mki6wXT") CurrentRoleLevelDetails=CONCAT("I am currently Manager, Research Support and Development in the University of XXXX Business School. ",
" I lead a team of research support officers to provide research support across the Business School.  I develop strategies and processes to improve the support processes.").
IF (ResponseId="R_2aLHyMJBw8s3YZv") CurrentRoleLevelDetails=CONCAT("Coordinator of XXXX IMPACT, the knowledge and technology transfer support arm of XXXX University XXX",
"X. We support and develop initiatives that add social or economic value, based on the knowledge produced at XXXX, promoting a knowledge-based and high-impact value creation activity through collaborat",
"ions with society and industry. We set up new programs to encourage entrepreneurship and new cross-cutting initiatives to strengthen collaboration with businesses. ").
IF (ResponseId="R_XoeES5Lz2HRTKLv") CurrentRoleLevelDetails=CONCAT("Since 7/2017: • Complex proposal development and submission: partnered (2; NIH P50, U54) or led (2 N",
"IH P01, NIH P30, NIH P50, NIH R25,  2 DoD Focused Program Awards, NIH U19 and U54 in development).   • Developmental and/or editorial support for NIH, NSF, and foundation proposals (16 NIH R01s, NIH S",
"10, NIH U01, NIH UG3/UH3, NIH DP1, NSF Major Research Instrumentation, NSF EDGE, XXXX Center (Institutional Development Grant), XXXX Discovery Institute, XXXX Foundation.  • Since June 2018, supported",
" submission of 105 proposals to 22 DoD Congressionally Directed Medical Research Programs.  Develop tracking sheets (required submission documents) and templates for required documents (with solicitat",
"ion guidelines and review criteria integrated); higher degree of support for 39 of these proposals (e.g., review).  • Template development: NIH R01, R21, P/U, Cancer Center Support Grant, SPORE, NCI P",
"01; NSF, U54, DoD Broad Agency Announcement and CDMRP solicitations • Development of online repository for R01, R21, and complex grant development support including tracking sheets for required docume",
"nts, templates for required documents that integrate NIH guidelines and review criteria, writing tips integrating guidance from the Grant Writer’s Application Workshop (Russell & Morrison 2017) with S",
"chool of Medicine Office of Research Development’s accrued knowledge, other supports (e.g., letter of support templates, timelines for development, references related to rigor and reproducibility, sex",
" as a biological variable)  • Proposal tracking sheet development: NIH K and F, NSF, DoD BAA and CDMRP solicitations • Connect School of Medicine faculty to relevant opportunities published by the Med",
"ical Technology Enterprise Consortium and the Medical CBRN (Chemical, Biological, Radiological and Nuclear) Defense Consortium").
IF (ResponseId="R_voSw84irNP4aL5L") CurrentRoleLevelDetails=CONCAT("Today I serve as Research Development Strategist at University of XXXX. I run an interdisciplinary s",
"eed grant program to increase collaborative projects among researchers at our XXXX campus and those at our XXXX Medical Campus and am now expanding the program to include the other two campuses in our",
" system. I also am leading the development of Strategic Intelligence services in the area of bioscience and biomedical research, and I work 25% with our Industry and Foundation Relations team in Advan",
"cement to expand our bioscience research enterprise. ").
IF (ResponseId="R_2zr6Wv7XhMSRI0f") CurrentRoleLevelDetails=CONCAT("Project coordinator at the University of XXXX ‣ Coordination of a newly founded research centre as p",
"art of its steering group ‣ Linking the centre to all other administrative units of the University and externals and orchestrating the respective processes (HR, finances, other research support servic",
"es such as legal service, research funding services, university management, funding bodies, external service providers, etc.) ‣ Support with funding applications, reporting, contracts/agreements, outr",
"each ‣ Proofreading and copy-editing of academic and non-academic material ‣ Organisation of meetings, workshops, conferences").
IF (ResponseId="R_1d072mTPfQb7vUo") CurrentRoleLevelDetails=CONCAT("I got a RMA job at Ac at Academic Research Organization( ARO) attached to XXXX University Hospital, ",
"Japan. My daily operational task is to correspondence with a funding agency, to support researchers to prepare in grant application documents, progress reports and final reports from the admirative pe",
"rspective. My position is under the director of my institution, so I support leaders to make dictions on strategic functions.").
IF (ResponseId="R_1kTggimtBaWH8tZ") CurrentRoleLevelDetails=CONCAT("Publishing Policies Manager at a Research Support Office of University School: Decision support anal",
"ysis on Open Science Policies and Scholarly Publishing; Advocacy and support of best practices; Monitoring of in-house publishing; Promoting activities of communication and training; team member of th",
"e pilot-project 'XXXX”.").
IF (ResponseId="R_2VfI8miujZiMMbG") CurrentRoleLevelDetails=CONCAT("I work for the Faculty of Science at the University of XXXX, assisting ARC and NHMRC applicants to a",
"pply for funding. It is a 'box-drop' office - the volume is too high (and the applicants too expert) for us to read individual applications. ").
IF (ResponseId="R_2SwTWYjsADfDlZE") CurrentRoleLevelDetails=CONCAT("Now I am a Research Administrator III at XXXX in the Central Office Proposal Team. I am supervise an",
"d submit proposals for College of XXXX, College of XXXX, and Institute for XXXX. I supervise and train Proposal Specialist II. I also enrolled in MRA and will be graduating in XXXX").
IF (ResponseId="R_C2fPRrRyBAcFCHT") CurrentRoleLevelDetails=CONCAT("• Updating the Office of Sponsored Programs and Research Services (OSPRS) website to raise awareness",
" of grant opportunities.  • Provide resources for faculty and staff interested in seeking and/or applying for external funding.  • Provide pre-award services to the faculty and staff across XXXX Unive",
"rsity  • Processing application through the internal cayuse database • Assist departmental faculty/principal investigators (PIs) in the development, preparation, and submission of grant and contract p",
"roposals. • Ensure all applications meet agency and university guidelines and published timetables and deadlines, including management of the just-in-time process.  • Confers with Pl at collaborating ",
"institutions to secure necessary sub-award documents for proposals.  • Assists Pl's in the development of budgets and budget justification.  • Create a proposal checklist for Pl based on solicitation ",
"requirements.  • Generates current and pending reports for Pl.  • Reviews all final proposal documents for consistency and compliance with sponsor guidelines and university policies.  • Advises Pl on ",
"any changes needed with proposal documents.  • Ensure all materials required for a full submission are prepared and obtain institutional approvals before completing proposal submission.  • Submits pro",
"posals to sponsors once the proposal is compliant. ").
IF (ResponseId="R_3neffvdQrzOhtVP") CurrentRoleLevelDetails=CONCAT("In my current role, I serve as the Director of Grants and Contracts for seven hospitals and a biomed",
"ical research institute in two states (XXXX). I was brought on board to create the first grants and contracts office in the network's history. I currently supervise a proposal writer and a Senior Gran",
"ts Accountant with another open position for a Grants Administrator. As our award portfolio grows, I expect to add proposal writers for each service line (i.e., surgery, oncology), post award support ",
"positions, and contract negotiators. These positions will report up to me, at least initially.").
IF (ResponseId="R_Avxp1lQ7poNbNSx") CurrentRoleLevelDetails=CONCAT("I provide leadership, planning, and operational management/oversight for sponsored project Post-Awar",
"d administration. I aggressively pursue process simplification and improved systems to better research administration practices at XXXX. oversees the supervision of staff involved with the administrat",
"ion of grants and contracts (four post-award teams, Financial Services, and a support team). I provide direction and oversight of professional staff with responsibility for personnel decisions includi",
"ng hiring, termination, evaluation, training, and promotion; determines priorities and work assignments. I develop staff to support University priorities and to better establish OVPR SPS as a Center o",
"f Excellence in providing research administration guidance and services. I lead teams to facilitate research and provide proper stewardship of sponsored funds. I oversee sponsored program accounts rec",
"eivable functions to include billing, reporting, and collections. I oversee post-award team compliance to meet uniform guidance, sponsor, and university requirements.   I manage, plan, and evaluate un",
"it operations, actions, and responsibilities to assure compliance with all relevant federal and state laws and University and sponsor policies and regulations. I lead and serve as the SPS point of con",
"tact with external and internal auditors and sponsors as needed. I develop, implement, evaluate, and/or revise Post-Award policies and procedures, and collaborates with other directors and University ",
"offices in the development of research administration policies and procedures. I establish operating procedures to increase consistent practices and achieve a reputation of predictable, client-facing,",
" excellent service to XXXX investigators and staff. I along with the OVPR SPS Training and Education Manager, leads research administration education and training programs for Post -Award activities f",
"or XXXX staff and investigators").
IF (ResponseId="R_3snnSHhQCIZSxa6") CurrentRoleLevelDetails=CONCAT("Head of Research Administration at The XXXX Academy - XXXX. We are a small research administration a",
"t a small research institution. We cover ph.d.-administration, pre-award, quality assurance, supporting local and institutional research fora, strategic processes etc. ").
IF (ResponseId="R_sbW6XIqquKZYH4t") CurrentRoleLevelDetails=CONCAT("I am a Senior Sponsored Research Financial Analyst in the central post-award research office at XXXX",
" University. In this role I am responsible for: monthly invoicing for grants, reviewing financial status reports for submission to the sponsor reviewing retroactive salary transfers, carryover request",
"s, reviewing award setup within the University's management system, institutional award closeout, etc.").
IF (ResponseId="R_Djfmsq2rZA6M7Op") CurrentRoleLevelDetails=CONCAT("I am the director of the Office of Research Administration in the College of Education at XXXX. I su",
"pervise 8 staff, two of which work in post-award, the rest in pre-award. One is a grad student who supports other grad students in the College in seeking grant funding. I report to the Associate Dean ",
"for Research. ").
IF (ResponseId="R_1LBFYZkKDnS27vL") CurrentRoleLevelDetails=CONCAT("co-leader of the Research Academy in the College of Agriculture, Consumer and Environmental Sciences",
" at the University of XXXX; professional curriculum development for new assistant researchers; grant writer; funding identifier; mentor; member of executive committee of the campus Research Developmen",
"t Community").
IF (ResponseId="R_1rvv8r4UQp9UrdT") CurrentRoleLevelDetails=CONCAT("I am a Research Office Manager, in a Research Office at Computer Institute in XXXX. I am responsible",
" for contact and meetings with national, multinational and foreign companies such as Intel, Samsung, AT&T, IBM, CI&T, Griaule, Motorola, Banco Bradesco; National and foreign research centers such as I",
"nstituto Eldorado, ETRI (South Korea). I am in direct contact with the Rectory and responsible for contacting funding agencies such as FAPESP and CNPq and stakeholders such as Funcamp and Softex. I he",
"lp IC researchers in preparing research projects with funding agencies and companies and do project accountability with FAPESP and CNPq agencies. I have two interns under my supervision who make purch",
"ases, quotes and submit grants for agreements. I am responsible for the financial management of researchers' accounts with FAPESP and CNPq and support the processing of all IC agreements, with draftin",
"g of minutes and amendments in Portuguese and English.").
IF (ResponseId="R_1DI3VxMq2EW3DSF") CurrentRoleLevelDetails=CONCAT("Heading up a new function at XXXX - Major Initiatives which provides bespoke support and advice to R",
"esearchers and Research Offices applying to major funding initiatives as well as developing pipeline of major funding applications across the University").
EXECUTE.

* FirstEmploymentSta
* is new for RAAAP-3.
RENAME VARIABLES EmploymentSta_First=FirstEmploymentStatus.
VARIABLE LABELS FirstEmploymentStatus "3f. First Employment Status".
MISSING VALUES FirstEmploymentStatus (-99).
ADD VALUE LABELS FirstEmploymentStatus -99 "No Response".
VARIABLE LEVEL FirstEmploymentStatus (NOMINAL).
EXECUTE.

* CurrentEmploymentSta
* is the CurrentEmploymentStatus - a match for RAAAP-1/2.
RENAME VARIABLES EmploymentSta_Current=CurrentEmploymentStatus.
VARIABLE LABELS CurrentEmploymentStatus "3. Current Employment Status".
MISSING VALUES CurrentEmploymentStatus (-99).
ADD VALUE LABELS CurrentEmploymentStatus -99 "No Response".
VARIABLE LEVEL CurrentEmploymentStatus (NOMINAL).
EXECUTE.

* CurrentEmploymentSD.
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES EmploymentSD=EmploymentStatusDetails.
VARIABLE LABELS EmploymentStatusDetails "3a. Details of employment status".
RECODE EmploymentStatusDetails ("-99"="").
MISSING VALUES EmploymentStatusDetails ("").
VALUE LABELS EmploymentStatusDetails "" "No Response".
EXECUTE.

* *** backcoding from EmploymentStatusDetails - CO.
IF (ResponseId="R_1FJJMwUcr5jqE0Y") FirstEmploymentStatus=10. /* no need to check as the filter was for FirstEmploymentStatus being blank.
IF ((ResponseId="R_XCam2lxqXIKwybv") AND SYSMIS(CurrentEmploymentStatus)) CurrentEmploymentStatus=10.
IF ((ResponseId="R_ZL7W18wTaNOZTmV") AND SYSMIS(CurrentEmploymentStatus)) CurrentEmploymentStatus=13.
IF (ResponseId="R_11hbMxg2htTYHqM") CurrentEmploymentStatus=10.
IF (ResponseId="R_RwBuZxLt8U8DeLf") CurrentEmploymentStatus=14.
IF (ResponseId="R_2SBpO2uGZTqcuVf") CurrentEmploymentStatus=14.
IF (ResponseId="R_XYRqTL2TBWObdF7") CurrentEmploymentStatus=10.
IF (ResponseId="R_pxQPumBJiE8BThv") CurrentEmploymentStatus=10.
IF (ResponseId="R_1Fwu9PMbwqC4ySv") CurrentEmploymentStatus=10.
IF (ResponseId="R_3RmFyt7FA5p8oNA") CurrentEmploymentStatus=18.
EXECUTE.

* *** anonymising EmploymentStatusDetails - CO.
IF (ResponseId="R_1F2LBqxhyel8W6j") EmploymentStatusDetails=CONCAT("I was employed since January 2017, full time on a contractual basis yearly at XXXX to provide admini",
"strative research support to support staff. This has not changed. I am still employed at XXXX full time on a yearly contractual basis to support, support staff with their research requirements.").
IF (ResponseId="R_3j2nGGdrTElITw0") EmploymentStatusDetails="I hold two poistions : ABS officer at XXXX and international cooperation officer in a European research infrastructure".
IF (ResponseId="R_2QibIJZYaBvfAAM") EmploymentStatusDetails="My RMA positions over my career have all been full-time (40/hours+) at XXXX covering sponsored programs including research, academic, and extensions services/Other programs.".
IF (ResponseId="R_24hGeKAxTWgPNAh") EmploymentStatusDetails="Coordino el XXXX de la Universidad XXXX y en simultánea realizo actividades de docencia e investigación.".
IF (ResponseId="R_3NHT1j3rde9I4Ll") EmploymentStatusDetails="Asistente de supervisión y monitoreo de proyectos de investigación con financiamiento de la XXXX y coordinador administrativo de 2 proyectos de investigación con financiamiento externo".
IF (ResponseId="R_3ikzEOBvDhDciL6") EmploymentStatusDetails=CONCAT("I work in the Texas XXXX University Sponsored Research Services Office (SRS.   This is a central off",
"ice that performs the full life cycle of sponsored research with approximately 190 employees.").
IF (ResponseId="R_uh2Kn1WtoHbLq6Z") EmploymentStatusDetails="Trabajo en la Vicerrectoría de Investigación de la XXXX con una experiencia de 25 años en el manejo operativo de los procesos de investigación, tiempo completo".
IF (ResponseId="R_20U6f6rLkppHvHR") EmploymentStatusDetails="They were both full-time roles at XXXX within the same CTSA department.".
IF (ResponseId="R_3KZOEwXOAfmrPm4") EmploymentStatusDetails=CONCAT("RMA role:  Main activities and responsibilities: stimulating fundamental and applied scientific rese",
"arch in the field of natural sciences at the XXXX University of Kyiv by establishing scientific and technical cooperation between scientific institutions (preparation of grants (scientific part and fi",
"nancial part)) and higher educational institutions both in Ukraine and abroad. My direct responsibilities: 1. formation of a scientific team capable of fulfilling the assigned scientific task 2. manag",
"ement when writing an application for a scientific grant, namely, coordination of the work of individual scientific groups in the formation of an application 3. management of the financial part of the",
" grant application, namely, the calculation of costing, the formation of a list of purchases of scientific equipment necessary for research 4. Management of the conduct of scientific research within t",
"he framework of the grant, preparation of both scientific and financial reports  Science role: • I plan, design conduct and report on long-term theoretical and experimental research on the green chemi",
"stry project on investigation of ionic liquids, Ionic liquids solutions under external damage by means of molecular simulation and experimental methods. • I process and analyze obtained data, wrote sc",
"ientific publications. Principal Research Scientist of the Faculty of Physics, Research and Project Manager XXXX University of Kyiv, Faculty of Physics• I deliver seminars and special courses to stude",
"stry project on investigation of ionic liquids, Ionic liquids solutions under external damage by means of molecular simulation and experimental methods. • I process and analyze obtained data, wrote sc",
" following peer-reviewed journals. • As a permanent member of the Ukrainian As a permanent member of the Ukrainian XXXX, I select conference abstracts.").
IF (ResponseId="R_1r7zno94TaEJ42Y") EmploymentStatusDetails=CONCAT("Before retirement I had been full time RMA at University of XXXX (NZ) for 20 years, Landcare Researc",
"h (XXXX Research Institute) for 9 years. Prior to that I was full time in a research field for 10 years.").
IF (ResponseId="R_3jdK7DKNO0jBAsO") EmploymentStatusDetails=CONCAT("I was a full time staff of the Office of Research, Innovation and Development at the University of X",
"XXX between January 2018 and December, 2020.  I am currently a full-time staff at the University of XXXX , leading the creation and establishment of a robust Research office at the Institution.").
IF (ResponseId="R_2c9OiCraCkmYXRL") EmploymentStatusDetails="First RMA role was Research Manager for XXXX (0.6) & Academic Convenor for interdisciplinary network (XXXX Research Initiative)".
IF (ResponseId="R_1C1Pow6FoX9Xawc") EmploymentStatusDetails="Together with my work on XXXX officer, I am also EIC (XXXX and XXXX) officer and Open Science specialist".
IF (ResponseId="R_Wxi460SuFKndMd3") EmploymentStatusDetails="employed at XXXX University for 4 years +".
IF (ResponseId="R_2uKDbVV1Gpqop5v") EmploymentStatusDetails=CONCAT("I started as a researcher, and soon after I started to assist in the research group's management, an",
"d on the strategic decision making and after that in the management of the research unit. As my research group had strong activity in cooperation initiatives with external entities, I was appointed he",
"ad of the XXXX office. After that, I").
IF (ResponseId="R_OlIRDhMSx9hSnDz") EmploymentStatusDetails=CONCAT("Focus areas: European funding (application processes, impact, implementation and management), projec",
"t coordination, and other external grants to researchers. Horizon 2020 (and earlier programs), LIFE and Interreg as main programs. Financial/administrative and tourism/environmental/renewably energy c",
"onsultancy tasks related to EU financed projects/programs. Service management concept. I have been Manager/Coordinator for several international projects. Process leader for EC project applications. I",
"nternal education to researchers and administrative staff in European funding. Global networking for research exchange and Horizon 2020 applications. Participating in several global network and Brusse",
"ls cooperation. I have a big network in Europe, Brussels and South/North America, (both in private and working areas) in different EC programmes.   Background Some of my experience: Working as monitor",
" for the European Commission (EC) XXXX with responsibility for Swedish and Danish nature and environment projects (LIFE). Swedish Environmental Protection Agency (SEPA) XXXX. National advisor to XXXX ",
"for the yearly Swedish applications in the LIFE nature and environment program in EU. 6th framework program DG TREN, CIVITAS XXXX International Financial and administrative Coordinator, project manage",
"ment, 32 partners in Europe. 52 measures in environmental issues. XXXX Department. EU Coordinator for the XXXX , Sweden in XXXX. Education, networking and training in EC projects. Implementation of EC",
"for the yearly Swedish applications in the LIFE nature and environment program in EU. 6th framework program DG TREN, CIVITAS XXXX International Financial and administrative Coordinator, project manage",
"o XXXX (which is connected to 7th framework programme in Brussels) in Stockholm and helps the regions to inform about EC programmes and help to start EC projects. XXXX --, financial/adm consultant and advisor for pr").
* ** NB these ones below were somehow misaligned with ResponseIds - the above coding has been fixed by hand.
IF (ResponseId="R_24IPqhS6kjx30op") EmploymentStatusDetails="Both my roles have been full time at XXXX".
IF (ResponseId="R_3r3fIdp4j3wz6Ku") EmploymentStatusDetails=CONCAT("First I was employed at The XXXX regional authority which is a really rigid organisation and my role",
" was strictly defined in one way. Now I´m working at XXXX University and the range of my RMA responsibilities is widely open.").
IF (ResponseId="R_5aKA4slvoJPK86Z") EmploymentStatusDetails="I was the XXXX intern first then I received a contract from the University of XXXX after my internship.".
IF (ResponseId="R_2czJ1j4wUFO5A8x") EmploymentStatusDetails="First: full-time all-in responsible for everything RMA Current: full-time RMA and KTO plus CEO of XXXX.".
IF (ResponseId="R_voSw84irNP4aL5L") EmploymentStatusDetails=CONCAT("I have worked as a full-time RD professional since 1992 in positions supporting interdisciplinary co",
"llaborative bioscience research at XXXX, University of XXXX Chicago, University of XXXX, XXXX University in St. Louis, XXXX University and now University of XXXX.").
IF (ResponseId="R_10PFeVVGJFYjYZw") EmploymentStatusDetails="Have been full-time research development (RD) since 2004. Started as RD Officer at UC XXXX, led two large RD offices, now an independent RD consultant with 70+ clients or former clients.".
IF (ResponseId="R_2qDfMgnYuBNCIK2") EmploymentStatusDetails="In XXXX".
IF (ResponseId="R_1Fwu9PMbwqC4ySv") EmploymentStatusDetails="I am a XXXX Awards Officer, full time permanent position".
IF (ResponseId="R_2rTw25ib3qpk37K") EmploymentStatusDetails="Full time employee for the Grant office at University of XXXX Italy".
IF (ResponseId="R_eKviY03SM54zToZ") EmploymentStatusDetails="Management Information Analyst at University of XXXX".
IF (ResponseId="R_eyus19fdMG1cxJn") EmploymentStatusDetails="In both roles, I've had an unpaid research role at XXXX Centre of Latin American Studies.".
IF (ResponseId="R_1eS0tq2DNtEx7kv") EmploymentStatusDetails="Scientific Research and Information Service Office at XXXX has also other administartion role.".
IF (ResponseId="R_1LtxjdfkXzKEuAw") EmploymentStatusDetails="My first RMA role was in the XXXX Research Support Office and it was a full-time job. I'm now a Research Strategy Manager which is also a full time RMA role.".
IF (ResponseId="R_3HG3FYdR50tgX35") EmploymentStatusDetails=CONCAT("My first role was supporting researchers in the Department of Pediatrics at the University of XXXX (",
"USA) and then XXXX Children's Hospital. Now I am full time employed as Director of Pre-Award at the University of XXXX (AUS)").
IF (ResponseId="R_1llOY5GFSrFD9nS") EmploymentStatusDetails=CONCAT("Prepare project proposals by determining concept, gathering and formatting information, writing draf",
"ts and obtaining approvals Research grant opportunities from government and non-government agencies Draft Memorandum of Understanding between organizations Craft speeches for Chief Guest (Convocation,",
" Training, XXXX) Conduct Interviews of Senior Management of XXXX University to provide information about different departments to parents and students Develop contents for blogs, articles, social medi",
"a and FDA’s website Proof read and edit website and newspaper articles before publication Identify, develop & manage FDA’s contacts with other national universities/institutions to create collaborativ",
"e environment Identify and assess future and current training needs through market analysis & consultation with training participants, their managers & human resource department Write training proposa",
"ls by assembling information including training objectives and outcomes Design capacity building modules along with training schedules & pre and post assessment test Prepare Course Packs/ Dossier of d",
"ifferent training modules Formulate capacity building development plan / training calendar Ensure quality of training contents are in-line with commitment made in the project documents Identify and se",
"lect resource persons for training courses Prepare & implement staffing plans, work plans & budget Conduct effective induction and orientation sessions Monitor, review & measure the progress of traine",
"ifferent training modules Formulate capacity building development plan / training calendar Ensure quality of training contents are in-line with commitment made in the project documents Identify and se",
"d management Maintain effective communication with trainees regarding the progress & development").
* *** NB these ones above were  somehow misaligned with ResponseIds - the above coding has been fixed by hand.
IF (ResponseId="R_1QL9yXWmXFaqCm0") EmploymentStatusDetails=CONCAT("Soy biólogo, con interés en la taxonomía botánica. Desde mis inicios trabaje en el Museo de mi unive",
"rsidad y alli teníamos que hacer de todo, desde el presupuesto de la oficina, los tramites administrativos, coordinar las visitas guiadas, hasta la publicación de artículos de nuevas especies (También",
" fui editor de la revista XXXX). Una vez creado el Vicerrectorado de Investigación, me destacaron allá para apoyar las actividades en XXXX. Estoy allí desde entonces, brindando soporte a las nuevas of",
"icinas que están realizando actividades en I+D+i").
IF (ResponseId="R_2Qm4AWDBP855uls") EmploymentStatusDetails=CONCAT("I have turned to actually coordinate large European projects, as XXXX (with 32 beneficiaries and 25 ",
"M€ budget) beside my supporting role. From being alone in my role I have recruited 4 new PM to do the same.").
IF (ResponseId="R_bIpQQm2XujkUdFL") EmploymentStatusDetails="Durante el primer año y medio de mi primeprimer cargo como RMA estuve haciendo un máster en XXXX en modalidad blended-learning, con 3 semanas presenciales".
IF (ResponseId="R_74E6xkjOr8nYoYV") EmploymentStatusDetails="3 years at XXXX, 5 years at XXXX, right now career break and taking executive courses".
EXECUTE.

* EmploymentTyp_First.
* NEW variable for RAAAP-3.
RENAME VARIABLES EmploymentTyp_First=FirstEmploymentType.
VARIABLE LABELS FirstEmploymentType "4f. First Employment Type".
MISSING VALUES FirstEmploymentType (-99).
ADD VALUE LABELS FirstEmploymentType -99 "No Response".
VARIABLE LEVEL FirstEmploymentType (NOMINAL).
EXECUTE.

* EmploymentTyp_Current.
* Same as a variable from RAAAP-2.
RENAME VARIABLES EmploymentTyp_Current=CurrentEmploymentType.
VARIABLE LABELS CurrentEmploymentType "4. Current Employment Type".
MISSING VALUES CurrentEmploymentType (-99).
ADD VALUE LABELS CurrentEmploymentType -99 "No Response".
VARIABLE LEVEL CurrentEmploymentType (NOMINAL).
EXECUTE.

* *** CurrentEmploymentTD.
* *** NEW variable for RAAAP-2. As this could be any employment details not just current.
RENAME VARIABLES CurrentEmploymentTD=EmploymentTypeDetails.
VARIABLE LABELS EmploymentTypeDetails "4a. Details of employment type".
MISSING VALUES EmploymentTypeDetails ("").
VALUE LABELS EmploymentTypeDetails "" "No Response".
EXECUTE.

* *** Anonymising EmploymentTypeDetails - CO.
IF (ResponseId="R_1qXojp58bjg3e2y") EmploymentTypeDetails="Also on a part time secondment to Research England support the XXXX.".
IF (ResponseId="R_1F2LBqxhyel8W6j") EmploymentTypeDetails=CONCAT("When I first began working at XXXX I was employed on a contractual basis from January - December of ",
"the year. Every year the contact is renewed yearly. However the needs and requirements for the position is a critical position and I am the only person that is responsible for the task to provide rese",
"arch support to support staff. ").
IF (ResponseId="R_3j2nGGdrTElITw0") EmploymentTypeDetails="I hold a permanent position at XXXX (ingenieure de recherche) and am seconded in a European research infrastructure.".
IF (ResponseId="R_2TZBSjgeZPtUPrm") EmploymentTypeDetails=CONCAT("I was first employed in a permanent position with a 2 year trial period, but my chair agreed to conv",
"ert to full formal permanent position after ~9 months so that I could get a morgage to enable me to move near the XXXX (I had a very long commute). After ~14 years in that position, I moved to the XXX",
"X's central grants office. Since I remained an employee of the same XXXX, I kept all benefits and did not have a trial period. ").
IF (ResponseId="R_1FP8RNxXVfKtAWh") EmploymentTypeDetails="Soy personal administrativo nombrado en en la Universidad XXXX-".
IF (ResponseId="R_2QibIJZYaBvfAAM") EmploymentTypeDetails=CONCAT("After initial 6-month probationary period, open-ended to retirement.  However, XXXX started a few ye",
"ars ago, annual contracts based on annual evaluations, but they are now doing quarterly evaluations.  My assumption is that if you are not accomplishing goals, there is the potential for termination. ",
" There were personnel that did have contracts not renewed (terminated) during that period.  Things never stay the same, always change. ").
IF (ResponseId="R_3GeabuOZKRLWctX") EmploymentTypeDetails="Head of XXXX was a fixed term 3 year post, but in my second year they made it permanent.".
IF (ResponseId="R_3QE3Q13hgMMMTbo") EmploymentTypeDetails="My 1st employment in RMA role was a fix term contract with the XXXX, and my current contract last to the end of the project cycle (3 years) in 2025. ".
IF (ResponseId="R_3g1OvUCvnGbGXOC") EmploymentTypeDetails="At XXXX my role is considered a standing position with no end date".
IF (ResponseId="R_10V031pskYFcb8N") EmploymentTypeDetails=CONCAT("Difficult to explain..legally/in principle I have a permanent contract, as I have worked for the XXX",
"X already &gt;20 years and thus the fixed term contract was legally changed to a permanent contract. However, it is somehow still 'bound' to my projects..so if a project ends, and no replacement for t",
"hose hours is found, it is quite unclear who will take up those contract hours and how it will be taken care of that I don't just 'lose hours'(and consequently get paid less). It's a situation that ha",
"sn't happened yet (and legally, I suppose I stand strong) but it's under constant discussion from my side and no clear answers.. ").
IF (ResponseId="R_1OUGTPdWJyk39o2") EmploymentTypeDetails=CONCAT("Initially employed on 11 month contract to deliver an EPSRC-funded Diversity Project. Further fixed ",
"term contracts/opportunities became forthcoming at XXXX, but first permanent position obtained at University of XXXX (Careers Consultant/Researcher Developer for PhD students and Early Career Research",
"ers) before then moving to University of XXXX (again permanent role) as Research Staff Officer, before moving to current role c. 2 years ago").
IF (ResponseId="R_1QENt6nxnPTJDlO") EmploymentTypeDetails="I started at XXXX in a temp role with Sparks Group, then later with Colonial Temps. ".
IF (ResponseId="R_1FyXEWie3tisXln") EmploymentTypeDetails="First contract was 2.5 years (mirroring length of the XXXX project) and current contract is 4.5 (mirroring the length of the XXXX project).".
IF (ResponseId="R_2SuYrS1Xa9nO4Qh") EmploymentTypeDetails="While in XXXX I was an on-going staff member for whom RMA was a deployed role. Now in a University I am on a 5 year contract at a more senior level.".
IF (ResponseId="R_3MMbLJqwlPuooG6") EmploymentTypeDetails=CONCAT("I have had permanent contracts twice.  Eventually, the University of XXXX realised that renewing fix",
"ed term contracts over and over again was illegal, so we were offered permanent contracts on the third renewal.  And I had a permanent contract at XXXX in Saudi Arabia.  With XXXX, I have a fixed term",
" contract, and they argue that it is because our core funding is fixed term - however - I find this disingenuous, and a pure attempt to avoid having to deal with redundancies in the extremely unlikely",
" event that our core funding would be lost. ").
IF (ResponseId="R_1d072mTPfQb7vUo") EmploymentTypeDetails=CONCAT("At FIRST, I entered this field as a temporary staff with 4 months contract, but my superior asked me",
" to continue for next 2.5 years during my MA course at another university as a part time staff. Later on after working at different field ( still in higher education and international cooperation) for",
" three years then invited again at University of XXXX as a teaching position. At current position is each year renewal and maximum to 5 years contract, However I have chances to change to a tenure pos",
"ition or switch  to a 5 year teaching position.").
IF (ResponseId="R_7V8Br1O0nYc9ia5") EmploymentTypeDetails="I am a full-time RMA at the University of XXXX.".
IF (ResponseId="R_9mNGpdciCOsD06R") EmploymentTypeDetails="I employed at the XXXX  University of New York and as higher education officers, our positions are funded by state and city appropriations. ".
IF (ResponseId="R_3pms37v9J3jA3dW") EmploymentTypeDetails="I am a full -time professor of XXXX University of Finance and Economics.".
EXECUTE.

* ** backcoding CurrentEmploymentType (and some FirstEmploymentType) based on free text responses where the user did not select from the list - SK.
IF (ResponseId="R_2uHEp1xP3YHqEWV") CurrentEmploymentType=2.
IF (ResponseId="R_3kH5stvLcVrUlb6") CurrentEmploymentType=1.
IF (ResponseId="R_2EsCAkrr5z1Niy1") CurrentEmploymentType=1.
IF (ResponseId="R_3EMzleWVMTrCLfN") CurrentEmploymentType=1.
IF (ResponseId="R_C77yYb41UXEwNW1") CurrentEmploymentType=2.
IF (ResponseId="R_3iCQbLACysURDO2") CurrentEmploymentType=1.
IF (ResponseId="R_3Oi7fOZF83D3Aad") CurrentEmploymentType=2.
IF (ResponseId="R_21drhm6sWwXqkHS") CurrentEmploymentType=2.
IF (ResponseId="R_1MYSAUCsfSS1n3Z") CurrentEmploymentType=1.
IF (ResponseId="R_21zZ4qC1DV5Bzye") CurrentEmploymentType=1.
IF (ResponseId="R_11hbMxg2htTYHqM") CurrentEmploymentType=2.
IF (ResponseId="R_1LnwYqGTD0VA5dr") CurrentEmploymentType=2.
IF (ResponseId="R_2v5Iba9IWowpAKC") CurrentEmploymentType=2.
IF (ResponseId="R_2Yh2S9HEAIWzDXM") CurrentEmploymentType=1.
IF (ResponseId="R_2Sj1sHd3QJaS7uw") CurrentEmploymentType=2.
IF (ResponseId="R_ZaEGq4j1Zt2n4R3") CurrentEmploymentType=1.
IF (ResponseId="R_3hA7WPG352X4IHG") CurrentEmploymentType=1.
IF (ResponseId="R_1Nxp6w0Q3sPhD2i") CurrentEmploymentType=2.
IF (ResponseId="R_12x7nuiLqzThRyY") CurrentEmploymentType=2.
IF (ResponseId="R_2tyXUZmpvr7weaG") CurrentEmploymentType=2.
IF (ResponseId="R_3OqOui6faRHLJ8R") CurrentEmploymentType=2.
EXECUTE.

* *** ResponsibilityFor_1.
* *** does the person work in the areas of Proposal Development in their FIRST role
* *** New in RAAAP-3.
RENAME VARIABLES ResponsibilityFor_First_1=FirstWorkedInProposalDevelopment.
VARIABLE LABELS FirstWorkedInProposalDevelopment "5fa. Did you first work in the area of Proposal Development?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInProposalDevelopment 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInProposalDevelopment (-99).
ADD VALUE LABELS FirstWorkedInProposalDevelopment -99 "No Response".
VARIABLE LEVEL FirstWorkedInProposalDevelopment (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_2=FirstWorkedInProjectSupport.
VARIABLE LABELS FirstWorkedInProjectSupport "5fb. Did you first work in the area of Project Support?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInProjectSupport 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInProjectSupport (-99).
ADD VALUE LABELS FirstWorkedInProjectSupport -99 "No Response".
VARIABLE LEVEL FirstWorkedInProjectSupport (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_3=FirstWorkedInTranslation.
VARIABLE LABELS FirstWorkedInTranslation "5fc. Did you first work in the area of Translation?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInTranslation 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInTranslation (-99).
ADD VALUE LABELS FirstWorkedInTranslation -99 "No Response".
VARIABLE LEVEL FirstWorkedInTranslation (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_4=FirstWorkedInPGR.
VARIABLE LABELS FirstWorkedInPGR "5fd. Did you first work in the area of Research Student Support?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInPGR 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInPGR (-99).
ADD VALUE LABELS FirstWorkedInPGR -99 "No Response".
VARIABLE LEVEL FirstWorkedInPGR (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_5=FirstWorkedInPolicy.
VARIABLE LABELS FirstWorkedInPolicy "5fe. Did you first work in the area of Policy/Governance?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInPolicy 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInPolicy (-99).
ADD VALUE LABELS FirstWorkedInPolicy -99 "No Response".
VARIABLE LEVEL FirstWorkedInPolicy (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_6=FirstWorkedInERA.
VARIABLE LABELS FirstWorkedInERA "5ff. Did you first work in the area of MIS/ERA/CRIS?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInERA 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInERA (-99).
ADD VALUE LABELS FirstWorkedInERA -99 "No Response".
VARIABLE LEVEL FirstWorkedInERA (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_7=FirstWorkedInCompliance.
VARIABLE LABELS FirstWorkedInCompliance "5fg. Did you first work in the area of Audit/Compliance?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInCompliance 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInCompliance (-99).
ADD VALUE LABELS FirstWorkedInCompliance -99 "No Response".
VARIABLE LEVEL FirstWorkedInCompliance (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_8=FirstWorkedInServiceDelivery.
VARIABLE LABELS FirstWorkedInServiceDelivery "5fh. Did you first work in the area of Service Delivery?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInServiceDelivery 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInServiceDelivery (-99).
ADD VALUE LABELS FirstWorkedInServiceDelivery -99 "No Response".
VARIABLE LEVEL FirstWorkedInServiceDelivery (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_9=FirstWorkedInTraining.
VARIABLE LABELS FirstWorkedInTraining "5fi. Did you first work in the area of Training/Communication?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInTraining 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInTraining (-99).
ADD VALUE LABELS FirstWorkedInTraining -99 "No Response".
VARIABLE LEVEL FirstWorkedInTraining (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_First_10=FirstWorkedInOther.
VARIABLE LABELS FirstWorkedInOther "5fj. Did you first work in the area of Other?". /* trying to retain Q numbers.
VALUE LABELS FirstWorkedInOther 1 "Yes" 0 "No".
MISSING VALUES FirstWorkedInOther (-99).
ADD VALUE LABELS FirstWorkedInOther -99 "No Response".
VARIABLE LEVEL FirstWorkedInOther (NOMINAL).
EXECUTE.



* *** ResponsibilityFor_1.
* *** does ther person work in the areas of Proposal Development.
* *** RAAAP-1 has ResponsibilityForProposalDevelopment - with 4 levels - yes we just have Yes/No like RAAAP-2 - hence change of variable name from RAAAP-1.
RENAME VARIABLES ResponsibilityFor_Current_1=WorksInProposalDevelopment.
VARIABLE LABELS WorksInProposalDevelopment "5a. Do you work in the area of Proposal Development?". /* trying to retain Q numbers.
VALUE LABELS WorksInProposalDevelopment 1 "Yes" 0 "No".
MISSING VALUES WorksInProposalDevelopment (-99).
ADD VALUE LABELS WorksInProposalDevelopment -99 "No Response".
VARIABLE LEVEL WorksInProposalDevelopment (NOMINAL).
EXECUTE.
* **** CHECK how to show "No" for where they did not tick the box ***.
* **** ASSUME that if nothing in this question is ticked then system missing, but if they ticked anything then untick=no.

RENAME VARIABLES ResponsibilityFor_Current_2=WorksInProjectSupport.
VARIABLE LABELS WorksInProjectSupport "5b. Do you work in the area of Project Support?". /* trying to retain Q numbers.
VALUE LABELS WorksInProjectSupport 1 "Yes" 0 "No".
MISSING VALUES WorksInProjectSupport (-99).
ADD VALUE LABELS WorksInProjectSupport -99 "No Response".
VARIABLE LEVEL WorksInProjectSupport (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_3=WorksInTranslation.
VARIABLE LABELS WorksInTranslation "5c. Do you work in the area of Translation?". /* trying to retain Q numbers.
VALUE LABELS WorksInTranslation 1 "Yes" 0 "No".
MISSING VALUES WorksInTranslation (-99).
ADD VALUE LABELS WorksInTranslation -99 "No Response".
VARIABLE LEVEL WorksInTranslation (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_4=WorksInPGR.
VARIABLE LABELS WorksInPGR "5d. Do you work in the area of Research Student Support?". /* trying to retain Q numbers.
VALUE LABELS WorksInPGR 1 "Yes" 0 "No".
MISSING VALUES WorksInPGR (-99).
ADD VALUE LABELS WorksInPGR -99 "No Response".
VARIABLE LEVEL WorksInPGR (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_5=WorksInPolicy.
VARIABLE LABELS WorksInPolicy "5e. Do you work in the area of Policy/Governance?". /* trying to retain Q numbers.
VALUE LABELS WorksInPolicy 1 "Yes" 0 "No".
MISSING VALUES WorksInPolicy (-99).
ADD VALUE LABELS WorksInPolicy -99 "No Response".
VARIABLE LEVEL WorksInPolicy (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_6=WorksInERA.
VARIABLE LABELS WorksInERA "5f. Do you work in the area of MIS/ERA/CRIS?". /* trying to retain Q numbers.
VALUE LABELS WorksInERA 1 "Yes" 0 "No".
MISSING VALUES WorksInERA (-99).
ADD VALUE LABELS WorksInERA -99 "No Response".
VARIABLE LEVEL WorksInERA (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_7=WorksInCompliance.
VARIABLE LABELS WorksInCompliance "5g. Do you work in the area of Audit/Compliance?". /* trying to retain Q numbers.
VALUE LABELS WorksInCompliance 1 "Yes" 0 "No".
MISSING VALUES WorksInCompliance (-99).
ADD VALUE LABELS WorksInCompliance -99 "No Response".
VARIABLE LEVEL WorksInCompliance (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_8=WorksInServiceDelivery.
VARIABLE LABELS WorksInServiceDelivery "5h. Do you work in the area of Service Delivery?". /* trying to retain Q numbers.
VALUE LABELS WorksInServiceDelivery 1 "Yes" 0 "No".
MISSING VALUES WorksInServiceDelivery (-99).
ADD VALUE LABELS WorksInServiceDelivery -99 "No Response".
VARIABLE LEVEL WorksInServiceDelivery (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_9=WorksInTraining.
VARIABLE LABELS WorksInTraining "5i. Do you work in the area of Training/Communication?". /* trying to retain Q numbers.
VALUE LABELS WorksInTraining 1 "Yes" 0 "No".
MISSING VALUES WorksInTraining (-99).
ADD VALUE LABELS WorksInTraining -99 "No Response".
VARIABLE LEVEL WorksInTraining (NOMINAL).
EXECUTE.

RENAME VARIABLES ResponsibilityFor_Current_10=WorksInOther.
VARIABLE LABELS WorksInOther "5j. Do you work in the area of Other?". /* trying to retain Q numbers.
VALUE LABELS WorksInOther 1 "Yes" 0 "No".
MISSING VALUES WorksInOther (-99).
ADD VALUE LABELS WorksInOther -99 "No Response".
VARIABLE LEVEL WorksInOther (NOMINAL).
EXECUTE.

* *** So now.. ASSUME that is there are no ticks in any column, then leave as system missing.
* *** But if the column has *ANY* ticks then treat the other non ticks as "no" rather than system missing.

* *** But before we do that... see if there is any backcoding to be done; as we only backcode in there is not a 0 or a 1 there already.
* ** backcoding for WorksInOtherArea - CO.
IF ((ResponseId="R_3PpJZnB9hjFuu1q") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_3qeXq918o2qlD6g") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_W7Lqt7k1h6dhR9D") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_1FP8RNxXVfKtAWh") AND SYSMIS(WorksInTranslation)) WorksInTranslation=1.
IF ((ResponseId="R_3ptosj7zagNJmNn") AND SYSMIS(WorksInProposalDevelopment)) WorksInProposalDevelopment=1.
IF ((ResponseId="R_qUBTumtu8k3TXPP") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_1LT2hoDmCuBrvJ4") AND SYSMIS(WorksInProposalDevelopment)) WorksInProposalDevelopment=1.
IF ((ResponseId="R_SWeo90tGRnIAO2J") AND SYSMIS(WorksInProposalDevelopment)) WorksInProposalDevelopment=1.
IF ((ResponseId="R_3iCQbLACysURDO2") AND SYSMIS(WorksInServiceDelivery)) WorksInServiceDelivery=1.
IF ((ResponseId="R_C1ZPih4jSoXfRyF") AND SYSMIS(WorksInProposalDevelopment)) WorksInProposalDevelopment=1.
IF ((ResponseId="R_3MtyfPSeoy6rzoM") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_1QzjAPjqKaHHPvE") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_31hLmO2o5xi3cB2") AND SYSMIS(WorksInProposalDevelopment)) WorksInProposalDevelopment=1.
IF ((ResponseId="R_2aLHyMJBw8s3YZv") AND SYSMIS(WorksInTraining)) WorksInTraining=1.
IF ((ResponseId="R_ZL7W18wTaNOZTmV") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_1Fwu9PMbwqC4ySv") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_2rVeN8gZFRK41dB") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
IF ((ResponseId="R_3FRJw8tmzjKzGKh") AND SYSMIS(WorksInProjectSupport)) WorksInProjectSupport=1.
DO IF (ResponseId="R_2QmJYirdD1hdVi2").
    IF SYSMIS(WorksInProposalDevelopment) WorksInProposalDevelopment=1.
    IF SYSMIS(WorksInProjectSupport) WorksInProjectSupport=1.
END IF.
DO IF (ResponseId="R_cZtud1WOYMKjlQZ").
    IF SYSMIS(WorksInProjectSupport) WorksInProjectSupport=1.
    IF SYSMIS(WorksInTranslation) WorksInTranslation=1.
END IF.
DO IF (ResponseId="R_3KBlXf1pDysQbqz").
    IF SYSMIS(WorksInPolicy) WorksInPolicy=1.
    IF SYSMIS(WorksInERA) WorksInERA=1.
END IF.
DO IF (ResponseId="R_O2yjCJOBC0l9ncB").
    IF SYSMIS(WorksInProposalDevelopment) WorksInProposalDevelopment=1.
    IF SYSMIS(WorksInProjectSupport) WorksInProjectSupport=1.
END IF.
DO IF (ResponseId="R_3iKZ28MbWHjpiNS").
    IF SYSMIS(WorksInCompliance) WorksInCompliance=1.
    IF SYSMIS(WorksInTraining) WorksInTraining=1.
END IF.
DO IF (ResponseId="R_32Ld70W5i3w8Z30").
    IF SYSMIS(WorksInProjectSupport) WorksInProjectSupport=1.
    IF SYSMIS(WorksInTranslation) WorksInTranslation=1.
END IF.
DO IF (ResponseId="R_O2yjCJOBC0l9ncB").
    IF SYSMIS(FirstWorkedInProposalDevelopment) FirstWorkedInProposalDevelopment=1.
    IF SYSMIS(FirstWorkedInProjectSupport) FirstWorkedInProjectSupport=1.
END IF.
DO IF (ResponseId="R_3n2Uu4kvghktqW3").
    IF SYSMIS(FirstWorkedInPolicy) FirstWorkedInPolicy=1.
END IF.
DO IF (ResponseId="R_1FJJMwUcr5jqE0Y").
    COMPUTE FirstWorkedInProposalDevelopment=1.
    COMPUTE FirstWorkedInProjectSupport=1.
    COMPUTE FirstWorkedInProjectSupport=1.
    COMPUTE FirstWorkedInTranslation=1.
    COMPUTE FirstWorkedInPolicy=1.
    COMPUTE FirstWorkedInServiceDelivery=1.
END IF.

DO IF (ResponseId="R_2eV9UX3zAXrKlz5").
    COMPUTE WorksInProposalDevelopment=1.
    COMPUTE WorksInProjectSupport=1.
END IF.
DO IF (ResponseId="R_2QX4sHMC38jwE76").
    COMPUTE WorksInProjectSupport=1.
    COMPUTE WorksInPolicy=1.
END IF.

DO IF (ResponseId="R_Dk7o5CCYHyDEout").
    COMPUTE WorksInProposalDevelopment=1.
    COMPUTE WorksInProjectSupport=1.
    COMPUTE WorksInServiceDelivery=1.
END IF.
DO IF (ResponseId="R_2f9tYVABsHIbLmz").
    COMPUTE WorksInProposalDevelopment=1.
    COMPUTE WorksInProjectSupport=1.
    COMPUTE WorksInPolicy=1.
END IF.
DO IF (ResponseId="R_2E06juupc514Q82").
    COMPUTE WorksInProjectSupport=1.
    COMPUTE WorksInPolicy=1.
    COMPUTE WorksInCompliance=1.
END IF.
IF (ResponseId="R_1OqtZxXbrNCAeXI") WorksInPGR=1.
IF (ResponseId="R_1NDlkL8jUmUkrwN") WorksInTraining=1.
IF (ResponseId="R_21zZ4qC1DV5Bzye") WorksInCompliance=1.
IF (ResponseId="R_11hbMxg2htTYHqM") WorksInPGR=1.
IF (ResponseId="R_2Sj1sHd3QJaS7uw") WorksInProposalDevelopment=1.
IF (ResponseId="R_2PBEXsUtmIlp8wy") WorksInOther=1.
IF (ResponseId="R_3ha30u5y52jKbQu") WorksInServiceDelivery=1.
IF (ResponseId="R_1rJmVIFV0IYpuso") WorksInTranslation=1.
EXECUTE.

RECODE FirstWorkedInProposalDevelopment FirstWorkedInProjectSupport FirstWorkedInTranslation FirstWorkedInPGR FirstWorkedInPolicy FirstWorkedInERA 
    FirstWorkedInCompliance FirstWorkedInServiceDelivery FirstWorkedInTraining FirstWorkedInOther (SYSMIS=0).
EXECUTE.
COMPUTE FirstWorkedIn = FirstWorkedInProposalDevelopment+FirstWorkedInProjectSupport+FirstWorkedInTranslation+FirstWorkedInPGR+FirstWorkedInPolicy+
    FirstWorkedInERA+FirstWorkedInCompliance+FirstWorkedInServiceDelivery+FirstWorkedInTraining+FirstWorkedInOther .
DO IF (FirstWorkedIn = 0).
    COMPUTE FirstWorkedInProposalDevelopment=$SYSMIS.
    COMPUTE FirstWorkedInProjectSupport=$SYSMIS.
    COMPUTE FirstWorkedInTranslation=$SYSMIS.
    COMPUTE FirstWorkedInPGR=$SYSMIS.
    COMPUTE FirstWorkedInPolicy=$SYSMIS.
    COMPUTE FirstWorkedInERA=$SYSMIS.
    COMPUTE FirstWorkedInCompliance=$SYSMIS.
    COMPUTE FirstWorkedInServiceDelivery=$SYSMIS.
    COMPUTE FirstWorkedInTraining=$SYSMIS.
    COMPUTE FirstWorkedInOther=$SYSMIS.
END IF.
EXECUTE.

RECODE WorksInProposalDevelopment WorksInProjectSupport WorksInTranslation WorksInPGR WorksInPolicy WorksInERA WorksInCompliance 
    WorksInServiceDelivery WorksInTraining WorksInOther (SYSMIS=0).
EXECUTE.
COMPUTE WorksIn = WorksInProposalDevelopment+WorksInProjectSupport+WorksInTranslation+WorksInPGR+WorksInPolicy+WorksInERA+
    WorksInCompliance+WorksInServiceDelivery+WorksInTraining+WorksInOther .
DO IF (WorksIn = 0).
    COMPUTE WorksInProposalDevelopment=$SYSMIS.
    COMPUTE WorksInProjectSupport=$SYSMIS.
    COMPUTE WorksInTranslation=$SYSMIS.
    COMPUTE WorksInPGR=$SYSMIS.
    COMPUTE WorksInPolicy=$SYSMIS.
    COMPUTE WorksInERA=$SYSMIS.
    COMPUTE WorksInCompliance=$SYSMIS.
    COMPUTE WorksInServiceDelivery=$SYSMIS.
    COMPUTE WorksInTraining=$SYSMIS.
    COMPUTE WorksInOther=$SYSMIS.
END IF.
EXECUTE.

* ResponsibilityFor_OD.
* Other areas that people might work in that they have added.
* *** Possible opportunity to add new codings if many responses the same.
RENAME VARIABLES ResponsibilityForOD=WorksInOtherArea.
VARIABLE LABELS WorksInOtherArea "5j. Details of other areas worked in".
MISSING VALUES WorksInOtherArea ("").
VALUE LABELS WorksInOtherArea "" "No Response".
EXECUTE.

* *** Anonymising for WorksInOtherArea ***.SK.
IF (ResponseId="R_3PjyKd6VFN2Igty") WorksInOtherArea="I'm working as a research secretary at XXXX project. The project is funded by XXXX Finland, among others.".
IF (ResponseId="R_3KZOEwXOAfmrPm4") WorksInOtherArea=CONCAT("Examples of projects in which I acted and act as RMA:  In 2018 as a member of international team tha",
"t includes groups from Ukraine, the United Kingdom, Spain and Italy, I contributed to the proposal 'XXXX” for a grant under umbrella of the European Union’s Horizon 2020. The proposal was evaluated po",
"sitively and got funding. In 2016 and 2019 I attracted funding from Erasmus+ program XXXX. I was selected as a Program Supervisor and Manager from XXXX. From 01/2017 to 12/2019, I was Manager of the g",
"rant of the XXXX (Grant: XXXX) 'XXXX' (I supervise team of 25 people). In 02/2014 and 11/2017 at the invitation from XXXX, I visited the aforesaid College as a Visiting Researcher and delivered lectur",
"es to Ph.D. students and performed scientific research in the field of XXXX.").
IF (ResponseId="R_3fTC8yYgPicY3vw") WorksInOtherArea="Las subáreas de la RMA efectivamente incluyen estas actividades de gestión, según lo establecido por el estatuto orgánico de la Universidad XXXX.".
IF (ResponseId="R_2bHJFxOSgqAmPBc") WorksInOtherArea="Legal expert in EU and French Laws applicable in the R&D field (XXXX)".
IF (ResponseId="R_1mFxj6qAch2WuA0") WorksInOtherArea=CONCAT("In my first job I was responsible to completing pieces of graduate student applications to attend XX",
"XX  I would consider that support and in my current position I review, submit, and train on what is expected in the application.  I also use several computer system to complete my work.   I am respons",
"ible to submitted 80 percent or more of the application, 100% of JITs and RPPRs as far as service delivery, The back and forth I do with research administrator when they are unsure of what is expected",
" from the PA/FOA is training and when we have new grants manager that are just starting out I do alot of training on PAs/FOAs and systems.").
IF (ResponseId="R_1rJmVIFV0IYpuso") WorksInOtherArea=CONCAT("All of the above for first role.  For current role Commercialisation skills do not fit the criteria ",
"you have set, we are not grants coordinators, Commercialisation leads the academics not vice versa, that is why it is often in a seperate company or area, eg XXXX or XXXX Innovations. ").
EXECUTE.

* ***.
* *** NOW the Japanese taxonomy.
* ***.

* JResponsibility* set of variables
* These are new to RAAAP-3 for the First role, but Current role is in RAAAP-2.
* NOTE that they are in sections - ticking a section implies that all subsections are worked in.
* JResponsibilityFor_10.

* RDP - First roles - Japanese Taxonomy.
RENAME VARIABLES (JRespFor_1_1=FirstJRespFor_RDP)
(JRespFor_2_1=FirstJRespFor_RDP_Policy)
(JRespFor_3_1=FirstJRespFor_RDP_InstRes)
(JRespFor_4_1=FirstJRespFor_RDP_Strategy).

* IF RDP is ticked AND none of the 3 inside have been. then tick them all.
* BUT IF RDP is ticked and only SOME of the 3 inside have been then do not change ticks.
* AND SO we also need to untick RDP so that there is consistency.
* AND if all of the 3 inside have been ticked and RDP has not, then tick RDP.
RECODE FirstJRespFor_RDP FirstJRespFor_RDP_Policy FirstJRespFor_RDP_InstRes FirstJRespFor_RDP_Strategy (SYSMIS=0).
EXECUTE.

COMPUTE RDP = FirstJRespFor_RDP_Policy+FirstJRespFor_RDP_InstRes+FirstJRespFor_RDP_Strategy.
DO IF (FirstJRespFor_RDP=1 AND RDP = 0). 
    COMPUTE FirstJRespFor_RDP_Policy=1.
    COMPUTE FirstJRespFor_RDP_InstRes=1.
    COMPUTE FirstJRespFor_RDP_Strategy=1.
ELSE IF (FirstJRespFor_RDP=1 AND RANGE(RDP,1,2)). 
    COMPUTE FirstJRespFor_RDP=0.
ELSE IF (FirstJRespFor_RDP=0 AND RDP = 3). 
    COMPUTE FirstJRespFor_RDP=1.
END IF.
EXECUTE.


* now harmonise the data options.
VARIABLE LABELS FirstJRespFor_RDP "6fa. Did you first work in the area of J-RDP?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_RDP 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_RDP (-99).
ADD VALUE LABELS FirstJRespFor_RDP -99 "No Response".
VARIABLE LEVEL FirstJRespFor_RDP (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_RDP_Policy "6faa. Did you first work in the area of J-RDP-Policy?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_RDP_Policy 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_RDP_Policy (-99).
ADD VALUE LABELS FirstJRespFor_RDP_Policy -99 "No Response".
VARIABLE LEVEL FirstJRespFor_RDP_Policy (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_RDP_InstRes "6fab. Did you first work in the area of J-RDP-Institutional Research?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_RDP_InstRes 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_RDP_InstRes (-99).
ADD VALUE LABELS FirstJRespFor_RDP_InstRes -99 "No Response".
VARIABLE LEVEL FirstJRespFor_RDP_InstRes (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_RDP_Strategy "6fac. Did you first work in the area of J-RDP-Planning?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_RDP_Strategy 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_RDP_Strategy (-99).
ADD VALUE LABELS FirstJRespFor_RDP_Strategy -99 "No Response".
VARIABLE LEVEL FirstJRespFor_RDP_Strategy (NOMINAL).
EXECUTE.

* RDP - current roles - Japanese Taxonomy.
RENAME VARIABLES (JRespFor_1_2=JRespFor_RDP)
(JRespFor_2_2=JRespFor_RDP_Policy)
(JRespFor_3_2=JRespFor_RDP_InstRes)
(JRespFor_4_2=JRespFor_RDP_Strategy).

* IF RDP is ticked AND none of the 3 inside have been. then tick them all.
* BUT IF RDP is ticked and only SOME of the 3 inside have been then do not change ticks.
* AND SO we also need to untick RDP so that there is consistency.
* AND if all of the 3 inside have been ticked and RDP has not, then tick RDP.
RECODE JRespFor_RDP JRespFor_RDP_Policy JRespFor_RDP_InstRes JRespFor_RDP_Strategy (SYSMIS=0).
EXECUTE.

COMPUTE RDP = JRespFor_RDP_Policy+JRespFor_RDP_InstRes+JRespFor_RDP_Strategy.
DO IF (JRespFor_RDP=1 AND RDP = 0). 
    COMPUTE JRespFor_RDP_Policy=1.
    COMPUTE JRespFor_RDP_InstRes=1.
    COMPUTE JRespFor_RDP_Strategy=1.
ELSE IF (JRespFor_RDP=1 AND RANGE(RDP,1,2)). 
    COMPUTE JRespFor_RDP=0.
ELSE IF (JRespFor_RDP=0 AND RDP = 3). 
    COMPUTE JRespFor_RDP=1.
END IF.
EXECUTE.


* now harmonise the data options.
VARIABLE LABELS JRespFor_RDP "6a. Do you work in the area of J-RDP?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_RDP 1 "Yes" 0 "No".
MISSING VALUES JRespFor_RDP (-99).
ADD VALUE LABELS JRespFor_RDP -99 "No Response".
VARIABLE LEVEL JRespFor_RDP (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_RDP_Policy "6aa. Do you work in the area of J-RDP-Policy?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_RDP_Policy 1 "Yes" 0 "No".
MISSING VALUES JRespFor_RDP_Policy (-99).
ADD VALUE LABELS JRespFor_RDP_Policy -99 "No Response".
VARIABLE LEVEL JRespFor_RDP_Policy (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_RDP_InstRes "6ab. Do you work in the area of J-RDP-Institutional Research?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_RDP_InstRes 1 "Yes" 0 "No".
MISSING VALUES JRespFor_RDP_InstRes (-99).
ADD VALUE LABELS JRespFor_RDP_InstRes -99 "No Response".
VARIABLE LEVEL JRespFor_RDP_InstRes (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_RDP_Strategy "6ac. Do you work in the area of J-RDP-Planning?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_RDP_Strategy 1 "Yes" 0 "No".
MISSING VALUES JRespFor_RDP_Strategy (-99).
ADD VALUE LABELS JRespFor_RDP_Strategy -99 "No Response".
VARIABLE LEVEL JRespFor_RDP_Strategy (NOMINAL).
EXECUTE.

* *** Now the first pre-award section of the J taxonomy.
RENAME VARIABLES (JRespFor_5_1=FirstJRespFor_Pre)
(JRespFor_6_1=FirstJRespFor_Pre_ProjPlan)
(JRespFor_7_1=FirstJRespFor_Pre_FundInfo)
(JRespFor_8_1=FirstJRespFor_Pre_IntNegotiation)
(JRespFor_9_1=FirstJRespFor_Pre_ExtNegotiation)
(JRespFor_10_1=FirstJRespFor_Pre_AppSupport).

RECODE FirstJRespFor_Pre FirstJRespFor_Pre_ProjPlan FirstJRespFor_Pre_FundInfo FirstJRespFor_Pre_IntNegotiation FirstJRespFor_Pre_ExtNegotiation FirstJRespFor_Pre_AppSupport (SYSMIS=0).
EXECUTE.

COMPUTE Pre = FirstJRespFor_Pre_ProjPlan+FirstJRespFor_Pre_FundInfo+FirstJRespFor_Pre_IntNegotiation+FirstJRespFor_Pre_ExtNegotiation+FirstJRespFor_Pre_AppSupport.
DO IF (FirstJRespFor_Pre=1 AND Pre = 0). 
    COMPUTE FirstJRespFor_Pre_ProjPlan=1.
    COMPUTE FirstJRespFor_Pre_FundInfo=1.
    COMPUTE FirstJRespFor_Pre_IntNegotiation=1.
    COMPUTE FirstJRespFor_Pre_ExtNegotiation=1.
    COMPUTE FirstJRespFor_Pre_AppSupport=1.
ELSE IF (FirstJRespFor_Pre=1 AND RANGE(Pre,1,4)). 
    COMPUTE FirstJRespFor_Pre=0.
ELSE IF (FirstJRespFor_Pre=0 AND Pre = 5). 
    COMPUTE FirstJRespFor_Pre=1.
END IF.
EXECUTE.

VARIABLE LABELS FirstJRespFor_Pre "6fb. Did you first work in the area of J-PreAward?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Pre 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Pre (-99).
ADD VALUE LABELS FirstJRespFor_Pre -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Pre (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Pre_ProjPlan "6fba. Did you first work in the area of J-Pre-Project Planning?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Pre_ProjPlan 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Pre_ProjPlan (-99).
ADD VALUE LABELS FirstJRespFor_Pre_ProjPlan -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Pre_ProjPlan (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Pre_FundInfo "6fbb. Did you first work in the area of J-Pre-Funding Information?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Pre_FundInfo 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Pre_FundInfo (-99).
ADD VALUE LABELS FirstJRespFor_Pre_FundInfo -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Pre_FundInfo (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Pre_IntNegotiation "6fbc. Did you first work in the area of J-Pre-Internal Negotiation?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Pre_IntNegotiation 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Pre_IntNegotiation (-99).
ADD VALUE LABELS FirstJRespFor_Pre_IntNegotiation -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Pre_IntNegotiation (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Pre_ExtNegotiation "6fbd. Did you first work in the area of J-Pre-External Negotiation?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Pre_ExtNegotiation 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Pre_ExtNegotiation (-99).
ADD VALUE LABELS FirstJRespFor_Pre_ExtNegotiation -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Pre_ExtNegotiation (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Pre_AppSupport "6fbe. Did you first work in the area of J-Pre-Application Support?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Pre_AppSupport 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Pre_AppSupport (-99).
ADD VALUE LABELS FirstJRespFor_Pre_AppSupport -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Pre_AppSupport (NOMINAL).
EXECUTE.

* *** Now the current pre-award section of the J taxonomy.
RENAME VARIABLES (JRespFor_5_2=JRespFor_Pre)
(JRespFor_6_2=JRespFor_Pre_ProjPlan)
(JRespFor_7_2=JRespFor_Pre_FundInfo)
(JRespFor_8_2=JRespFor_Pre_IntNegotiation)
(JRespFor_9_2=JRespFor_Pre_ExtNegotiation)
(JRespFor_10_2=JRespFor_Pre_AppSupport).

RECODE JRespFor_Pre JRespFor_Pre_ProjPlan JRespFor_Pre_FundInfo JRespFor_Pre_IntNegotiation JRespFor_Pre_ExtNegotiation JRespFor_Pre_AppSupport (SYSMIS=0).
EXECUTE.

COMPUTE Pre = JRespFor_Pre_ProjPlan+JRespFor_Pre_FundInfo+JRespFor_Pre_IntNegotiation+JRespFor_Pre_ExtNegotiation+JRespFor_Pre_AppSupport.
DO IF (JRespFor_Pre=1 AND Pre = 0). 
    COMPUTE JRespFor_Pre_ProjPlan=1.
    COMPUTE JRespFor_Pre_FundInfo=1.
    COMPUTE JRespFor_Pre_IntNegotiation=1.
    COMPUTE JRespFor_Pre_ExtNegotiation=1.
    COMPUTE JRespFor_Pre_AppSupport=1.
ELSE IF (JRespFor_Pre=1 AND RANGE(Pre,1,4)). 
    COMPUTE JRespFor_Pre=0.
ELSE IF (JRespFor_Pre=0 AND Pre = 5). 
    COMPUTE JRespFor_Pre=1.
END IF.
EXECUTE.

VARIABLE LABELS JRespFor_Pre "6b. Do you work in the area of J-PreAward?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Pre 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Pre (-99).
ADD VALUE LABELS JRespFor_Pre -99 "No Response".
VARIABLE LEVEL JRespFor_Pre (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Pre_ProjPlan "6ba. Do you work in the area of J-Pre-Project Planning?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Pre_ProjPlan 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Pre_ProjPlan (-99).
ADD VALUE LABELS JRespFor_Pre_ProjPlan -99 "No Response".
VARIABLE LEVEL JRespFor_Pre_ProjPlan (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Pre_FundInfo "6bb. Do you work in the area of J-Pre-Funding Information?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Pre_FundInfo 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Pre_FundInfo (-99).
ADD VALUE LABELS JRespFor_Pre_FundInfo -99 "No Response".
VARIABLE LEVEL JRespFor_Pre_FundInfo (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Pre_IntNegotiation "6bc. Do you work in the area of J-Pre-Internal Negotiation?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Pre_IntNegotiation 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Pre_IntNegotiation (-99).
ADD VALUE LABELS JRespFor_Pre_IntNegotiation -99 "No Response".
VARIABLE LEVEL JRespFor_Pre_IntNegotiation (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Pre_ExtNegotiation "6bd. Do you work in the area of J-Pre-External Negotiation?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Pre_ExtNegotiation 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Pre_ExtNegotiation (-99).
ADD VALUE LABELS JRespFor_Pre_ExtNegotiation -99 "No Response".
VARIABLE LEVEL JRespFor_Pre_ExtNegotiation (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Pre_AppSupport "6be. Do you work in the area of J-Pre-Application Support?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Pre_AppSupport 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Pre_AppSupport (-99).
ADD VALUE LABELS JRespFor_Pre_AppSupport -99 "No Response".
VARIABLE LEVEL JRespFor_Pre_AppSupport (NOMINAL).
EXECUTE.

* *** Now post-award section of J taxonomy (first).
RENAME VARIABLES (JRespFor_11_1=FirstJRespFor_Post)
(JRespFor_12_1=FirstJRespFor_Post_ExtAdjust)
(JRespFor_13_1=FirstJRespFor_Post_ProgressMgt)
(JRespFor_14_1=FirstJRespFor_Post_Accounting)
(JRespFor_15_1=FirstJRespFor_Post_ProjEval)
(JRespFor_16_1=FirstJRespFor_Post_Reporting).

RECODE FirstJRespFor_Post FirstJRespFor_Post_ExtAdjust FirstJRespFor_Post_ProgressMgt FirstJRespFor_Post_Accounting FirstJRespFor_Post_ProjEval FirstJRespFor_Post_Reporting (SYSMIS=0).
EXECUTE.

COMPUTE Post = FirstJRespFor_Post_ExtAdjust+FirstJRespFor_Post_ProgressMgt+FirstJRespFor_Post_Accounting+FirstJRespFor_Post_ProjEval+FirstJRespFor_Post_Reporting.
DO IF (FirstJRespFor_Post=1 AND Pre = 0). 
    COMPUTE FirstJRespFor_Post_ExtAdjust=1.
    COMPUTE FirstJRespFor_Post_ProgressMgt=1.
    COMPUTE FirstJRespFor_Post_Accounting=1.
    COMPUTE FirstJRespFor_Post_ProjEval=1.
    COMPUTE FirstJRespFor_Post_Reporting=1.
ELSE IF (FirstJRespFor_Post=1 AND RANGE(Post,1,4)). 
    COMPUTE FirstJRespFor_Post=0.
ELSE IF (FirstJRespFor_Post=0 AND Post = 5). 
    COMPUTE FirstJRespFor_Post=1.
END IF.
EXECUTE.

VARIABLE LABELS FirstJRespFor_Post "6fc. Did you first work in the area of J-PostAward?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Post 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Post (-99).
ADD VALUE LABELS FirstJRespFor_Post -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Post (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Post_ExtAdjust "6fca. Did you first work in the area of J-Post-External Adjustment?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Post_ExtAdjust 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Post_ExtAdjust (-99).
ADD VALUE LABELS FirstJRespFor_Post_ExtAdjust -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Post_ExtAdjust (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Post_ProgressMgt "6fcb. Did you first work in the area of J-Post-Progress Management?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Post_ProgressMgt 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Post_ProgressMgt (-99).
ADD VALUE LABELS FirstJRespFor_Post_ProgressMgt -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Post_ProgressMgt (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Post_Accounting "6fcc. Did you first work in the area of J-Post-Accounting?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Post_Accounting 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Post_Accounting (-99).
ADD VALUE LABELS FirstJRespFor_Post_Accounting -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Post_Accounting (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Post_ProjEval "6fcd. Did you first work in the area of J-Post-Project Evaluation?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Post_ProjEval 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Post_ProjEval (-99).
ADD VALUE LABELS FirstJRespFor_Post_ProjEval -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Post_ProjEval (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Post_Reporting "6fce. Did you first work in the area of J-Post-Reporting?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Post_Reporting 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Post_Reporting (-99).
ADD VALUE LABELS FirstJRespFor_Post_Reporting -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Post_Reporting (NOMINAL).
EXECUTE.

* *** Now post-award section of J taxonomy (current).
RENAME VARIABLES (JRespFor_11_2=JRespFor_Post)
(JRespFor_12_2=JRespFor_Post_ExtAdjust)
(JRespFor_13_2=JRespFor_Post_ProgressMgt)
(JRespFor_14_2=JRespFor_Post_Accounting)
(JRespFor_15_2=JRespFor_Post_ProjEval)
(JRespFor_16_2=JRespFor_Post_Reporting).

RECODE JRespFor_Post JRespFor_Post_ExtAdjust JRespFor_Post_ProgressMgt JRespFor_Post_Accounting JRespFor_Post_ProjEval JRespFor_Post_Reporting (SYSMIS=0).
EXECUTE.

COMPUTE Post = JRespFor_Post_ExtAdjust+JRespFor_Post_ProgressMgt+JRespFor_Post_Accounting+JRespFor_Post_ProjEval+JRespFor_Post_Reporting.
DO IF (JRespFor_Post=1 AND Pre = 0). 
    COMPUTE JRespFor_Post_ExtAdjust=1.
    COMPUTE JRespFor_Post_ProgressMgt=1.
    COMPUTE JRespFor_Post_Accounting=1.
    COMPUTE JRespFor_Post_ProjEval=1.
    COMPUTE JRespFor_Post_Reporting=1.
ELSE IF (JRespFor_Post=1 AND RANGE(Post,1,4)). 
    COMPUTE JRespFor_Post=0.
ELSE IF (JRespFor_Post=0 AND Post = 5). 
    COMPUTE JRespFor_Post=1.
END IF.
EXECUTE.


VARIABLE LABELS JRespFor_Post "6c. Do you work in the area of J-PostAward?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Post 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Post (-99).
ADD VALUE LABELS JRespFor_Post -99 "No Response".
VARIABLE LEVEL JRespFor_Post (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Post_ExtAdjust "6ca. Do you work in the area of J-Post-External Adjustment?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Post_ExtAdjust 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Post_ExtAdjust (-99).
ADD VALUE LABELS JRespFor_Post_ExtAdjust -99 "No Response".
VARIABLE LEVEL JRespFor_Post_ExtAdjust (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Post_ProgressMgt "6cb. Do you work in the area of J-Post-Progress Management?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Post_ProgressMgt 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Post_ProgressMgt (-99).
ADD VALUE LABELS JRespFor_Post_ProgressMgt -99 "No Response".
VARIABLE LEVEL JRespFor_Post_ProgressMgt (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Post_Accounting "6cc. Do you work in the area of J-Post-Accounting?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Post_Accounting 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Post_Accounting (-99).
ADD VALUE LABELS JRespFor_Post_Accounting -99 "No Response".
VARIABLE LEVEL JRespFor_Post_Accounting (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Post_ProjEval "6cd. Do you work in the area of J-Post-Project Evaluation?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Post_ProjEval 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Post_ProjEval (-99).
ADD VALUE LABELS JRespFor_Post_ProjEval -99 "No Response".
VARIABLE LEVEL JRespFor_Post_ProjEval (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Post_Reporting "6ce. Do you work in the area of J-Post-Reporting?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Post_Reporting 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Post_Reporting (-99).
ADD VALUE LABELS JRespFor_Post_Reporting -99 "No Response".
VARIABLE LEVEL JRespFor_Post_Reporting (NOMINAL).
EXECUTE.

* *** the final "other" section of the Japanese taxonomy (first).
RENAME VARIABLES (JRespFor_17_1=FirstJRespFor_Other)
(JRespFor_18_1=FirstJRespFor_Other_International)
(JRespFor_19_1=FirstJRespFor_Other_Education)
(JRespFor_20_1=FirstJRespFor_Other_Industry)
(JRespFor_21_1=FirstJRespFor_Other_IP)
(JRespFor_22_1=FirstJRespFor_Other_Branding)
(JRespFor_23_1=FirstJRespFor_Other_PR)
(JRespFor_24_1=FirstJRespFor_Other_Events)
(JRespFor_25_1=FirstJRespFor_Other_Safety)
(JRespFor_26_1=FirstJRespFor_Other_Compliance).

RECODE FirstJRespFor_Other FirstJRespFor_Other_Education FirstJRespFor_Other_International FirstJRespFor_Other_Industry FirstJRespFor_Other_IP FirstJRespFor_Other_Branding FirstJRespFor_Other_PR 
    FirstJRespFor_Other_Events FirstJRespFor_Other_Safety FirstJRespFor_Other_Compliance (SYSMIS=0).
EXECUTE.

COMPUTE Other = FirstJRespFor_Other_Education+FirstJRespFor_Other_International+FirstJRespFor_Other_Industry+FirstJRespFor_Other_IP+
FirstJRespFor_Other_Branding+FirstJRespFor_Other_PR+FirstJRespFor_Other_Events+FirstJRespFor_Other_Safety+FirstJRespFor_Other_Compliance.
DO IF (FirstJRespFor_Other=1 AND Pre = 0). 
    COMPUTE FirstJRespFor_Other_Education=1.
    COMPUTE FirstJRespFor_Other_International=1.
    COMPUTE FirstJRespFor_Other_Industry=1.
    COMPUTE FirstJRespFor_Other_IP=1.
    COMPUTE FirstJRespFor_Other_Branding=1.
    COMPUTE FirstJRespFor_Other_PR=1.
    COMPUTE FirstJRespFor_Other_Events=1.
    COMPUTE FirstJRespFor_Other_Safety=1.
    COMPUTE FirstJRespFor_Other_Compliance=1.
ELSE IF (FirstJRespFor_Other=1 AND RANGE(Post,1,8)). 
    COMPUTE FirstJRespFor_Other=0.
ELSE IF (FirstJRespFor_Other=0 AND Post = 9). 
    COMPUTE FirstJRespFor_Other=1.
END IF.
EXECUTE.

VARIABLE LABELS FirstJRespFor_Other "6fd. Did you first work in the area of J-Other?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other (-99).
ADD VALUE LABELS FirstJRespFor_Other -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_Education "6fda. Did you first work in the area of J-Other-Education?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_Education 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_Education (-99).
ADD VALUE LABELS FirstJRespFor_Other_Education -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_Education (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_International "6fdb. Did you first work in the area of J-Other-International Collaboration?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_International 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_International (-99).
ADD VALUE LABELS FirstJRespFor_Other_International -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_International (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_Industry "6fdc. Did you first work in the area of J-Other-Industry Collaboration?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_Industry 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_Industry (-99).
ADD VALUE LABELS FirstJRespFor_Other_Industry -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_Industry (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_IP "6fdd. Did you first work in the area of J-Other-Intellectual Property?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_IP 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_IP (-99).
ADD VALUE LABELS FirstJRespFor_Other_IP -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_IP (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_Branding "6fde. Did you first work in the area of J-Other-Institution Branding?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_Branding 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_Branding (-99).
ADD VALUE LABELS FirstJRespFor_Other_Branding -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_Branding (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_PR "6fdf. Did you first work in the area of J-Other-Public Relations?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_PR 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_PR (-99).
ADD VALUE LABELS FirstJRespFor_Other_PR -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_PR (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_Events "6fdg. Did you first work in the area of J-Other-Events?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_Events 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_Events (-99).
ADD VALUE LABELS FirstJRespFor_Other_Events -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_Events (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_Safety "6fdh. Did you first work in the area of J-Other-Safety?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_Safety 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_Safety (-99).
ADD VALUE LABELS FirstJRespFor_Other_Safety -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_Safety (NOMINAL).
EXECUTE.
VARIABLE LABELS FirstJRespFor_Other_Compliance "6fdi. Did you first work in the area of J-Other-Compliance?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_Other_Compliance 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_Other_Compliance (-99).
ADD VALUE LABELS FirstJRespFor_Other_Compliance -99 "No Response".
VARIABLE LEVEL FirstJRespFor_Other_Compliance (NOMINAL).
EXECUTE.

* *** the final "other" section of the Japanese taxonomy (current).
RENAME VARIABLES (JRespFor_17_2=JRespFor_Other)
(JRespFor_18_2=JRespFor_Other_International)
(JRespFor_19_2=JRespFor_Other_Education)
(JRespFor_20_2=JRespFor_Other_Industry)
(JRespFor_21_2=JRespFor_Other_IP)
(JRespFor_22_2=JRespFor_Other_Branding)
(JRespFor_23_2=JRespFor_Other_PR)
(JRespFor_24_2=JRespFor_Other_Events)
(JRespFor_25_2=JRespFor_Other_Safety)
(JRespFor_26_2=JRespFor_Other_Compliance).

RECODE JRespFor_Other JRespFor_Other_Education JRespFor_Other_International JRespFor_Other_Industry JRespFor_Other_IP JRespFor_Other_Branding JRespFor_Other_PR JRespFor_Other_Events JRespFor_Other_Safety JRespFor_Other_Compliance (SYSMIS=0).
EXECUTE.

COMPUTE Other = JRespFor_Other_Education+JRespFor_Other_International+JRespFor_Other_Industry+JRespFor_Other_IP+
JRespFor_Other_Branding+JRespFor_Other_PR+JRespFor_Other_Events+JRespFor_Other_Safety+JRespFor_Other_Compliance.
DO IF (JRespFor_Other=1 AND Pre = 0). 
    COMPUTE JRespFor_Other_Education=1.
    COMPUTE JRespFor_Other_International=1.
    COMPUTE JRespFor_Other_Industry=1.
    COMPUTE JRespFor_Other_IP=1.
    COMPUTE JRespFor_Other_Branding=1.
    COMPUTE JRespFor_Other_PR=1.
    COMPUTE JRespFor_Other_Events=1.
    COMPUTE JRespFor_Other_Safety=1.
    COMPUTE JRespFor_Other_Compliance=1.
ELSE IF (JRespFor_Other=1 AND RANGE(Post,1,8)). 
    COMPUTE JRespFor_Other=0.
ELSE IF (JRespFor_Other=0 AND Post = 9). 
    COMPUTE JRespFor_Other=1.
END IF.
EXECUTE.


VARIABLE LABELS JRespFor_Other "6d. Do you work in the area of J-Other?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other (-99).
ADD VALUE LABELS JRespFor_Other -99 "No Response".
VARIABLE LEVEL JRespFor_Other (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_Education "6da. Do you work in the area of J-Other-Education?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_Education 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_Education (-99).
ADD VALUE LABELS JRespFor_Other_Education -99 "No Response".
VARIABLE LEVEL JRespFor_Other_Education (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_International "6db. Do you work in the area of J-Other-International Collaboration?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_International 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_International (-99).
ADD VALUE LABELS JRespFor_Other_International -99 "No Response".
VARIABLE LEVEL JRespFor_Other_International (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_Industry "6dc. Do you work in the area of J-Other-Industry Collaboration?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_Industry 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_Industry (-99).
ADD VALUE LABELS JRespFor_Other_Industry -99 "No Response".
VARIABLE LEVEL JRespFor_Other_Industry (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_IP "6dd. Do you work in the area of J-Other-Intellectual Property?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_IP 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_IP (-99).
ADD VALUE LABELS JRespFor_Other_IP -99 "No Response".
VARIABLE LEVEL JRespFor_Other_IP (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_Branding "6de. Do you work in the area of J-Other-Institution Branding?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_Branding 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_Branding (-99).
ADD VALUE LABELS JRespFor_Other_Branding -99 "No Response".
VARIABLE LEVEL JRespFor_Other_Branding (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_PR "6df. Do you work in the area of J-Other-Public Relations?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_PR 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_PR (-99).
ADD VALUE LABELS JRespFor_Other_PR -99 "No Response".
VARIABLE LEVEL JRespFor_Other_PR (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_Events "6dg. Do you work in the area of J-Other-Events?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_Events 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_Events (-99).
ADD VALUE LABELS JRespFor_Other_Events -99 "No Response".
VARIABLE LEVEL JRespFor_Other_Events (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_Safety "6dh. Do you work in the area of J-Other-Safety?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_Safety 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_Safety (-99).
ADD VALUE LABELS JRespFor_Other_Safety -99 "No Response".
VARIABLE LEVEL JRespFor_Other_Safety (NOMINAL).
EXECUTE.
VARIABLE LABELS JRespFor_Other_Compliance "6di. Do you work in the area of J-Other-Compliance?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_Other_Compliance 1 "Yes" 0 "No".
MISSING VALUES JRespFor_Other_Compliance (-99).
ADD VALUE LABELS JRespFor_Other_Compliance -99 "No Response".
VARIABLE LEVEL JRespFor_Other_Compliance (NOMINAL).
EXECUTE.

* *** Other "other" in Japanese taxonomy (something else entirely) for first role.
RENAME VARIABLES JRespFor_27_1=FirstJRespFor_SomethingElse.
RECODE FirstJRespFor_SomethingElse (SYSMIS=0).
EXECUTE.
VARIABLE LABELS FirstJRespFor_SomethingElse "6fe. Did you first work in the area of J-Something Else Entirely?". /* trying to retain Q numbers.
VALUE LABELS FirstJRespFor_SomethingElse 1 "Yes" 0 "No".
MISSING VALUES FirstJRespFor_SomethingElse (-99).
ADD VALUE LABELS FirstJRespFor_SomethingElse -99 "No Response".
VARIABLE LEVEL FirstJRespFor_SomethingElse (NOMINAL).
EXECUTE.

* *** Other "other" in Japanese taxonomy (something else entirely).
RENAME VARIABLES JRespFor_27_2=JRespFor_SomethingElse.
RECODE JRespFor_SomethingElse (SYSMIS=0).
EXECUTE.
VARIABLE LABELS JRespFor_SomethingElse "6e. Do you work in the area of J-Something Else Entirely?". /* trying to retain Q numbers.
VALUE LABELS JRespFor_SomethingElse 1 "Yes" 0 "No".
MISSING VALUES JRespFor_SomethingElse (-99).
ADD VALUE LABELS JRespFor_SomethingElse -99 "No Response".
VARIABLE LEVEL JRespFor_SomethingElse (NOMINAL).
EXECUTE.

* *** do this backcoding first so that the refilling of not 1s with 0s will happen.
* *** backcoding from JRespFor_SomethingElseD - CO.
IF (ResponseId="R_ODXwSvbCy2bzS37") FirstJRespFor_SomethingElse=1.
DO IF (ResponseId="R_1EXuIVpws7EVteE").
    COMPUTE FirstJRespFor_RDP_Strategy=1.
    COMPUTE FirstJRespFor_Other_Compliance=1.
END IF.
DO IF (ResponseId="R_yUcqox0yn1lxdGF").
    COMPUTE FirstJRespFor_Pre_ProjPlan=1.
    COMPUTE FirstJRespFor_Pre_AppSupport=1.
    COMPUTE FirstJRespFor_Other_Events=1.
END IF.
IF (ResponseId="R_3nvAxIyWxJ4F1SZ") FirstJRespFor_Pre_AppSupport=1.
IF (ResponseId="R_12S8x2VYaRu58RR") FirstJRespFor_Pre=1.
IF (ResponseId="R_x437fn7shATzcBP") FirstJRespFor_Pre_AppSupport=1.
DO IF (ResponseId="R_21drhm6sWwXqkHS").
    COMPUTE FirstJRespFor_RDP_Strategy=1.
    COMPUTE FirstJRespFor_Other_International=1.
END IF.
IF (ResponseId="R_3ewOOjLRS3mPd8v") FirstJRespFor_SomethingElse=1.
* and now coding into current... but only if blank (the list above for First were all blank.
IF ((ResponseId="R_ODXwSvbCy2bzS37") AND SYSMIS(JRespFor_SomethingElse)) JRespFor_SomethingElse=1.
IF ((ResponseId="R_1kXliHVGWNYAIKJ") AND SYSMIS(JRespFor_Other_Compliance)) JRespFor_Other_Compliance=1.
IF ((ResponseId="R_yUcqox0yn1lxdGF") AND SYSMIS(JRespFor_Other_Events)) JRespFor_Other_Events=1.
IF ((ResponseId="R_3ptosj7zagNJmNn") AND SYSMIS(JRespFor_Other_Events)) JRespFor_Other_Events=1.
IF ((ResponseId="R_x437fn7shATzcBP") AND SYSMIS(JRespFor_RDP_InstRes)) JRespFor_RDP_InstRes=1.
IF ((ResponseId="R_2X0xMo49JYRzQMd") AND SYSMIS(JRespFor_Post_ProgressMgt)) JRespFor_Post_ProgressMgt=1.
IF ((ResponseId="R_ZL7W18wTaNOZTmV") AND SYSMIS(JRespFor_RDP_InstRes)) JRespFor_RDP_InstRes=1.
IF ((ResponseId="R_3ewOOjLRS3mPd8v") AND SYSMIS(JRespFor_SomethingElse)) JRespFor_SomethingElse=1.
DO IF (ResponseId="R_1EXuIVpws7EVteE").
    IF(SYSMIS(JRespFor_RDP)) JRespFor_RDP=1.
    IF(SYSMIS(JRespFor_Pre)) JRespFor_Pre=1.
    IF(SYSMIS(JRespFor_Post)) JRespFor_Post=1.
    IF(SYSMIS(JRespFor_Other_Compliance)) JRespFor_Other_Compliance=1.
END IF.
DO IF (ResponseId="R_3nvAxIyWxJ4F1SZ").
    IF(SYSMIS(JRespFor_Other_Events)) JRespFor_Other_Events=1.
    IF(SYSMIS(JRespFor_Other_Compliance)) JRespFor_Other_Compliance=1.
    IF(SYSMIS(JRespFor_SomethingElse)) JRespFor_SomethingElse=1.
END IF.
DO IF (ResponseId="R_12S8x2VYaRu58RR").
    IF(SYSMIS(JRespFor_Pre_IntNegotiation)) JRespFor_Pre_IntNegotiation=1.
    IF(SYSMIS(JRespFor_Post_ProgressMgt)) JRespFor_Post_ProgressMgt=1.
    IF(SYSMIS(JRespFor_Post_Accounting)) JRespFor_Post_Accounting=1.
    IF(SYSMIS(JRespFor_Other_Compliance)) JRespFor_Other_Compliance=1.
END IF.
DO IF (ResponseId="R_21drhm6sWwXqkHS").
    IF(SYSMIS(JRespFor_RDP_Strategy)) JRespFor_RDP_Strategy=1.
    IF(SYSMIS(JRespFor_Other_International)) JRespFor_Other_International=1.
END IF.
DO IF (ResponseId="R_2zHlDSb3sfxes3M").
    IF(SYSMIS(JRespFor_RDP_InstRes)) JRespFor_RDP_InstRes=1.
    IF(SYSMIS(JRespFor_Pre_ProjPlan)) JRespFor_Pre_ProjPlan=1.
    IF(SYSMIS(JRespFor_Pre_FundInfo)) JRespFor_Pre_FundInfo=1.
END IF.
DO IF (ResponseId="R_p4yDGvHSyRDGWzf").
    IF(SYSMIS(JRespFor_Pre_ProjPlan)) JRespFor_Pre_ProjPlan=1.
    IF(SYSMIS(JRespFor_Post_Reporting)) JRespFor_Post_Reporting=1.
    IF(SYSMIS(JRespFor_Other_International)) JRespFor_Other_International=1.
    IF(SYSMIS(JRespFor_Other_Compliance)) JRespFor_Other_Compliance=1.
    IF(SYSMIS(JRespFor_SomethingElse)) JRespFor_SomethingElse=1.
END IF.
* *** and now for those where current was blank, so no need to check (although the syntax of some does as it was copy and pasted).
IF (ResponseId="R_ODXwSvbCy2bzS37") JRespFor_SomethingElse=1.
DO IF (ResponseId="R_1i4egVoKCbjECz9").
    IF(SYSMIS(JRespFor_Pre_ExtNegotiation)) JRespFor_Pre_ExtNegotiation=1.
    IF(SYSMIS(JRespFor_Post_ExtAdjust)) JRespFor_Post_ExtAdjust=1.
END IF.
DO IF (ResponseId="R_3EMzleWVMTrCLfN").
    IF(SYSMIS(JRespFor_Pre)) JRespFor_Pre=1.
    IF(SYSMIS(JRespFor_Post_Reporting)) JRespFor_Post_Reporting=1.
END IF.
IF (ResponseId="R_1OqtZxXbrNCAeXI") JRespFor_Other_Compliance=1.
IF (ResponseId="R_3mb0DoTd3FachmK") JRespFor_Pre_AppSupport=1.
IF (ResponseId="R_2fiX115mjw6dlME") JRespFor_Post_Reporting=1.
IF (ResponseId="R_2zBVjJVSnqJG1uV") JRespFor_Other_Compliance=1.
DO IF (ResponseId="R_1IGXK6n6bEEqrLP").
    IF(SYSMIS(JRespFor_RDP_InstRes)) JRespFor_RDP_InstRes=1.
    IF(SYSMIS(JRespFor_Post_Reporting)) JRespFor_Post_Reporting=1.
    IF(SYSMIS(JRespFor_Other_Compliance)) JRespFor_Other_Compliance=1.
END IF.
IF (ResponseId="R_bHrYuZezvWRn7jP") JRespFor_RDP=1.
EXECUTE.

* *** IF every single option for first role is unticked, then revert them to SYSMIS.
COMPUTE FirstJCurrent = FirstJRespFor_RDP+FirstJRespFor_RDP_Policy+FirstJRespFor_RDP_InstRes+FirstJRespFor_RDP_Strategy+FirstJRespFor_Pre+FirstJRespFor_Pre_ProjPlan+
FirstJRespFor_Pre_FundInfo+FirstJRespFor_Pre_IntNegotiation+FirstJRespFor_Pre_ExtNegotiation+FirstJRespFor_Pre_AppSupport+FirstJRespFor_Post+FirstJRespFor_Post_ExtAdjust+
FirstJRespFor_Post_ProgressMgt+FirstJRespFor_Post_Accounting+FirstJRespFor_Post_ProjEval+FirstJRespFor_Post_Reporting+FirstJRespFor_Other+FirstJRespFor_Other_International+
FirstJRespFor_Other_Education+FirstJRespFor_Other_Industry+FirstJRespFor_Other_IP+FirstJRespFor_Other_Branding+FirstJRespFor_Other_PR+FirstJRespFor_Other_Events+
FirstJRespFor_Other_Safety+FirstJRespFor_Other_Compliance+FirstJRespFor_SomethingElse.
EXECUTE.
    
DO IF (FirstJCurrent = 0).
    COMPUTE FirstJRespFor_RDP=$SYSMIS.
    COMPUTE FirstJRespFor_RDP_Policy=$SYSMIS.
    COMPUTE FirstJRespFor_RDP_InstRes=$SYSMIS.
    COMPUTE FirstJRespFor_RDP_Strategy=$SYSMIS.
    COMPUTE FirstJRespFor_Pre=$SYSMIS.
    COMPUTE FirstJRespFor_Pre_ProjPlan=$SYSMIS.
    COMPUTE FirstJRespFor_Pre_FundInfo=$SYSMIS.
    COMPUTE FirstJRespFor_Pre_IntNegotiation=$SYSMIS.
    COMPUTE FirstJRespFor_Pre_ExtNegotiation=$SYSMIS.
    COMPUTE FirstJRespFor_Pre_AppSupport=$SYSMIS.
    COMPUTE FirstJRespFor_Post=$SYSMIS.
    COMPUTE FirstJRespFor_Post_ExtAdjust=$SYSMIS.
    COMPUTE FirstJRespFor_Post_ProgressMgt=$SYSMIS.
    COMPUTE FirstJRespFor_Post_Accounting=$SYSMIS.
    COMPUTE FirstJRespFor_Post_ProjEval=$SYSMIS.
    COMPUTE FirstJRespFor_Post_Reporting=$SYSMIS.
    COMPUTE FirstJRespFor_Other=$SYSMIS.
    COMPUTE FirstJRespFor_Other_International=$SYSMIS.
    COMPUTE FirstJRespFor_Other_Education=$SYSMIS.
    COMPUTE FirstJRespFor_Other_Industry=$SYSMIS.
    COMPUTE FirstJRespFor_Other_IP=$SYSMIS.
    COMPUTE FirstJRespFor_Other_Branding=$SYSMIS.
    COMPUTE FirstJRespFor_Other_PR=$SYSMIS.
    COMPUTE FirstJRespFor_Other_Events=$SYSMIS.
    COMPUTE FirstJRespFor_Other_Safety=$SYSMIS.
    COMPUTE FirstJRespFor_Other_Compliance=$SYSMIS.
    COMPUTE FirstJRespFor_SomethingElse=$SYSMIS.
END IF.
EXECUTE. 

* *** IF every single option for current role is unticked, then revert them to SYSMIS.
COMPUTE JCurrent = JRespFor_RDP+JRespFor_RDP_Policy+JRespFor_RDP_InstRes+JRespFor_RDP_Strategy+JRespFor_Pre+JRespFor_Pre_ProjPlan+
JRespFor_Pre_FundInfo+JRespFor_Pre_IntNegotiation+JRespFor_Pre_ExtNegotiation+JRespFor_Pre_AppSupport+JRespFor_Post+JRespFor_Post_ExtAdjust+
JRespFor_Post_ProgressMgt+JRespFor_Post_Accounting+JRespFor_Post_ProjEval+JRespFor_Post_Reporting+JRespFor_Other+JRespFor_Other_International+
JRespFor_Other_Education+JRespFor_Other_Industry+JRespFor_Other_IP+JRespFor_Other_Branding+JRespFor_Other_PR+JRespFor_Other_Events+
JRespFor_Other_Safety+JRespFor_Other_Compliance+JRespFor_SomethingElse.
EXECUTE.
    
DO IF (JCurrent = 0).
    COMPUTE JRespFor_RDP=$SYSMIS.
    COMPUTE JRespFor_RDP_Policy=$SYSMIS.
    COMPUTE JRespFor_RDP_InstRes=$SYSMIS.
    COMPUTE JRespFor_RDP_Strategy=$SYSMIS.
    COMPUTE JRespFor_Pre=$SYSMIS.
    COMPUTE JRespFor_Pre_ProjPlan=$SYSMIS.
    COMPUTE JRespFor_Pre_FundInfo=$SYSMIS.
    COMPUTE JRespFor_Pre_IntNegotiation=$SYSMIS.
    COMPUTE JRespFor_Pre_ExtNegotiation=$SYSMIS.
    COMPUTE JRespFor_Pre_AppSupport=$SYSMIS.
    COMPUTE JRespFor_Post=$SYSMIS.
    COMPUTE JRespFor_Post_ExtAdjust=$SYSMIS.
    COMPUTE JRespFor_Post_ProgressMgt=$SYSMIS.
    COMPUTE JRespFor_Post_Accounting=$SYSMIS.
    COMPUTE JRespFor_Post_ProjEval=$SYSMIS.
    COMPUTE JRespFor_Post_Reporting=$SYSMIS.
    COMPUTE JRespFor_Other=$SYSMIS.
    COMPUTE JRespFor_Other_International=$SYSMIS.
    COMPUTE JRespFor_Other_Education=$SYSMIS.
    COMPUTE JRespFor_Other_Industry=$SYSMIS.
    COMPUTE JRespFor_Other_IP=$SYSMIS.
    COMPUTE JRespFor_Other_Branding=$SYSMIS.
    COMPUTE JRespFor_Other_PR=$SYSMIS.
    COMPUTE JRespFor_Other_Events=$SYSMIS.
    COMPUTE JRespFor_Other_Safety=$SYSMIS.
    COMPUTE JRespFor_Other_Compliance=$SYSMIS.
    COMPUTE JRespFor_SomethingElse=$SYSMIS.
END IF.
EXECUTE. 


* JResponsibilityFor_OD.
* Other areas that people might work in that they have added.
* *** Possible opportunity to add new codings if many responses the same.
RENAME VARIABLES JResponsibilityForOD=JRespFor_SomethingElseD.
VARIABLE LABELS JRespFor_SomethingElseD "6ea. Details of other areas worked in".
MISSING VALUES JRespFor_SomethingElseD ("").
VALUE LABELS JRespFor_SomethingElseD "" "No Response".
EXECUTE.


* *** end of day 1 coding ***. (for v1 document).
* *** Anonymising for WorksInOtherArea ***.SK.
IF (ResponseId="R_2QFCLFRc4WivaZe") JRespFor_SomethingElseD="Running internal grant agency - XXXX".
IF (ResponseId="R_24hGeKAxTWgPNAh") JRespFor_SomethingElseD="Coordinador de un grupo de investigación y dos semilleros de investigación y Coordinador Ejecutivo del Observatorio de XXXX".
IF (ResponseId="R_2xz4afuk9SUlISa") JRespFor_SomethingElseD="My current Centre functions as a XXXX research network of 21 high education institutions. ".
IF (ResponseId="R_yUctdkabBhB4DND") JRespFor_SomethingElseD=CONCAT("Many points answered in previous item. As my expertise grew I was more and more responsible for comm",
"unication with international institutions - administration of US cooperation - industrial research partner (PI of DARPA or IARPA projects) our institution was in subcontractor position. I was responsi",
"ble for registration of our institution in US GOV SAM in period 2013 - 2019. I established and maintained also registrations of our institution in many Suppliers Portals of our sponzors (XXXX). Regist",
"ration in XXXX etc.). I was responsible for execution of financial support, which ONRG provided for on-line platform of the international conference, which our institution organized for about 1900 res",
"earchers. As for PR - I was representing our institution when visiting our US partners (industrial partner in Boston, XXXX in Baltimore and NSF in Alexandria). As for intellectual property – I maintai",
"ned a patent filing initiated by our Japanese industrial partner. ").
IF (ResponseId="R_2ClmnbYx0TWK2Fe") JRespFor_SomethingElseD="Delivering an education programme Development of global data standards for XXXX".
IF (ResponseId="R_5aKA4slvoJPK86Z") JRespFor_SomethingElseD="I am still in the area of work since I joined the University of XXXX.".
EXECUTE.
    
* *** same as RAAAP-2.
VARIABLE LEVEL JobDescriptionMatch (ORDINAL).
VARIABLE LABELS JobDescriptionMatch "7. Does your job description match your duties?".
MISSING VALUES JobDescriptionMatch (-99).
ADD VALUE LABELS JobDescriptionMatch -99 "No Response".
EXECUTE.
*JobDescriptionMatchD need to do anything - for example if they did not respond to Q7 but put text here we could backcode Q7 based on that..
VARIABLE LABELS JobDescriptionMatchD "7a. Details of job description matching duties".
MISSING VALUES JobDescriptionMatchD ("").
VALUE LABELS JobDescriptionMatchD "" "No Response".
EXECUTE.

* *** JobDescriptionMatchD anonymising - SK (lead by MD).
IF (ResponseId="R_vuIfPwu5i0erJrH") JobDescriptionMatchD="Aunque mi contrato es con un tercero a XXXX, en este se especifica que soy auxiliar en el apoyo a los proyectos de Investigación. ".
IF (ResponseId="R_3KZOEwXOAfmrPm4") JobDescriptionMatchD=CONCAT("Since XXXX, I have been the chief manager of the Ministry XXXX of Ukraine grant aimed at the long-te",
"rm development of the science direction 'Mathematical and natural sciences' at the XXXX University of Kyiv XXXX. In 2018 as a member of international team that includes groups from Ukraine, the United",
" Kingdom, Spain and Italy, I contributed to the proposal 'XXXX” for a grant under umbrella of the European Union’s Horizon 2020. The proposal was evaluated positively and got funding. In 2016 and 2019",
" I attracted funding from Erasmus+ program ' XXXX. I was selected as a Program Supervisor and Manager from the Ukrainian side. From 01/2017 to 12/2019, I was Manager of the grant of the Ministry of XX",
"XX of Ukraine (XXXX) 'XXXX.' (I supervise team of 25 people). In XXXX and XXXX at the invitation from Prof. Dr. XXXX( the College of XXXX of XXXX University, China), I visited the aforesaid ",
"College as a Visiting Researcher and delivered lectures to Ph.D. students and performed scientific research in the field of 'XXXX.").
IF (ResponseId="R_25AYzZpB7yAyLWK") JobDescriptionMatchD="retired; provide mentoring for XXXX members and consulting as requested.".
IF (ResponseId="R_24hGeKAxTWgPNAh") JobDescriptionMatchD=CONCAT("Las funciones como Coordinador Ejecutivo del Observatorio de Ciencia y Tecnología de XXXX Universida",
"d XXXX estan dadas en una Resolución de rectoria. Las demas funciones en la normativa interna de XXXX universidad.").
IF (ResponseId="R_2xz4afuk9SUlISa") JobDescriptionMatchD="XXXX advocacy on the XXXX and training staff take up a lot of time at present".
IF (ResponseId="R_XGRG8DQi7XhZVtf") JobDescriptionMatchD=CONCAT("Job descriptions are vague enough to fit in everythign I do ... for example, my job is 'to establish",
" a research environment'. That can mean anything. :) Interestingly, I have not beein thinking in pre-and post award until I attended EARMA (XXXX). I will be giving this aspect some thought in order to",
" sharpen my job profile. ").
EXECUTE.
* *** JobDescriptionMatchD backcoding, where selection was blank - SK.
IF (ResponseId="R_32PeBWKva0RgpG4") JobDescriptionMatch=2.
IF (ResponseId="R_3nPDIQ7UmAx7L6z") JobDescriptionMatch=4.
EXECUTE.

* which areas to you support.
RENAME VARIABLES SubjectAreasSupport_4=SubjectAreasSupport_Science.
VARIABLE LABELS SubjectAreasSupport_Science "8a. Do you support research in the area of Science?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Science 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Science (-99).
ADD VALUE LABELS SubjectAreasSupport_Science -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Science (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_5=SubjectAreasSupport_Medicine.
VARIABLE LABELS SubjectAreasSupport_Medicine "8b. Do you support research in the area of Medicine?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Medicine 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Medicine (-99).
ADD VALUE LABELS SubjectAreasSupport_Medicine -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Medicine (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_6=SubjectAreasSupport_Enginering.
VARIABLE LABELS SubjectAreasSupport_Enginering "8c. Do you support research in the area of Engineering?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Enginering 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Enginering (-99).
ADD VALUE LABELS SubjectAreasSupport_Enginering -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Enginering (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_7=SubjectAreasSupport_Business.
VARIABLE LABELS SubjectAreasSupport_Business "8d. Do you support research in the area of Busines?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Business 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Business (-99).
ADD VALUE LABELS SubjectAreasSupport_Business -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Business (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_8=SubjectAreasSupport_SocialScience.
VARIABLE LABELS SubjectAreasSupport_SocialScience "8e. Do you support research in the area of Social Science?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_SocialScience 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_SocialScience (-99).
ADD VALUE LABELS SubjectAreasSupport_SocialScience -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_SocialScience (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_9=SubjectAreasSupport_Humanities.
VARIABLE LABELS SubjectAreasSupport_Humanities "8f. Do you support research in the area of Humanties?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Humanities 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Humanities (-99).
ADD VALUE LABELS SubjectAreasSupport_Humanities -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Humanities (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_10=SubjectAreasSupport_Arts.
VARIABLE LABELS SubjectAreasSupport_Arts "8g. Do you support research in the area of Arts?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Arts 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Arts (-99).
ADD VALUE LABELS SubjectAreasSupport_Arts -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Arts (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_11=SubjectAreasSupport_General.
VARIABLE LABELS SubjectAreasSupport_General "8h. Do you support research in the area of General?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_General 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_General (-99).
ADD VALUE LABELS SubjectAreasSupport_General -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_General (NOMINAL).
EXECUTE.
RENAME VARIABLES SubjectAreasSupport_12=SubjectAreasSupport_Other.
VARIABLE LABELS SubjectAreasSupport_Other "8i. Do you support research in the area of Other?". /* trying to retain Q numbers.
VALUE LABELS SubjectAreasSupport_Other 1 "Yes" 0 "No".
MISSING VALUES SubjectAreasSupport_Other (-99).
ADD VALUE LABELS SubjectAreasSupport_Other -99 "No Response".
VARIABLE LEVEL SubjectAreasSupport_Other (NOMINAL).
EXECUTE.
* *** could be interesting to see how many subject areas are covered by each individual...?.
* *** ALSO question - if they ticked General/All should we back fill all the other areas... Did not do this in RAAAP-2 so leave as is.
RECODE SubjectAreasSupport_Science SubjectAreasSupport_Medicine SubjectAreasSupport_Enginering SubjectAreasSupport_Business
SubjectAreasSupport_SocialScience SubjectAreasSupport_Humanities SubjectAreasSupport_Arts SubjectAreasSupport_General
SubjectAreasSupport_Other (SYSMIS=0).
EXECUTE.

COMPUTE SubjectAreas = SubjectAreasSupport_Science+SubjectAreasSupport_Medicine+SubjectAreasSupport_Enginering+SubjectAreasSupport_Business+
SubjectAreasSupport_SocialScience+SubjectAreasSupport_Humanities+SubjectAreasSupport_Arts+SubjectAreasSupport_General+
SubjectAreasSupport_Other .
DO IF (FirstWorkedIn = 0).
    COMPUTE SubjectAreasSupport_Science=$SYSMIS.
    COMPUTE SubjectAreasSupport_Medicine=$SYSMIS.
    COMPUTE SubjectAreasSupport_Enginering=$SYSMIS.
    COMPUTE SubjectAreasSupport_Business=$SYSMIS.
    COMPUTE SubjectAreasSupport_SocialScience=$SYSMIS.
    COMPUTE SubjectAreasSupport_Humanities=$SYSMIS.
    COMPUTE SubjectAreasSupport_Arts=$SYSMIS.
    COMPUTE SubjectAreasSupport_General=$SYSMIS.
    COMPUTE SubjectAreasSupport_Other=$SYSMIS.
END IF.
EXECUTE.

RENAME VARIABLES SubjectAreasSupportO=SubjectAreasSupport_OD.
VARIABLE LABELS SubjectAreasSupport_OD "8. Please give details (of other areas of research that you support)". /* trying to retain Q numbers.
MISSING VALUES SubjectAreasSupport_OD ("").
VALUE LABELS SubjectAreasSupport_OD "" "No Response".
* Opportunity to backcode 8a-8i based on the text here.  Not done for RAAAP-2..
* *** backcoding for SubjectAreasSupportO where no choices were made - SK.
IF (ResponseId="R_2fCnbSkCnHCbL9e") SubjectAreasSupport_Humanities=1.
EXECUTE.

* *** anonymising SubjectAreasSupport_OD - CO.
IF (ResponseId="R_zbYqrmbOc59xEg9") SubjectAreasSupport_OD="Deux universités Shs, XXXX CNRS et des musées sont dans la COMUE où je travaille. Nb : plus 1laboratoire en mathématiques et 3 en informatique".
IF (ResponseId="R_O6F21eHhkWL2Uil") SubjectAreasSupport_OD="XXXX and Center for XXXX Policy".
IF (ResponseId="R_2QibIJZYaBvfAAM") SubjectAreasSupport_OD=CONCAT("I handle sponsored programs for 3-depts under the Institute XXXX Sciences, including Entomology and ",
"nematology,  Microbiology and Cell Science, and XXXX Research and Education Center (XXXX).  We deal with programs that cover agriculture, human and natural resources, and the life sciences with educat",
"ion, research and service. Funding for projects come from federal, state, local, international, non-profit organizations, grower groups and commercial companies.  I've worked on projects that had MTAs",
", MOUs, N/CDAs CRADA, MAs, Data Usage Agreements, Clinical Trials, IPAs and a variety of other agreements.  I no longer negotiate agreements as our DSP does that, but will assist as needed, and will s",
"ometimes draft an agreement or modification if time allows.  Life is never boring.  I hope in the next 3-years to train and pass on most of my KSAs as possible to my assistants to takeover the depts. ",
"when I retire XXXX with all 35-years in at XXXX/XXXX.").
IF (ResponseId="R_1IKU6aw0alWKVxE") SubjectAreasSupport_OD="En Ciencias de la Salud: Facultad de XXXX.".
IF (ResponseId="R_5AbkpmgNehadjkR") SubjectAreasSupport_OD="In engineering we also account XXXX degree programmes, as it is one programme in our Faculty of XXXX Technology (although XXXX might be more logically in 'Other'...).".
IF (ResponseId="R_3PjyKd6VFN2Igty") SubjectAreasSupport_OD="XXXX Flagship project belongs to the social sciences.".
IF (ResponseId="R_XiFgWlqq2gMbqIV") SubjectAreasSupport_OD="The XXXX Academy of Sciences, Institute of XXXX".
IF (ResponseId="R_241sBkQTgKl95S5") SubjectAreasSupport_OD="The Centre I manage spans the Faculty of Social Sciences and XXXX and Institute of XXXX".
IF (ResponseId="R_3KBlXf1pDysQbqz") SubjectAreasSupport_OD="Trabajo en Universidad Pública con el mayor índice de productos e investigadores en Colombia: Universidad XXXX Colombia.".
IF (ResponseId="R_vuIfPwu5i0erJrH") SubjectAreasSupport_OD=CONCAT("En el Centro De investigaciones de la Facultas de Ciencias XXXX administramos en mayor parte proyect",
"os de Investigación de las áreas de Ciencias Exactas, pero también administramos proyectos del área d ela Salud y de ingeniería. ").
IF (ResponseId="R_1giqLH2DJtmxWB2") SubjectAreasSupport_OD="XXXX".
IF (ResponseId="R_3KZOEwXOAfmrPm4") SubjectAreasSupport_OD=CONCAT("I have been the chief manager of the Ministry XXXX of Ukraine grant aimed at the long-term developme",
"nt of the science direction 'Mathematical and natural sciences' at the XXXX University of Kyiv (XXXX) (I supervise team of 54 people).").
IF (ResponseId="R_x5E62jE9Yuu0GWt") SubjectAreasSupport_OD="Support faculty and staff in College of XXXX Medicine and College of XXXX".
IF (ResponseId="R_CgMiqcUS7e49kd3") SubjectAreasSupport_OD="I work within the College of Science which also incorporates the National Centre for XXXX and the XXXX Institute of XXXX Technology".
IF (ResponseId="R_2wiST9UonTMxm9Q") SubjectAreasSupport_OD="I Work at the central research office .so I attend to different people on a daily basis. I am also the RA in charge of Faculty of Public health , Institute of XXXX and Institute of XXXX".
IF (ResponseId="R_u1wK0UmEhy0QC1X") SubjectAreasSupport_OD=CONCAT("My current departments include XXXX Water Institute, Biological Sciences, Chemistry & Biochemistry, ",
"College of Business, Chemical and Biological Engineering, Institute for Communication Research, New College, Physics & Astronomy, Psychology, Theatre & Dance, and University Libraries.").
IF (ResponseId="R_24IPqhS6kjx30op") SubjectAreasSupport_OD="My current portfolio focuses on the Health Faculty but I have worked across most faculties during my time at XXXX".
IF (ResponseId="R_3r3fIdp4j3wz6Ku") SubjectAreasSupport_OD="As mentioned I´m working at the Faculty of Economics and Administration at XXXX currently so the projects are focused on economics and interdisciplinary themes/areas.".
IF (ResponseId="R_2aQ5YCASVXk1lEM") SubjectAreasSupport_OD="I work for the Institute of XXXX Medicine XXXX, so obviously health (including one health approach) focused on tropical diseases.".
IF (ResponseId="R_2uEUle5HiEnk0WK") SubjectAreasSupport_OD="Process awards and proposals for College of XXXX along with Public Service and Agriculture.".
IF (ResponseId="R_CkSUTDyJge3AXbb") SubjectAreasSupport_OD="Work at a XXXX medicine at academic medical center".
EXECUTE.

* *** Q9 & 9a.
VARIABLE LEVEL EducationAligned (NOMINAL).
MISSING VALUES EducationAligned (-99).
ADD VALUE LABELS EducationAligned -99 "No Response".
EXECUTE.
VARIABLE LEVEL EducationAlignedDet (NOMINAL).
VARIABLE LABELS EducationAlignedDet "9. Details of Education alignment". /* trying to retain Q numbers.
MISSING VALUES EducationAlignedDet ("").
VALUE LABELS EducationAlignedDet "" "No Response".
EXECUTE.

* *** Q10 & 10a.
VARIABLE LEVEL EducationAlignImp (NOMINAL).
MISSING VALUES EducationAlignImp (-99).
ADD VALUE LABELS EducationAlignImp -99 "No Response".
EXECUTE.
RENAME VARIABLES EducationAlignImpD=EducationAlignImpDet. /* to be a little more consistent.
VARIABLE LABELS EducationAlignImpDet "10. Details of Importance of Education alignment". /* trying to retain Q numbers.
VARIABLE LEVEL EducationAlignImpDet (NOMINAL).
MISSING VALUES EducationAlignImpDet ("").
VALUE LABELS EducationAlignImpDet "" "No Response".

* *** backcoding EducationAlignedDet --> EducationAligned - MF.
IF (ResponseId="R_28TxK6Bo3YyD8oU") EducationAlignedDet=CONCAT("Studies: Biology First work experience at the XXXX, where I gained experience writing and submitting",
" proposals myself. Later, I set up the first structures for research funding at a newly established university and attended the relevant seminars.  In the meantime, well anchored in the topic through ",
"exchange rounds and further training.   Therefore, building knowledge through experience, not through training").
IF (ResponseId="R_2QibIJZYaBvfAAM") EducationAlignedDet=CONCAT("I have the following degrees, A.S. in Secondary Education; BA in Communications-Public Relations; XX",
"XX: MA '97 in Political Science - Public Administration and Policy; ABD in Political Science - American Government (did all the class work, but burnt out on the dissertation as I worked full time duri",
"ng MA/ABD...so All But Dissertation).  The combination of all degrees gave me  KSAs for working as a RMA.  Also, I grew up in XXXX farmlands and fishing region, so agriculture was always a part of my ",
"life.").
IF (ResponseId="R_2TSFRpKy2BkddTT") EducationAlignedDet="I work in XXXX (XXXX) wich is focused in R&D in the fields of communications. I have qualifications as a engineer - but in a close related field and Innovation management . ".
IF (ResponseId="R_2zBVjJVSnqJG1uV") EducationAlignedDet="I have a Masters and PhD in Health Sciences with a focused research ethics track, and have been a XXXX fellow at XXXX and a XXXX Fellow at XXXX".
IF (ResponseId="R_30u6OAmJlen7ZsG") EducationAlignedDet="Bachelor XXXX Univeristy in Management, Economics and Law".
IF (ResponseId="R_3fk0Uq37u62EMV9") EducationAlignedDet=CONCAT("My education background is varied, Associate of Science in Biology, Bachelor of Science in Business ",
"Administration (Management Info Science), Master of Science in Education, Doctorate in Higher Education Administration.  Master Diploma XXXX.").
IF (ResponseId="R_3fkjzJYupDKFe3M") EducationAlignedDet=CONCAT("I've recently completed a PhD course (Hons) in European Union Studies focused on Technology Transfer",
" and Innovation Strategy for the internationalization of SMEs from the University of XXXX, Spain (2021), a postgraduate course at the XXXX University (Prague, Czech Republic) on Management of Science ",
"and Innovation (2019-2020) and a training Designing a Smart Specialisation Strategy (2019) at the XXXX (Lausanne, Switzerland) which gave me additional skills on project and innovation management. Pre",
"viuosly I hold a Master of Business Studies (Hons) in European Integration, EU Policies and Project Management at the University of XXXX, Italy (2011). I hold a Master’s degree (Hons) in Political Sci",
"ence - International Politics and Diplomacy at the University of XXXX, Italy (2009) and a Bachelor’s degree in Political Science – International Relations and Affairs at the University of XXXX, Italy ",
"(2006).").
IF (ResponseId="R_3KZOEwXOAfmrPm4") EducationAlignedDet=CONCAT("EDUCATION AND TRAINING [summaries, goals, and objectives redacted]: XXXX 2012 – Certificate of Senio",
"r Research Scientist in Thermal Physics and Molecular Physics; XXXX 2011-Doctor (Dr. hab.) in Physical and Mathematical Sciences; XXXX 1996- PhD in Physical and Mathematical Sciences;  XXXX 1984 – XXX",
"X 1989-Diploma of Higher Education, Physics").
IF (ResponseId="R_3neffvdQrzOhtVP") EducationAlignedDet=CONCAT("I have a B.A. in English (Writing), which supports my work in proposal development and critical anal",
"ysis of funder requirements. I also hold a MRA from XXXX, which prepared me to advance my career in research administration.").
IF (ResponseId="R_3OqOui6faRHLJ8R") EducationAlignedDet="I have a PhD in Microbiology. I am research manager for XXXX in my university, so work with people from disciplines all across life sciences and some humanities.".
IF (ResponseId="R_3rY4N8rczw05hTq") EducationAlignedDet=CONCAT("I have a PhD in Cognitive Science. XXXX. It brings together economists and psychiatry / psychology t",
"o investigate it. So there is some overlap with my educational background and their current work.").
IF (ResponseId="R_7V8Br1O0nYc9ia5") EducationAlignedDet="I hold a first-class honours degree in literary studies from the University of XXXX and am about to submit a doctoral thesis in postcolonial literary studies".
IF (ResponseId="R_e9BjHcgAYawMfVD") EducationAlignedDet=CONCAT("yes, I am Project Management PMI PMP certified plus two other Italian PM and IT pm certified PMP Ach",
"ievement certificate (XXXX) (XXXX) Norma UNI CEI EN ISO/IEC XXXX, Norma UNI XXXX, Norma UNI ISO XXXX, Norma UNI XXXX - Certification ICT Project Manager UNIXXXX:2017 – CEPAS XXXX - Certification – Pro",
"ject Manager UNIXXXX8:2016 - CEPAS XXXX ").
IF (ResponseId="R_voSw84irNP4aL5L") EducationAlignedDet=CONCAT("I grew up in a family of science and engineering in XXXX, which was a city designed to advance US sc",
"ience and engineering, so I was surrounded by science.  I studied political science and english in undergrad and went on to grad school for library and information science.  I learned (and continue to",
" learn) biology on my own.").
IF (ResponseId="R_xz7cuPzcuvbZYWd") EducationAlignedDet="I have a completely unrelated PhD on Classics. Could not find a job with it, took extra MA on Higher Education studies from XXX and managed to find these kind of mangement jobs afterwards. ".
IF (ResponseId="R_24LOCLjAR3HvFEO") EducationAlignedDet="I have a PhD in XXXX on University-Industry collaborations.".
IF (ResponseId="R_XiFgWlqq2gMbqIV") EducationAlignedDet=CONCAT("My university program was focused on Economic and Social and Cultural anthropology. I had been doing",
" project manager and Czech Development Agency (so different topic), later on, I was employed at one NGO as an Operations and Finance manager (again, totally different topic, it was think-thank) and no",
"w I'm here. It's a bit challenging, but I'm dealing with it. ").
IF (ResponseId="R_zbYqrmbOc59xEg9") EducationAlignedDet=CONCAT("Je suis docteure en anthropologie et diplômée de XXXX. Après pas de formation pour savoir faire une ",
"veille ou monter un projet national ou européen. J’ai eu des formations durant mes années professionnelles, payées par mes employeurs. Ex : médiation scientifique, gérer une direction de la recherche.").
EXECUTE.

* *** backcoding EducationAlignedImpDet --> EducationAligned - none needed -  MF..

* *** backcoding InstituionCharDet - SK. - need to do this before the extra variable InstitutionCharacter2 is created!.
IF (ResponseId="R_yvFlwpakwyAmKuB") InstitutionCharacter=9.
EXECUTE.

* *** backcoding from CurrentEmployer  InstitutionCharacter - SK.
IF (ResponseId="R_2xIS6eGRb0tzhLO") InstitutionCharacter=14.
IF (ResponseId="R_7PreZyn3dT8v3sR") InstitutionCharacter=9.
IF (ResponseId="R_WwHIzuDpU3P9rZT") InstitutionCharacter=10.
IF (ResponseId="R_yViU8jKu3L2U5S9") InstitutionCharacter=15.
IF (ResponseId="R_WinUBsLz9r6muop") InstitutionCharacter=77.
IF (ResponseId="R_1IKU6aw0alWKVxE") InstitutionCharacter=9.
IF (ResponseId="R_2y7XDOebvc7cpiv") InstitutionCharacter=77.
IF (ResponseId="R_cAxXTkcxVgBehvb") InstitutionCharacter=77.
IF (ResponseId="R_2dYjYEzISnc2nsq") InstitutionCharacter=77.
IF (ResponseId="R_31voYV4FQe9bVzU") InstitutionCharacter=14.
IF (ResponseId="R_1dAd4CdWbCBgsgY") InstitutionCharacter=13.
IF (ResponseId="R_3itfJb4WPjF9Y5z") InstitutionCharacter=13.
IF (ResponseId="R_ewCOL6JpvypYH4t") InstitutionCharacter=77.
IF (ResponseId="R_3oZTJGWQGCjbZ6y") InstitutionCharacter=9.
IF (ResponseId="R_2eQZMPRnzFmAxrU") InstitutionCharacter=9.
IF (ResponseId="R_Uih4OBHmwLoAefn") InstitutionCharacter=13.
IF (ResponseId="R_3NJNEk3gwgRVgNy") InstitutionCharacter=11.
IF (ResponseId="R_3iKXCKQnfpw7hny") InstitutionCharacter=9.
IF (ResponseId="R_22LAPG71bLb5rOd") InstitutionCharacter=10.
IF (ResponseId="R_2dvgf4W6vUwnpc8") InstitutionCharacter=12.
IF (ResponseId="R_paf30yu0ndXUL2F") InstitutionCharacter=14.
IF (ResponseId="R_10NujRcD3OtOnBp") InstitutionCharacter=10.
IF (ResponseId="R_yvFlwpakwyAmKuB") InstitutionCharacter=9.
IF (ResponseId="R_293NbFHTmBjb3QO") InstitutionCharacter=9.
IF (ResponseId="R_3L78kHvhdoqxy6c") InstitutionCharacter=14.
IF (ResponseId="R_3prx1Dk55ez171F") InstitutionCharacter=16.
IF (ResponseId="R_2z6ZyQwyn4DIBEv") InstitutionCharacter=13.
IF (ResponseId="R_3KQ70x8anRkQdq8") InstitutionCharacter=14.
IF (ResponseId="R_3dSWtQE0EvVQtl8") InstitutionCharacter=14.
IF (ResponseId="R_1r7zno94TaEJ42Y") InstitutionCharacter=77.
IF (ResponseId="R_2Y4GOgyVzixKZml") InstitutionCharacter=14.
IF (ResponseId="R_z7hhCxB67DqDO9P") InstitutionCharacter=10.
IF (ResponseId="R_2WSZ1UiruW0AjUT") InstitutionCharacter=13.
IF (ResponseId="R_3KBeO3H0zBWEvxb") InstitutionCharacter=9.
IF (ResponseId="R_3FPCZKGkOZwTFvr") InstitutionCharacter=9.
IF (ResponseId="R_2wErhhnu4DAV4up") InstitutionCharacter=15.
IF (ResponseId="R_5704V5hNwSGsfQt") InstitutionCharacter=11.
IF (ResponseId="R_0xi5a9npJiozcyt") InstitutionCharacter=14.
IF (ResponseId="R_2rjQORzohn0jaqZ") InstitutionCharacter=8.
IF (ResponseId="R_12th1ZqK7dnVOZQ") InstitutionCharacter=16.
IF (ResponseId="R_1H1D1jeCrMqN0Cz") InstitutionCharacter=10.
IF (ResponseId="R_OuN1P5hCTA2Sk5X") InstitutionCharacter=77.
IF (ResponseId="R_3e5qBucAMgXqumU") InstitutionCharacter=77.
IF (ResponseId="R_1IpjBK66y0ii6Ws") InstitutionCharacter=14.
IF (ResponseId="R_12RNmBXGFgue4W0") InstitutionCharacter=8.
IF (ResponseId="R_1l0ls1uDc7Dd6yi") InstitutionCharacter=77.
IF (ResponseId="R_2YkOZCVs3zNaUV6") InstitutionCharacter=9.
IF (ResponseId="R_3mjzSjQcSdumg7A") InstitutionCharacter=14.
IF (ResponseId="R_33lm5GA37qAEgUJ") InstitutionCharacter=15.
IF (ResponseId="R_pRizaw6mkamDRvP") InstitutionCharacter=10.
IF (ResponseId="R_2zeGXho1Xx00cFP") InstitutionCharacter=10.
IF (ResponseId="R_2TnvpZXXGjfmR0o") InstitutionCharacter=15.
IF (ResponseId="R_31mzvDjteqQyDNn") InstitutionCharacter=10.
IF (ResponseId="R_2AHcv0cQnWOHAw2") InstitutionCharacter=9.
IF (ResponseId="R_V43LBsaPLspFTmV") InstitutionCharacter=15.
IF (ResponseId="R_cRYDiBF5b0lGHiF") InstitutionCharacter=13.
IF (ResponseId="R_3qk8HXtE5D8Yld7") InstitutionCharacter=77.
IF (ResponseId="R_2tKBU3HFOrgL5sq") InstitutionCharacter=15.
IF (ResponseId="R_O2n02BxC6cT7Bvz") InstitutionCharacter=77.
IF (ResponseId="R_RwBuZxLt8U8DeLf") InstitutionCharacter=9.
IF (ResponseId="R_1mmf5crJQIXDJMF") InstitutionCharacter=9.
IF (ResponseId="R_10GVqP9Vf2AMxQp") InstitutionCharacter=9.
IF (ResponseId="R_2XnW60b0Aysfjjf") InstitutionCharacter=13.
IF (ResponseId="R_3EMQTTX2SP5ncKH") InstitutionCharacter=14.
IF (ResponseId="R_42QdEnVkC5Zx1QJ") InstitutionCharacter=10.
IF (ResponseId="R_sUrdLe5WItzTCNz") InstitutionCharacter=77.
IF (ResponseId="R_Tvk38cmwXeJB0MF") InstitutionCharacter=10.
IF (ResponseId="R_3M0vSuDkCbGtUka") InstitutionCharacter=77.
IF (ResponseId="R_1FaibUVDJVHQUXj") InstitutionCharacter=10.
IF (ResponseId="R_1jvp6CN31KJRQX6") InstitutionCharacter=8.
IF (ResponseId="R_3D0UoDqL5nicyV7") InstitutionCharacter=77.
IF (ResponseId="R_31WzXQEceSzgagX") InstitutionCharacter=13.
IF (ResponseId="R_DwSvyvXy61iTVbH") InstitutionCharacter=77.
IF (ResponseId="R_2wbrfireJxDZbSy") InstitutionCharacter=13.
IF (ResponseId="R_6SiG3rbgrq8J7QR") InstitutionCharacter=14.
IF (ResponseId="R_2aQ5YCASVXk1lEM") InstitutionCharacter=9.
IF (ResponseId="R_1rMp9ORLOJ3T9AE") InstitutionCharacter=9.
EXECUTE.
* *** backcoding from InstituionTypeDetails - SK.
IF (ResponseId="R_WoJQ6s9d9effGyl") InstitutionType=4.
* *** backcoding from CurrentEmployer  InstitutionType - SK.
IF (ResponseId="R_sLPBDIkprcAsIM1") InstitutionType=4.
IF (ResponseId="R_3oASwzkFo1DyHSC") InstitutionType=4.
IF (ResponseId="R_WwHIzuDpU3P9rZT") InstitutionType=4.
IF (ResponseId="R_27f0UgfTMmLOkf8") InstitutionType=4.
IF (ResponseId="R_RLzrZfnvPDI7Cc9") InstitutionType=4.
IF (ResponseId="R_1LimYBk3Edl5RiI") InstitutionType=4.
IF (ResponseId="R_2TGd1XuDaThBT6S") InstitutionType=4.
IF (ResponseId="R_tLjx8IIevtLt4hr") InstitutionType=4.
IF (ResponseId="R_3lAAdbMmNJlFWiK") InstitutionType=4.
IF (ResponseId="R_2atv3fSrZ5B3vyr") InstitutionType=4.
IF (ResponseId="R_1oGvUDI7BMIFKyU") InstitutionType=4.
IF (ResponseId="R_2rko8yfqr5vD8Xq") InstitutionType=4.
IF (ResponseId="R_3kOk9btNNygLXFf") InstitutionType=4.
IF (ResponseId="R_2rT8YtdlfbYBdNJ") InstitutionType=4.
IF (ResponseId="R_1Dw3auuZTr3RUiY") InstitutionType=4.
IF (ResponseId="R_31F6qH8k3Lajmu1") InstitutionType=4.
IF (ResponseId="R_XiFgWlqq2gMbqIV") InstitutionType=4.
IF (ResponseId="R_1CJvCzSQaNVlnNA") InstitutionType=4.
IF (ResponseId="R_2saITIHelW6sDmd") InstitutionType=4.
IF (ResponseId="R_vSIXNwHwDo0zJp7") InstitutionType=4.
IF (ResponseId="R_293NbFHTmBjb3QO") InstitutionType=4.
IF (ResponseId="R_3p8SFtwTJMnPakz") InstitutionType=4.
IF (ResponseId="R_3Kp88wcHBnougMx") InstitutionType=4.
IF (ResponseId="R_qJ9U8DcOqzsCwCd") InstitutionType=4.
IF (ResponseId="R_C77yYb41UXEwNW1") InstitutionType=4.
IF (ResponseId="R_1JXQKxGS2hCMgN2") InstitutionType=4.
IF (ResponseId="R_3CPNbHH68V26bOD") InstitutionType=4.
IF (ResponseId="R_24oX6c3OOp5s9mN") InstitutionType=5.
IF (ResponseId="R_22Ex2b3GwQQOTAo") InstitutionType=4.
IF (ResponseId="R_1hX1oFfkT78HkkV") InstitutionType=4.
IF (ResponseId="R_2tx0e1Usf8Kw5Tw") InstitutionType=4.
IF (ResponseId="R_3p2NKJoPWrfL9Fu") InstitutionType=4.
IF (ResponseId="R_0d0JNn6TLyqJFzr") InstitutionType=4.
IF (ResponseId="R_6MuTrOAZohrUnAd") InstitutionType=4.
IF (ResponseId="R_2qxsU0ymP0JbHGD") InstitutionType=4.
IF (ResponseId="R_yxXnGjutuhnj9eN") InstitutionType=4.
IF (ResponseId="R_xcnODB1iMt3rYMF") InstitutionType=4.
IF (ResponseId="R_CgMiqcUS7e49kd3") InstitutionType=4.
IF (ResponseId="R_VW5dWxf9L3NPMOZ") InstitutionType=4.
IF (ResponseId="R_3wtNJeYMHSmCIzn") InstitutionType=4.
IF (ResponseId="R_2EcSjxhfQyLLnOf") InstitutionType=5.
IF (ResponseId="R_24CdujaOyvoEVZ8") InstitutionType=4.
IF (ResponseId="R_3qk8HXtE5D8Yld7") InstitutionType=4.
IF (ResponseId="R_pcq9n9IWKn9eAJX") InstitutionType=4.
IF (ResponseId="R_2Vx96mjpKVDYOry") InstitutionType=4.
IF (ResponseId="R_2EF8sjy4w0Xuv17") InstitutionType=4.
IF (ResponseId="R_2XnW60b0Aysfjjf") InstitutionType=6.
IF (ResponseId="R_2R87WB1eIDjGueh") InstitutionType=4.
IF (ResponseId="R_2fiydj3ygclMNDk") InstitutionType=4.
IF (ResponseId="R_27BWBAEOSU2Uc9P") InstitutionType=4.
IF (ResponseId="R_2Xd1W2vlMgUecCO") InstitutionType=4.
IF (ResponseId="R_p5hukz3aLh4umpr") InstitutionType=4.
IF (ResponseId="R_2c0ifWszdXNtk98") InstitutionType=4.
IF (ResponseId="R_3FWCDPoiY5ET84N") InstitutionType=5.
IF (ResponseId="R_1NC7JUjQCVj7POo") InstitutionType=4.
IF (ResponseId="R_3MMbLJqwlPuooG6") InstitutionType=4.
IF (ResponseId="R_Cel5kpECuzmu4Zb") InstitutionType=4.
IF (ResponseId="R_3FUyhnbB2lq655B") InstitutionType=4.
IF (ResponseId="R_wZem8cP1mki6wXT") InstitutionType=4.
IF (ResponseId="R_bBCaCW8tMlOVxzX") InstitutionType=4.
IF (ResponseId="R_322QWDZ2GjmcWlW") InstitutionType=4.
IF (ResponseId="R_2c6kpNCpJc7bgNs") InstitutionType=4.
IF (ResponseId="R_3M0vSuDkCbGtUka") InstitutionType=4.
IF (ResponseId="R_3rThawIlrIWZKYI") InstitutionType=6.
IF (ResponseId="R_2duN1w4xavAD3cz") InstitutionType=5.
EXECUTE.

* *** backcoding ContactDetails - SK.
IF (ResponseId="R_2Cq549E51sH5273") InstitutionCharacter=9.
IF (ResponseId="R_ZL6RuQEHYzK4x0d") InstitutionType=4.
EXECUTE.

* *** Q11 - note that some labels are updated from RAAAP-2.
RENAME VARIABLES (InstitutionCharacter = InstitutionCharacter2). /* so the RAAAP-2 version is called 2 at the end.
COMPUTE InstitutionCharacter = InstitutionCharacter2. /* then create the variable that will be RAAAP-1 comparable.
VARIABLE LABELS InstitutionCharacter "11r1. How would you characterize your institution, irrespective of size?". /* trying to retain Q numbers.
VARIABLE LABELS InstitutionCharacter2 "11. How would you characterize your institution, irrespective of size?". /* trying to retain Q numbers.
FORMATS InstitutionCharacter (f8).
VARIABLE LEVEL InstitutionCharacter (NOMINAL).
MISSING VALUES InstitutionCharacter (-99).
* align with RAAAP-1 is OK - however NOTE a new option. (17=College) - For RAAAP-1 compatability...
IF InstitutionCharacter=17 InstitutionCharacter=88. /* note that there was no 77 (other) option in RAAAP-1, so 17 college has to map back to "Not Sure" 88.
* so College is reported as Not Sure in the RAAAP-1 compatible InstitutoinCharacter variable.
* IF anyone want to revisit the RAAAP-1 data to create a new 17 coding then they can!.
IF InstitutionCharacter=77 InstitutionCharacter=88. /* similarly 77 "Other" did not exist so also maps back to 88.
VALUE LABELS InstitutionCharacter 8 "University - PUI" 9 "University - Research Active" 10 "University - Research Intensive" 11 "Research Institute" 12 "Research Funder"
13 "Private Company" 14 "Hospital" 15 "Charity" 16 "Government Department" 88 "Not Sure" -99 "No Response".
EXECUTE.
ADD VALUE LABELS InstitutionCharacter 11 "Research Institute / Centre" 15 "Charity / NGO". /* updated label in RAAAP-3 for clarity and consistency with question text.
EXECUTE.

VARIABLE LEVEL InstitutionCharacter2 (NOMINAL).
MISSING VALUES InstitutionCharacter2 (-99).
ADD VALUE LABELS InstitutionCharacter2 -99 "No Response".
EXECUTE.

* *** InstitutionCharDet - is already correct.
VARIABLE LEVEL InstitutionCharDet (NOMINAL).
VARIABLE LABELS InstitutionCharDet "11. Details of Institution character". /* trying to retain Q numbers.
MISSING VALUES InstitutionCharDet ("").
VALUE LABELS InstitutionCharDet "" "No Response".
EXECUTE.

* ***.InstitutionCharDet anonymising - SK (lead by MD).
IF (ResponseId="R_3D76c0whwj9MflJ") InstitutionCharDet="XXXX Business School, XXXX Canada".
IF (ResponseId="R_26nn8nNjiQcjcw6") InstitutionCharDet="Universidad XXXX, universidad acreditada por 10 años. (Máxima acreditación)".
IF (ResponseId="R_1H1U8TBrLRUZOxc") InstitutionCharDet="University of XXXX is known for it's research.".
IF (ResponseId="R_3k0RTTTr9LQBC8C") InstitutionCharDet="University of XXXX is a PUI.  We are the second largest university under the University of XXXX System".
IF (ResponseId="R_1ocowEGGnw6WS17") InstitutionCharDet="I work at XXXX.".
IF (ResponseId="R_sG9ye2Yfv3maL7j") InstitutionCharDet="XXXX University".
IF (ResponseId="R_8hKTQujvJJMwgcF") InstitutionCharDet="Ranked XXXX in Australia".
IF (ResponseId="R_3qOe9q9wSeTMKkN") InstitutionCharDet="XXXX Land Grant Institution - One of the big 10".
IF (ResponseId="R_9AA2wk0LV8zEh21") InstitutionCharDet="XXXX for the University XXXX".
IF (ResponseId="R_1ghcFMpkqOE0a8h") InstitutionCharDet="XXXX University".
IF (ResponseId="R_1ozjwg8qp3shjHP") InstitutionCharDet="I work at XXXX University which is a top-tier research university and medical center.".
IF (ResponseId="R_30iuujLG8Xj0vyu") InstitutionCharDet="University of XXXX".
IF (ResponseId="R_2QibIJZYaBvfAAM") InstitutionCharDet=CONCAT("'Over the past decade, the University of XXXX has moved into the top tier of research universities b",
"y providing world-class faculty across 16 colleges with the resources they need to produce groundbreaking research and useful new products. XXXX Health, the university’s academic health center, plays ",
"a leading role in XXXX's research enterprise, generating 52 percent of total research awards.' ").
IF (ResponseId="R_2TSFRpKy2BkddTT") InstitutionCharDet="https://XXXX".
IF (ResponseId="R_1nVn0QxmCyZD9UH") InstitutionCharDet="Working at the University of XXXXSchool of Medicine ".
IF (ResponseId="R_ewCOL6JpvypYH4t") InstitutionCharDet=CONCAT("The XXXX is Germany's XXXX research performing organisation, I work in the head office which ccordin",
"ates the XXXX research centres (which have connections to a number of universities, but are independent non-university research institutions.").
IF (ResponseId="R_3PjyKd6VFN2Igty") InstitutionCharDet="I am working at the University of XXXX in Finland.".
IF (ResponseId="R_2AGP92KlyBh0BB7") InstitutionCharDet="XXXX is a member of the Russell Group of resarch intensive universities in the UK".
IF (ResponseId="R_1DH9ZvHnh0XRT8r") InstitutionCharDet="XXXX".
IF (ResponseId="R_2EsCAkrr5z1Niy1") InstitutionCharDet="university XXXX".
IF (ResponseId="R_1EaHtXdThblcqoL") InstitutionCharDet="I work at XXXX University, an R1 school".
IF (ResponseId="R_XiFgWlqq2gMbqIV") InstitutionCharDet="The Czech Academy of XXXX, Institute of XXXX".
IF (ResponseId="R_3NJNEk3gwgRVgNy") InstitutionCharDet="XXXX, Prague, not sure how to classify it".
IF (ResponseId="R_3nMnyRuuUS4FjSD") InstitutionCharDet="XXXX University, XXXX".
IF (ResponseId="R_56DIeQBIFiQGWzv") InstitutionCharDet="I work at the University XXXX, BC, Canada".
IF (ResponseId="R_7O6eJj89Q89k7g5") InstitutionCharDet="I work for XXXX. It's predominantly education-based, but our research expenditures are over $1 billion/year, so I would say we're also very research intensive.".
IF (ResponseId="R_3IWYShP9Kgz5c4I") InstitutionCharDet="XXXX University in Canada. ".
IF (ResponseId="R_3HjKJdnDccJsJoX") InstitutionCharDet="I current work at the XXXX University Medical Campus, which houses the Schools of Medicine, Dental Medicine, and Public Health as well as an affiliated academic medical center.".
IF (ResponseId="R_3g1OvUCvnGbGXOC") InstitutionCharDet="XXXX University hit 1 billion dollars in research. ".
IF (ResponseId="R_1mymfUfw7rl436U") InstitutionCharDet="University of XXXX".
IF (ResponseId="R_cvknvutaMtUZey5") InstitutionCharDet="We are XXXX University in Denmark in all ways, including research funding and outputs".
IF (ResponseId="R_1gqdvQEO3N8iQi7") InstitutionCharDet="XXXX University, XXXX, NC, USA".
IF (ResponseId="R_vuIfPwu5i0erJrH") InstitutionCharDet=CONCAT("La Universidad XXXX siempre se ha caracterizado por darle importancia a la Investigación y por eso h",
"a implementado mecanismos que ha permitido tener en sus ejes misionales la Docencia, la Investigación y la extensión. ").
IF (ResponseId="R_x437fn7shATzcBP") InstitutionCharDet="University of XXXX".
IF (ResponseId="R_tVUYTQkAZuBnUXL") InstitutionCharDet="My university was ranked XXXX out of 50 Canadian Research Universities in 2019 (based on 2018 data).".
IF (ResponseId="R_3KZOEwXOAfmrPm4") InstitutionCharDet=CONCAT("XXXX National University of XXXX is today a classic university with a distinct research profile, and",
" the leading contemporary academic and educational hub of Ukraine. With the independent Ukrainian nation arising, the University is facing new challenges and responsibilities. (https:// XXXX)").
IF (ResponseId="R_10V031pskYFcb8N") InstitutionCharDet="Academic University Hospital...but that wasn't one of the options (XXXX University Medical centres)".
IF (ResponseId="R_PRpAWYsLCHt1Dih") InstitutionCharDet="XXXX University".
IF (ResponseId="R_1CqDPec4VbXnxHu") InstitutionCharDet="The University of XXXX".
IF (ResponseId="R_z8P9HK8CqyY4wxj") InstitutionCharDet="XXXX University. Research active central academic staff and submits to the REF. ".
IF (ResponseId="R_2CIm9hxkFikvd2m") InstitutionCharDet="XXXX University is a top tier research university and I work for a research center within the university that is focused on nanoscale science. ".
IF (ResponseId="R_1BURMHj3aoCNTd2") InstitutionCharDet="XXXX research institute (mainly privately funded but also brings in external grants)".
IF (ResponseId="R_2X7EyyL12GVLz78") InstitutionCharDet="University of XXXX - we do not have a medical school. The medical school is a sister institution".
IF (ResponseId="R_0d0JNn6TLyqJFzr") InstitutionCharDet="University of XXXX".
IF (ResponseId="R_VU4q4ElUUCgdTfr") InstitutionCharDet="University of XXXX".
IF (ResponseId="R_1LomsZYqKZY3Bv4") InstitutionCharDet="I work at the University of XXXX within the XXXX Institute, a very heavily focused Research institution.".
IF (ResponseId="R_3imx9rSC1XIZpFJ") InstitutionCharDet="I work at a XXXX University in Texas.  ".
IF (ResponseId="R_2tokcXkfh8nRMWB") InstitutionCharDet="XXXX ".
IF (ResponseId="R_1FyXEWie3tisXln") InstitutionCharDet="XXXX's primary focus is undergraduate teaching but much of the focus is on creativity many of the lecturers also have their own creative practice, which counts as research. ".
IF (ResponseId="R_Op138QqyphhKru1") InstitutionCharDet="Institute of Polish XXXX".
IF (ResponseId="R_3nrekHdl5I4GAHS") InstitutionCharDet="XXXX University".
IF (ResponseId="R_1Nggafyom3ohKVd") InstitutionCharDet="XXXX".
IF (ResponseId="R_xcnODB1iMt3rYMF") InstitutionCharDet="I work at a Tribal university on the XXXX Nation".
IF (ResponseId="R_2ykmetKogGJguaX") InstitutionCharDet="University of XXXX, an AAU R1 institution".
IF (ResponseId="R_2zHlDSb3sfxes3M") InstitutionCharDet="XXXX university".
IF (ResponseId="R_WkT1HrAIc7emHTz") InstitutionCharDet="XXXX University, XXXX, RI".
IF (ResponseId="R_2B9BketGf8GGN2x") InstitutionCharDet="The University of XXXX is known as a research institute.".
IF (ResponseId="R_2zBVjJVSnqJG1uV") InstitutionCharDet="XXXX university is a leading research intensive university in South Africa".
IF (ResponseId="R_2OHlPCG3pOtAEMq") InstitutionCharDet="XXXX".
IF (ResponseId="R_3nSq5tNnUEPWadq") InstitutionCharDet="My institution is ranked XXXX  in THE World University Ranking for citations ".
IF (ResponseId="R_2axe2zuFr9VwLiB") InstitutionCharDet="XXXX University is an Australian 'Group of 8' research intensive university and highly ranked by global standards.".
IF (ResponseId="R_3EQifCFqNA5tmo0") InstitutionCharDet="I work in XXXX".
IF (ResponseId="R_2Cpk1LXJpckeqaO") InstitutionCharDet="University of XXXX, Portugal".
IF (ResponseId="R_2rBje45dGzN8Sew") InstitutionCharDet="I work with the College of Medicine, University of XXXX".
IF (ResponseId="R_20ZPN46QFtpqMMJ") InstitutionCharDet="XXXX Institute".
IF (ResponseId="R_1K9genRnZ1f58hK") InstitutionCharDet="My institution, University of XXXX, is on the Carnegie list of Tier 1 Research Institutions.".
IF (ResponseId="R_eECF6QEprdgiGnD") InstitutionCharDet="I work at the University of XXXX, which is in the U15, the top 15 research intensive universities in Canada.".
IF (ResponseId="R_PzD1gN0pdmL0sW5") InstitutionCharDet="I work for XXXX University".
IF (ResponseId="R_2RWdYeHLzJ7tjOz") InstitutionCharDet="Associate of Unviersity of XXXX, Univeristy of XXXX, XXXX University".
IF (ResponseId="R_2flZyR7ZsMulop9") InstitutionCharDet="University of XXXX, large, high performing university with significant research income".
IF (ResponseId="R_1Cs84M5ZZG39GdP") InstitutionCharDet="The XXXX University XXXX, Faculty of Information Technology".
IF (ResponseId="R_21ifNh11fhxOTqJ") InstitutionCharDet="XXXX University".
IF (ResponseId="R_wZem8cP1mki6wXT") InstitutionCharDet="The University of XXXX".
IF (ResponseId="R_2aLHyMJBw8s3YZv") InstitutionCharDet="XXXX University XXXX very well ranked when it comes to Universities below 50 years old".
IF (ResponseId="R_b7vK1hvz6uhTuKZ") InstitutionCharDet="XXXX university in the Republic of Ireland".
IF (ResponseId="R_3g7qvu9akPQXsS6") InstitutionCharDet="University of XXXX - Carnegie R1 status".
IF (ResponseId="R_voSw84irNP4aL5L") InstitutionCharDet="University of XXXX is an R1 institution.  All of my past employers, except XXXX, have been R1 universities. ".
IF (ResponseId="R_xae87MSkLclxrPz") InstitutionCharDet="XXXX".
IF (ResponseId="R_3CAZuY0AOAjG0Ci") InstitutionCharDet="University of XXXX".
IF (ResponseId="R_1i4o2VOnrpIuOpu") InstitutionCharDet="XXXX Australia's largest not-for-profit provider of XXXX".
IF (ResponseId="R_2VpW1ZKkEwU5IOj") InstitutionCharDet="My employer is The University of XXXX. The other three institutions most closely involved in the grant are also research intensive and highly ranked.".
IF (ResponseId="R_O3czEAXx1Wco0Nj") InstitutionCharDet="I work at the XXXX Centre for XXXX University. ".
IF (ResponseId="R_x59QnzaT3CRgjZf") InstitutionCharDet="I work at XXXX University ".
IF (ResponseId="R_3iKZ28MbWHjpiNS") InstitutionCharDet="Universidad XXXX".
IF (ResponseId="R_7V8Br1O0nYc9ia5") InstitutionCharDet="the University of XXXX is ranked XXXX in the 2022 Times Higher Education World University Rankings".
IF (ResponseId="R_2CfDUrbbqfSvQw2") InstitutionCharDet="I work at XXXX University.".
IF (ResponseId="R_enE5ZjVo8HMTNZf") InstitutionCharDet="Community Hospital, XXXX Canada".
IF (ResponseId="R_1hLsBje4lCmn3eM") InstitutionCharDet="Universidade XXXX, fundamentada em três pilares: ensino, pesquisa e extensão.".
IF (ResponseId="R_2aQ5YCASVXk1lEM") InstitutionCharDet="XXXX is a not-for-profit Foundation of Public Utility (XXXX)with a research, educational and service delivery mission.".
IF (ResponseId="R_1fftxier7MqGYcK") InstitutionCharDet="XXXX University had $900M in research funding in 2021, I believe that is considered Tier 1. ".
IF (ResponseId="R_3neffvdQrzOhtVP") InstitutionCharDet="I work for a XXXX-hospital healthcare system/network with a Biomedical Research Institute. The network covers XXXX and the XXXX region of New York.".
IF (ResponseId="R_2TSQ0JFaJWJNBio") InstitutionCharDet="University of XXXX, PUI, primarily teaching, but we do have a fair number of grant projects.".
IF (ResponseId="R_2CJIEH6xzKv4RYE") InstitutionCharDet="University of XXXX, just awarded R1 status". 
EXECUTE.

* *** InstitutionType - is already correct.
VARIABLE LEVEL InstitutionType (NOMINAL).
MISSING VALUES InstitutionType (-99).
ADD VALUE LABELS InstitutionType -99 "No Response".
EXECUTE.

* *** InstitutionTypeDet - is already correct.
VARIABLE LEVEL InstitutionTypeDet (NOMINAL).
VARIABLE LABELS InstitutionTypeDet "12. Details of Institution type". /* trying to retain Q numbers.
MISSING VALUES InstitutionTypeDet ("").
VALUE LABELS InstitutionTypeDet "" "No Response".
EXECUTE.

* *** InstitutionTypeDet anonymsing - SK (lead by MD).
IF (ResponseId="R_1k0NfstcLl36mo4") InstitutionTypeDet="I work for XXXX New Zealand ".
IF (ResponseId="R_1ozjwg8qp3shjHP") InstitutionTypeDet="XXXX is a 503C non-profit organization.".
IF (ResponseId="R_2QibIJZYaBvfAAM") InstitutionTypeDet="University of XXXX is classified as a public educational institution.".
IF (ResponseId="R_2TSFRpKy2BkddTT") InstitutionTypeDet="https://XXXX.pt".
IF (ResponseId="R_3PjyKd6VFN2Igty") InstitutionTypeDet="Anyone who meets certain requirements can apply to the University of XXXX. Students are selected by examination and according to their school record.".
IF (ResponseId="R_2EsCAkrr5z1Niy1") InstitutionTypeDet="University XXXX".
IF (ResponseId="R_3HjKJdnDccJsJoX") InstitutionTypeDet="XXXX University is a private, non-profit institution.".
IF (ResponseId="R_2cdVVA3WatGoePn") InstitutionTypeDet="XXXX University".
IF (ResponseId="R_1mymfUfw7rl436U") InstitutionTypeDet="University of XXXX".
IF (ResponseId="R_Y93djfigq7orofD") InstitutionTypeDet="XXXX".
IF (ResponseId="R_vuIfPwu5i0erJrH") InstitutionTypeDet="La Universidad XXXX es una Universidad Pública".
IF (ResponseId="R_3KZOEwXOAfmrPm4") InstitutionTypeDet=CONCAT("XXXX Naitonal University of XXXX is today a classic university with a distinct research profile, and",
" the leading contemporary academic and educational hub of Ukraine. With the independent Ukranian nation arising, the University is facing new challenges and responsibilities. (https://XXXX)").
IF (ResponseId="R_1LwHuR9YN7eTQB2") InstitutionTypeDet="	private, non-profit, state-related educational institution incorporated under XXXX".
IF (ResponseId="R_QbR57tyraLVStB7") InstitutionTypeDet="Scietific institute of the Polish XXXX ".
IF (ResponseId="R_3imx9rSC1XIZpFJ") InstitutionTypeDet="I work at a XXXX University in Texas.  ".
IF (ResponseId="R_Op138QqyphhKru1") InstitutionTypeDet="Institute of Polish XXXX ".
IF (ResponseId="R_1Nggafyom3ohKVd") InstitutionTypeDet="XXXX".
IF (ResponseId="R_2XiCol6w2NAJS7P") InstitutionTypeDet="state supported institution. we are one of the only XXXX institutions left in the state of Texas (meaning we are not part of a larger system).".
IF (ResponseId="R_1goxfDPomPcu1t3") InstitutionTypeDet="The XXXX is a very publicly focussed institution".
IF (ResponseId="R_3PcrUBXAkYbIIft") InstitutionTypeDet="XXXX University of China is a state-owned  'Double First-Class”  university in China.".
IF (ResponseId="R_1f8hqb0pDvRhrpx") InstitutionTypeDet="Universidade XXXX".
IF (ResponseId="R_20ZPN46QFtpqMMJ") InstitutionTypeDet="XXXX is a registered association".
IF (ResponseId="R_3MMbLJqwlPuooG6") InstitutionTypeDet="The University of XXXX is its own sort of thing. ".
IF (ResponseId="R_3FUyhnbB2lq655B") InstitutionTypeDet="XXXX University".
IF (ResponseId="R_wZem8cP1mki6wXT") InstitutionTypeDet="The University of XXXX".
IF (ResponseId="R_3pgaq2b6bfcwkfN") InstitutionTypeDet="XXXX public institution in NJ - XXXX students.".
IF (ResponseId="R_dg3meGn1o7POGYh") InstitutionTypeDet="The University of XXXX, Australia ".
IF (ResponseId="R_7V8Br1O0nYc9ia5") InstitutionTypeDet=CONCAT("The University of XXXX is a public research university in XXXX, Australia.  Established in XXXX univ",
"ersity in Australia and the XXXX in the state of Victoria. It was the XXXX Australian institution to offer a Doctor of Philosophy.  XXXX....XXXX  The university is divided into XXXX faculties includin",
"g XXXX.").
IF (ResponseId="R_1hLsBje4lCmn3eM") InstitutionTypeDet="Universidade pública, com recursos advindos do XXX.".
IF (ResponseId="R_1fftxier7MqGYcK") InstitutionTypeDet="XXXX University, XXXX campus".
EXECUTE.

* *** backcoding InstitutionTypeDet - SK.
IF (ResponseId="R_27f0UgfTMmLOkf8") InstitutionType=4.
IF (ResponseId="R_1LimYBk3Edl5RiI") InstitutionType=5.
IF (ResponseId="R_3lAAdbMmNJlFWiK") InstitutionType=4.
IF (ResponseId="R_1oGvUDI7BMIFKyU") InstitutionType=4.
IF (ResponseId="R_2rko8yfqr5vD8Xq") InstitutionType=4.
IF (ResponseId="R_3kOk9btNNygLXFf") InstitutionType=4.
IF (ResponseId="R_2rT8YtdlfbYBdNJ") InstitutionType=4.
IF (ResponseId="R_31F6qH8k3Lajmu1") InstitutionType=4.
IF (ResponseId="R_XiFgWlqq2gMbqIV") InstitutionType=4.
IF (ResponseId="R_1kNzQoaQ7i58YyA") InstitutionType=5.
IF (ResponseId="R_3fw07eCaftKR5ec") InstitutionType=4.
IF (ResponseId="R_3p8SFtwTJMnPakz") InstitutionType=4.
IF (ResponseId="R_24oX6c3OOp5s9mN") InstitutionType=5.
IF (ResponseId="R_1hX1oFfkT78HkkV") InstitutionType=4.
IF (ResponseId="R_3p2NKJoPWrfL9Fu") InstitutionType=4.
IF (ResponseId="R_0d0JNn6TLyqJFzr") InstitutionType=4.
IF (ResponseId="R_b1JAX3Skssc0yI1") InstitutionType=4.
IF (ResponseId="R_1I6L1PLGu3PTmC2") InstitutionType=4.
IF (ResponseId="R_CgMiqcUS7e49kd3") InstitutionType=4.
IF (ResponseId="R_VW5dWxf9L3NPMOZ") InstitutionType=4.
IF (ResponseId="R_1f10GunpDb9XwO3") InstitutionType=4.
IF (ResponseId="R_cTR6S9jNkiYU74t") InstitutionType=4.
IF (ResponseId="R_3qk8HXtE5D8Yld7") InstitutionType=4.
IF (ResponseId="R_pcq9n9IWKn9eAJX") InstitutionType=4.
IF (ResponseId="R_2XnW60b0Aysfjjf") InstitutionType=6.
IF (ResponseId="R_2c0ifWszdXNtk98") InstitutionType=4.
IF (ResponseId="R_1NC7JUjQCVj7POo") InstitutionType=4.
IF (ResponseId="R_3MMbLJqwlPuooG6") InstitutionType=4.
IF (ResponseId="R_3FUyhnbB2lq655B") InstitutionType=4.
IF (ResponseId="R_wZem8cP1mki6wXT") InstitutionType=4.
IF (ResponseId="R_1E08SeDy3giP0Qd") InstitutionType=5.
IF (ResponseId="R_2c6kpNCpJc7bgNs") InstitutionType=4.
EXECUTE.

* *** Q13 Org Dept.  new in RAAAP-3 we also ask for the First role.
RENAME VARIABLES (OrgDepartment_Current = OrgDepartment). /* to match RAAAP-2.
VARIABLE LEVEL OrgDepartment OrgDepartment_First (NOMINAL).
MISSING VALUES OrgDepartment OrgDepartment_First (-99).
ADD VALUE LABELS OrgDepartment OrgDepartment_First -99 "No Response".
VARIABLE LABELS OrgDepartment "13. What part of your organisation do you currently work in?". /* trying to retain Q numbers.
VARIABLE LABELS OrgDepartment_First "13F. What part of the organisation did you first work in?". /* trying to retain Q numbers.
EXECUTE.
* *** InstitutionTypeDet - is already correct.
VARIABLE LEVEL OrgDepartmentDetails (NOMINAL).
VARIABLE LABELS OrgDepartmentDetails "13a. Details of part of organisation worked in". /* trying to retain Q numbers.
MISSING VALUES OrgDepartmentDetails ("").
VALUE LABELS OrgDepartmentDetails "" "No Response".
EXECUTE.

* *** backcoding for OrgDepartmentDetails - CO.  first lot are where OrgDepartment_First was blank.
IF (ResponseId="R_296bdcR9SS1Xtno") OrgDepartment_First=5.
IF (ResponseId="R_XCam2lxqXIKwybv") OrgDepartment_First=6.
IF (ResponseId="R_1kXliHVGWNYAIKJ") OrgDepartment_First=4.
IF (ResponseId="R_3gYPnP1GcPHlVBw") OrgDepartment_First=4.
IF (ResponseId="R_263zbwxFEOIKa1V") OrgDepartment_First=4.
IF (ResponseId="R_1QGw9hB3FSnoNSH") OrgDepartment_First=6.
IF (ResponseId="R_10r6NRPa9bFvTzv") OrgDepartment_First=6.
IF (ResponseId="R_3nc7O837Zf7TXlx") OrgDepartment_First=4.
IF ((ResponseId="R_3PpJZnB9hjFuu1q") AND SYSMIS(OrgDepartment)) OrgDepartment=6.
IF ((ResponseId="R_XCam2lxqXIKwybv") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_1kXliHVGWNYAIKJ") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_3ptosj7zagNJmNn") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_263zbwxFEOIKa1V") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_1QGw9hB3FSnoNSH") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_2aaTrRSQHe80D62") AND SYSMIS(OrgDepartment)) OrgDepartment=7.
IF ((ResponseId="R_10r6NRPa9bFvTzv") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_2zHiGQ63taMvU8d") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_3hbDWYTuJYjDP2T") AND SYSMIS(OrgDepartment)) OrgDepartment=4.
IF ((ResponseId="R_3nc7O837Zf7TXlx") AND SYSMIS(OrgDepartment)) OrgDepartment=5.
* *** and now where the OrgDepartment is definitley blank.
IF (ResponseId="R_3kH5stvLcVrUlb6") OrgDepartment=4.
IF (ResponseId="R_3KUgebMvWg9oS0A") OrgDepartment=4.
IF (ResponseId="R_3R3Z0iphXeHKg85") OrgDepartment=6.
IF (ResponseId="R_C77yYb41UXEwNW1") OrgDepartment=7.
IF (ResponseId="R_3KZOEwXOAfmrPm4") OrgDepartment=6.
IF (ResponseId="R_Dk7o5CCYHyDEout") OrgDepartment=4.
IF (ResponseId="R_2f9tYVABsHIbLmz") OrgDepartment=4.
IF (ResponseId="R_3mb0DoTd3FachmK") OrgDepartment=6.
IF (ResponseId="R_2rjQORzohn0jaqZ") OrgDepartment=5.
IF (ResponseId="R_3sojZGgZmjeP13t") OrgDepartment=4.
IF (ResponseId="R_11hbMxg2htTYHqM") OrgDepartment=4.
IF (ResponseId="R_RwBuZxLt8U8DeLf") OrgDepartment=4.
IF (ResponseId="R_1d6t391m07thH6H") OrgDepartment=6.
IF (ResponseId="R_Zk6vXOkjGqzBeLf") OrgDepartment=6.
EXECUTE.

* *** OrgDepartmentDetails anonymsing - SK (lead by MD).
IF (ResponseId="R_3qI6lGFnqqRX708") OrgDepartmentDetails="El primer RMA fue en el Centro de consultoría y servicios integrados de la XXXX Universidad XXXX, actualmente en el XXXX (Centro de investigación de Ciencias Sociales) de la XXXX,".
IF (ResponseId="R_3fkjzJYupDKFe3M") OrgDepartmentDetails="I am work for the Department of XXXX - Italy and In parallel I collaborate with the XXXX- Czech Republic".
IF (ResponseId="R_1ozjwg8qp3shjHP") OrgDepartmentDetails="My first role was at XXXX University in a Sponsored Programs central office. My current role is in the Department of Physics at XXXX University in an Academic/Research Department".
IF (ResponseId="R_2QibIJZYaBvfAAM") OrgDepartmentDetails=CONCAT("As previously stated, I work for 3-departments (Entomology and Nematology, Microbiology and Cell Sci",
"ence and Gulf Coast Research and Education Center) in the Institute of Food and Agricultural Sciences (XXXX) handling their grant proposals and agreements etc..").
IF (ResponseId="R_1Fb2KEbfJC5K2Z9") OrgDepartmentDetails=CONCAT("The Universidade XXXX has 9 Organic Units. The Organic Units are either Faculties or Reserach Instit",
"utes. Before XXXX these Organic Units had independent legal status and functioned completely autonosmously. I work for one Reserach Institute of XXXX university. So in that sense i could say I work at",
" a central office. Since the merge in XXXX, I think i have to say that I work for a non-central office.").
IF (ResponseId="R_1FP8RNxXVfKtAWh") OrgDepartmentDetails="Brindé servicios en la Biblioteca Central, en la Dirección de Asuntos Académicos, en el XXXX y en la Dirección de Servicios Académicos. ".
IF (ResponseId="R_2wconplnDXCKssP") OrgDepartmentDetails="First emplyment as RMA was in the Danish Ministry of XXXX".
IF (ResponseId="R_9TENwBWm60POaFX") OrgDepartmentDetails="Forme parte del equipo de Vocaciones y Formación de la Dirección de Inteligencia de Recursos para la XXXX".
IF (ResponseId="R_Uih4OBHmwLoAefn") OrgDepartmentDetails=CONCAT("In my first position at a US federal funder (NSF), my office was embedded at XXXX University in New ",
"York, where I referred to a department head, as well as to the Program Officer at the main office in Washington DC. I'm currently self-employed, so the categories are not relevant.").
IF (ResponseId="R_2saITIHelW6sDmd") OrgDepartmentDetails="First role at XXXX (NGO, charitable foundation, grants team). Current role at XXXX (charity, grants team)".
IF (ResponseId="R_3IWYShP9Kgz5c4I") OrgDepartmentDetails="My first role was embedded in a XXXX, which had somewhat formed its own department at the University. ".
IF (ResponseId="R_20U6f6rLkppHvHR") OrgDepartmentDetails="I work for a Center for Advancing Translational Science Award (CTSA) site at XXXX, funded through NIH.".
IF (ResponseId="R_vuIfPwu5i0erJrH") OrgDepartmentDetails="El Centro de investigaciones de la Facultad de Ciencias Exactas y Naturales es una oficina de la Facultad de Ciencias exactas de la Universidad XXXX".
IF (ResponseId="R_3KZOEwXOAfmrPm4") OrgDepartmentDetails=CONCAT("RMA at Physics Faculty (XXXX university of XXXX)  activity allows to conduct high-quality research w",
"ork and helps to obtain good results in the implementation of projects through coordination of work between researchers and administration, which is achieved through public activities and discussion o",
"f each stage of the project").
IF (ResponseId="R_PRpAWYsLCHt1Dih") OrgDepartmentDetails="XXXX has a central Office of Grant and Research Development".
IF (ResponseId="R_1OUGTPdWJyk39o2") OrgDepartmentDetails="First: part of HR at XXXX Current: Research and Enterprise Services at XXXX".
IF (ResponseId="R_3qeTbQnOAW6iOxH") OrgDepartmentDetails="my first RMA role was in the XXXX embassy in Ukraine".
IF (ResponseId="R_wZem8cP1mki6wXT") OrgDepartmentDetails="In my first role I managed a Research Hub and supported a number of academics both at the University of XXXX but also academics at other Institutions across Australia.".
IF (ResponseId="R_voSw84irNP4aL5L") OrgDepartmentDetails=CONCAT("I was with the Center for Risk Management in the Health Sciences Research Division at XXXX. XXXX was",
" a small interdisicplinary research center focused on managing risks to humans and the environment associated with environmental contaminants (Superfund sites, etc.).").
IF (ResponseId="R_1i4o2VOnrpIuOpu") OrgDepartmentDetails="First role - XXXX State Government, Department of Child Safety, Communities and Disability Services".
IF (ResponseId="R_C2fPRrRyBAcFCHT") OrgDepartmentDetails="I started at XXXX Uni. OSP office as an assistant to their grant and contract officers and am a Proposal coordinator for XXXX University's sponsored programs office. ".
IF (ResponseId="R_1E1oxbUOClvvmUF") OrgDepartmentDetails=CONCAT("En el primer cargo trabajé en la Dirección NAiconal de Investigación de la Universidad XXXX apoyando",
" procesos de las 10 sedes a nivel nacional.  Actualmente, trabajo con el XXXX con presencia en cuatro ciudades del país.").
EXECUTE.

* *** Impact section - in RAAAP-2 this was the "guest" section.  For RAAAP-3 only one has been retained = Q14 (was Q31 in RAAAP-2).
VARIABLE LABELS IE_SupportImpact "14a. I support impact in my role".
MISSING VALUES IE_SupportImpact (-99).
ADD VALUE LABELS IE_SupportImpact -99 "No Response".
VARIABLE LEVEL IE_SupportImpact (NOMINAL).
EXECUTE.
VARIABLE LABELS IE_UnderstandImpact "14b. I understand what impact is".
MISSING VALUES IE_UnderstandImpact (-99).
ADD VALUE LABELS IE_UnderstandImpact -99 "No Response".
VARIABLE LEVEL IE_UnderstandImpact (NOMINAL).
EXECUTE.
VARIABLE LABELS IE_ImpactStrategy "14c. My institution has an impact strategy".
MISSING VALUES IE_ImpactStrategy (-99).
ADD VALUE LABELS IE_ImpactStrategy -99 "No Response".
VARIABLE LEVEL IE_ImpactStrategy (NOMINAL).
EXECUTE.
VARIABLE LABELS IE_ImpactTraining "14d. I have access to impact training and development".
MISSING VALUES IE_ImpactTraining (-99).
ADD VALUE LABELS IE_ImpactTraining -99 "No Response".
VARIABLE LEVEL IE_ImpactTraining (NOMINAL).
EXECUTE.

VARIABLE LABELS IE_SupportEngagement "14e. I support engagement in my role".
MISSING VALUES IE_SupportEngagement (-99).
ADD VALUE LABELS IE_SupportEngagement -99 "No Response".
VARIABLE LEVEL IE_SupportEngagement (NOMINAL).
EXECUTE.
VARIABLE LABELS IE_UnderstandEngagement "14f. I understand what engagement is".
MISSING VALUES IE_UnderstandEngagement (-99).
ADD VALUE LABELS IE_UnderstandEngagement -99 "No Response".
VARIABLE LEVEL IE_UnderstandEngagement (NOMINAL).
EXECUTE.
VARIABLE LABELS IE_EngagementStrategy "14g. My institution has an engagement strategy".
MISSING VALUES IE_EngagementStrategy (-99).
ADD VALUE LABELS IE_EngagementStrategy -99 "No Response".
VARIABLE LEVEL IE_EngagementStrategy (NOMINAL).
EXECUTE.
VARIABLE LABELS IE_EngagementTraining "14h. I have access to engagement training and development".
MISSING VALUES IE_EngagementTraining (-99).
ADD VALUE LABELS IE_EngagementTraining -99 "No Response".
VARIABLE LEVEL IE_EngagementTraining (NOMINAL).
EXECUTE.

* IE_ImpactAtWorkDet.
* is a string, and may well end up in a separate datafile to protect anonymity.
VARIABLE LABELS IE_ImpactAtWorkDet "14. Details of impact/engagement at work".
MISSING VALUES IE_ImpactAtWorkDet ("").
VALUE LABELS IE_ImpactAtWorkDet "" "No Response".
EXECUTE.

* *** anonymising IE_ImpactAtWorkDet - CO.
IF (ResponseId="R_1QopVY5Iuk6gLPV") IE_ImpactAtWorkDet="At this moment, my current university management after the reform(XXXX Malaysia) does not really serious about research management anymore.".
IF (ResponseId="R_10PFeVVGJFYjYZw") IE_ImpactAtWorkDet=CONCAT("Currently the lead consultant on a 2-year XXXX initiative to increase research competitiveness and c",
"apacity at Historically Black Colleges and Universities (HBCUs). Great project that I think all stakeholders agree has enormous potential in terms of impact and engagement.").
IF (ResponseId="R_r0ynvwfhMNuisX7") IE_ImpactAtWorkDet=CONCAT("En mi encargo actual participo de varios proyectos como XXXX y asociaciones como XXXX (XXXX) que bus",
"can la articulación de la universidad con diversas entidades para mejorar la transferencia de la investigación.").
IF (ResponseId="R_1fftxier7MqGYcK") IE_ImpactAtWorkDet=CONCAT("the current research center I support, Institute for XXXX(XXXX), partners with other non-profits and",
" companies.  I interact with their research and contract offices to support our project reporting and implementation.").
IF (ResponseId="R_1goxfDPomPcu1t3") IE_ImpactAtWorkDet="The XXXX is in the process of developing its new impact and KE strategies with our new PVC Research now that the XXXX's institutional strategy has been revised.".
IF (ResponseId="R_2RWdYeHLzJ7tjOz") IE_ImpactAtWorkDet="University (XXXX) highly ranked globally for impact".
IF (ResponseId="R_1ozjwg8qp3shjHP") IE_ImpactAtWorkDet=CONCAT("We have both local community impact strategies and engagement/volunteering opportunities for faculty",
", staff, and students. XXXX's Global Health Institute also works on global strategies and engagement.").
EXECUTE.

* *** backcoding IE_ImpactAtWorkDet - SK.
DO IF (ResponseId="R_1LZ3ciVvcQM19r0").
    COMPUTE IE_SupportImpact=3.
    COMPUTE IE_UnderstandImpact=3.
    COMPUTE IE_ImpactStrategy=3.
    COMPUTE IE_ImpactTraining=3.
    COMPUTE IE_SupportEngagement=3.
    COMPUTE IE_UnderstandEngagement=3.
    COMPUTE IE_EngagementStrategy=3.
    COMPUTE IE_EngagementTraining=3.
END IF.
DO IF (ResponseId="R_2qdX3Jw1AXhCgTx").
    COMPUTE IE_SupportImpact=1.
    COMPUTE IE_UnderstandImpact=1.
    COMPUTE IE_ImpactStrategy=3.
    COMPUTE IE_ImpactTraining=3.
    COMPUTE IE_SupportEngagement=1.
    COMPUTE IE_UnderstandEngagement=1.
    COMPUTE IE_EngagementStrategy=3.
    COMPUTE IE_EngagementTraining=3.
END IF.
EXECUTE.

* *** Q15. *** perhaps could be a number rather than pick list.
VARIABLE LEVEL NumRARoles(NOMINAL).
MISSING VALUES NumRARoles (-99).
ADD VALUE LABELS NumRARoles -99 "No Response".
VARIABLE LABELS NumRARoles "15. No. of research administration job roles/titles".
EXECUTE.

VARIABLE LABELS NumRARolesDetails "15a. Details of No. of roles".
MISSING VALUES NumRARolesDetails ("").
VALUE LABELS NumRARolesDetails "" "No Response".
EXECUTE.

* *** Anonymising NumRARolesDetails - MF.
IF (ResponseId="R_1fftxier7MqGYcK") NumRARolesDetails="1997 - 2001 University of XXXX, Technology Transfer project manager 2015 - 2022 XXXX University, Business Coordinator and Research Administator".
IF (ResponseId="R_1Nggafyom3ohKVd") NumRARolesDetails="7 years at Institute of XXXX; 4 years at National Institute of XXXX; 1 year at XXXX.".
IF (ResponseId="R_1OUGTPdWJyk39o2") NumRARolesDetails=CONCAT("1) Consultant - XXXX Diversity project (Postdoc Development Centre, XXXX College) 2) Project Manager",
" - Enterprise & Entrepreneurship Project (Graduate School/Postdoc Development Centre, XXXX College) 3)Freelancing Trainer/Consultant - delivering materials to XXXX College; University of XXXX 4) Caree",
"rs Consultant: Postgraduate & Early Career Researchers (Doctoral College, University of XXXX) 5) Research Staff Officer (Research & Enterprise Services, University of XXXX) 6) Research Metrics Analyst",
" (Research & Enterprise Services, University of XXXX)").
IF (ResponseId="R_2tchnU0EKlxDrQE") NumRARolesDetails=CONCAT("20 Years at XXXX 5 years at XXXX University  presently at XXXX College of Medicine (3 years in Count",
"ing) and it's been super amazing so far.   Lots of work, lots of challenges. Its still an amazing adventure.").
IF (ResponseId="R_2VfI8miujZiMMbG") NumRARolesDetails=CONCAT("1986 - 1987: Clerical officer - Australian XXXX Committee. 1990 - 1992: Administrative officer - Res",
"earch Coordination Office - XXXX University. 2011 - 2019: Senior Advisor, Research Development - College of XXXX - XXXX University.  2019 - Present: Senior Research Initiative Coordinator - Faculty of",
" XXXX - University of XXXX.").
IF (ResponseId="R_3iCQbLACysURDO2") NumRARolesDetails="He trabajado en dos universidades privadas en XXXX, en el cargo de Director de Investigaciones".
IF (ResponseId="R_3iJYkTgeo1OjDaO") NumRARolesDetails=CONCAT("Post Award Assistant then Post Award Analyst I then Post Award Analyst II at XXXX State Foundation; ",
"Account Manager at XXXX Electrical and Computer Engineering Department, Research Administrator then Financial Research Account Manager at XXXX's Office of Sponsored Programs").
IF (ResponseId="R_3KZOEwXOAfmrPm4") NumRARolesDetails=CONCAT("Since XX/2021, I have been the chief manager of the XXXX of Ukraine grant aimed at the long-term dev",
"elopment of the science direction 'XXXX' at the XXXX University of XXXX (XXXX) (I supervise team of XXXX people). In 2018 as a member of international team that includes groups from Ukraine, the Unite",
"d Kingdom, Spain and Italy, I contributed to the proposal 'XXXX” for a grant under umbrella of the European Union’s Horizon 2020. The proposal was evaluated positively and got funding. In 2016 and 201",
"9 I attracted funding from Erasmus+ program ' for internships of students at XXXX University (UK). I was selected as a Program Supervisor and Manager from the Ukrainian side. From XX/2017 to XX/2019, ",
"I was Manager of the grant of the XXXX of Ukraine (Grant: XXXX) 'XXXX.' (I supervise team of XX people). In XX/2014 and XX/2017 at the invitation from Prof. Dr. XXXX( the College of XXXX of XXXX Unive",
"rsity, China), I visited the aforesaid College as a Visiting Researcher and delivered lectures to Ph.D. students and performed scientific research in the field of 'XXXX.").
IF (ResponseId="R_3pyxkk7GlsjWX1D") NumRARolesDetails=CONCAT("Technically I have had 6 titles, but really only two roles. In Sponsored Programs, I advanced throug",
"h Grants Specialist, Assistant Grants Officer, Grants Officer, and Senior Grants Officer: mostly the same type of dutied, but increasing caseload and mentoring responsibilities. In the proposal develo",
"pment part of my career, I was a 'Proposal XXXX Officer' for a short time, then a self-titled Director of Proposal XXXX, and for only 3 months now have I been the offical Director of the Office for Pr",
"oposal XXXX.").
IF (ResponseId="R_e9BjHcgAYawMfVD") NumRARolesDetails="I worked for a International Center made up of three University partners and then two separate Universityìies: University of XXXX and University of XXXX.".
IF (ResponseId="R_rqN3J5i9b1brMYN") NumRARolesDetails="Hemos desempeñado como Academica, e Investigadora en Universidad 'XXXX.' sin rol, además de Universidad 'XXXX'.".
IF (ResponseId="R_voSw84irNP4aL5L") NumRARolesDetails="My RD roles have been at XXXX, XXXX, UW-XXXX, XXXX, XXXX, CU XXXX plus I have served as a RD consultant for two private sector companies.".
IF (ResponseId="R_vuIfPwu5i0erJrH") NumRARolesDetails="Siempre me he desempeñado en el mismo rol, que es el de Auxiliar administrativo del Centro de Investigaciones-XXXX.".
IF (ResponseId="R_wZem8cP1mki6wXT") NumRARolesDetails="Manager ARC XXXX Research Hub Research Support Lead, in the University of XXXX Faculty of Medicine and Health Manager, Research Support and Development in the University of XXXX Business School".
IF (ResponseId="R_yx6J17OyiFPdoc1") NumRARolesDetails="My roles have been in  1. Cooperative Research Centre for XXXX Information  2. NHMRC Centre of Research Excellence (XXXX)  3. ARC Centre of Excellence (XXXX)".
IF (ResponseId="R_zbYqrmbOc59xEg9") NumRARolesDetails=CONCAT("Chercheuse contractuelle. Travaux avec le ministère de XXXX en France, avec le CNRS. Chargée de valo",
"risation et animatrice de la cellule recherche dans une UFR. Directrice-adjointe d’une direction de la recherche dans une université en ShS, et coordinatrice des laboratoires. Chargée de mission coord",
"ination de la recherche et des études doctorales.").
IF (ResponseId="R_XoeES5Lz2HRTKLv") NumRARolesDetails=CONCAT("Interim position (2011-2017) • Identified solicitations and sponsors (government, foundation, and co",
"rporate) relevant to the XXXX strategic plan and the research interests of its XXXX faculty; made early career faculty aware of grant programs available to them and supported proposal development.  • ",
"Analyzed potential funding sources (short-term and long-range) to optimize grant opportunities. • Developed and managed Research Development website and coordinated monthly e-mail blasts alerting cons",
"tituents (XXXX faculty, students (ugrad, masters, PhD, postdoc) of ~1,100 relevant recurring deadlines  • Identified and facilitated research collaborations. • Managed submission process for large pro",
"posals by assisting PIs with timelines for proposal preparation, editing/review, and the submission process; independently led proposal development and submission support for XXXX multimillion dollar ",
"grants to a variety of agencies (XXXX) • Mentored early career and new-to-research faculty proposal development resulting in awards (2 of 3 NSF CAREER proposals supported; XXXX).   • Supported 140 sub",
"missions total over this time period ($XXXX million proposed; $XXXX million in awards).  Assisted with teambuilding as needed. • Acted as a liaison with program officers and XXXX’s Office of Research ",
"Support. • Ensured faculty had knowledge of proposal deadlines and solicitation requirements. • Led workshops to educate postdocs and graduate students on finding funding. Organized proposal developme",
"missions total over this time period ($XXXX million proposed; $XXXX million in awards).  Assisted with teambuilding as needed. • Acted as a liaison with program officers and XXXX’s Office of Research ",
"onservation Initiative’s startup of annual summit on innovation for conservation efforts).  Resulted in 40K in support of XXXX (25K XXXX Council").
EXECUTE.

* *** Q16.
VARIABLE LEVEL NumYearsPUI (ORDINAL). 
FORMATS NumYearsPUI(f8.1).
MISSING VALUES NumYearsPUI (-99).
VARIABLE LABELS NumYearsPUI "16a. How many years have you worked in Predominantly Undergraduate Institutions". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsUniActive (ORDINAL). 
FORMATS NumYearsUniActive(f8.1).
MISSING VALUES NumYearsUniActive (-99).
VARIABLE LABELS NumYearsUniActive "16b. How many years have you worked in Research Active Universities". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsUniIntense (ORDINAL). 
FORMATS NumYearsUniIntense(f8.1).
MISSING VALUES NumYearsUniIntense (-99).
VARIABLE LABELS NumYearsUniIntense "16c. How many years have you worked in Research Intensive Universities". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsCollege (ORDINAL). 
FORMATS NumYearsCollege(f8.1).
MISSING VALUES NumYearsCollege (-99).
VARIABLE LABELS NumYearsCollege "16d. How many years have you worked in Colleges". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsInstitute (ORDINAL). 
FORMATS NumYearsInstitute(f8.1).
MISSING VALUES NumYearsInstitute (-99).
VARIABLE LABELS NumYearsInstitute "16e. How many years have you worked in Research Institutes / Centres". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsFunder (ORDINAL). 
FORMATS NumYearsFunder(f8.1).
MISSING VALUES NumYearsFunder (-99).
VARIABLE LABELS NumYearsFunder "16f. How many years have you worked in Research Funders". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsCompany (ORDINAL). 
FORMATS NumYearsCompany(f8.1).
MISSING VALUES NumYearsCompany (-99).
VARIABLE LABELS NumYearsCompany "16g. How many years have you worked in Companies". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsHospital (ORDINAL). 
FORMATS NumYearsHospital(f8.1).
MISSING VALUES NumYearsHospital (-99).
VARIABLE LABELS NumYearsHospital "16h. How many years have you worked in Hospitals". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsCharity (ORDINAL). 
FORMATS NumYearsCharity(f8.1).
MISSING VALUES NumYearsCharity (-99).
VARIABLE LABELS NumYearsCharity "16i. How many years have you worked in Charities". /* trying to retain Q numbers./* *** NOTE that the question should have been "Charities / NGOs" but NGOs was missed.

VARIABLE LEVEL NumYearsOGD (ORDINAL). 
FORMATS NumYearsOGD(f8.1).
MISSING VALUES NumYearsOGD (-99).
VARIABLE LABELS NumYearsOGD "16j. How many years have you worked in Government Departments". /* trying to retain Q numbers.

VARIABLE LEVEL NumYearsOther (ORDINAL). 
FORMATS NumYearsOther(f8.1).
MISSING VALUES NumYearsOther (-99).
VARIABLE LABELS NumYearsOther "16k. How many years have you worked in Other places". /* trying to retain Q numbers.

RENAME VARIABLES NumYearsOther_TEXT=NumYearsOtherD.
VARIABLE LABELS NumYearsOtherD "16kd. Please give details (of other places you have worked)". /* trying to retain Q numbers.

VARIABLE LABELS NumYearsWorkedAtDet "16. Details of lengths at institution types". /* trying to retain Q numbers.
EXECUTE.

* *** anonymising NumYearsOtherD - MF.
IF (ResponseId="R_2Bzl4nMaOiUjwA0") NumYearsOtherD="National Agency XXXX Programme".
IF (ResponseId="R_2urOeJvBzZLMV7G") NumYearsOtherD="XXXX Conference".
IF (ResponseId="R_3qk8HXtE5D8Yld7") NumYearsOtherD="XXXX".
EXECUTE.

* *** anonymising NumYearsWorkedAtDet - MF.
IF (ResponseId="R_1dAd4CdWbCBgsgY") NumYearsWorkedAtDet="17 years at XXXX and 3+ years at XXXX".
IF (ResponseId="R_1f7de5Bhk1uMVj1") NumYearsWorkedAtDet="My experience in the hospital was about 3 years and more precisely it was in a research lab located in a hospital and linked to Assistance Publique Hôpitaux de XXXX (XXXX)".
IF (ResponseId="R_1fftxier7MqGYcK") NumYearsWorkedAtDet="I also worked as a lab technician at the University of XXXX from 1985 - 1987 before going to industry".
IF (ResponseId="R_1FyXEWie3tisXln") NumYearsWorkedAtDet="Before joining XXXX University I worked in a lecturing role at XXXX College, for 7 years in Further Education and then for 10 years in Higher Education.".
IF (ResponseId="R_1goxfDPomPcu1t3") NumYearsWorkedAtDet=CONCAT("I've worked at XXXX, XXXX  and the XXXX Universities (second tier); The University of XXXX and XXXX ",
"(research active although different in size and shape); The XXXX (mostly teaching and practice-based)").
IF (ResponseId="R_1Nggafyom3ohKVd") NumYearsWorkedAtDet="Institute of XXXX, XXXX, and XXXX".
IF (ResponseId="R_3G3cI7nZJmK6BVS") NumYearsWorkedAtDet="12 years at PUIs and 23 years as a funder (15 NIH & 8 at the XXXX Foundation)".
IF (ResponseId="R_3iX9mlRbOIjIeBs") NumYearsWorkedAtDet="Out of college, I very briefly worked for a pharmaceutical company before coming to XXXX University of XXXX".
IF (ResponseId="R_3NJNEk3gwgRVgNy") NumYearsWorkedAtDet="I've only worked for XXXX, not sure how to classify it".
IF (ResponseId="R_3PjyKd6VFN2Igty") NumYearsWorkedAtDet="I have been in my current position for three years, but in total I have been in the administration of the University of XXXX for more than 40 years.".
IF (ResponseId="R_3qk8HXtE5D8Yld7") NumYearsWorkedAtDet="XXXX is a membership organisation supporting UK based research performing institutions".
IF (ResponseId="R_pRizaw6mkamDRvP") NumYearsWorkedAtDet="Data may be skewed, I don't know how my institution is defined (3 options for university) - XXXX University 5 years, SBIR firm 2 years".
IF (ResponseId="R_RXHqGdnUCCSDWM1") NumYearsWorkedAtDet="University of XXXX Health Science Campus, XXXX Clinic,  XXXX university".
IF (ResponseId="R_vuIfPwu5i0erJrH") NumYearsWorkedAtDet="Siempre he trabajado en la XXXX".
IF (ResponseId="R_w6jY1zcHSPH1mZb") NumYearsWorkedAtDet="I´ve worked for an Science Association (regional association of XX non-university-Institutes with diffrent disciplines)".
IF (ResponseId="R_wZem8cP1mki6wXT") NumYearsWorkedAtDet="I have actually worked at the University of XXXX for longer than 5 years.  I was previously in a XXXX role at this institution.".
EXECUTE.

* *** backcoding from NumYearsWorkedAtDet - SK.
IF (ResponseId="R_yvFlwpakwyAmKuB") NumYearsUniActive=10.
EXECUTE.

* *** Q17 Joining the profession.
VARIABLE LEVEL JoinRAReason (NOMINAL).
MISSING VALUES JoinRAReason (-99).
ADD VALUE LABELS JoinRAReason -99 "No Response".
EXECUTE.

RENAME VARIABLES JoinRAResonDetails=JoinRAMoreDetails. /* To match RAAAP-1 <-- but this is new?.[Also spelling mistake! doh!].
VARIABLE LABELS JoinRAMoreDetails "17a. Please give details (of how you became an RMA)". /* trying to retain Q numbers.
EXECUTE.

* *** Anonymising - SK.
IF (ResponseId="R_1DV8NObhROXDKzO") JoinRAMoreDetails=CONCAT("Trained and worked in forensic science for many years.  When my daughters came along, I could no lon",
"ger work away from home so much and so looked for something more local, that had a societal benefit.  My first RMA was at XXXX University, UK, which provides education to non-typical entrants.").
IF (ResponseId="R_1FP8RNxXVfKtAWh") JoinRAMoreDetails="En la XXXX los funcionarios son rotados a otras oficinas sin previa consulta.".
IF (ResponseId="R_1n2dDzfQ0zmYPdB") JoinRAMoreDetails=CONCAT("With the current one for a cumulative year as Acting Deputy Vice-Chancellor for Research, Postgradua",
"te Studies and Innovation, I was requested by university management to fill in the post as it vacated.  For previous roles as Head f Department of XXXX and Dean of School of XXXX where both include re",
"search management and administration (combined 8 years), I applied for such positions.").
IF (ResponseId="R_2Se7cNW8QP9c5mA") JoinRAMoreDetails="Fui eleito chefe de departamento, diretor do instituto e indicado chefe do laboratório de referência em XXXX".
IF (ResponseId="R_1fftxier7MqGYcK") JoinRAMoreDetails="I wanted to be in tech transfer after completing my MBA.  I was hired at XXXX after a conversation with a faculty member.".
IF (ResponseId="R_RXHqGdnUCCSDWM1") JoinRAMoreDetails="the Research Assistant position was at XXXX Clinic in research administration international project management group within cardiology. No hands on human subject or animal research - ever.".
EXECUTE.

* *** Backcoding from JoinRAMoreDeatails - SK.
IF (ResponseId="R_1kIhDmbqxaXpoe3") JoinRAReason=1.
IF (ResponseId="R_2CfRaQfZFWRFv7y") JoinRAReason=3.
IF (ResponseId="R_XiFgWlqq2gMbqIV") JoinRAReason=1.
IF (ResponseId="R_33rjic9gz9QkF0O") JoinRAReason=2.
IF (ResponseId="R_3JrSTbEyyuNciDl") JoinRAReason=2.
IF (ResponseId="R_PNGi6CnzZVYb1Xr") JoinRAReason=3.
IF (ResponseId="R_2rCKMv4lD5Hg2qj") JoinRAReason=3.
IF (ResponseId="R_1HcsAzy3pmwDhVH") JoinRAReason=3.
IF (ResponseId="R_2Se7cNW8QP9c5mA") JoinRAReason=4.
EXECUTE.

* JoinRAInterested - * exact match to RAAAP-1.
VARIABLE LABELS JoinRAInterested "18a. I became an RMA because: interested in profession". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAInterested (ORDINAL).
MISSING VALUES JoinRAInterested (-99).
ADD VALUE LABELS JoinRAInterested -99 "No Response".
EXECUTE.
* JoinRASkillsMatch - * exact match to RAAAP-1.
VARIABLE LABELS JoinRASkillsMatch "18b. I became an RMA because: matched my skills". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRASkillsMatch (ORDINAL).
MISSING VALUES JoinRASkillsMatch (-99).
ADD VALUE LABELS JoinRASkillsMatch -99 "No Response".
EXECUTE.
* JoinRATemporary - * exact match to RAAAP-1.
VARIABLE LABELS JoinRATemporary "18c. I became an RMA because: it was a temporary role". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRATemporary (ORDINAL).
MISSING VALUES JoinRATemporary (-99).
ADD VALUE LABELS JoinRATemporary -99 "No Response".
EXECUTE.
* JoinRAFriend - * exact match to RAAAP-1.
VARIABLE LABELS JoinRAFriend "18d. I became an RMA because: a friend recommended it". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAFriend (ORDINAL).
MISSING VALUES JoinRAFriend (-99).
ADD VALUE LABELS JoinRAFriend -99 "No Response".
EXECUTE.
* JoinRAJustApplied - * exact match to RAAAP-1.
VARIABLE LABELS JoinRAJustApplied "18e. I became an RMA because: a position was available". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAJustApplied (ORDINAL).
MISSING VALUES JoinRAJustApplied (-99).
ADD VALUE LABELS JoinRAJustApplied -99 "No Response".
EXECUTE.
* JoinRAResearcher - * exact match to RAAAP-1.
VARIABLE LABELS JoinRAResearcher "18f. I became an RMA because: moved from research". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAResearcher (ORDINAL).
MISSING VALUES JoinRAResearcher (-99).
ADD VALUE LABELS JoinRAResearcher -99 "No Response".
EXECUTE.
* JoinRAAdmin - * exact match to RAAAP-1.
VARIABLE LABELS JoinRAAdmin "18g. I became an RMA because: moved from other admin". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAAdmin (ORDINAL).
MISSING VALUES JoinRAAdmin (-99).
ADD VALUE LABELS JoinRAAdmin -99 "No Response".
EXECUTE.
* *** these next ones are new to RAAAP-2 (based on feedback from RAAAP-1)
* JoinRALocal - * no exact match to RAAAP-1, but analysis of JoinRAOther1,2,3 could perhaps be done.
VARIABLE LABELS JoinRALocal "18h. I became an RMA because: wanted a local job". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRALocal (ORDINAL).
MISSING VALUES JoinRALocal (-99).
ADD VALUE LABELS JoinRALocal -99 "No Response".
EXECUTE.
* JoinRAUni - * no exact match to RAAAP-1, but analysis of JoinRAOther1,2,3 could perhaps be done.
VARIABLE LABELS JoinRAUni "18i. I became an RMA because: wanted a to work at this organisation". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAUni (ORDINAL).
MISSING VALUES JoinRAUni (-99).
ADD VALUE LABELS JoinRAUni -99 "No Response".
EXECUTE.
* JoinRAOther - * no exact match to RAAAP-1, but analysis of JoinRAOther1,2,3 could perhaps be done.
VARIABLE LABELS JoinRAOther "18z. I became an RMA because: some other reason". /* trying to retain Q numbers.
VARIABLE LEVEL JoinRAOther (ORDINAL).
MISSING VALUES JoinRAOther (-99).
ADD VALUE LABELS JoinRAOther -99 "No Response".
EXECUTE.
* JoinRAOtherDetails
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES JoinRAOtherDetails=JoinRAOtherDet.
VARIABLE LABELS JoinRAOtherDet "18. Details of other reason for becoming an RMA".
RECODE JoinRAOtherDet ("-99"="").
MISSING VALUES JoinRAOtherDet ("").
VALUE LABELS JoinRAOtherDet "" "No Response".
EXECUTE.


* *** JoinRAOtherDet anonymising.
IF (ResponseId="R_1i4egVoKCbjECz9") JoinRAOtherDet="I wanted to work at XXXX as a contract manager.".
IF (ResponseId="R_28A3bj5GmXPdkEh") JoinRAOtherDet="I wanted to move to XXXX and it was a position that was available".
EXECUTE.

* *** Q19.

* *** Now reasons for staying an RMA - again soe are direct matches, some are new
* StayRAGoodPay - * exact match to RAAAP-1.
VARIABLE LABELS StayRAGoodPay "19a. I stayed an RMA because: it pays well". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAGoodPay (ORDINAL).
MISSING VALUES StayRAGoodPay (-99).
ADD VALUE LABELS StayRAGoodPay -99 "No Response".
EXECUTE.
* StayRANotBoring - * exact match to RAAAP-1.
VARIABLE LABELS StayRANotBoring "19b. I stayed an RMA because: it is never boring". /* trying to retain Q numbers.
VARIABLE LEVEL StayRANotBoring (ORDINAL).
MISSING VALUES StayRANotBoring (-99).
ADD VALUE LABELS StayRANotBoring -99 "No Response".
EXECUTE.
* StayRAAdvancement - * exact match to RAAAP-1.
VARIABLE LABELS StayRAAdvancement "19c. I stayed an RMA because: opportunity for advancement". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAAdvancement (ORDINAL).
MISSING VALUES StayRAAdvancement (-99).
ADD VALUE LABELS StayRAAdvancement -99 "No Response".
EXECUTE.
* StayRANoOpportunity - * exact match to RAAAP-1.
VARIABLE LABELS StayRANoOpportunity "19d. I stayed an RMA because: no opportunity to change". /* trying to retain Q numbers.
VARIABLE LEVEL StayRANoOpportunity (ORDINAL).
MISSING VALUES StayRANoOpportunity (-99).
ADD VALUE LABELS StayRANoOpportunity -99 "No Response".
EXECUTE.
* StayRACouldntMove - * exact match to RAAAP-1.
VARIABLE LABELS StayRACouldntMove "19e. I stayed an RMA because: unsuccessful trying to move". /* trying to retain Q numbers.
VARIABLE LEVEL StayRACouldntMove (ORDINAL).
MISSING VALUES StayRACouldntMove (-99).
ADD VALUE LABELS StayRACouldntMove -99 "No Response".
EXECUTE.
* StayRASecurity - * exact match to RAAAP-1.
VARIABLE LABELS StayRASecurity "19f. I stayed an RMA because: job security". /* trying to retain Q numbers.
VARIABLE LEVEL StayRASecurity (ORDINAL).
MISSING VALUES StayRASecurity (-99).
ADD VALUE LABELS StayRASecurity -99 "No Response".
EXECUTE.
* StayRAFun - * exact match to RAAAP-1.
VARIABLE LABELS StayRAFun "19g. I stayed an RMA because: its a fun profession". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAFun (ORDINAL).
MISSING VALUES StayRAFun (-99).
ADD VALUE LABELS StayRAFun -99 "No Response".
EXECUTE.
* StayRANotWant - * exact match to RAAAP-1.
VARIABLE LABELS StayRANotWant "19h. I stayed an RMA because: I don't want to move". /* trying to retain Q numbers.
VARIABLE LEVEL StayRANotWant (ORDINAL).
MISSING VALUES StayRANotWant (-99).
ADD VALUE LABELS StayRANotWant -99 "No Response".
EXECUTE.
* StayRAFaculty - * exact match to RAAAP-1.
VARIABLE LABELS StayRAFaculty "19i. I stayed an RMA because: I like working with faculty". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAFaculty (ORDINAL).
MISSING VALUES StayRAFaculty (-99).
ADD VALUE LABELS StayRAFaculty -99 "No Response".
EXECUTE.
* StayRAChallenging - * exact match to RAAAP-1.
VARIABLE LABELS StayRAChallenging "19j. I stayed an RMA because: I like the challenging work". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAChallenging (ORDINAL).
MISSING VALUES StayRAChallenging (-99).
ADD VALUE LABELS StayRAChallenging -99 "No Response".
EXECUTE.
* *** these are new ones for RAAAP-2, based on feedback from RAAAP-1.  Coult *try* to match to RAAAP-1 StatRAOther1,2,3..
* StayRANewProfession - * this is a new one for RAAAP-2.
VARIABLE LABELS StayRANewProfession "19k. I stayed an RMA because: help shaping a new profession". /* trying to retain Q numbers.
VARIABLE LEVEL StayRANewProfession (ORDINAL).
MISSING VALUES StayRANewProfession (-99).
ADD VALUE LABELS StayRANewProfession -99 "No Response".
EXECUTE.
* StayRATooLate - * this is a new one for RAAAP-2.
VARIABLE LABELS StayRATooLate "19l. I stayed an RMA because: too late to change career". /* trying to retain Q numbers.
VARIABLE LEVEL StayRATooLate (ORDINAL).
MISSING VALUES StayRATooLate (-99).
ADD VALUE LABELS StayRATooLate -99 "No Response".
EXECUTE.
* StayRADontIntend - * this is a new one for RAAAP-2.
VARIABLE LABELS StayRADontIntend "19m. I stayed an RMA because: do not intend to stay". /* trying to retain Q numbers.
VARIABLE LEVEL StayRADontIntend (ORDINAL).
MISSING VALUES StayRADontIntend (-99).
ADD VALUE LABELS StayRADontIntend -99 "No Response".
EXECUTE.
* StayRACouldntMove.0 - * this is a new one for RAAAP-2.
RENAME VARIABLES StayRACouldntMove.0=StayRAWantToMove.
VARIABLE LABELS StayRAWantToMove "19n. I stayed an RMA because: but I want to move". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAWantToMove (ORDINAL).
MISSING VALUES StayRAWantToMove (-99).
ADD VALUE LABELS StayRAWantToMove -99 "No Response".
EXECUTE.
* StayRAOther - * not exact match to RAAAP-1, but could try to align with StayRAOther1,2,3..
VARIABLE LABELS StayRAOther "19z. I stayed an RMA because: some other reason". /* trying to retain Q numbers.
VARIABLE LEVEL StayRAOther (ORDINAL).
MISSING VALUES StayRAOther (-99).
ADD VALUE LABELS StayRAOther -99 "No Response".
EXECUTE.
* StayRANotStayed_1 - * this is a new one for RAAAP-2.
RENAME VARIABLES StayRANotStayed_1=StayRANotStayed.
VARIABLE LABELS StayRANotStayed "19x. I stayed an RMA because: I have left / am leaving". /* trying to retain Q numbers.
VARIABLE LEVEL StayRANotStayed (ORDINAL).
MISSING VALUES StayRANotStayed (-99).
ADD VALUE LABELS StayRANotStayed -99 "No Response".
EXECUTE.
* StayRAOtherDetails
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES StayRAOtherDetails=StayRAOtherDet.
VARIABLE LABELS StayRAOtherDet "19. Details of other reason for staying an RMA".
RECODE StayRAOtherDet ("-99"="").
MISSING VALUES StayRAOtherDet ("").
VALUE LABELS StayRAOtherDet "" "No Response".
EXECUTE.

* *** StayRAOtherDet anonymising -SK.
IF (ResponseId="R_3kH5stvLcVrUlb6") StayRAOtherDet=CONCAT("I have applied for a few other jobs but always lack some thing. As a long time admin person, it is n",
"ot so easy to show new skills/merits as this is something I have to develop outside my research admin post if I want another kind of job (such as a leader position). I think it is a real dilemma. I su",
"pport teaching staff to get more merits, research funding etc, while my own merits spiral downwards. I enjoy supporting staff to grow but also wish I could do more of this myself. Since breaking my XX",
"XX at work in 2018 due to tiredness and having been on the receiving end of institutional critique from the PhD group, I have decided to pursue my private work much more. But there is a limit of hours",
" in a day and the admin job can sometimes fracture the brain. It would be great to work like 70%.").
IF (ResponseId="R_2EsCAkrr5z1Niy1") StayRAOtherDet="I will be leaving University XXXX to move to other university in 2 months time".
IF (ResponseId="R_3EQifCFqNA5tmo0") StayRAOtherDet=CONCAT("I hope that by doing my PhD, new career opportunities will open up and at the moment I intend to con",
"tinue doing the same because XXXX is close to the educational institution where I intend to attend my PhD.").
IF (ResponseId="R_bBCaCW8tMlOVxzX") StayRAOtherDet="Not many jobs offered in my field of choice, and would like to stay in XXXX as my partner and friends live here, and am paying off a mortgage.".
IF (ResponseId="R_1mxRSsK7qmKFwFz") StayRAOtherDet=CONCAT("In the last two decades I have been at the forefront and heavily involved in getting the research ma",
"nagement and research translation functions recognised and valued as professions of choice. I hold international accreditation as an RTTP (Registered Technology Transfer Professional) and am a ARMS (A",
"ustralasian Research Management Society) XXXX. I would like to continue my contributions as a senior university leader.").
IF (ResponseId="R_1i4o2VOnrpIuOpu") StayRAOtherDet=CONCAT("XXXX's purpose is to ensure that all children have the learning, development and wellbeing outcomes ",
"they need for school and life. My role has a significant part to play in achieving on our purpose through building the evidence base.").
EXECUTE.

* *** END of PART A.


* *** Now qualifications - these have been revamped since RAAAP-1, so now we ask about qualifications before and during being an RMA
* *** RAAAP-1 was the highest qual... so to get that we will have to join these two pieces of RAAAP-3 data.  May as well do that while we are here!
* *** Also note that RAAAP-2 added "Foundation" as a level between "High School" and "Bachelor's".
* *** Q20.
RENAME VARIABLES HighestQualLevel_1=HighestQualBefore.
VARIABLE LABELS HighestQualBefore "20. Highest academic qualification before becoming an RMA". /* trying to retain Q numbers.
VARIABLE LEVEL HighestQualBefore (ORDINAL).
MISSING VALUES HighestQualBefore (-99).
EXECUTE.
* *** HighestQualBeforeSub.
VARIABLE LABELS HighestQualSubjectBefore "20a. Highest academic qualification subject area before becoming an RMA". /* trying to retain Q numbers.
VARIABLE LEVEL HighestQualSubjectBefore (NOMINAL).
FORMATS HighestQualSubjectBefore(f8.1).
MISSING VALUES HighestQualSubjectBefore (-99).
ADD VALUE LABELS HighestQualSubjectBefore -99 "No Response".
EXECUTE.
* HighestQualBeforeSD
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES HighestQuals_11=HighestQualSubjectBeforeDet.
VARIABLE LABELS HighestQualSubjectBeforeDet "20b. Highest academic qualification subject details before becoming an RMA".
MISSING VALUES HighestQualSubjectBeforeDet ("").
VALUE LABELS HighestQualSubjectBeforeDet "" "No Response".
EXECUTE

* *** anonymising HighestQualSubjectBeforeDet - MF.
IF (ResponseId="R_3p9HmDdYWIhU5Sd") HighestQualSubjectBeforeDet="B.ing (XXXX) Industrial Engineering".
IF (ResponseId="R_3fkjzJYupDKFe3M") HighestQualSubjectBeforeDet=CONCAT("Master of Business Studies (Hons) in XXXX at the University of XXXX, Italy (XXXX). She holds a Maste",
"r’s degree (Hons) in XXXX at the University of XXXX, Italy (XXXX) and a Bachelor’s degree in XXXX at the University of XXXX, Italy (XXXX)").
IF (ResponseId="R_3fk0Uq37u62EMV9") HighestQualSubjectBeforeDet=CONCAT("Associates of Science Biology, Bachelor of Business Administration Management Information Systems, M",
"aster of Science Education, Doctorate of Education Higher Education Administration.  Master's Diploma XXXX Studies.").
IF (ResponseId="R_3ikzEOBvDhDciL6") HighestQualSubjectBeforeDet="Industrial Distribution.    I worked in industrial sales upon graduating for 4 years before going to work with XXXX University".
IF (ResponseId="R_3G9sOhTadwQE8wE") HighestQualSubjectBeforeDet="MA in XXXX".
IF (ResponseId="R_1IGK5UktCJqHSwF") HighestQualSubjectBeforeDet="Master in Biology, PhD in Forest Ecology, Research on XXXX".
IF (ResponseId="R_2zHlDSb3sfxes3M") HighestQualSubjectBeforeDet="XXXX women's history".
IF (ResponseId="R_1OTZgKNgpSJJ8xw") HighestQualSubjectBeforeDet="1) B.A. in history and 2) B.A. in XXXX".
IF (ResponseId="R_2VjMIfFPDm0ETzS") HighestQualSubjectBeforeDet="Master degree in Public Health and PhD in XXXX Studies".
IF (ResponseId="R_2bHJFxOSgqAmPBc") HighestQualSubjectBeforeDet="Business Law, XXXX Law, Telecommunication Law, Business administration".
IF (ResponseId="R_3JelxaMjip7C4Lg") HighestQualSubjectBeforeDet="Masters of Health Science, Bachelor of Applied Science, Grad Dip in Community Health, Paediatric Nurse, Registered Nurse, Leadership Course and XXXX course".
EXECUTE.

* *** HighestQualification --> should actually be HighestQualDuring.
RENAME VARIABLES HighestQualLevel_2=HighestQualDuring.
VARIABLE LABELS HighestQualDuring "20c. Highest academic qualification while being an RMA". /* trying to retain Q numbers.
VARIABLE LEVEL HighestQualDuring (ORDINAL).
MISSING VALUES HighestQualDuring (-99).
ADD VALUE LABELS HighestQualDuring -99 "No Response".
EXECUTE.

* *** HighestQualSubject.
VARIABLE LABELS HighestQualSubjectDuring "20d. Highest academic qualification subject area while being an RMA". /* trying to retain Q numbers.
VARIABLE LEVEL HighestQualSubjectDuring (NOMINAL).
FORMATS HighestQualSubjectDuring(f8.1).
MISSING VALUES HighestQualSubjectDuring (-99).
ADD VALUE LABELS HighestQualSubjectDuring -99 "No Response".
EXECUTE.

* *** NOTE THAT - For "None" additional qualification, often the subject area was selected.. and hence was "Other" - it should really be SYSMIS - so do that.
IF ((HighestQualDuring=4) & (HighestQualSubjectDuring=12)) HighestQualSubjectDuring=$SYSMIS. /* 60 instances
IF (ResponseId="R_3kvN0R8dzd6FjQn") HighestQualSubjectDuring=$SYSMIS. /* backcoded from AnyIssues [SK].
EXECUTE.

* HighestQualSubjectD
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES HighestQuals_12=HighestQualSubjectDuringDet.
VARIABLE LABELS HighestQualSubjectDuringDet "20e. Highest academic qualification subject details while being an RMA".
MISSING VALUES HighestQualSubjectDuringDet ("").
VALUE LABELS HighestQualSubjectDuringDet "" "No Response".
EXECUTE.

* *** Anonymisg HighestQualSubjectBeforeDet - MF.
IF (ResponseId="R_1FfBSQmqwVk0eS1") HighestQualSubjectDuringDet="PhD in English Literature - XXXX Canadian Literature".
IF (ResponseId="R_3fkjzJYupDKFe3M") HighestQualSubjectDuringDet=CONCAT("PhD course (Hons) in European Union Studies focused on XXXX from the University of XXXX, Spain (XXXX",
"), a postgraduate course at the XXXX University (XXXX, Czech Republic) on XXXX (XXXX) and XXXX (XXXX) at the XXXX Polytechnique XXXX (XXXX)").
IF (ResponseId="R_bIpQQm2XujkUdFL") HighestQualSubjectDuringDet="Gestión de XXXX".
IF (ResponseId="R_7Vhfy6dUdehydYR") HighestQualSubjectDuringDet="Magister en Salud Pública y Especialista en proyecto de XXXX".
IF (ResponseId="R_2cdVVA3WatGoePn") HighestQualSubjectDuringDet="I'm currently in XXXX's RA masters program".
IF (ResponseId="R_2B9BketGf8GGN2x") HighestQualSubjectDuringDet="Completed Certified XXXX Purchasing Manager (XXXX)".
IF (ResponseId="R_2CwYsHlMJu9LMqE") HighestQualSubjectDuringDet="Association of Project Managers (APM) Project Management Qualification (XXXX)".
IF (ResponseId="R_pGHFO0MKwRpIUNz") HighestQualSubjectDuringDet="Graduate of Australian Institute of XXXX".
IF (ResponseId="R_2wiST9UonTMxm9Q") HighestQualSubjectDuringDet="Continueing Education Certificate in Research Administration (XXXX Fellowship)".
IF (ResponseId="R_U9kXVY0h5c4HVL3") HighestQualSubjectDuringDet="MS, Research Administration, XXXX".
EXECUTE.

* *** Backcoding from HighestQualSubjectBeforeDet - SK.
IF (ResponseId="R_2rpRYiJ1jKphLen") HighestQualSubjectBefore=6.
IF (ResponseId="R_3mkptFxSt38AUaY") HighestQualSubjectBefore=5.
IF (ResponseId="R_3eq9uQtyQqZtVQU") HighestQualSubjectBefore=8.
IF (ResponseId="R_1DYanbxC3462eyu") HighestQualSubjectBefore=9.
IF (ResponseId="R_1CxBKxmTKRMpWHf") HighestQualSubjectBefore=8.
IF (ResponseId="R_26ewMtsfM3FCf7f") HighestQualSubjectBefore=6.
IF (ResponseId="R_1IsaI3dk9k7bXff") HighestQualSubjectBefore=7.
IF (ResponseId="R_1pQc3q2aKpZ1CDG") HighestQualSubjectBefore=7.
IF (ResponseId="R_293NbFHTmBjb3QO") HighestQualSubjectBefore=4.
IF (ResponseId="R_zT2eNBT6YR3Iuw9") HighestQualSubjectBefore=7.
IF (ResponseId="R_3R3Z0iphXeHKg85") HighestQualSubjectBefore=7.
IF (ResponseId="R_3iCQbLACysURDO2") HighestQualSubjectBefore=12.
IF (ResponseId="R_1ISnIcs9T2Lj5jV") HighestQualSubjectBefore=7.
IF (ResponseId="R_22Ex2b3GwQQOTAo") HighestQualSubjectBefore=9.
IF (ResponseId="R_SCoX4MsRRsbiCel") HighestQualSubjectBefore=8.
IF (ResponseId="R_Zt9jhMRClOnW8Qp") HighestQualSubjectBefore=12.
IF (ResponseId="R_wLZ4EYWzqeHmJah") HighestQualSubjectBefore=4.
IF (ResponseId="R_1E3XSookHdo4bz9") HighestQualSubjectBefore=12.
IF (ResponseId="R_qDRxvTys6SzeRcR") HighestQualSubjectBefore=7.
IF (ResponseId="R_DiuinV5MkqEaDkd") HighestQualSubjectBefore=4.
IF (ResponseId="R_1QzjAPjqKaHHPvE") HighestQualSubjectBefore=5.
IF (ResponseId="R_2D7xj79aZOwRDso") HighestQualSubjectBefore=9.
IF (ResponseId="R_uq4mndSbAJTJkxX") HighestQualSubjectBefore=10.
IF (ResponseId="R_2Yh2S9HEAIWzDXM") HighestQualSubjectBefore=4.
IF (ResponseId="R_3n6GuiK2Jkuzkur") HighestQualSubjectBefore=4.
IF (ResponseId="R_1PYrNLM24qcVgKz") HighestQualSubjectBefore=5.
IF (ResponseId="R_dhj37VMR8aBDw2t") HighestQualSubjectBefore=9.
IF (ResponseId="R_2q4OkdopAIPpJFR") HighestQualSubjectBefore=8.
IF (ResponseId="R_1mPAQ10gkttsdr0") HighestQualSubjectBefore=8.
IF (ResponseId="R_3KveEINHRTsTyzA") HighestQualSubjectBefore=9.
IF (ResponseId="R_2tmzDPoZpocaAD9") HighestQualSubjectBefore=8.
IF (ResponseId="R_1CeyvZZ5LrYWShP") HighestQualSubjectBefore=7.
IF (ResponseId="R_24is7KpLNiY9yCk") HighestQualSubjectBefore=8.
IF (ResponseId="R_12EYXkGLH2Pbpp6") HighestQualSubjectBefore=9.
IF (ResponseId="R_3MS89nmgOGSEd9i") HighestQualSubjectBefore=8.
IF (ResponseId="R_RLGGl21PBZwD1TP") HighestQualSubjectBefore=5.
IF (ResponseId="R_2Wwfjp0dxjqqu1f") HighestQualSubjectBefore=7.
IF (ResponseId="R_3PMoZkWLtjEpFkL") HighestQualSubjectBefore=4.
IF (ResponseId="R_3pgV8hMhQdKw9cV") HighestQualBefore=$SYSMIS. /* HighestQual selected in error - an not unselectable.
EXECUTE.

RECODE HighestQualBefore HighestQualDuring
    (8 = 4.0)
    (9 = 5.0)
    (10 = 5.5)
    (11 = 6.0)
    (12 = 7.0)
    (13 = 8.0)
    (-99=SYSMIS)
    (ELSE=Copy).
VALUE LABELS HighestQualBefore HighestQualDuring 4 "None" 5 "High School" 5.5 "Foundation" 6 "Bachelor's" 7 "Master's" 8 "Doctorate" -99 "No Response".
EXECUTE.

* *** backcoding from HighestQualSubjectDuringDet - CO.
IF (ResponseId="R_2fHtPbKMDe6okbS") HighestQualSubjectDuring=8.
IF (ResponseId="R_3qOe9q9wSeTMKkN") HighestQualSubjectDuring=8.
IF (ResponseId="R_3DkA3HV4oJ8jTJF") HighestQualSubjectDuring=4.
IF (ResponseId="R_3fkjzJYupDKFe3M") HighestQualSubjectDuring=7.
IF (ResponseId="R_1IKU6aw0alWKVxE") HighestQualSubjectDuring=8.
IF (ResponseId="R_cAxXTkcxVgBehvb") HighestQualSubjectDuring=8.
IF (ResponseId="R_vObAu147CuWrCMN") HighestQualSubjectDuring=8.
IF (ResponseId="R_2ab1eC1WwhyDv9A") HighestQualSubjectDuring=7.
IF (ResponseId="R_pJJmbgjAoJJnprb") HighestQualSubjectDuring=8.
IF (ResponseId="R_2RWFejiyU9U386K") HighestQualSubjectDuring=8.
IF (ResponseId="R_1hxUCBWwtm204Po") HighestQualSubjectDuring=9.
IF (ResponseId="R_qxrNlcdR5IW05TH") HighestQualSubjectDuring=8.
IF (ResponseId="R_117rhnaHayOWTfo") HighestQualSubjectDuring=8.
IF (ResponseId="R_3QMF0PkQJy9andD") HighestQualSubjectDuring=7.
IF (ResponseId="R_2cdVVA3WatGoePn") HighestQualSubjectDuring=8.
IF (ResponseId="R_25QNmshvWmX0kMB") HighestQualSubjectDuring=7.
IF (ResponseId="R_3O2jSdrxjC3POMi") HighestQualSubjectDuring=9.
IF (ResponseId="R_24vXwqSplDYMBBp") HighestQualSubjectDuring=8.
IF (ResponseId="R_263zbwxFEOIKa1V") HighestQualSubjectDuring=7.
IF (ResponseId="R_3KBlXf1pDysQbqz") HighestQualSubjectDuring=9.
IF (ResponseId="R_30vI4P8tsMFSqLu") HighestQualSubjectDuring=6.
IF (ResponseId="R_3KZOEwXOAfmrPm4") HighestQualSubjectDuring=1.
IF (ResponseId="R_2xyjK3we5NkCh85") HighestQualSubjectDuring=8.
IF (ResponseId="R_2TRV38gVPOH0Nik") HighestQualSubjectDuring=7.
IF (ResponseId="R_3m2yC0gf5ht26sw") HighestQualSubjectDuring=5.
IF (ResponseId="R_2z6ZyQwyn4DIBEv") HighestQualSubjectDuring=8.
IF (ResponseId="R_2WOpBR7Ya18gYG5") HighestQualSubjectDuring=9.
IF (ResponseId="R_5heOjSYDgQWI2lj") HighestQualSubjectDuring=5.
IF (ResponseId="R_10pb3RgLws4q8lC") HighestQualSubjectDuring=5.
IF (ResponseId="R_3ikf9OyJ33abw0A") HighestQualSubjectDuring=9.
IF (ResponseId="R_2ZHQEykPAtXeIHC") HighestQualSubjectDuring=6.
IF (ResponseId="R_1LifDNNDvAqbxvg") HighestQualSubjectDuring=4.
IF (ResponseId="R_3EQYk10uOO6BPln") HighestQualSubjectDuring=7.
IF (ResponseId="R_1LomsZYqKZY3Bv4") HighestQualSubjectDuring=7.
IF (ResponseId="R_Xhd66792r6UfCjT") HighestQualSubjectDuring=7.
IF (ResponseId="R_3NKYFuS2LltbExP") HighestQualSubjectDuring=7.
IF (ResponseId="R_2VIUyPRmdgbCoNo") HighestQualSubjectDuring=7.
IF (ResponseId="R_3imx9rSC1XIZpFJ") HighestQualSubjectDuring=7.
IF (ResponseId="R_YPlbztn9MyC8ck9") HighestQualSubjectDuring=4.
IF (ResponseId="R_1IpjBK66y0ii6Ws") HighestQualSubjectDuring=4.
IF (ResponseId="R_6MddLHmgYmwzZ5v") HighestQualSubjectDuring=4.
IF (ResponseId="R_xz7cuPzcuvbZYWd") HighestQualSubjectDuring=8.
IF (ResponseId="R_30csdV1S96uN5GU") HighestQualSubjectDuring=9.
IF (ResponseId="R_3MbehZZZTChdbuj") HighestQualSubjectDuring=7.
IF (ResponseId="R_1E3XSookHdo4bz9") HighestQualSubjectDuring=8.
IF (ResponseId="R_1n3c1NJB3k1f1ub") HighestQualSubjectDuring=8.
IF (ResponseId="R_2zeGXho1Xx00cFP") HighestQualSubjectDuring=7.
IF (ResponseId="R_1rPspI1ZKXE5gM4") HighestQualSubjectDuring=7.
IF (ResponseId="R_24D7Y0LOQXXc1LQ") HighestQualSubjectDuring=9.
IF (ResponseId="R_3psTyZ79Le9reSa") HighestQualSubjectDuring=7.
IF (ResponseId="R_C1daRR5oxjsUoG5") HighestQualSubjectDuring=4.
IF (ResponseId="R_3G39HpWUtefem5c") HighestQualSubjectDuring=8.
IF (ResponseId="R_123fRdDbzJOvUvC") HighestQualSubjectDuring=7.
IF (ResponseId="R_cRYDiBF5b0lGHiF") HighestQualSubjectDuring=6.
IF (ResponseId="R_pflzVp3JPINSAEh") HighestQualSubjectDuring=7.
IF (ResponseId="R_qDRxvTys6SzeRcR") HighestQualSubjectDuring=7.
IF (ResponseId="R_2EF8sjy4w0Xuv17") HighestQualSubjectDuring=4.
IF (ResponseId="R_3HtstTEgJAQKqGA") HighestQualSubjectDuring=7.
IF (ResponseId="R_1pAQwfakkF6tHyg") HighestQualSubjectDuring=7.
IF (ResponseId="R_3lzATLKPJPhRrDt") HighestQualSubjectDuring=7.
IF (ResponseId="R_1IsAYsXdo9UVMBe") HighestQualSubjectDuring=9.
IF (ResponseId="R_2XhrPMuO21RVRqm") HighestQualSubjectDuring=9.
IF (ResponseId="R_3ho9DMDVYJuEz2a") HighestQualSubjectDuring=9.
IF (ResponseId="R_BrZY84RSuvIEULf") HighestQualSubjectDuring=4.
IF (ResponseId="R_1Qo2iznWHPZYO9i") HighestQualSubjectDuring=7.
IF (ResponseId="R_qQ7IVDrFSH5lq7f") HighestQualSubjectDuring=7.
IF (ResponseId="R_1rxcqa4QgrXABYc") HighestQualSubjectDuring=6.
IF (ResponseId="R_bI7NDB8vYFk8ADf") HighestQualSubjectDuring=8.
IF (ResponseId="R_Xn5DHooROr9JIoF") HighestQualSubjectDuring=7.
IF (ResponseId="R_1QopVY5Iuk6gLPV") HighestQualSubjectDuring=4.
IF (ResponseId="R_2y8YX9SvcHA2wN5") HighestQualSubjectDuring=4.
IF (ResponseId="R_snTB022ftHynxSh") HighestQualSubjectDuring=7.
IF (ResponseId="R_3n1w8yYwqITmAmn") HighestQualSubjectDuring=7.
IF (ResponseId="R_2TO9Y6KriQkhWN7") HighestQualSubjectDuring=4.
IF (ResponseId="R_DwSvyvXy61iTVbH") HighestQualSubjectDuring=6.
IF (ResponseId="R_dg3meGn1o7POGYh") HighestQualSubjectDuring=5.
IF (ResponseId="R_23SbBOD52jiFfMt") HighestQualSubjectDuring=5.
IF (ResponseId="R_2tmzDPoZpocaAD9") HighestQualSubjectDuring=9.
IF (ResponseId="R_2aQ5YCASVXk1lEM") HighestQualSubjectDuring=5.
IF (ResponseId="R_1mWo0vw92TSpik9") HighestQualSubjectDuring=7.
IF (ResponseId="R_3EXp3KpPUDwMa6E") HighestQualSubjectDuring=7.
IF (ResponseId="R_3HG3FYdR50tgX35") HighestQualSubjectDuring=7.
EXECUTE.

* *** Now create a variable to directly match RAAAP-1 data.
COMPUTE HighestQualification=MAX(HighestQualBefore,HighestQualDuring).
VARIABLE LABELS HighestQualification "20r1. Highest academic qualification".
VARIABLE LEVEL HighestQualification (ORDINAL).
MISSING VALUES HighestQualification (-99).
ADD VALUE LABELS HighestQualification 4 "None" 5 "High School" 5.5 "Foundation" 6 "Bachelor's" 7 "Master's" 8 "Doctorate" -99 "No Response".
EXECUTE.

* And now something similar for subject area.
COMPUTE HighestQualificationSubject=HighestQualSubjectBefore.
DO IF (HighestQualification >= HighestQualBefore).
    DO IF SYSMIS(HighestQualSubjectDuring). 
        COMPUTE HighestQualificationSubject=HighestQualSubjectBefore.
    ELSE.
        COMPUTE HighestQualificationSubject=HighestQualSubjectDuring.
    END IF.
END IF.
EXECUTE.
* *** note that this assumes that for RAAAP data people would have chosen the subject area of their most recent (eg) masters if they have done one while being an RMA.
VARIABLE LEVEL HighestQualificationSubject (NOMINAL).
MISSING VALUES HighestQualificationSubject (-99).
ADD VALUE LABELS HighestQualificationSubject -99 "No Response".
EXECUTE.
APPLY DICTIONARY from *
/SOURCE VARIABLES = HighestQualSubjectBefore
/TARGET VARIABLES = HighestQualificationSubject
/NEWVARS.
VARIABLE LABELS HighestQualificationSubject "20r1. Highest academic qualification subject ". /* matches RAAAP-1.
EXECUTE.
IF HighestQualification=5.5 HighestQualification=5. /* as this was not in RAAAP-1.
FORMATS HighestQualification(f8.1).
EXECUTE.

STRING HighestQualificationSubjectDet (A2000). /* probably too long, but keep them the same...
COMPUTE HighestQualificationSubjectDet=(HighestQualSubjectBeforeDet).
IF (HighestQualification >= HighestQualBefore) HighestQualificationSubjectDet=HighestQualSubjectDuringDet.
* *** Same logic used for details in case it might be useful for people later on?  Easiest to do it here!?
* *** Although that gives two places to check for anonymisation.
EXECUTE.
APPLY DICTIONARY from *
/SOURCE VARIABLES = HighestQualSubjectBeforeDet
/TARGET VARIABLES = HighestQualificationSubjectDet
/NEWVARS.
* *** WARNING ColumnWidth for HighestQualSubjectBeforeDet is 15 but HighestQualificationSubjectDet is left at 32.
* *** this warning can be ignored.
VARIABLE LABELS HighestQualificationSubjectDet "20r1. Highest academic qualification subject details ". /* matches RAAAP-1.
MISSING VALUES HighestQualificationSubjectDet ("").
VALUE LABELS HighestQualificationSubjectDet "" "No Response".
EXECUTE.


* *** Now the section on professional qualifications.
* *** Many are a direct match for RAAAP-1 and all for RAAAP-2.
* *** ARMS ***.
RENAME VARIABLES ProfessionalQuals_1=PQ_AU_ARMF.
* *** PQ_AU_ARMF is a direct match to RAAAP-1.
VARIABLE LABELS PQ_AU_ARMF "21a. Professional Qualification - Australasia - ARM(F)".
VALUE LABELS PQ_AU_ARMF 1 "Yes".
MISSING VALUES PQ_AU_ARMF (-99).
ADD VALUE LABELS PQ_AU_ARMF -99 "No Response".
VARIABLE LEVEL PQ_AU_ARMF (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_2=PQ_AU_ARMA.
* *** PQ_AU_ARMP is NOT a direct match to RAAAP-1. Professional --> Advanced - is it equivalent?.
VARIABLE LABELS PQ_AU_ARMA "21b. Professional Qualification - Australasia - ARM(A)".
VALUE LABELS PQ_AU_ARMA 1 "Yes".
MISSING VALUES PQ_AU_ARMA (-99).
ADD VALUE LABELS PQ_AU_ARMA -99 "No Response".
VARIABLE LEVEL PQ_AU_ARMA (NOMINAL).
EXECUTE.
* *** CARA ***.
RENAME VARIABLES ProfessionalQuals_3=PQ_CA_CRA.
* *** PQ_CA_CRA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_CA_CRA "21c. Professional Qualification - Canada - CRA".
VALUE LABELS PQ_CA_CRA 1 "Yes".
MISSING VALUES PQ_CA_CRA (-99).
ADD VALUE LABELS PQ_CA_CRA -99 "No Response".
VARIABLE LEVEL PQ_CA_CRA (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_4=PQ_CA_CRM.
* *** PQ_CA_CRM is a direct match to RAAAP-1.
VARIABLE LABELS PQ_CA_CRM "21d. Professional Qualification - Canada - CRM".
VALUE LABELS PQ_CA_CRM 1 "Yes".
MISSING VALUES PQ_CA_CRM (-99).
ADD VALUE LABELS PQ_CA_CRM -99 "No Response".
VARIABLE LEVEL PQ_CA_CRM (NOMINAL).
EXECUTE.
* *** EARMA ***.
RENAME VARIABLES ProfessionalQuals_5=PQ_EU_CRA.
* *** PQ_EU_CRA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_EU_CRA "21e. Professional Qualification - Europe - CRA".
VALUE LABELS PQ_EU_CRA 1 "Yes".
MISSING VALUES PQ_EU_CRA (-99).
ADD VALUE LABELS PQ_EU_CRA -99 "No Response".
VARIABLE LEVEL PQ_EU_CRA (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_6=PQ_EU_CRM.
* *** PQ_EU_CRM is a direct match to RAAAP-1.
VARIABLE LABELS PQ_EU_CRM "21f. Professional Qualification - Europe - CRM".
VALUE LABELS PQ_EU_CRM 1 "Yes".
MISSING VALUES PQ_EU_CRM (-99).
ADD VALUE LABELS PQ_EU_CRM -99 "No Response".
VARIABLE LEVEL PQ_EU_CRM (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_7=PQ_EU_CLRM.
* *** PQ_EU_CLRM is a direct match to RAAAP-1.
VARIABLE LABELS PQ_EU_CLRM "21g. Professional Qualification - Europe - CLRM".
VALUE LABELS PQ_EU_CLRM 1 "Yes".
MISSING VALUES PQ_EU_CLRM (-99).
ADD VALUE LABELS PQ_EU_CLRM -99 "No Response".
VARIABLE LEVEL PQ_EU_CLRM (NOMINAL).
EXECUTE.
* *** United Kingom ***.
RENAME VARIABLES ProfessionalQuals_8=PQ_UK_CRA.
* *** PQ_UK_CRA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_UK_CRA "21h. Professional Qualification - UK - CRA".
VALUE LABELS PQ_UK_CRA 1 "Yes".
MISSING VALUES PQ_UK_CRA (-99).
ADD VALUE LABELS PQ_UK_CRA -99 "No Response".
VARIABLE LEVEL PQ_UK_CRA (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_9=PQ_UK_CRM.
* *** PQ_UK_CRM is a direct match to RAAAP-1.
VARIABLE LABELS PQ_UK_CRM "21i. Professional Qualification - UK - CRM".
VALUE LABELS PQ_UK_CRM 1 "Yes".
MISSING VALUES PQ_UK_CRM (-99).
ADD VALUE LABELS PQ_UK_CRM -99 "No Response".
VARIABLE LEVEL PQ_UK_CRM (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_10=PQ_UK_CLRM.
* *** PQ_UK_CLRM is a direct match to RAAAP-1.
VARIABLE LABELS PQ_UK_CLRM "21j. Professional Qualification - UK - CLRM".
VALUE LABELS PQ_UK_CLRM 1 "Yes".
MISSING VALUES PQ_UK_CLRM (-99).
ADD VALUE LABELS PQ_UK_CLRM -99 "No Response".
VARIABLE LEVEL PQ_UK_CLRM (NOMINAL).
EXECUTE.
* *** US [RACC] ***.
RENAME VARIABLES ProfessionalQuals_20=PQ_US_CRA.
* *** PQ_US_CRA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_US_CRA "21k. Professional Qualification - US - CRA".
VALUE LABELS PQ_US_CRA 1 "Yes".
MISSING VALUES PQ_US_CRA (-99).
ADD VALUE LABELS PQ_US_CRA -99 "No Response".
VARIABLE LEVEL PQ_US_CRA (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_12=PQ_US_CPRA.
* *** PQ_US_CPRA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_US_CPRA "21l. Professional Qualification - US - CPRA".
VALUE LABELS PQ_US_CPRA 1 "Yes".
MISSING VALUES PQ_US_CPRA (-99).
ADD VALUE LABELS PQ_US_CPRA -99 "No Response".
VARIABLE LEVEL PQ_US_CPRA (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_13=PQ_US_CFRA.
* *** PQ_US_CFRA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_US_CFRA "21m. Professional Qualification - US - CFRA".
VALUE LABELS PQ_US_CFRA 1 "Yes".
MISSING VALUES PQ_US_CFRA (-99).
ADD VALUE LABELS PQ_US_CFRA -99 "No Response".
VARIABLE LEVEL PQ_US_CFRA (NOMINAL).
EXECUTE.
* *** other US ***.
RENAME VARIABLES ProfessionalQuals_14=PQ_US_CIP.
* *** PQ_US_CIP is a direct match to RAAAP-1.
VARIABLE LABELS PQ_US_CIP "21n. Professional Qualification - US - CIP".
VALUE LABELS PQ_US_CIP 1 "Yes".
MISSING VALUES PQ_US_CIP (-99).
ADD VALUE LABELS PQ_US_CIP -99 "No Response".
VARIABLE LEVEL PQ_US_CIP (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_15=PQ_US_CPIA.
* *** PQ_US_CPIA is a direct match to RAAAP-1.
VARIABLE LABELS PQ_US_CPIA "21o. Professional Qualification - US - CPIA".
VALUE LABELS PQ_US_CPIA 1 "Yes".
MISSING VALUES PQ_US_CPIA (-99).
ADD VALUE LABELS PQ_US_CPIA -99 "No Response".
VARIABLE LEVEL PQ_US_CPIA (NOMINAL).
EXECUTE.
* *** academic qualificiations in Research Administration ***.
RENAME VARIABLES ProfessionalQuals_16=PQ_Bachelor.
* *** PQ_Bachelor is a direct match to RAAAP-1.
VARIABLE LABELS PQ_Bachelor "21p. Professional Qualification - Bachelor's".
VALUE LABELS PQ_Bachelor 1 "Yes".
MISSING VALUES PQ_Bachelor (-99).
ADD VALUE LABELS PQ_Bachelor -99 "No Response".
VARIABLE LEVEL PQ_Bachelor (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_17=PQ_Master.
* *** PQ_Master is a direct match to RAAAP-1.
VARIABLE LABELS PQ_Master "21q. Professional Qualification - Master's".
VALUE LABELS PQ_Master 1 "Yes".
MISSING VALUES PQ_Master (-99).
ADD VALUE LABELS PQ_Master -99 "No Response".
VARIABLE LEVEL PQ_Master (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_18=PQ_Doctor.
* *** PQ_Doctor is a direct match to RAAAP-1.
VARIABLE LABELS PQ_Doctor "21r. Professional Qualification - Doctorate".
VALUE LABELS PQ_Doctor 1 "Yes".
MISSING VALUES PQ_Doctor (-99).
ADD VALUE LABELS PQ_Doctor -99 "No Response".
VARIABLE LEVEL PQ_Doctor (NOMINAL).
EXECUTE.
* *** Something else.... ***.
RENAME VARIABLES ProfessionalQuals_19=PQ_Other.
* *** PQ_Other is a direct match to RAAAP-1.
VARIABLE LABELS PQ_Other "21s. Professional Qualification - Other".
VALUE LABELS PQ_Other 1 "Yes".
MISSING VALUES PQ_Other (-99).
ADD VALUE LABELS PQ_Other -99 "No Response".
VARIABLE LEVEL PQ_Other (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_21=PQ_None.
* *** PQ_None is a NOT direct match to RAAAP-1.  Here we ask for a specific assertion about no professional qualifications in RMA.
VARIABLE LABELS PQ_None "21t. Professional Qualification - None".
VALUE LABELS PQ_None 1 "Yes".
MISSING VALUES PQ_None (-99).
ADD VALUE LABELS PQ_None -99 "No Response".
VARIABLE LEVEL PQ_None (NOMINAL).
EXECUTE.
RENAME VARIABLES ProfessionalQuals_22=PQ_NoneAvailable.
* *** NEW  for RAAAP-3 Here we ask for a specific assertion about no professional qualifications available in RMA for my role.
VARIABLE LABELS PQ_NoneAvailable "21u. Professional Qualification - None Available".
VALUE LABELS PQ_NoneAvailable 1 "Yes".
MISSING VALUES PQ_NoneAvailable (-99).
ADD VALUE LABELS PQ_NoneAvailable -99 "No Response".
VARIABLE LEVEL PQ_NoneAvailable (NOMINAL).
EXECUTE.

* PQ_OtherDetails. *** Direct match with RAAAP-1/2.
* is a string, and may well end up in a separate datafile to protect anonymity.
VARIABLE LABELS PQ_OtherDetails "21z. Details of Other professional qualifications ".
MISSING VALUES PQ_OtherDetails ("").
VALUE LABELS PQ_OtherDetails "" "No Response".
EXECUTE.

* *** Anonymising PQ_OtherDetails - CO.
IF (ResponseId="R_2QibIJZYaBvfAAM") PQ_OtherDetails="Certified Public Administrator (a part of the MA program in Political Science -Public Policy and Administration [Public Affairs]) https://XXXX".
IF (ResponseId="R_1itcxqJQ20UqUuh") PQ_OtherDetails="XXXX in Certificate in Research Management (CRM) - Canada but not yet graduated".
IF (ResponseId="R_shE8R9wbYChkjVD") PQ_OtherDetails="XXXX SARIMA programme for Professional Certificate in Research Management".
IF (ResponseId="R_2qEKrEnSxTQ4kPW") PQ_OtherDetails="Earned CRA in 2018; XXXX.".
IF (ResponseId="R_2RayvTdm4kdJ8tg") PQ_OtherDetails="I earned the CRA in XXXX and have kept it current.".
IF (ResponseId="R_WDafRkNQetSKJ3P") PQ_OtherDetails="XXXX an Advanced Certificate in Research Administration in the U.S.".
IF (ResponseId="R_1QaBIwwFq6BtGtv") PQ_OtherDetails="But I participated in XXXX Japanese URA Qualification and got other certificates related to analysis tools".
IF (ResponseId="R_2CIm9hxkFikvd2m") PQ_OtherDetails="XXXX University offers a foundational certificate course in research management".
IF (ResponseId="R_RLzrZfnvPDI7Cc9") PQ_OtherDetails="Consortium for the Development of Human Resources to Support 'Multi-functional' Research https:XXXX".
IF (ResponseId="R_3m4xohCFglaXmcy") PQ_OtherDetails="CRA: registered for XXXX".
IF (ResponseId="R_3KpzsXKs5qYpshJ") PQ_OtherDetails="XXXX Foundation Level accreditation".
IF (ResponseId="R_PG0HqGUBoP7qdDb") PQ_OtherDetails="XXXX the CARA research administrative certificate.".
IF (ResponseId="R_1jvp6CN31KJRQX6") PQ_OtherDetails="XXXX enrolled in the Certificate in Research Administration (Canada)".
IF (ResponseId="R_2uPTC5SCnWsrFgS") PQ_OtherDetails="XXXX the ARMA Foundation Course in Research Administration and Management".
IF (ResponseId="R_6A2qPGaTeZuewSd") PQ_OtherDetails="XXXX a US Certified Research Admin (CRA) certification".
IF (ResponseId="R_2bO6GBtB1OR0X93") PQ_OtherDetails="XXXX the foundation accreditation with ARMS.".
IF (ResponseId="R_3EgvMcBGAIgpZfz") PQ_OtherDetails="XXXX CRM".
IF (ResponseId="R_3hthFRgsvCZD8Sg") PQ_OtherDetails="XXXX CRM".
IF (ResponseId="R_2teYcFW6XKV0wTn") PQ_OtherDetails="XXXX EARMA CRM (Europe)".
IF (ResponseId="R_1LomsZYqKZY3Bv4") PQ_OtherDetails="XXXX a Foundation course with ARMA for research management".
IF (ResponseId="R_1K6WG3OendP1rVN") PQ_OtherDetails="XXXX the SRAI LevelUp micro-credentialing.".
IF (ResponseId="R_2q3hxsC4CMk4EBq") PQ_OtherDetails="XXXX university of Technology".
IF (ResponseId="R_24wkYFp025LmGRO") PQ_OtherDetails="Earned CRA credential XXXX".
IF (ResponseId="R_30vrQBcc4JUkTCp") PQ_OtherDetails="earned CRA in XXXX & have renewed twice in XXXX & XXXX".
IF (ResponseId="R_rqN3J5i9b1brMYN") PQ_OtherDetails="Estudios de Postgrado acerca de 'Website Databases Contents' en 'XXXX University' en XXXX en XXXX.".
IF (ResponseId="R_31Z3nzl5ppkscaY") PQ_OtherDetails="I am XXXX certificate program through CARA/Mohawk College, XXXX.".
IF (ResponseId="R_2CjL36XMuqFlYHV") PQ_OtherDetails="I am XXXX to gain the EARMA certificate in Research Management (CRM)".
IF (ResponseId="R_b7vK1hvz6uhTuKZ") PQ_OtherDetails="I am XXXX EARMA CRM".
IF (ResponseId="R_1drU471Bhrdhh4x") PQ_OtherDetails="XXXX the Australasia Foundation Level".
IF (ResponseId="R_2TGd1XuDaThBT6S") PQ_OtherDetails="XXXX the Australasia Foundation level".
IF (ResponseId="R_2Xd1W2vlMgUecCO") PQ_OtherDetails="XXXX the Advanced Certificate in Research Management (UK).".
IF (ResponseId="R_1oBh6iWj33NSqMF") PQ_OtherDetails="XXXX the ARMA qualification but do not currently have any research admin related qualification".
IF (ResponseId="R_DGdw0Xsyo8vO9ZD") PQ_OtherDetails="I XXXX ARMA’s qualifications framework and XXXX. Was already very experienced when the qualifications were developed.".
IF (ResponseId="R_1DIKxJzAUUdzZ3j") PQ_OtherDetails="I earned my CRA credential in XXXX and have kept it up-to-date/renewed it.".
IF (ResponseId="R_2ZVUdoaDpybtR8Y") PQ_OtherDetails="I had applied for a masters in Research Administration (XXXX) at XXXX University but I couldn’t make it due to some financial constraints. I will most likely enroll next year.".
IF (ResponseId="R_2Ey2YLlD6BAw5nH") PQ_OtherDetails="I have a Master of Business Administration (MBA) along with several information technology and cybersecurity certificates.  I received 'SRAI Certificate in XXXX'".
IF (ResponseId="R_ZJFsONaMoTFPD33") PQ_OtherDetails="I have a Postgraduate Course in Science and Technology Management and XXXX (XXXX), on XXXX".
IF (ResponseId="R_1LhC28RKl2r39zP") PQ_OtherDetails="I have been a CRA since XXXX".
IF (ResponseId="R_1F5FoPuYzHNgGeP") PQ_OtherDetails="I have been meaning to get my CRA but life has brought on changes over the last few years; XXXX.".
IF (ResponseId="R_2nuCteJU2a0c2PL") PQ_OtherDetails="I have taken an XXXX provided by EARMA".
IF (ResponseId="R_28SBKSxYa8xFDBr") PQ_OtherDetails="I received an accreditation in Research administration from XXXX University".
IF (ResponseId="R_D934SCyhR3vYpQ5") PQ_OtherDetails="I served as XXXX for the Certificate in Research Admin (Canada)".
IF (ResponseId="R_3q9WbtyF44D2dzg") PQ_OtherDetails="I was in the XXXX CRA cohort. My certification is a joint CARA/ARMA certification (ETHA - UK)".
IF (ResponseId="R_1d072mTPfQb7vUo") PQ_OtherDetails="In Japan we do not have official accreditation system, but University XXXX has given me a certified URA(University Research Administrator) title.".
IF (ResponseId="R_2xz4afuk9SUlISa") PQ_OtherDetails="IPRC Senior RM Professional status conffered in XXXX.  Currently studying a Postgrad diploma in RMA, through XXXX, XXXX University.".
IF (ResponseId="R_3sHvPLLYzXeqhQB") PQ_OtherDetails="Leadership Development for Mid Career Women (XXXX School of Business)".
IF (ResponseId="R_1q7B42kCMem5b12") PQ_OtherDetails="MA Project Management at  'XXXX' University XXXX, XXXX Faculty of Business and Administration".
IF (ResponseId="R_2XnW60b0Aysfjjf") PQ_OtherDetails="Maestría en Ingeniería Agronómica, por la Universidad XXXX y Maestría en Gestión de Empresas de Base Biotecnológica (Master of Biotechnology) por University of XXXX".
IF (ResponseId="R_2z75HDt7hxbaw7K") PQ_OtherDetails="Maestría en Investigación en Documentación, tesis en gestión de la investigación, Universidad XXXX  Doctorado en XXXX; Tesis University research Governance, XXXX University".
IF (ResponseId="R_1C7OkQbPnTWpO4m") PQ_OtherDetails="Masters IEP XXXX & ENS XXXX (FR)".
IF (ResponseId="R_1K9genRnZ1f58hK") PQ_OtherDetails="My initial certification as a US - Certified Research Administrator was XXXX, and I recertified for XXXX.".
IF (ResponseId="R_1ghcaUJJbn68VHm") PQ_OtherDetails="Not sure if I chosed correctly above: I only have a XXXX course on Management XXXX on Science and Technology".
IF (ResponseId="R_0iHgPDCF9WIilCV") PQ_OtherDetails="Obtained my CRA in XXXX and have maintained the certification.  Currently seeking advance certification.".
IF (ResponseId="R_2TSFRpKy2BkddTT") PQ_OtherDetails="Phd student in University of XXXX - Portugal in Industrial Engineering and Management  focusing in the triple helix of innovation in the Defense economy".
IF (ResponseId="R_4TLNy0cLowpixCV") PQ_OtherDetails="RACC CRA effective through XXXX".
IF (ResponseId="R_0VqtfQprkvdWZ7H") PQ_OtherDetails="received CRA in XXXX".
IF (ResponseId="R_1mxRSsK7qmKFwFz") PQ_OtherDetails="Registered Technology Transfer Professional (RTTP) https://attp.global/about/alliance-members/  Accredited XXXX - Australasian Research Management Society".
IF (ResponseId="R_2WSZ1UiruW0AjUT") PQ_OtherDetails="Scheduled to take CRA test in XXXX (for United States)".
IF (ResponseId="R_1d65hu6zMw22ThR") PQ_OtherDetails="Senior Project manager by XXXX".
IF (ResponseId="R_3qOe9q9wSeTMKkN") PQ_OtherDetails="Started Masters program in research administration at XXXX.".
IF (ResponseId="R_29fSvPFUApwQStW") PQ_OtherDetails="Three modules of project management course offered within the University of XXXX - Denmark".
IF (ResponseId="R_3JxVEhwdigp6VPG") PQ_OtherDetails="Took a POST-GRADUATE IN SCIENCE AND TECHNOLOGY MANAGEMENT AND XXXX".
IF (ResponseId="R_1jAENrpiFgBRvMi") PQ_OtherDetails="Will graduate with MRA in XXXX".
IF (ResponseId="R_3EoOIhHlW8wsfLL") PQ_OtherDetails="Will take the CRA and CPRA exam in XXXX".
IF (ResponseId="R_2Qm4AWDBP855uls") PQ_OtherDetails=CONCAT("Certified project manager, level C (IPMA Number SE2271-C) XXXX Accredited Project Excellence Prepara",
"tion Assessor (IPMA/XXXX) XXXX  Certification in work environment responsibility (OHSAS 18001) XXXX").
IF (ResponseId="R_AcjzJWX61tXH5yF") PQ_OtherDetails=CONCAT("I began XXXX at a former institution, but there is no funding to continue it at my current instituti",
"on. Moreover, XXXX seems to have lost the record my successful completion, which is quite annoying.").
IF (ResponseId="R_ewCOL6JpvypYH4t") PQ_OtherDetails=CONCAT("3-months full-time course in research administration at the German University for Administration in ",
"XXXX, two six-day courses in research management leadership with my current employer, who has a leadership academy widely recognized in the German context.").
IF (ResponseId="R_3KUgebMvWg9oS0A") PQ_OtherDetails=CONCAT("I am an academic in the area of Chemical Engineering.  I am registered as a Chartered Engineer with ",
"the Engineering Council, a Fellow of the Institution of XXXX (XXXX) and a professional engineer with the Board of Engineers XXXX (XXXX).  Being in these professional bodies gives me an understanding o",
"f what professionalization is about.").
IF (ResponseId="R_10HrHVJFS68MxGd") PQ_OtherDetails=CONCAT("I am on a taskforce to develop RD credentialing within XXXX. CRA is not an appropriate credential fo",
"r what I do (although some of the curriculum is good to know for higher level administration in my field). In addition, I would like to try to earn an ELS credential (Editor in the Life Sciences) to i",
"ncrease my chances of being able to work in a medical school.").
IF (ResponseId="R_2urOeJvBzZLMV7G") PQ_OtherDetails=CONCAT("I attended a lot of courses of project management at national level, european level, International X",
"XXX - 2 XXXX summer schools, International XXXX Leadership  programme - XXXX oriented on research and co-operation of universities with companies. I had a lot of meetings with other research managers ",
"during my previous jobs - so I learned a lot from that meetings and practice. The most important were projects for me - participation in them was the best management school ever.  I realised also a lo",
"t of courses according soft skills and language courses (English, German, French, Russian and Chinese nowdays).  During my master studies I received strong background according management, marketing, ",
"accounting, law and administration.").
IF (ResponseId="R_1dh0nhxAOZ8F68r") PQ_OtherDetails=CONCAT("I have completed XXXX of the Australasia foundational level accreditation, however I tend to miss ou",
"t when modules become available to attend in favor of (at first more senior and now more junior) colleagues. Covid19 has also meant that these modules are less available.").
IF (ResponseId="R_2WwEyNITlmZ1Kgh") PQ_OtherDetails=CONCAT("I was 'certified' according to the requirements of my first university.  They provided their own tra",
"ining and required it to be renewed every 5 years.  I also completed a short course on business operations management at universities thru the University of XXXX.").
IF (ResponseId="R_3P6MY5ID2VuYOIR") PQ_OtherDetails=CONCAT("My university (XXXX) offers Research Administration Academy and requires all research admins take th",
"e classes and exam certification. XXXX also offers an XXXX certification. The XXXX has fewer classes, but there is a certification exam as well. We have maintain continuing education credits for or ce",
"rtifications to remain active.").
IF (ResponseId="R_e9BjHcgAYawMfVD") PQ_OtherDetails=CONCAT("PMP Project Management Institute (PMI) N°: XXXX  Project Management Professional (Professional) PMP ",
"Exam Power Preparation School of Business of The XXXX University and ESI International PMP Achievement certificate (XXXX) (XXXX) Norma UNI CEI EN ISO/IEC 17024, Norma UNI 11506, Norma UNI ISO 21500, N",
"orma UNI 11648 - Certification ICT Project Manager XXXX – CEPAS n°XXXX - Certification – Project Manager XXXX - CEPAS n°XXXX all other Research manager courses - XXXX - XXXX CHAMBER OF COMMERCE Brusse",
"ls - European project accounting and management course (5 days)- XXXX: Webinar on Research Infrastructures RI's: XXXX; XXXX H2020 Coordinators' Day (Amendments and Reporting) Cisco WebEx, on the XXXX ",
"- EUROPEAN COMMISSION DIRECTORATE-GENERAL FOR RESEARCH & INNOVATION; other similar webinars").
EXECUTE.

* *** Backcoding for PQ_OtherDetails - SK.
IF (ResponseId="R_1FfBSQmqwVk0eS1") PQ_None=1.
IF (ResponseId="R_1n3GkULv9YSwTYu") PQ_US_CRA=1.
IF (ResponseId="R_2xxcIVEFriNObMx") PQ_Other=1.
IF (ResponseId="R_337Q5GBFqvmzCLb") PQ_Other=1.
IF (ResponseId="R_3s4CftKBa3K1A95") PQ_Other=1.
IF (ResponseId="R_2dvgf4W6vUwnpc8") PQ_Other=1.
IF (ResponseId="R_11jT1bi4QcrTOIl") PQ_None=1.
IF (ResponseId="R_1r30Eir7crAxJGg") PQ_Master=1.
IF (ResponseId="R_26i1oUtP2twCRSD") PQ_None=1.
IF (ResponseId="R_3j0sVPzQNRzhtie") PQ_Other=1.
IF (ResponseId="R_0iBOJdRxZ8p3ZOF") PQ_Other=1.
IF (ResponseId="R_3DkxKT4u4fpV9Lb") PQ_None=1.
IF (ResponseId="R_3NKZw8cCtRo9cxF") PQ_Other=1.
IF (ResponseId="R_Xhd66792r6UfCjT") PQ_Master=1.
IF (ResponseId="R_3CE3IBd1DVN1Mub") PQ_None=1.
IF (ResponseId="R_3F5pdRRsODrvJch") PQ_None=1.
IF (ResponseId="R_DiuinV5MkqEaDkd") PQ_None=1.
IF (ResponseId="R_1melr13qnZLDngr") PQ_Other=1.
IF (ResponseId="R_3Ja4r1Mg2okTHzy") PQ_None=1.
IF (ResponseId="R_ZaEGq4j1Zt2n4R3") PQ_Other=1.
IF (ResponseId="R_29oeGDIZx6c1pOV") PQ_Other=1.
IF (ResponseId="R_1QopVY5Iuk6gLPV") PQ_None=1.
IF (ResponseId="R_xae87MSkLclxrPz") PQ_Other=1.
IF (ResponseId="R_XU2xYCplODgE2Q1") PQ_None=1.
EXECUTE.

* *** AnyCRA has been used in some RAAAP-1 Analyses - so useful to add it here I think ***.
COMPUTE AnyCRA = 0.
VARIABLE LABELS AnyCRA "21x. Any National RA Certification".
MISSING VALUES AnyCRA (-99).
VALUE LABELS AnyCRA 1 "Yes" -99 "No Response" 0 "No".
VARIABLE LEVEL AnyCRA (NOMINAL).
FORMATS AnyCRA (f8).
EXECUTE.

DO IF MAX(PQ_AU_ARMF TO PQ_OTHER)=1.
    COMPUTE AnyCRA=1.
ELSE.
    COMPUTE AnyCRA=0.
END IF.
EXECUTE.

* *** Q22. For RAAAP-3 added a n/a option for the likert-type scales.
RENAME VARIABLES ProfessionalQualVal_1=PQ_NoDifference.
RENAME VARIABLES ProfessionalQualVal_2=PQ_HelpedPromotion.
RENAME VARIABLES ProfessionalQualVal_3=PQ_DoJobBetter.
RENAME VARIABLES ProfessionalQualVal_4=PQ_MoreConfidence.
RENAME VARIABLES ProfessionalQualVal_5=PQ_Status.
RENAME VARIABLES ProfessionalQualVal_6=PQ_ThinkItWould.
VARIABLE LABELS PQ_NoDifference "22a. PQs made no difference to me".
VARIABLE LABELS PQ_HelpedPromotion "22b. PQs helped get promotion / new job".
VARIABLE LABELS PQ_DoJobBetter "22c. PQs help me do job better".
VARIABLE LABELS PQ_MoreConfidence "22d. PQs give me more confidence".
VARIABLE LABELS PQ_Status "22e. PQs increase my credibility".
VARIABLE LABELS PQ_ThinkItWould "22f. PQs don't have, but think it would help my career".
MISSING VALUES PQ_NoDifference PQ_HelpedPromotion PQ_DoJobBetter PQ_MoreConfidence PQ_Status PQ_ThinkItWould (-99).
ADD VALUE LABELS PQ_NoDifference PQ_HelpedPromotion PQ_DoJobBetter PQ_MoreConfidence PQ_Status PQ_ThinkItWould -99 "No Response".
VARIABLE LEVEL PQ_NoDifference PQ_HelpedPromotion PQ_DoJobBetter PQ_MoreConfidence PQ_Status PQ_ThinkItWould (NOMINAL).
EXECUTE.
* ProfessionalQualValD. *** Also new for RAAAP-2.
* is a string, and may well end up in a separate datafile to protect anonymity.
RENAME VARIABLES ProfessionalQualValD=PQ_OtherComments.
VARIABLE LABELS PQ_OtherComments "22z. Other comments about professional qualifications".
MISSING VALUES PQ_OtherComments ("").
VALUE LABELS PQ_OtherComments "" "No Response".
EXECUTE.

* *** Anonymising PQ_OtherComments - CO.
IF (ResponseId="R_2QibIJZYaBvfAAM") PQ_OtherComments=CONCAT("I've talked with the XXXX Deans about these programs including participation in NCURA for profession",
"al development.  There are many new RAs with less than 10-years experience.   XXXX has developed a XXXX (XXXX) program with certification, which is good, but in my opinion only a start.  There should ",
"be ongoing professional development as this field grows and changes, and it's difficult to keep up on your own.  FRAC is an excellent program, which I've only been able to attend this year as I was on",
"e handling 3-active departments.  From my conversation with the Deans they will now work on having a NCURA training Program at XXXX.  We used to have these periodically at XXXX over the last few decad",
"es, but in recent years.  Membership for individuals and attending other programs was not a part of the discussion.  I belonged to NCURA and attended programs when I was a part of the XXXX Sponsored P",
"rograms Office, but it was dissolved in XXXX.  Becoming a departmental RA, these opportunities decreased with a focus more on proposals and funding research, than my training and development.   The De",
"ans will also support the CRA (Certified Research Administrator), but not financially.  However, they are considering a salary increment once completed.  A start for newcomers, not so much for me.  Bu",
"t I'd like to see those that come after me to have more opportunities and development.  Professional certifications and continual professional development would be important to both the RA and the org",
"anization.  My opinion.").
IF (ResponseId="R_1itcxqJQ20UqUuh") PQ_OtherComments="FYI - XXXX CRM (Canada) - it gives me a good overall overview of the field - keeps me in touch with RA colleagues and potential colleagues".
IF (ResponseId="R_27IDMdkHzQrtQvU") PQ_OtherComments="The focus of my doctoral dissertation was 'XXXX' - there was no correlation found between educational background or accreditation and success in a role as a healthcare administrator.".
IF (ResponseId="R_3qfzmcC8tup2MfE") PQ_OtherComments=CONCAT("Professional accreditation is important and I am a mentor on AUA XXXX and ARMA XXXX.  I have complet",
"ed an MBA over 10 years ago when no professional certification was available and this provided me with many skills which I use today.").
EXECUTE.

* *** Backcoding from PQ_OtherComments - SK.
IF (ResponseId="R_2coaYZkhabe2jqX") PQ_ThinkItWould=1.
IF (ResponseId="R_2bT8bXFA0KjkYeY") PQ_ThinkItWould=4.
IF (ResponseId="R_1eqPESEhOMpFGZu") PQ_ThinkItWould=2.
IF (ResponseId="R_3hgXWMHm8fs2mji") PQ_ThinkItWould=2.
EXECUTE.

* *** Q23 ProfessionalDev_55..70.
RENAME VARIABLES ProfessionalDev_55=PD_Comms.
VARIABLE LABELS PD_Comms "23a. Professional Development - Communication".
RENAME VARIABLES ProfessionalDev_56=PD_Collab.
VARIABLE LABELS PD_Collab "23b. Professional Development - Teamwork/Collaboration".
RENAME VARIABLES ProfessionalDev_57=PD_Adapt.
VARIABLE LABELS PD_Adapt "23c. Professional Development - Adaptability/Change Management".
RENAME VARIABLES ProfessionalDev_58=PD_ProblemSolving.
VARIABLE LABELS PD_ProblemSolving "23d. Professional Development - Problem-solving".
RENAME VARIABLES ProfessionalDev_59=PD_Observation.
VARIABLE LABELS PD_Observation "23e. Professional Development - Critical Observation".
RENAME VARIABLES ProfessionalDev_60=PD_Coaching.
VARIABLE LABELS PD_Coaching "23f. Professional Development - Coaching". /* This is a change for RAAAP-2 (part of "Mentoring and Coaching" from RAAAP-1).
RENAME VARIABLES ProfessionalDev_61=PD_StressManagement.
VARIABLE LABELS PD_StressManagement "23g. Professional Development - Stress Management".  /* This is a new one for RAAAP-2 - could be useful for cross reference with Shambrook data.
RENAME VARIABLES ProfessionalDev_62=PD_ServiceCulture.
VARIABLE LABELS PD_ServiceCulture "23h. Professional Development - Service Culture".  /* This is a new one for RAAAP-2.
RENAME VARIABLES ProfessionalDev_63=PD_InitiativeTaking.
VARIABLE LABELS PD_InitiativeTaking "23i. Professional Development - Initiative Taking".
RENAME VARIABLES ProfessionalDev_64=PD_EDI.
VARIABLE LABELS PD_EDI "23j. Professional Development - Cultural and Diversity".
RENAME VARIABLES ProfessionalDev_65=PD_TakingResponsibility.
VARIABLE LABELS PD_TakingResponsibility "23k. Professional Development - Taking Responsibility".
RENAME VARIABLES ProfessionalDev_66=PD_ProjectManagement.
VARIABLE LABELS PD_ProjectManagement "23l. Professional Development - Project Management".
RENAME VARIABLES ProfessionalDev_67=PD_MentoringOnly. /* The PD_Mentoring is used in RAAAP-1 for Mentoring and Coaching.
VARIABLE LABELS PD_MentoringOnly "23m. Professional Development - Mentoring". /* The RAAAP-1 text is OK though, for combined it is "Mentoring an Coaching".
RENAME VARIABLES ProfessionalDev_68=PD_ConflictResolution.
VARIABLE LABELS PD_ConflictResolution "23n. Professional Development - Conflict Resolution".
RENAME VARIABLES ProfessionalDev_69=PD_LanguageSkills.
VARIABLE LABELS PD_LanguageSkills "23o. Professional Development - Language Skills". /* new for RAAAP-2 - ties into the new questions on how many languages do you use at work.
RENAME VARIABLES ProfessionalDev_70=PD_Other.
VARIABLE LABELS PD_Other "23p. Professional Development - Other".

RENAME VARIABLES ProfessionalDev_71=PD_None. /* new for RAAAP-3 to get a positive affirmation of None rather than just an absence of ticks.

* *** Backcoding from PD_OtherDetails - SK - do it here in case there are any for mentoring (which there are not as it happends).
IF (ResponseId="R_74E6xkjOr8nYoYV") PD_Other=1.
IF (ResponseId="R_OuKcTEOqX3Rjx3r") PD_EDI=1.
IF (ResponseId="R_3JelxaMjip7C4Lg") PD_None=1.
EXECUTE.

* *** add in a Mentoring and Coaching to match RAAAP-1.
COMPUTE PD_Mentoring=MAX(PD_Coaching,PD_MentoringOnly).
VARIABLE LABELS PD_Mentoring "23r1. Professional Development - Mentoring and Coaching".
VARIABLE LABELS PD_None "23x. Professional Development - None".

VALUE LABELS PD_Comms PD_Collab PD_Adapt PD_ProblemSolving PD_Observation PD_Coaching
PD_StressManagement PD_ServiceCulture PD_InitiativeTaking PD_EDI PD_TakingResponsibility
PD_ProjectManagement PD_MentoringOnly PD_ConflictResolution PD_LanguageSkills PD_Other
PD_Mentoring PD_None 1 "Yes" -99 "No Response".
MISSING VALUES PD_Comms PD_Collab PD_Adapt PD_ProblemSolving PD_Observation PD_Coaching
PD_StressManagement PD_ServiceCulture PD_InitiativeTaking PD_EDI PD_TakingResponsibility 
PD_ProjectManagement PD_MentoringOnly PD_ConflictResolution PD_LanguageSkills PD_Other
PD_Mentoring PD_None (-99).
VARIABLE LEVEL PD_Comms PD_Collab PD_Adapt PD_ProblemSolving PD_Observation PD_Coaching
PD_StressManagement PD_ServiceCulture PD_InitiativeTaking PD_EDI PD_TakingResponsibility 
PD_ProjectManagement PD_MentoringOnly PD_ConflictResolution PD_LanguageSkills PD_Other
PD_Mentoring PD_None (NOMINAL).
EXECUTE.

* PD_OtherDetails. exact match to RAAAP-1/2
* is a string, and may well end up in a separate datafile to protect anonymity.
VARIABLE LABELS PD_OtherDetails "23. Details of Other professional development".
MISSING VALUES PQ_OtherComments ("").
VALUE LABELS PQ_OtherComments "" "No Response".
EXECUTE.

* *** anonymising PD_OtherDetails- CO.
IF (ResponseId="R_SP3fcyxcsL4pKpj") PD_OtherDetails=CONCAT("Association of XXXX (XXXX) Postgrad Certificate in University Administration. Distance learning prog",
"ramme so was actually extremely time intense. Was useful in building my knowledge of the higher education system and interrogating it from an intellectual view point via knowledge assignments. Less pr",
"actical value but great on my CV and built my confidence.  Advance XXXX Leadership programme - amazing and inspirational short programme which developed my self esteem, reinvigorated my career ambitio",
"ns (I ventured into an even more specialist area of research engagement after this course) and taught me many transferable skills on personal impact, effective communication and resilience.  XXXX Enga",
"ge Academy - fantastic interesting enjoyable course over series of few months. Excellent blend of practical skills on supporting engagement with research, developing an engagement strategy, garnering ",
"buy in and support for engagement and extended my network of fellow research engagement professionals. It spurred me on to deliver even higher quality engagement activities and get greater senior buy ",
"in, and to present case study session at the national XXXX conference. Pivotal course in my career.").
IF (ResponseId="R_Uo5l1t4a0B1vXkR") PD_OtherDetails="Currently completing PGDip RMA at XXXX University".
IF (ResponseId="R_3oGVkVM6DyQJwhV") PD_OtherDetails=CONCAT("XXXX lab management -Facilitation -University of XXXX Researcher management and Leadership  -Many co",
"urses on EU proposal development and project management (facilitated through the Norwegian Research Council) -XXXX societal impact -EU Helpdesk innovation management and exploitation etc -EARMA confer",
"ence and webinars").
IF (ResponseId="R_1ODK8yo4TlG7xDg") PD_OtherDetails=CONCAT("Have taken advantage of many professional development opportunities specific to research administrat",
"ion/job knowledge.  Most have been at conferences/workshops, in person and virtual, so not sure they would be considered 'classes,' though I do consider them professional development.  Have also taken",
" the Developmental Edge virtual course XXXX.  This is a personal and professional growth course that addresses how we identify areas for growth in ourselves and strategize how to move forward in those",
" areas.  This doesn't fit in any of the above listed categories but I consider it professional development as well.").
IF (ResponseId="R_2ymwXT0C6K4ZMPm") PD_OtherDetails=CONCAT("I am taking institution's sponsored project management training series; I took XXXX grantsmanship co",
"urse; I attend NORDP's webinars. I have viewed some NIH training modules online; plan to finish NIH's and NSF's training modules.").
IF (ResponseId="R_2aaECc37WOETzqG") PD_OtherDetails=CONCAT("I attended various training programs while being a member of staff at the Wellcome Trust and at XXXX",
", XXXX. I would like to mention three highlights which I found helpful: i) Process development, ii) Influencing skills and iii) digital marketing (relevant for my role as the Head of Research Communic",
"ations, when our institution was making a transition to being on social media). I also believe that training on the job made me sensitive to matters such as service culture, diversity, being a self-st",
"arter and change management & planning .").
IF (ResponseId="R_3dE8npkjy5d8mnD") PD_OtherDetails="I have completed XXXX Library Systems Certifications. They have diversified my duties at the library, although RMA tasks they have not added.".
IF (ResponseId="R_1n2dDzfQ0zmYPdB") PD_OtherDetails="I have taken a 1 year certficate professional Executive Leadership Course (Strategy) from University of XXXX.  This course covers all elements indicated above.".
IF (ResponseId="R_1llz9vuusTFc7xn") PD_OtherDetails="I have taken XXXX, a course on racial equity, and Managing Up. I feel that all three gave me insights that have helped my overall ability to interact with others in the workplace.".
IF (ResponseId="R_6VTOgZlWMFvqh0J") PD_OtherDetails="I teach a workshop on 'Professional Development XXXX' - so yes, I certainly believe these types of sessions have helped my career (and my personal life, in some instances).".
IF (ResponseId="R_2Vm7IjlGxgsBS5Q") PD_OtherDetails=CONCAT("I took a XXXX Early Career Research Administrator XXXX. I think it was useful, but not necessarily v",
"ital. What was vital was understanding the broad cross section of tasks/responsibilities people with similar titles do, even though they vary wildly!").
IF (ResponseId="R_2Bzl4nMaOiUjwA0") PD_OtherDetails="I was awarded by XXXX Fellowship for research administrators and was chosen for special courses for VR research project managers (it was only my initiative, my boss just signed the approval)".
IF (ResponseId="R_2Qm4AWDBP855uls") PD_OtherDetails=CONCAT("PPS, Project management, XXXX Accredited Project Excellence Preparation Assessor H2020 Marie Curie W",
"S Financial Helpdesk, XXXX Writing competitive ITN Proposals in the H2020 MSCA, Yellow Research, XXXX PPS, Project governance II, XXXX Writing a winning proposal, XXXX Research Support Services for Ho",
"rizon 2020, XXXX Finance in Horizon 2020, XXXX, XXXX Consortium Agreements for Horizon 2020, XXXX How to Write a Competitive Proposal for Horizon 2020, XXXX How to write the abstract and impact of a F",
"P 7 proposal, XXXX Clear leadership, XXXX Value Management XXXX P3M3 - project maturity XXXX Resource planning w/ governance of projects and portfolio XXXX MSProject 2011 Project management, XXXX Rese",
"arch Program Management course at XXXX").
IF (ResponseId="R_wZem8cP1mki6wXT") PD_OtherDetails="The additional courses I did were: XXXX Leaders and Managers Program (XXXX) Leadership XXXX program  I found the project management course and XXXX program to be particularly good for my career".
IF (ResponseId="R_2QibIJZYaBvfAAM") PD_OtherDetails=CONCAT("The University of XXXX has always offered training and development for it's employees.  When able I'",
"ve taken many of these programs and some offer certificates, such as Supervisory XXXX Certificate; XXXX (Leadership Enhancement and XXXX) Certificate; Conducting Research Responsibly XXXX;  XXXX Compl",
"iance satellite program (XXXX); 'Write Winning Grants' - XXXX;  Compliance: XXXX;Compliance & Ethics: XXXX; and Protecting XXXX, along with others as possible to fit in my schedule.  Yes, they helped ",
"me in my career in XXXX and probably job security, but not in advancement.  I would have had to leave XXXX and move for advancement and that would have been difficult.  Yes, I recognize this factor.").
IF (ResponseId="R_2b3gGxKX9xnpkGg") PD_OtherDetails="WT Grant Project Management training  run in-house by XXXX.".
IF (ResponseId="R_2rpRYiJ1jKphLen") PD_OtherDetails="XXXX of Research International Leadership Programme - (SRA International (US) + Association of Research Managers and Administrators (UK) +  Leadership Foundation for Higher Education (UK)) 1.".
IF (ResponseId="R_1i4o2VOnrpIuOpu") PD_OtherDetails="Yes - professional/Leadership development courses including a Chief Executive Women's Scholarship (XXXX) to XXXX 'Women in Leadership' course".
IF (ResponseId="R_1FtV3AJcFglICUx") PD_OtherDetails=CONCAT("Yes, I attained a Science communication course @Università XXXX and a Popular science writing course",
" @University of XXXX. Both helped learning how to translate 'scientific language' into 'proposal language'").
EXECUTE.

* Q24 & 25 Languages Spoken / Used same as RAAAP-2.
MISSING VALUES LanguagesSpoken (-99).
VARIABLE LABELS LanguagesSpoken '24. Number of languages spoken'.
VARIABLE LEVEL LanguagesSpoken(ORDINAL).
FORMATS LanguagesSpoken(f8).
ADD VALUE LABELS LanguagesSpoken -99 "No Response".
EXECUTE.
MISSING VALUES LanguagesUsed (-99).
VARIABLE LABELS LanguagesUsed '25. Number of languages used at work'.
VARIABLE LEVEL LanguagesUsed(ORDINAL).
FORMATS LanguagesUsed(f8).
ADD VALUE LABELS LanguagesUsed -99 "No Response".
EXECUTE.


* *** now professional body membership.
* Matches RAAAP-2 but with seven additional associations added: CLORA, COREMA, KOsRIS II, MyRMA, NARIMA, NWM, & PRISM.
* NOTE "Participated" could also include past (non current) membership of.
* *** ALSO NOTE the question on NONE - save internal consistency question as above.

RENAME VARIABLES Associations_38_1=Assoc_ACU_Member.
RENAME VARIABLES Associations_38_2=Assoc_ACU_Participated.
VARIABLE LABELS Assoc_ACU_Member "26am. Member of ACU (Commonwealth)".
VARIABLE LABELS Assoc_ACU_Participated "26ap. Participated in ACU (Commonwealth)".
RENAME VARIABLES Associations_39_1=Assoc_ARMA_Member.
RENAME VARIABLES Associations_39_2=Assoc_ARMA_Participated.
VARIABLE LABELS Assoc_ARMA_Member "26bm. Member of ARMA (UK)".
VARIABLE LABELS Assoc_ARMA_Participated "26bp. Participated in ARMA (UK)".
RENAME VARIABLES Associations_40_1=Assoc_ARMANL_Member.
RENAME VARIABLES Associations_40_2=Assoc_ARMANL_Participated.
VARIABLE LABELS Assoc_ARMANL_Member "26cm. Member of ARMANL (Netherlands)".
VARIABLE LABELS Assoc_ARMANL_Participated "26cp. Participated in ARMANL (Netherlands)".
RENAME VARIABLES Associations_41_1=Assoc_ARMS_Member.
RENAME VARIABLES Associations_41_2=Assoc_ARMS_Participated.
VARIABLE LABELS Assoc_ARMS_Member "26dm. Member of ARMS (Australasia)".
VARIABLE LABELS Assoc_ARMS_Participated "26dp. Participated in ARMS (Australasia)".
RENAME VARIABLES Associations_42_1=Assoc_AUA_Member.
RENAME VARIABLES Associations_42_2=Assoc_AUA_Participated.
VARIABLE LABELS Assoc_AUA_Member "26em. Member of AUA (UK)".
VARIABLE LABELS Assoc_AUA_Participated "26ep. Participated in AUA (UK)".
RENAME VARIABLES Associations_43_1=Assoc_AURAM_Member.
RENAME VARIABLES Associations_43_2=Assoc_AURAM_Participated.
VARIABLE LABELS Assoc_AURAM_Member "26fm. Member of AURAM (Austria)".
VARIABLE LABELS Assoc_AURAM_Participated "26fp. Participated in AURAM (Austria)".
RENAME VARIABLES Associations_44_1=Assoc_AUTM_Member.
RENAME VARIABLES Associations_44_2=Assoc_AUTM_Participated.
VARIABLE LABELS Assoc_AUTM_Member "26gm. Member of AUTM (USA)".
VARIABLE LABELS Assoc_AUTM_Participated "26gp. Participated in AUTM (USA)".
RENAME VARIABLES Associations_45_1=Assoc_BESTPRAC_Member.
RENAME VARIABLES Associations_45_2=Assoc_BESTPRAC_Participated.
VARIABLE LABELS Assoc_BESTPRAC_Member "26hm. Member of BESTPRAC (Europe)".
VARIABLE LABELS Assoc_BESTPRAC_Participated "26hp. Participated in BESTPRAC (Europe)".
RENAME VARIABLES Associations_46_1=Assoc_BRAMA_Member.
RENAME VARIABLES Associations_46_2=Assoc_BRAMA_Participated.
VARIABLE LABELS Assoc_BRAMA_Member "26im. Member of BRAMA (Brazil)".
VARIABLE LABELS Assoc_BRAMA_Participated "26ip. Participated in BRAMA (Brazil)".
RENAME VARIABLES Associations_47_1=Assoc_CabRIMA_Member.
RENAME VARIABLES Associations_47_2=Assoc_CabRIMA_Participated.
VARIABLE LABELS Assoc_CabRIMA_Member "26jm. Member of CabRIMA (Caribbean)".
VARIABLE LABELS Assoc_CabRIMA_Participated "26jp. Participated in CabRIMA (Caribbean)".
RENAME VARIABLES Associations_48_1=Assoc_CARA_Member.
RENAME VARIABLES Associations_48_2=Assoc_CARA_Participated.
VARIABLE LABELS Assoc_CARA_Member "26km. Member of CARA (Canada)".
VARIABLE LABELS Assoc_CARA_Participated "26kp. Participated in CARA (Canada)".
RENAME VARIABLES Associations_49_1=Assoc_CARIMA_Member.
RENAME VARIABLES Associations_49_2=Assoc_CARIMA_Participated.
VARIABLE LABELS Assoc_CARIMA_Member "26lm. Member of CARIMA (Central Africa)".
VARIABLE LABELS Assoc_CARIMA_Participated "26lp. Participated in CARIMA (Central Africa)".
RENAME VARIABLES Associations_50_1=Assoc_CASSSP_Member.
RENAME VARIABLES Associations_50_2=Assoc_CASSSP_Participated.
VARIABLE LABELS Assoc_CASSSP_Member "26mm. Member of CASSSP (China)".
VARIABLE LABELS Assoc_CASSSP_Participated "26mp. Participated in CASSSP (China)".
RENAME VARIABLES Associations_51_1=Assoc_CLASP_Member.
RENAME VARIABLES Associations_51_2=Assoc_CLASP_Participated.
VARIABLE LABELS Assoc_CLASP_Member "26nm. Member of CLASP (USA)".
VARIABLE LABELS Assoc_CLASP_Participated "26np. Participated in CLASP (USA)".
RENAME VARIABLES Associations_52_1=Assoc_CLORA_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_52_2=Assoc_CLORA_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_CLORA_Member "26oam. Member of CLORA (France)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_CLORA_Participated "26oap. Participated in CLORA (France)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_53_1=Assoc_COREMA_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_53_2=Assoc_COREMA_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_COREMA_Member "26obm. Member of COREMA (Colombia)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_COREMA_Participated "26obp. Participated in COREMA (Colombia)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_54_1=Assoc_COGR_Member.
RENAME VARIABLES Associations_54_2=Assoc_COGR_Participated.
VARIABLE LABELS Assoc_COGR_Member "26om. Member of COGR (USA)".
VARIABLE LABELS Assoc_COGR_Participated "26op. Participated in COGR (USA)".
RENAME VARIABLES Associations_55_1=Assoc_DARMA_Member.
RENAME VARIABLES Associations_55_2=Assoc_DARMA_Participated.
VARIABLE LABELS Assoc_DARMA_Member "26pm. Member of DARMA (Denmark)".
VARIABLE LABELS Assoc_DARMA_Participated "26pp. Participated in DARMA (Denmark)".
RENAME VARIABLES Associations_56_1=Assoc_EARIMA_Member.
RENAME VARIABLES Associations_56_2=Assoc_EARIMA_Participated.
VARIABLE LABELS Assoc_EARIMA_Member "26qm. Member of EARIMA (Eastern Africa)".
VARIABLE LABELS Assoc_EARIMA_Participated "26qp. Participated in EARIMA (Eastern Africa)".
RENAME VARIABLES Associations_57_1=Assoc_EARMA_Member.
RENAME VARIABLES Associations_57_2=Assoc_EARMA_Participated.
VARIABLE LABELS Assoc_EARMA_Member "26rm. Member of EARMA (Europe)".
VARIABLE LABELS Assoc_EARMA_Participated "26rp. Participated in EARMA (Europe)".
RENAME VARIABLES Associations_58_1=Assoc_FDP_Member.
RENAME VARIABLES Associations_58_2=Assoc_FDP_Participated.
VARIABLE LABELS Assoc_FDP_Member "26sm. Member of FDP (USA)".
VARIABLE LABELS Assoc_FDP_Participated "26sp. Participated in FDP (USA)".
RENAME VARIABLES Associations_59_1=Assoc_FinnARMA_Member.
RENAME VARIABLES Associations_59_2=Assoc_FinnARMA_Participated.
VARIABLE LABELS Assoc_FinnARMA_Member "26tm. Member of Finn-ARMA (Finland)".
VARIABLE LABELS Assoc_FinnARMA_Participated "26tp. Participated in Finn-ARMA (Finland)".
RENAME VARIABLES Associations_60_1=Assoc_GARMA_Member.
RENAME VARIABLES Associations_60_2=Assoc_GARMA_Participated.
VARIABLE LABELS Assoc_GARMA_Member "26um. Member of FORTRAMA (Germany)".
VARIABLE LABELS Assoc_GARMA_Participated "26up. Participated in FORTRAMA (Germany)".
RENAME VARIABLES Associations_61_1=Assoc_IceARMA_Member.
RENAME VARIABLES Associations_61_2=Assoc_IceARMA_Participated.
VARIABLE LABELS Assoc_IceARMA_Member "26vm. Member of IceARMA (Iceland)".
VARIABLE LABELS Assoc_IceARMA_Participated "26vp. Participated in IceARMA (Iceland)".
RENAME VARIABLES Associations_62_1=Assoc_IRMI_Member.
RENAME VARIABLES Associations_62_2=Assoc_IRMI_Participated.
VARIABLE LABELS Assoc_IRMI_Member "26wm. Member of IRMI (India)". /* could also be listed as India Alliance?.
VARIABLE LABELS Assoc_IRMI_Participated "26wp. Participated in IRMI (India)".
RENAME VARIABLES Associations_63_1=Assoc_INORMS_Member.
RENAME VARIABLES Associations_63_2=Assoc_INORMS_Participated.
VARIABLE LABELS Assoc_INORMS_Member "26xm. Member of INORMS (Global)". /* although not officially a member organisation - I wonder how many associate with the INORMS umbrella.
VARIABLE LABELS Assoc_INORMS_Participated "26xp. Participated in INORMS (Global)".
RENAME VARIABLES Associations_64_1=Assoc_Italy_Member.
RENAME VARIABLES Associations_64_2=Assoc_Italy_Participated.
VARIABLE LABELS Assoc_Italy_Member "26ym. Member of Italian grouping (Italy)". /* no official name for Italian grouping as yet.
VARIABLE LABELS Assoc_Italy_Participated "26yp. Participated in Italian grouping (Italy)".
RENAME VARIABLES Associations_65_1=Assoc_KOsRISII_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_65_2=Assoc_KOsRISII_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_KOsRISII_Member "26yam. Member of KOsRIS II (Slovenia)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_KOsRISII_Participated "26yap. Participated in KOsRIS II (Slovenia)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_66_1=Assoc_MyRMA_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_66_2=Assoc_MyRMA_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_MyRMA_Member "26ybm. Member of MyRMA (Malaysia)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_MyRMA_Participated "26ybp. Participated in MyRMA (Malaysia)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_67_1=Assoc_NARIMA_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_67_2=Assoc_NARIMA_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_NARIMA_Member "26ycm. Member of NARIMA (N Africa)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_NARIMA_Participated "26ycp. Participated in NARIMA (N Africa)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_68_1=Assoc_NARMA_Member.
RENAME VARIABLES Associations_68_2=Assoc_NARMA_Participated.
VARIABLE LABELS Assoc_NARMA_Member "26zm. Member of NARMA (Norway)".
VARIABLE LABELS Assoc_NARMA_Participated "26zp. Participated in NARMA (Norway)".
RENAME VARIABLES Associations_69_1=Assoc_NCURA_Member.
RENAME VARIABLES Associations_69_2=Assoc_NCURA_Participated.
VARIABLE LABELS Assoc_NCURA_Member "26aam. Member of NCURA (USA)".
VARIABLE LABELS Assoc_NCURA_Participated "26aap. Participated in NCURA (USA)".
RENAME VARIABLES Associations_70_1=Assoc_NWM_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_70_2=Assoc_NWM_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_NWM_Member "26aaam. Member of NWM (Germany)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_NWM_Participated "26aaap. Participated in NWM (Germany)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_71_1=Assoc_NORDP_Member.
RENAME VARIABLES Associations_71_2=Assoc_NORDP_Participated.
VARIABLE LABELS Assoc_NORDP_Member "26abm. Member of NORDP (USA)".
VARIABLE LABELS Assoc_NORDP_Participated "26abp. Participated in NORDP (USA)".
RENAME VARIABLES Associations_72_1=Assoc_PIC_Member.
RENAME VARIABLES Associations_72_2=Assoc_PIC_Participated.
VARIABLE LABELS Assoc_PIC_Member "26acm. Member of PIC (Portugal)".
VARIABLE LABELS Assoc_PIC_Participated "26acp. Participated in PIC (Portugal)".
RENAME VARIABLES Associations_73_1=Assoc_PrU_Member.
RENAME VARIABLES Associations_73_2=Assoc_PrU_Participated.
VARIABLE LABELS Assoc_PrU_Member "26adm. Member of PraxisAuril (UK)".
VARIABLE LABELS Assoc_PrU_Participated "26adp. Participated in PraxisAuril (UK)".
RENAME VARIABLES Associations_74_1=Assoc_PRISM_Member.  /* new in RAAAP-3.
RENAME VARIABLES Associations_74_2=Assoc_PRISM_Participated.  /* new in RAAAP-3.
VARIABLE LABELS Assoc_PRISM_Member "26adam. Member of PRISM (UK)".  /* new in RAAAP-3.
VARIABLE LABELS Assoc_PRISM_Participated "26adap. Participated in PRISM (UK)".  /* new in RAAAP-3.
RENAME VARIABLES Associations_75_1=Assoc_RMANJ_Member.
RENAME VARIABLES Associations_75_2=Assoc_RMANJ_Participated.
VARIABLE LABELS Assoc_RMANJ_Member "26aem. Member of RMAN-J (Japan)".
VARIABLE LABELS Assoc_RMANJ_Participated "26aep. Participated in RMAN-J (Japan)".
RENAME VARIABLES Associations_76_1=Assoc_SARIMA_Member.
RENAME VARIABLES Associations_76_2=Assoc_SARIMA_Participated.
VARIABLE LABELS Assoc_SARIMA_Member "26afm. Member of SARIMA (Southern Africa)".
VARIABLE LABELS Assoc_SARIMA_Participated "26afp. Participated in SARIMA (Southern Africa)".
RENAME VARIABLES Associations_77_1=Assoc_SRAI_Member.
RENAME VARIABLES Associations_77_2=Assoc_SRAI_Participated.
VARIABLE LABELS Assoc_SRAI_Member "26agm. Member of SRAI (USA)".
VARIABLE LABELS Assoc_SRAI_Participated "26agp. Participated in SRAI (USA)".
RENAME VARIABLES Associations_78_1=Assoc_SWARMA_Member.
RENAME VARIABLES Associations_78_2=Assoc_SWARMA_Participated.
VARIABLE LABELS Assoc_SWARMA_Member "26ahm. Member of Swedish association (Sweden)".
VARIABLE LABELS Assoc_SWARMA_Participated "26ahp. Participated in Swedish association (Sweden)".
RENAME VARIABLES Associations_79_1=Assoc_WARIMA_Member.
RENAME VARIABLES Associations_79_2=Assoc_WARIMA_Participated.
VARIABLE LABELS Assoc_WARIMA_Member "26aim. Member of WARIMA (Western Africa)".
VARIABLE LABELS Assoc_WARIMA_Participated "26aip. Participated in WARIMA (Western Africa)".
RENAME VARIABLES Associations_80_1=Assoc_None_Member.
RENAME VARIABLES Associations_80_2=Assoc_None_Participated.
VARIABLE LABELS Assoc_None_Member "26axm. Member of None of the above".
VARIABLE LABELS Assoc_None_Participated "26axp. Participated in None of the above".
RENAME VARIABLES Associations_81_1=Assoc_Other_Member.
RENAME VARIABLES Associations_81_2=Assoc_Other_Participated.
VARIABLE LABELS Assoc_Other_Member "26azm. Member of Other association".
VARIABLE LABELS Assoc_Other_Participated "26azp. Participated in Other association".

* Assoc_OtherDetails. exact match to RAAAP-1/2.
* is a string, and may well end up in a separate datafile to protect anonymity.
VARIABLE LABELS Assoc_OtherDetails "26az. Details of Other association(s)".
MISSING VALUES Assoc_OtherDetails ("").
VALUE LABELS Assoc_OtherDetails "" "No Response".
EXECUTE.

* *** and add the associations mentioned 5 or more times in the free text Assoc_OtherDetails.
COMPUTE Assoc_ARIS_Member = -99. /* Advancing Research Impact in Society (ARIS).
COMPUTE Assoc_ARIS_Participated = -99.
COMPUTE Assoc_AUECO_Member = -99. /* Association of University Export Control Officials (AUECO).
COMPUTE Assoc_BEARMA_Member = -99. /* Belgian Association of Research Managers and Administrators (BE-ARMA).
COMPUTE Assoc_CAPANR_Member = -99. /* CAP ANR (now CAP Research) French National funding Agency Network
COMPUTE Assoc_CASE_Member = -99. /* Council for Advancement and Support of Education (CASE).
COMPUTE Assoc_CURIE_Member = -99. /* Reseau C.U.R.I.E.
COMPUTE Assoc_CZARMA_Member = -99. /* Czech Association of Research Managers and Administrators (CZ-ARMA).
COMPUTE Assoc_GPA_Member = -99. /* Grant Professionals Association (GPA).
COMPUTE Assoc_PMI_Member = -99. /* Project Management Institut (PMI)
COMPUTE Assoc_PRIMR_Member = -99. /* Public Responsibility in Medicine and Research (PRIM&R).
COMPUTE Assoc_PRIMR_Participated = -99.
COMPUTE Assoc_RACC_Member = -99. /* Research Administration Certification Council (RACC).
COMPUTE Assoc_RACC_Participated = -99.
COMPUTE Assoc_SOCRA_Member = -99. /* Society of Clinical Research Associates (SoCRA).
COMPUTE Assoc_UIDP_Member = -99. /* University Industry Demonstration Partnership (UIDP).
COMPUTE Assoc_UIDP_Participated = -99.
VARIABLE LABELS Assoc_ARIS_Member "26xxam. Member of ARIS (USA)".
VARIABLE LABELS Assoc_ARIS_Participated "26xxap. Participated in ARIS (USA)".
VARIABLE LABELS Assoc_AUECO_Member "26xxbm. Member of AUECO (USA)".
VARIABLE LABELS Assoc_BEARMA_Member "26xxcm. Member of BE-ARMA (BE)".
VARIABLE LABELS Assoc_CAPANR_Member "26xxdm. Member of CAP ANR (FR)".
VARIABLE LABELS Assoc_CASE_Member "26xxem. Member of CASE (USA)".
VARIABLE LABELS Assoc_CURIE_Member "26xxfm. Member of CURIE (FR)".
VARIABLE LABELS Assoc_CZARMA_Member "26xxgm. Member of CZARMA (CZ)".
VARIABLE LABELS Assoc_GPA_Member "26xxhm. Member of GPA (USA)".
VARIABLE LABELS Assoc_PMI_Member "26xxim. Member of PMI (Global)".
VARIABLE LABELS Assoc_PRIMR_Member "26xxjm. Member of PRIM&R (USA)".
VARIABLE LABELS Assoc_PRIMR_Participated "26xxjp. Participated of PRIM&R (USA)".
VARIABLE LABELS Assoc_RACC_Member "26xxkm. Member of RACC (USA)".
VARIABLE LABELS Assoc_RACC_Participated "26xxkp. Participated of RACC (USA)".
VARIABLE LABELS Assoc_SOCRA_Member "26xxlm. Member of SOCRA (USA)".
VARIABLE LABELS Assoc_UIDP_Member "26xxmm. Member of UIDP (USA)".
VARIABLE LABELS Assoc_UIDP_Participated "26xxmp. Participated of UIDP (USA)".

MISSING VALUES Assoc_ARIS_Member TO Assoc_UIDP_Participated (-99).
VALUE LABELS Assoc_ARIS_Member TO Assoc_UIDP_Participated 1 "Yes" -99 "No Response".
VARIABLE LEVEL Assoc_ARIS_Member TO Assoc_UIDP_Participated (NOMINAL).
FORMATS Assoc_ARIS_Member TO Assoc_UIDP_Participated (f8).
EXECUTE.

* *** Backcoding from Assoc_OtherDetails (but leave the original text).
IF (ResponseId="R_1FvPNTKSHNDO7QZ") Assoc_CASE_Member=1.
IF (ResponseId="R_3O2HFb0ibCwMMxu") Assoc_ARIS_Participated=1.
IF (ResponseId="R_dniCUrsyYDDKHHX") Assoc_PRIMR_Participated=1.
IF (ResponseId="R_1mm7P0sEfaX5hl2") Assoc_PMI_Member=1.
IF (ResponseId="R_shE8R9wbYChkjVD") Assoc_PMI_Member=1.
IF (ResponseId="R_88MxXev2GQdBHxv") Assoc_BEARMA_Member=1.
IF (ResponseId="R_4TLNy0cLowpixCV") Assoc_SOCRA_Member=1.
IF (ResponseId="R_2qEKrEnSxTQ4kPW") Assoc_CASE_Member=1.
IF (ResponseId="R_3p9lX1t9YPgY09M") Assoc_CZARMA_Member=1.
IF (ResponseId="R_1GOdpyosOqa1nbQ") Assoc_BEARMA_Member=1.
IF (ResponseId="R_1dAd4CdWbCBgsgY") Assoc_UIDP_Member=1.
IF (ResponseId="R_2TBnDbFKdMA2Ft0") Assoc_SOCRA_Member=1.
IF (ResponseId="R_AtfHeZEIssMwdUJ") Assoc_PRIMR_Member=1.
IF (ResponseId="R_1LS5isrS7xa8t9l") Assoc_PRIMR_Member=1.
IF (ResponseId="R_AogoLsxqv7Pe0Zb") Assoc_GPA_Member=1.
IF (ResponseId="R_2ZOZ6wNfae6qpYJ") Assoc_CZARMA_Member=1.
IF (ResponseId="R_3R3fCIeaaA3zz22") Assoc_UIDP_Member=1.
IF (ResponseId="R_2VjqKGc8u0pAfee") Assoc_AUECO_Member=1.
IF (ResponseId="R_1pQc3q2aKpZ1CDG") Assoc_RACC_Member=1.
IF (ResponseId="R_bHORA8d3vgf0cxj") Assoc_AUECO_Member=1.
IF (ResponseId="R_3NxgjtLpjbgKU4J") Assoc_AUECO_Member=1.
IF (ResponseId="R_1LANV0VAwr8S6lW") Assoc_RACC_Member=1.
IF (ResponseId="R_2lZImWlwf1RLkI1") Assoc_GPA_Member=1.
IF (ResponseId="R_3nMnyRuuUS4FjSD") Assoc_CZARMA_Member=1.
IF (ResponseId="R_214VXlRQeqkdcIG") Assoc_CASE_Member=1.
IF (ResponseId="R_297ffiHArT19fgs") Assoc_BEARMA_Member=1.
IF (ResponseId="R_3iKXCKQnfpw7hny") Assoc_GPA_Member=1.
IF (ResponseId="R_3nIx0SQStLVMM2Z") Assoc_GPA_Member=1.
IF (ResponseId="R_2Suy3dfp5ayTvdB") Assoc_PRIMR_Member=1.
IF (ResponseId="R_3izqgphabC2Lpf1") Assoc_UIDP_Member=1.
IF (ResponseId="R_322VrA3XG9L8vTv") Assoc_GPA_Member=1.
IF (ResponseId="R_yUcqox0yn1lxdGF") Assoc_UIDP_Member=1.
IF (ResponseId="R_3EnH1w0aUWz1Db9") Assoc_PRIMR_Member=1.
IF (ResponseId="R_3gYPnP1GcPHlVBw") Assoc_ARIS_Member=1.
IF (ResponseId="R_2QFCLFRc4WivaZe") Assoc_CZARMA_Member=1.
IF (ResponseId="R_3FWFbDsdAJhWv8e") Assoc_PMI_Member=1.
IF (ResponseId="R_2fD1wbetrL8xj6z") Assoc_PMI_Member=1.
IF (ResponseId="R_2R3na5Caqg4b32u") Assoc_RACC_Participated=1.
IF (ResponseId="R_1hT5AWkMrrdPlU5") Assoc_BEARMA_Member=1.
IF (ResponseId="R_111ijrRHn5WNKeW") Assoc_BEARMA_Member=1.
IF (ResponseId="R_cSBVzVzdFFFPSJr") Assoc_GPA_Member=1.
IF (ResponseId="R_1gATj1dPqFCUXtf") Assoc_PRIMR_Member=1.
IF (ResponseId="R_27W1Owd5tg7KtU8") Assoc_PRIMR_Member=1.
IF (ResponseId="R_byCiQQoO8HOluN3") Assoc_UIDP_Member=1.
IF (ResponseId="R_2fcCzvtaWw0mrYF") Assoc_CASE_Member=1.
IF (ResponseId="R_3ez64E0RDsFayoF") Assoc_PMI_Member=1.
IF (ResponseId="R_27OuG8NovZvzpoj") Assoc_ARIS_Member=1.
IF (ResponseId="R_DLRGPlS0tRPUSqZ") Assoc_SOCRA_Member=1.
IF (ResponseId="R_3KBeO3H0zBWEvxb") Assoc_ARIS_Member=1.
IF (ResponseId="R_3q7kXEh3XwYAcCc") Assoc_ARIS_Participated=1.
IF (ResponseId="R_10HrHVJFS68MxGd") Assoc_ARIS_Member=1.
IF (ResponseId="R_1jVq3PnGTVqgzj7") Assoc_GPA_Member=1.
IF (ResponseId="R_12th1ZqK7dnVOZQ") Assoc_PRIMR_Member=1.
IF (ResponseId="R_2BnQemp6XjaAMoO") Assoc_PRIMR_Member=1.
IF (ResponseId="R_e9BjHcgAYawMfVD") Assoc_PMI_Member=1.
IF (ResponseId="R_1PYJk5y4uZK6FMW") Assoc_PRIMR_Member=1.
IF (ResponseId="R_33lm5GA37qAEgUJ") Assoc_RACC_Member=1.
IF (ResponseId="R_2TnvtvMZR32pH7W") Assoc_AUECO_Member=1.
IF (ResponseId="R_3p6gipBLKReL2gA") Assoc_RACC_Member=1.
IF (ResponseId="R_2uCeigMFZN9m1Dw") Assoc_UIDP_Member=1.
IF (ResponseId="R_bJeMFQYLoAIBZAJ") Assoc_PRIMR_Member=1.
IF (ResponseId="R_1rOCZjTUqEg19xh") Assoc_PRIMR_Member=1.
IF (ResponseId="R_V43LBsaPLspFTmV") Assoc_AUECO_Member=1.
IF (ResponseId="R_1r2KRPMYZioIAi2") Assoc_SOCRA_Member=1.
IF (ResponseId="R_3nSP9qFMgSrrzJV") Assoc_SOCRA_Member=1.
IF (ResponseId="R_6hZGyWhyz9CQjnP") Assoc_PRIMR_Member=1.
IF (ResponseId="R_1LhC28RKl2r39zP") Assoc_UIDP_Member=1.
IF (ResponseId="R_OdHW5xqfgRBWxeF") Assoc_ARIS_Member=1.
IF (ResponseId="R_2aQ3kW1ntkSOeYB") Assoc_CURIE_Member=1.
IF (ResponseId="R_26lh3I8ZlLEE6yK") Assoc_UIDP_Member=1.
IF (ResponseId="R_28M6SC6KwjQdycl") Assoc_CAPANR_Member=1.
IF (ResponseId="R_27Jp3etdyjMI8TG") Assoc_CAPANR_Member=1.
IF (ResponseId="R_1dtuh144J0CSPQc") Assoc_PRIMR_Member=1.
IF (ResponseId="R_1BXIMUmTydwh8fh") Assoc_CAPANR_Member=1.
IF (ResponseId="R_1mPAQ10gkttsdr0") Assoc_GPA_Member=1.
IF (ResponseId="R_voSw84irNP4aL5L") Assoc_CASE_Member=1.
IF (ResponseId="R_3oBKQJjOSHL8oRo") Assoc_ARIS_Member=1.
IF (ResponseId="R_1DC4j5JSlYOMyrf") Assoc_CZARMA_Member=1.
IF (ResponseId="R_10PFeVVGJFYjYZw") Assoc_CASE_Member=1.
IF (ResponseId="R_cPcRYMyPu7Egpc5") Assoc_CAPANR_Member=1.
IF (ResponseId="R_3hmQ5jXp6CRSvGX") Assoc_PMI_Member=1.
IF (ResponseId="R_1oj0zhiThUvA6i1") Assoc_CURIE_Member=1.
IF (ResponseId="R_3KveEINHRTsTyzA") Assoc_CURIE_Member=1.
IF (ResponseId="R_3enoL5vuZTqH7kf") Assoc_CAPANR_Member=1.
IF (ResponseId="R_1TcCfc1bI2iYqeB") Assoc_CURIE_Member=1.
IF (ResponseId="R_12lmXqjF6TeCy8R") Assoc_SOCRA_Member=1.
IF (ResponseId="R_vDNeq0j4Y2fzLS9") Assoc_CAPANR_Member=1.
IF (ResponseId="R_2rqhMAv7VzXUQa6") Assoc_CAPANR_Member=1.
IF (ResponseId="R_AtfHeZEIssMwdUJ") Assoc_SOCRA_Member=1.
IF (ResponseId="R_1LS5isrS7xa8t9l") Assoc_AUECO_Member=1.
IF (ResponseId="R_3R3fCIeaaA3zz22") Assoc__Participated=1.
IF (ResponseId="R_bHORA8d3vgf0cxj") Assoc_PRIMR_Member=1.
IF (ResponseId="R_28M6SC6KwjQdycl") Assoc_CURIE_Member=1.
IF (ResponseId="R_cPcRYMyPu7Egpc5") Assoc_CURIE_Member=1.
IF (ResponseId="R_3enoL5vuZTqH7kf") Assoc_CURIE_Member=1.
IF (ResponseId="R_2rqhMAv7VzXUQa6") Assoc_CURIE_Member=1.
EXECUTE.

** Assoc_OtherDetails Anonymising SK (lead my MD).
IF (ResponseId="R_rqN3J5i9b1brMYN") Assoc_OtherDetails="Instituto XXXX, Colegio de XXXX del Perú, y Asociación XXXX del Perú.".
IF (ResponseId="R_1FfBSQmqwVk0eS1") Assoc_OtherDetails="XXXX (XXXX Network)".
IF (ResponseId="R_2Qm4AWDBP855uls") Assoc_OtherDetails=CONCAT("I am personally a member of SWARMA, the university is an institutional member of EARMA, XXXX. I am X",
"XXX Research Manager certificate course, assigned by XXXX since 2018-present. Member of the XXXX, EARMA XXXX").
IF (ResponseId="R_3p9lX1t9YPgY09M") Assoc_OtherDetails="I am among the XXXX members of CZARMA - Czech Association of Research Managers and Administrators, coming to life at the time of this survey (early 2022).".
IF (ResponseId="R_2QFCLFRc4WivaZe") Assoc_OtherDetails="I am involved in XXXX CZARMA (Czech Association of Research Managers and Administrators)".
IF (ResponseId="R_3KUgebMvWg9oS0A") Assoc_OtherDetails="XXXX University Research Administrators (XXXX)".
IF (ResponseId="R_3IQ7ksGUwvCKbeI") Assoc_OtherDetails="Association of Professional Engineers and Geoscientists of Alberta (P.Eng.) and the Institute of Electrical and Computer Engineers (XXXX)".
IF (ResponseId="R_3q9WbtyF44D2dzg") Assoc_OtherDetails="ADARUQ - The province of Quebec (in Canada) has an association of research administrators. XXXX".
IF (ResponseId="R_1ibztKXCwT9gOYi") Assoc_OtherDetails="Miembro de REDUGI. Que agrupa a los jefes de servicio de investigación de las universidades españolas. XXXX de CRUE. (conferencia de rectores españoles)".
IF (ResponseId="R_3qJV14SQCCiQPYe") Assoc_OtherDetails="XXXX Polish Academy of Sciences coordinated by PolSCA Office.".
IF (ResponseId="R_2CjL36XMuqFlYHV") Assoc_OtherDetails="We are currently trying to create an association in Cyprus of which i am XXXX ".
IF (ResponseId="R_2s7RByXYsP2EgIO") Assoc_OtherDetails="Research managers group member at Universities' Networks such as XXXX, XXXX, XXXX".
IF (ResponseId="R_voSw84irNP4aL5L") Assoc_OtherDetails="SHRM (past), XXXX, ABRF, CASE".
IF (ResponseId="R_BXo42nVQfo203zb") Assoc_OtherDetails="XXXX Universita".
IF (ResponseId="R_1FaibUVDJVHQUXj") Assoc_OtherDetails="Society for Maintenance Reliability Professionals, I serve as the XXXX for our local chapter.".
IF (ResponseId="R_3fcv255jynOPcSd") Assoc_OtherDetails="XXXX member of the European Association of Innovation Consultants (EAIC) since XXXX, Member of the French Association of Innovation Consultants (ACI) since XXXX".
IF (ResponseId="R_2Se7cNW8QP9c5mA") Assoc_OtherDetails="Sociedade Brasileira de Medicina Tropical, XXXX".
EXECUTE.    

* *** Backcoding from Assoc_OtherDetails - SK.
IF (ResponseId="R_2S2ml5bnwgtVKre") Assoc_ARMS_Member=1.
IF (ResponseId="R_3f7YBqaIyRf8CCl") Assoc_COREMA_Member=1.
IF (ResponseId="R_3CAQjcOaKqKfcEH") Assoc_None_Member=1.
IF (ResponseId="R_2TsXObNYsPJUjTr") Assoc_KOsRISII_Member=1.
IF (ResponseId="R_2B9BketGf8GGN2x") Assoc_NCURA_Member=1.
IF (ResponseId="R_2B9BketGf8GGN2x") Assoc_Other_Member=$SYSMIS.
IF (ResponseId="R_dbwDi1LXQyrX5Kx") Assoc_NCURA_Participated=1.
IF (ResponseId="R_2VvGqQbVu363AHI") Assoc_ARMS_Participated=1.
IF (ResponseId="R_D7QMeVC5KfIrFnP") Assoc_SRAI_Member=1.
IF (ResponseId="R_D7QMeVC5KfIrFnP") Assoc_OtherDetails="ARCS (Australia);".
IF (ResponseId="R_DISYJr8qtHhrAbv") Assoc_SARIMA_Participated=1.
IF (ResponseId="R_DISYJr8qtHhrAbv") Assoc_None_Participated=$SYSMIS.
EXECUTE.

VALUE LABELS
Assoc_ACU_Member Assoc_ACU_Participated
Assoc_ARMA_Member Assoc_ARMA_Participated
Assoc_ARMANL_Member Assoc_ARMANL_Participated
Assoc_ARMS_Member Assoc_ARMS_Participated
Assoc_AUA_Member Assoc_AUA_Participated
Assoc_AURAM_Member Assoc_AURAM_Participated
Assoc_AUTM_Member Assoc_AUTM_Participated
Assoc_BESTPRAC_Member Assoc_BESTPRAC_Participated
Assoc_BRAMA_Member Assoc_BRAMA_Participated
Assoc_CabRIMA_Member Assoc_CabRIMA_Participated
Assoc_CARA_Member Assoc_CARA_Participated
Assoc_CARIMA_Member Assoc_CARIMA_Participated
Assoc_CASSSP_Member Assoc_CASSSP_Participated
Assoc_CLASP_Member Assoc_CLASP_Participated
Assoc_CLORA_Member Assoc_CLORA_Participated
Assoc_COREMA_Member Assoc_COREMA_Participated
Assoc_COGR_Member Assoc_COGR_Participated
Assoc_DARMA_Member Assoc_DARMA_Participated
Assoc_EARIMA_Member Assoc_EARIMA_Participated
Assoc_EARMA_Member Assoc_EARMA_Participated
Assoc_FDP_Member Assoc_FDP_Participated
Assoc_FinnARMA_Member Assoc_FinnARMA_Participated
Assoc_GARMA_Member Assoc_GARMA_Participated
Assoc_IceARMA_Member Assoc_IceARMA_Participated
Assoc_IRMI_Member Assoc_IRMI_Participated
Assoc_INORMS_Member Assoc_INORMS_Participated
Assoc_Italy_Member Assoc_Italy_Participated
Assoc_KOsRISII_Member Assoc_KOsRISII_Participated
Assoc_MyRMA_Member Assoc_MyRMA_Participated
Assoc_NARIMA_Member Assoc_NARIMA_Participated
Assoc_NARMA_Member Assoc_NARMA_Participated
Assoc_NCURA_Member Assoc_NCURA_Participated
Assoc_NWM_Member Assoc_NWM_Participated
Assoc_NORDP_Member Assoc_NORDP_Participated
Assoc_PIC_Member Assoc_PIC_Participated
Assoc_PrU_Member Assoc_PrU_Participated
Assoc_PRISM_Member Assoc_PRISM_Participated
Assoc_RMANJ_Member Assoc_RMANJ_Participated
Assoc_SARIMA_Member Assoc_SARIMA_Participated
Assoc_SRAI_Member Assoc_SRAI_Participated
Assoc_SWARMA_Member Assoc_SWARMA_Participated
Assoc_WARIMA_Member Assoc_WARIMA_Participated
Assoc_None_Member Assoc_None_Participated
Assoc_Other_Member Assoc_Other_Participated
1 "Yes" -99 "No Response".

MISSING VALUES
Assoc_ACU_Member Assoc_ACU_Participated
Assoc_ARMA_Member Assoc_ARMA_Participated
Assoc_ARMANL_Member Assoc_ARMANL_Participated
Assoc_ARMS_Member Assoc_ARMS_Participated
Assoc_AUA_Member Assoc_AUA_Participated
Assoc_AURAM_Member Assoc_AURAM_Participated
Assoc_AUTM_Member Assoc_AUTM_Participated
Assoc_BESTPRAC_Member Assoc_BESTPRAC_Participated
Assoc_BRAMA_Member Assoc_BRAMA_Participated
Assoc_CabRIMA_Member Assoc_CabRIMA_Participated
Assoc_CARA_Member Assoc_CARA_Participated
Assoc_CARIMA_Member Assoc_CARIMA_Participated
Assoc_CASSSP_Member Assoc_CASSSP_Participated
Assoc_CLASP_Member Assoc_CLASP_Participated
Assoc_CLORA_Member Assoc_CLORA_Participated
Assoc_COREMA_Member Assoc_COREMA_Participated
Assoc_COGR_Member Assoc_COGR_Participated
Assoc_DARMA_Member Assoc_DARMA_Participated
Assoc_EARIMA_Member Assoc_EARIMA_Participated
Assoc_EARMA_Member Assoc_EARMA_Participated
Assoc_FDP_Member Assoc_FDP_Participated
Assoc_FinnARMA_Member Assoc_FinnARMA_Participated
Assoc_GARMA_Member Assoc_GARMA_Participated
Assoc_IceARMA_Member Assoc_IceARMA_Participated
Assoc_IRMI_Member Assoc_IRMI_Participated
Assoc_INORMS_Member Assoc_INORMS_Participated
Assoc_Italy_Member Assoc_Italy_Participated
Assoc_KOsRISII_Member Assoc_KOsRISII_Participated
Assoc_MyRMA_Member Assoc_MyRMA_Participated
Assoc_NARIMA_Member Assoc_NARIMA_Participated
Assoc_NARMA_Member Assoc_NARMA_Participated
Assoc_NCURA_Member Assoc_NCURA_Participated
Assoc_NWM_Member Assoc_NWM_Participated
Assoc_NORDP_Member Assoc_NORDP_Participated
Assoc_PIC_Member Assoc_PIC_Participated
Assoc_PrU_Member Assoc_PrU_Participated
Assoc_PRISM_Member Assoc_PRISM_Participated
Assoc_RMANJ_Member Assoc_RMANJ_Participated
Assoc_SARIMA_Member Assoc_SARIMA_Participated
Assoc_SRAI_Member Assoc_SRAI_Participated
Assoc_SWARMA_Member Assoc_SWARMA_Participated
Assoc_WARIMA_Member Assoc_WARIMA_Participated
Assoc_None_Member Assoc_None_Participated
Assoc_Other_Member Assoc_Other_Participated
(-99).


VARIABLE LEVEL
Assoc_ACU_Member Assoc_ACU_Participated
Assoc_ARMA_Member Assoc_ARMA_Participated
Assoc_ARMANL_Member Assoc_ARMANL_Participated
Assoc_ARMS_Member Assoc_ARMS_Participated
Assoc_AUA_Member Assoc_AUA_Participated
Assoc_AURAM_Member Assoc_AURAM_Participated
Assoc_AUTM_Member Assoc_AUTM_Participated
Assoc_BESTPRAC_Member Assoc_BESTPRAC_Participated
Assoc_BRAMA_Member Assoc_BRAMA_Participated
Assoc_CabRIMA_Member Assoc_CabRIMA_Participated
Assoc_CARA_Member Assoc_CARA_Participated
Assoc_CARIMA_Member Assoc_CARIMA_Participated
Assoc_CASSSP_Member Assoc_CASSSP_Participated
Assoc_CLASP_Member Assoc_CLASP_Participated
Assoc_CLORA_Member Assoc_CLORA_Participated
Assoc_COREMA_Member Assoc_COREMA_Participated
Assoc_COGR_Member Assoc_COGR_Participated
Assoc_DARMA_Member Assoc_DARMA_Participated
Assoc_EARIMA_Member Assoc_EARIMA_Participated
Assoc_EARMA_Member Assoc_EARMA_Participated
Assoc_FDP_Member Assoc_FDP_Participated
Assoc_FinnARMA_Member Assoc_FinnARMA_Participated
Assoc_GARMA_Member Assoc_GARMA_Participated
Assoc_IceARMA_Member Assoc_IceARMA_Participated
Assoc_IRMI_Member Assoc_IRMI_Participated
Assoc_INORMS_Member Assoc_INORMS_Participated
Assoc_Italy_Member Assoc_Italy_Participated
Assoc_KOsRISII_Member Assoc_KOsRISII_Participated
Assoc_MyRMA_Member Assoc_MyRMA_Participated
Assoc_NARIMA_Member Assoc_NARIMA_Participated
Assoc_NARMA_Member Assoc_NARMA_Participated
Assoc_NCURA_Member Assoc_NCURA_Participated
Assoc_NWM_Member Assoc_NWM_Participated
Assoc_NORDP_Member Assoc_NORDP_Participated
Assoc_PIC_Member Assoc_PIC_Participated
Assoc_PrU_Member Assoc_PrU_Participated
Assoc_PRISM_Member Assoc_PRISM_Participated
Assoc_RMANJ_Member Assoc_RMANJ_Participated
Assoc_SARIMA_Member Assoc_SARIMA_Participated
Assoc_SRAI_Member Assoc_SRAI_Participated
Assoc_SWARMA_Member Assoc_SWARMA_Participated
Assoc_WARIMA_Member Assoc_WARIMA_Participated
Assoc_None_Member Assoc_None_Participated
Assoc_Other_Member Assoc_Other_Participated
(NOMINAL).
EXECUTE.

* *** Day 3 ***.
* *** New for RAAAP-3 as well as where you currently work (the location of your employer), we also ask where you were born.
* *** This is as a (simple) attempt at looking at RMA mobility.
* *** Note that for some countries (Australia, Canada, UK, and U.S. we also ask for region [as requested by the national association].
* *** from country we can create the large regions, eg Europe - to create larger groupings for statistical analysis.
* *** backcoding can also be done for those that provided employer but omit country.
* *** so that if country is not given, but affiliation later is, eh UoKent, then we can backcode UK as CountryOfEmployment and hence AnalysisRegionOfEmployment

* *** BACKCODING - based on Employer... if country is missing but an employer is provided then this can probably be back coded, maybe state too
* *** NOTE that other things could also be looked at - for example institution type, and character
* *** *** xxxx provided instition. Of those x selected other, xx did not answer.
* *** *** All xx can be backcoded based on institutoin name, x US ones can have states, and x UK one a nation.
* *** *** Note that xx were from Gibralta - these a a British Overseas Territory, so coded as UK, but with no nation.

* *** One response from Puerto Rico selected "Other" and so we can back code.
IF (ResponseId="R_1ibztKXCwT9gOYi") CountryOfEmployment=435. /* this one is in Spain.
DO IF (ResponseId="R_123fRdDbzJOvUvC").
    COMPUTE CountryOfEmployment=501. /*US.
    COMPUTE StateOfEmployment=385. /*Puerto Rico.
END IF.
EXECUTE.    

VARIABLE LABELS CountryOfEmployment "27. Country of Employment".
VARIABLE LEVEL CountryOfEmployment (NOMINAL).
MISSING VALUES CountryOfEmployment (-99).
ADD VALUE LABELS CountryOfEmployment -99 "No Response".
* also change some value labels to match RAAAP-1.
ADD VALUE LABELS CountryOfEmployment 215 "Hong Kong" 471 "Tanzania" 499 "United Kingdom" 501 "United States" 564 "Vietnam". /* although there are no Hong Kong or Tanzania responses this time.


* *** now create ContinentOfEmployment, RegionOfEmployment and AnalysisRegionOfEmployment, to match RAAAP-1/2.
* *** add continent

COMPUTE ContinentOfEmployment = CountryOfEmployment.

ADD VALUE LABELS ContinentOfEmployment 1001 "Africa".
ADD VALUE LABELS ContinentOfEmployment 1002 "Asia".
ADD VALUE LABELS ContinentOfEmployment 1003 "Europe".
ADD VALUE LABELS ContinentOfEmployment 1004 "North America".
ADD VALUE LABELS ContinentOfEmployment 1005 "South America".
ADD VALUE LABELS ContinentOfEmployment 1006 "Oceania".
ADD VALUE LABELS ContinentOfEmployment 1007 "Antarctica".
ADD VALUE LABELS ContinentOfEmployment 1999 "OTHER".
if sysmis(ContinentOfEmployment) ContinentOfEmployment = -99.
MISSING VALUES ContinentOfEmployment (-99).
ADD VALUE LABELS ContinentOfEmployment -99 "No Response".


* *** These translations are taken from wikipedia, some seem strange eg Turkey counts as Asia... but OK.
* *** ALSO note that in general this turned out to not be so useful for analyses due to the distribution of data - AnalysisRegionOfEmployment is probably the best.

if ContinentOfEmployment = 7 ContinentOfEmployment = 1003. /* Albania.
if ContinentOfEmployment = 15 ContinentOfEmployment = 1001. /* Angola.
if ContinentOfEmployment = 23 ContinentOfEmployment = 1005. /* Argentina.
if ContinentOfEmployment = 31 ContinentOfEmployment = 1006. /* Australia.
if ContinentOfEmployment = 33 ContinentOfEmployment = 1003. /* Austria.
if ContinentOfEmployment = 35 ContinentOfEmployment = 1002. /* Azerbajan [none in RAAAP-3].
if ContinentOfEmployment = 37 ContinentOfEmployment = 1004. /* Bahamas.
if ContinentOfEmployment = 43 ContinentOfEmployment = 1004. /* Barbados
if ContinentOfEmployment = 47 ContinentOfEmployment = 1003. /* Belgium
if ContinentOfEmployment = 61 ContinentOfEmployment = 1003. /* Bosnia and Herzegovina.
if ContinentOfEmployment = 63 ContinentOfEmployment = 1001. /* Botswana [none in RAAAP-3].
if ContinentOfEmployment = 65 ContinentOfEmployment = 1005. /* Brazil.
if ContinentOfEmployment = 71 ContinentOfEmployment = 1003. /* Bulgaria -[none in RAAAP-3].
if ContinentOfEmployment = 79 ContinentOfEmployment = 1002. /* Cambodia.
if ContinentOfEmployment = 81 ContinentOfEmployment = 1001. /* Cameroon [none in RAAAP-3].
if ContinentOfEmployment = 83 ContinentOfEmployment = 1004. /* Canada.
if ContinentOfEmployment = 101 ContinentOfEmployment = 1005. /* Chile.
if ContinentOfEmployment = 103 ContinentOfEmployment = 1002. /* China.
if ContinentOfEmployment = 109 ContinentOfEmployment = 1005. /* Colombia.
if ContinentOfEmployment = 121 ContinentOfEmployment = 1003. /* Croatia.
if ContinentOfEmployment = 127 ContinentOfEmployment = 1002. /* Cyprus. *** SHOULD Cyprus be listed in Europe rather then Asia???.
if ContinentOfEmployment = 133 ContinentOfEmployment = 1003. /* Czech Republic.
if ContinentOfEmployment = 135 ContinentOfEmployment = 1003. /* Denmark.
if ContinentOfEmployment = 139 ContinentOfEmployment = 1004. /*  Dominica  [none in RAAAP-3].
if ContinentOfEmployment = 151 ContinentOfEmployment = 1003. /* no 151 in RAAAP-2/3, nor RAAAP-1.
if ContinentOfEmployment = 153 ContinentOfEmployment = 1001. /* Equitorial Guinea  [none in RAAAP-3]..
if ContinentOfEmployment = 157 ContinentOfEmployment = 1003. /* Estonia.
if ContinentOfEmployment = 171 ContinentOfEmployment = 1003. /* Finland.
if ContinentOfEmployment = 173 ContinentOfEmployment = 1003. /* France.
if ContinentOfEmployment = 181 ContinentOfEmployment = 1001. /* Gambia  [none in RAAAP-3].
if ContinentOfEmployment = 185 ContinentOfEmployment = 1003. /* Germany.
if ContinentOfEmployment = 187 ContinentOfEmployment = 1001. /* Ghana.
if ContinentOfEmployment = 191 ContinentOfEmployment = 1003. /* Greece.
if ContinentOfEmployment = 215 ContinentOfEmployment = 1002. /* Hong Kong [none in RAAAP-3].
if ContinentOfEmployment = 217 ContinentOfEmployment = 1003. /* Hungary.
if ContinentOfEmployment = 219 ContinentOfEmployment = 1003. /* Iceland
if ContinentOfEmployment = 221 ContinentOfEmployment = 1002. /* India.
if ContinentOfEmployment = 223 ContinentOfEmployment = 1002. /* Indonesia [none in RAAAP-3].
if ContinentOfEmployment = 227 ContinentOfEmployment = 1002. /* Iraq  [none in RAAAP-3]..
if ContinentOfEmployment = 229 ContinentOfEmployment = 1003. /* Ireland.
if ContinentOfEmployment = 233 ContinentOfEmployment = 1002. /* Israel [none in RAAAP-3].
if ContinentOfEmployment = 235 ContinentOfEmployment = 1003. /* Italy.
if ContinentOfEmployment = 239 ContinentOfEmployment = 1004. /* Jamaica [none in RAAAP-3].
if ContinentOfEmployment = 241 ContinentOfEmployment = 1002. /* Japan.
if ContinentOfEmployment = 247 ContinentOfEmployment = 1002. /* Kazakhstan [none in RAAAP-3]..
if ContinentOfEmployment = 249 ContinentOfEmployment = 1001. /* Kenya.
if ContinentOfEmployment = 265 ContinentOfEmployment = 1003. /* Latvia [none in RAAAP-3]..
if ContinentOfEmployment = 271 ContinentOfEmployment = 1001. /* Liberia [none in RAAAP-3]..
if ContinentOfEmployment = 277 ContinentOfEmployment = 1003. /* Lithuania.
if ContinentOfEmployment = 279 ContinentOfEmployment = 1003. /* Luxembourg.
if ContinentOfEmployment = 283 ContinentOfEmployment = 1003. /* North Macedonia.
if ContinentOfEmployment = 287 ContinentOfEmployment = 1001. /* Malawi [none in RAAAP-3].
if ContinentOfEmployment = 289 ContinentOfEmployment = 1002. /* Malaysia.
if ContinentOfEmployment = 295 ContinentOfEmployment = 1003. /* Malta.
if ContinentOfEmployment = 307 ContinentOfEmployment = 1004. /* Mexico [none in RAAAP-3].
if ContinentOfEmployment = 323 ContinentOfEmployment = 1001. /* Morocco [none in RAAAP-3]..
if ContinentOfEmployment = 325 ContinentOfEmployment = 1001. /* Mozambique.
if ContinentOfEmployment = 327 ContinentOfEmployment = 1001. /* Namibia.
if ContinentOfEmployment = 333 ContinentOfEmployment = 1003. /* Netherlands.
if ContinentOfEmployment = 339 ContinentOfEmployment = 1006. /* New Zealand.
if ContinentOfEmployment = 345 ContinentOfEmployment = 1001. /* Nigeria.
if ContinentOfEmployment = 357 ContinentOfEmployment = 1003. /* Norway.
if ContinentOfEmployment = 365 ContinentOfEmployment = 1002. /* Pakistan.
if ContinentOfEmployment = 373 ContinentOfEmployment = 1005. /* Paraquay.
if ContinentOfEmployment = 375 ContinentOfEmployment = 1005. /*  Peru.
if ContinentOfEmployment = 381 ContinentOfEmployment = 1003. /* Poland.
if ContinentOfEmployment = 383 ContinentOfEmployment = 1003. /* Portugal.
if ContinentOfEmployment = 385 ContinentOfEmployment = 1004. /* 385 Pueto Rico in 1 not 2.
if ContinentOfEmployment = 387 ContinentOfEmployment = 1002. /* Qatar.
if ContinentOfEmployment = 391 ContinentOfEmployment = 1003. /* Romania
if ContinentOfEmployment = 395 ContinentOfEmployment = 1001. /* Rwanda. [none in RAAAP-3].
if ContinentOfEmployment = 403 ContinentOfEmployment = 1002. /* Saudi Arabia.
if ContinentOfEmployment = 407 ContinentOfEmployment = 1001. /* Senegal [none in RAAAP-3]..
if ContinentOfEmployment = 409 ContinentOfEmployment = 1003. /* Serbia.
if ContinentOfEmployment = 411 ContinentOfEmployment = 1004. /* Seychelles  [none in RAAAP-3].
if ContinentOfEmployment = 413 ContinentOfEmployment = 1001. /* Sierra Leone [none in RAAAP-3]..
if ContinentOfEmployment = 415 ContinentOfEmployment = 1002. /* Singapore.
if ContinentOfEmployment = 419 ContinentOfEmployment = 1003. /* Slovakia.
if ContinentOfEmployment = 421 ContinentOfEmployment = 1003. /* Slovenia.
if ContinentOfEmployment = 425 ContinentOfEmployment = 1001. /* Somalia [none in RAAAP-3]..
if ContinentOfEmployment = 427 ContinentOfEmployment = 1001. /* South Africa.
if ContinentOfEmployment = 435 ContinentOfEmployment = 1003. /* Spain.
if ContinentOfEmployment = 443 ContinentOfEmployment = 1004. /* Saint Kitts and Nevis [none in RAAAP-3]..
if ContinentOfEmployment = 461 ContinentOfEmployment = 1003. /* Sweden.
if ContinentOfEmployment = 463 ContinentOfEmployment = 1003. /* Switzerland.
if ContinentOfEmployment = 469 ContinentOfEmployment = 1002. /* Tajikistan [none in RAAAP-3]..
if ContinentOfEmployment = 471 ContinentOfEmployment = 1001. /* Tanzania [none in RAAAP-3].
if ContinentOfEmployment = 473 ContinentOfEmployment = 1002. /* Thailand [none in RAAAP-3].
if ContinentOfEmployment = 485 ContinentOfEmployment = 1002. /* Turkey.
if ContinentOfEmployment = 493 ContinentOfEmployment = 1001. /* Uganda.
if ContinentOfEmployment = 495 ContinentOfEmployment = 1003. /* Ukraine.
if ContinentOfEmployment = 497 ContinentOfEmployment = 1002. /* UAE.
if ContinentOfEmployment = 499 ContinentOfEmployment = 1003. /* UK.
if ContinentOfEmployment = 501 ContinentOfEmployment = 1004. /* US.
if ContinentOfEmployment = 554 ContinentOfEmployment = 1005. /* Uruguay [none in RAAAP-3]..
if ContinentOfEmployment = 564 ContinentOfEmployment = 1002. /* Vietnam.
if ContinentOfEmployment = 576 ContinentOfEmployment = 1001. /* Zimbabwe [none in RAAAP-3].
if ContinentOfEmployment = 999 ContinentOfEmployment = 1999. /* 999 is OTHER.

FORMATS ContinentOfEmployment(f8).
ADD VALUE LABELS ContinentOfEmployment -99 "No Response".
VARIABLE LABELS ContinentOfEmployment "27x. Continent of Employment".
VARIABLE LEVEL ContinentOfEmployment (NOMINAL).
EXECUTE.
* ***NOTE that there a 5 "OTHER" responses to Country... [999] these will pass through to ContinentOfEmployment.
* *** And to RegionOfEmployment and AnalysisRegionOfEmployment.

* *** BACKHERE - do a cross check of country to continent. ***.

COMPUTE RegionOfEmployment = CountryOfEmployment.

ADD VALUE LABELS RegionOfEmployment 2001 "Africa".
ADD VALUE LABELS RegionOfEmployment 2002 "Americas (rest of)".
ADD VALUE LABELS RegionOfEmployment 2003 "Asia".
ADD VALUE LABELS RegionOfEmployment 2004 "Canada".
ADD VALUE LABELS RegionOfEmployment 2005 "Europe (rest of)".
ADD VALUE LABELS RegionOfEmployment 2006 "Oceania".
ADD VALUE LABELS RegionOfEmployment 2007 "Scandinavia".
ADD VALUE LABELS RegionOfEmployment 2008 "UK".
ADD VALUE LABELS RegionOfEmployment 2009 "USA".
ADD VALUE LABELS RegionOfEmployment 2999 "OTHER".
if sysmis(RegionOfEmployment) RegionOfEmployment = -99.
MISSING VALUES RegionOfEmployment (-99).
ADD VALUE LABELS RegionOfEmployment -99 "No Response".


if RegionOfEmployment = 7 RegionOfEmployment = 2005.
if RegionOfEmployment = 15 RegionOfEmployment = 2001.
if RegionOfEmployment = 23 RegionOfEmployment = 2002.
if RegionOfEmployment = 31 RegionOfEmployment = 2006.
if RegionOfEmployment = 33 RegionOfEmployment = 2005.
if RegionOfEmployment = 35 RegionOfEmployment = 2003.
if RegionOfEmployment = 37 RegionOfEmployment = 2002.
if RegionOfEmployment = 43 RegionOfEmployment = 2002. /* 43 Barbados - new in RAAAP-2 data.
if RegionOfEmployment = 47 RegionOfEmployment = 2005.
if RegionOfEmployment = 61 RegionOfEmployment = 2005. /* 61 Bosnia and Herzegovina - new in RAAAP-2 data.
if RegionOfEmployment = 63 RegionOfEmployment = 2001.
if RegionOfEmployment = 65 RegionOfEmployment = 2002.
if RegionOfEmployment = 71 RegionOfEmployment = 2005. /* 71 Bulgaria - new in RAAAP-2 data.
if RegionOfEmployment = 79 RegionOfEmployment = 2003.
if RegionOfEmployment = 81 RegionOfEmployment = 2001.
if RegionOfEmployment = 83 RegionOfEmployment = 2004.
if RegionOfEmployment = 101 RegionOfEmployment = 2002.
if RegionOfEmployment = 103 RegionOfEmployment = 2003. /* 103 China - new in RAAAP-2 data.
if RegionOfEmployment = 109 RegionOfEmployment = 2002.
if RegionOfEmployment = 121 RegionOfEmployment = 2005.
if RegionOfEmployment = 127 RegionOfEmployment = 2005.
if RegionOfEmployment = 133 RegionOfEmployment = 2005. /* 133 Czech Republic - new in RAAAP-2 data.
if RegionOfEmployment = 135 RegionOfEmployment = 2007.
if RegionOfEmployment = 139 RegionOfEmployment = 2002. /* 139 Dominica - new in RAAAP-2 data.
if RegionOfEmployment = 151 RegionOfEmployment = 2008.
if RegionOfEmployment = 153 RegionOfEmployment = 2001. /* 153 Equitorial Guinea - new in RAAAP-2 data.
if RegionOfEmployment = 157 RegionOfEmployment = 2005.
if RegionOfEmployment = 171 RegionOfEmployment = 2007.
if RegionOfEmployment = 173 RegionOfEmployment = 2005.
if RegionOfEmployment = 181 RegionOfEmployment = 2001.
if RegionOfEmployment = 185 RegionOfEmployment = 2005.
if RegionOfEmployment = 187 RegionOfEmployment = 2001.
if RegionOfEmployment = 191 RegionOfEmployment = 2005.
if RegionOfEmployment = 215 RegionOfEmployment = 2003.
if RegionOfEmployment = 217 RegionOfEmployment = 2005.
if RegionOfEmployment = 219 RegionOfEmployment = 2007.
if RegionOfEmployment = 221 RegionOfEmployment = 2003. /* 221 India - new in RAAAP-2 data.
if RegionOfEmployment = 223 RegionOfEmployment = 2003.
if RegionOfEmployment = 227 RegionOfEmployment = 2003.
if RegionOfEmployment = 229 RegionOfEmployment = 2005.
if RegionOfEmployment = 233 RegionOfEmployment = 2003.
if RegionOfEmployment = 235 RegionOfEmployment = 2005.
if RegionOfEmployment = 239 RegionOfEmployment = 2002.
if RegionOfEmployment = 241 RegionOfEmployment = 2003.
if RegionOfEmployment = 247 RegionOfEmployment = 2003.
if RegionOfEmployment = 249 RegionOfEmployment = 2001.
if RegionOfEmployment = 265 RegionOfEmployment = 2005. /* 265 Latvia - new in RAAAP-2 data.
if RegionOfEmployment = 271 RegionOfEmployment = 2001. /* 271 Liberia - new in RAAAP-2 data.
if RegionOfEmployment = 277 RegionOfEmployment = 2005. /* 277 Lithuania - new in RAAAP-2 data.
if RegionOfEmployment = 279 RegionOfEmployment = 2005.
if RegionOfEmployment = 283 RegionOfEmployment = 2005. /* 283 North Macedonia - new in RAAAP-2 data.
if RegionOfEmployment = 287 RegionOfEmployment = 2001.
if RegionOfEmployment = 289 RegionOfEmployment = 2003.
if RegionOfEmployment = 295 RegionOfEmployment = 2005.
if RegionOfEmployment = 307 RegionOfEmployment = 2002.
if RegionOfEmployment = 323 RegionOfEmployment = 2001. /* 323 Morocco - new in RAAAP-2 data.
if RegionOfEmployment = 325 RegionOfEmployment = 2001.
if RegionOfEmployment = 327 RegionOfEmployment = 2001.
if RegionOfEmployment = 333 RegionOfEmployment = 2005.
if RegionOfEmployment = 339 RegionOfEmployment = 2006.
if RegionOfEmployment = 345 RegionOfEmployment = 2001.
if RegionOfEmployment = 353 RegionOfEmployment = 2008.
if RegionOfEmployment = 357 RegionOfEmployment = 2007.
if RegionOfEmployment = 365 RegionOfEmployment = 2003.
if RegionOfEmployment = 373 RegionOfEmployment = 2002.
if RegionOfEmployment = 375 RegionOfEmployment = 2002. /* 375 Peru - new in RAAAP-2 data.
if RegionOfEmployment = 381 RegionOfEmployment = 2005.
if RegionOfEmployment = 383 RegionOfEmployment = 2005.
if RegionOfEmployment = 385 RegionOfEmployment = 2002.
if RegionOfEmployment = 387 RegionOfEmployment = 2003.
if RegionOfEmployment = 391 RegionOfEmployment = 2005.
if RegionOfEmployment = 395 RegionOfEmployment = 2001.
if RegionOfEmployment = 403 RegionOfEmployment = 2003.
if RegionOfEmployment = 405 RegionOfEmployment = 2008.
if RegionOfEmployment = 407 RegionOfEmployment = 2001. /* 407 Senegal - new in RAAAP-2 data.
if RegionOfEmployment = 409 RegionOfEmployment = 2005. /* 409 Serbia - new in RAAAP-2 data.
if RegionOfEmployment = 411 RegionOfEmployment = 2002. /* 411 Seychelles - new in RAAAP-2 data.
if RegionOfEmployment = 413 RegionOfEmployment = 2001.
if RegionOfEmployment = 415 RegionOfEmployment = 2003.
if RegionOfEmployment = 419 RegionOfEmployment = 2005. /* 419 Slovakia - new in RAAAP-2 data.
if RegionOfEmployment = 421 RegionOfEmployment = 2005.
if RegionOfEmployment = 425 RegionOfEmployment = 2001. /* 425 Somalia - new in RAAAP-2 data.
if RegionOfEmployment = 427 RegionOfEmployment = 2001.
if RegionOfEmployment = 435 RegionOfEmployment = 2005.
if RegionOfEmployment = 443 RegionOfEmployment = 2002. /* 443 Saint Kitts and Nevis - new in RAAAP-2 data.
if RegionOfEmployment = 461 RegionOfEmployment = 2007.
if RegionOfEmployment = 463 RegionOfEmployment = 2005.
if RegionOfEmployment = 469 RegionOfEmployment = 2003.
if RegionOfEmployment = 471 RegionOfEmployment = 2001.
if RegionOfEmployment = 473 RegionOfEmployment = 2003.
if RegionOfEmployment = 485 RegionOfEmployment = 2003.
if RegionOfEmployment = 493 RegionOfEmployment = 2001.
if RegionOfEmployment = 495 RegionOfEmployment = 2005.
if RegionOfEmployment = 497 RegionOfEmployment = 2003.
if RegionOfEmployment = 499 RegionOfEmployment = 2008.
if RegionOfEmployment = 501 RegionOfEmployment = 2009.
if RegionOfEmployment = 552 RegionOfEmployment = 2009.
if RegionOfEmployment = 554 RegionOfEmployment = 2002. /* 554 Uruguay - new in RAAAP-2 data.
if RegionOfEmployment = 564 RegionOfEmployment = 2003. /* 564 Viet Nam - new in RAAAP-2 data.
if RegionOfEmployment = 566 RegionOfEmployment = 2008.
if RegionOfEmployment = 576 RegionOfEmployment = 2001.
if RegionOfEmployment = 999 RegionOfEmployment = 2999. /* 999 is OTHER.

FORMATS RegionOfEmployment(f8).
ADD VALUE LABELS RegionOfEmployment -99 "No Response".
VARIABLE LABELS RegionOfEmployment "27y. Region of Employment".
VARIABLE LEVEL RegionOfEmployment (NOMINAL).
EXECUTE.

* this is the geographic variable that has most been used for analysis in RAAAP-1.
COMPUTE AnalysisRegionOfEmployment = RegionOfEmployment.

ADD VALUE LABELS AnalysisRegionOfEmployment 3001 "Canada".
ADD VALUE LABELS AnalysisRegionOfEmployment 3002 "Europe (excl UK)".
ADD VALUE LABELS AnalysisRegionOfEmployment 3003 "Oceania".
ADD VALUE LABELS AnalysisRegionOfEmployment 3004 "Rest of World".
ADD VALUE LABELS AnalysisRegionOfEmployment 3005 "UK".
ADD VALUE LABELS AnalysisRegionOfEmployment 3006 "USA".
if sysmis(AnalysisRegionOfEmployment) AnalysisRegionOfEmployment = -99.
MISSING VALUES AnalysisRegionOfEmployment (-99).
ADD VALUE LABELS AnalysisRegionOfEmployment -99 "No Response".

if AnalysisRegionOfEmployment = 2001 AnalysisRegionOfEmployment = 3004.
if AnalysisRegionOfEmployment = 2002 AnalysisRegionOfEmployment = 3004.
if AnalysisRegionOfEmployment = 2003 AnalysisRegionOfEmployment = 3004.
if AnalysisRegionOfEmployment = 2004 AnalysisRegionOfEmployment = 3001.
if AnalysisRegionOfEmployment = 2005 AnalysisRegionOfEmployment = 3002.
if AnalysisRegionOfEmployment = 2006 AnalysisRegionOfEmployment = 3003.
if AnalysisRegionOfEmployment = 2007 AnalysisRegionOfEmployment = 3002.
if AnalysisRegionOfEmployment = 2008 AnalysisRegionOfEmployment = 3005.
if AnalysisRegionOfEmployment = 2009 AnalysisRegionOfEmployment = 3006.
IF AnalysisRegionOfEmployment = 2999 AnalysisRegionOfEmployment = -99.   /* 999 is OTHER.

FORMATS AnalysisRegionOfEmployment(f8).
ADD VALUE LABELS AnalysisRegionOfEmployment -99 "No Response".
VARIABLE LABELS AnalysisRegionOfEmployment "27z. Analysis Region of Employment".
VARIABLE LEVEL AnalysisRegionOfEmployment (NOMINAL).
execute.

* this is the geographic variable that has most been used for analysis in RAAAP-1.
COMPUTE AnalysisRegionOfEmployment = RegionOfEmployment.

ADD VALUE LABELS AnalysisRegionOfEmployment 3001 "Canada".
ADD VALUE LABELS AnalysisRegionOfEmployment 3002 "Europe (excl UK)".
ADD VALUE LABELS AnalysisRegionOfEmployment 3003 "Oceania".
ADD VALUE LABELS AnalysisRegionOfEmployment 3004 "Rest of World".
ADD VALUE LABELS AnalysisRegionOfEmployment 3005 "UK".
ADD VALUE LABELS AnalysisRegionOfEmployment 3006 "USA".
if sysmis(AnalysisRegionOfEmployment) AnalysisRegionOfEmployment = -99.
MISSING VALUES AnalysisRegionOfEmployment (-99).
ADD VALUE LABELS AnalysisRegionOfEmployment -99 "No Response".

if AnalysisRegionOfEmployment = 2001 AnalysisRegionOfEmployment = 3004.
if AnalysisRegionOfEmployment = 2002 AnalysisRegionOfEmployment = 3004.
if AnalysisRegionOfEmployment = 2003 AnalysisRegionOfEmployment = 3004.
if AnalysisRegionOfEmployment = 2004 AnalysisRegionOfEmployment = 3001.
if AnalysisRegionOfEmployment = 2005 AnalysisRegionOfEmployment = 3002.
if AnalysisRegionOfEmployment = 2006 AnalysisRegionOfEmployment = 3003.
if AnalysisRegionOfEmployment = 2007 AnalysisRegionOfEmployment = 3002.
if AnalysisRegionOfEmployment = 2008 AnalysisRegionOfEmployment = 3005.
if AnalysisRegionOfEmployment = 2009 AnalysisRegionOfEmployment = 3006.
IF AnalysisRegionOfEmployment = 2999 AnalysisRegionOfEmployment = -99.   /* 999 is OTHER.

FORMATS AnalysisRegionOfEmployment(f8).
ADD VALUE LABELS AnalysisRegionOfEmployment -99 "No Response".
VARIABLE LABELS AnalysisRegionOfEmployment "27z. Analysis Region of Employment".
VARIABLE LEVEL AnalysisRegionOfEmployment (NOMINAL).
execute.

* *** Q28 is the country of birth - this could also be used to create 3 new variables.. ContinentOfBirth, RegionOfBirth, and AnalysisRegionOfBirth.
* *** BACKHERE if we want to do that.

VARIABLE LABELS CountryOfBirth "28. Country of Birth".
VARIABLE LEVEL CountryOfBirth (NOMINAL).
MISSING VALUES CountryOfBirth (-99).
ADD VALUE LABELS CountryOfBirth -99 "No Response".
* also change some value labels to match RAAAP-1.
ADD VALUE LABELS CountryOfBirth 215 "Hong Kong" 471 "Tanzania" 499 "United Kingdom" 501 "United States" 564 "Vietnam". /* although there are no Hong Kong or Tanzania responses this time.
* *** 10 "Other".
IF (ResponseId="R_2PjIAZd1uGp7juj") CountryOfBirth=103. /* China (free text said Taiwan).(also AnyOtherComments).
* *** 1121 "same as country of birth" so copy those over.
IF (CountryOfBirth=1000) CountryOfBirth=CountryOfEmployment. /* Same as now... so copy over - there were 1121 of these.
EXECUTE.

* *** Q27a-d the part of the country.
* *** Some text fields are completely empty (might be an artifact of qualtrics), so delete them.
DELETE VARIABLES AusStateOfEmployment_21_TEXT NationOfEmployment_777_TEXT AusStateOfBirth_21_TEXT NationOfBirth_777_TEXT.
* *** NB there was some text in one NationOfEmployment_777_TEXT field but the content was unuseful.

VARIABLE LABELS AusStateOfEmployment "27a. Australian State of Employment".
MISSING VALUES AusStateOfEmployment (-99).
ADD VALUE LABELS AusStateOfEmployment -99 "No Response".
VARIABLE LEVEL AusStateOfEmployment (NOMINAL).
EXECUTE.

VARIABLE LABELS StateOfEmployment "27b. US State of Employment".
MISSING VALUES StateOfEmployment (-99).
ADD VALUE LABELS StateOfEmployment -99 "No Response".
VARIABLE LEVEL StateOfEmployment (NOMINAL).
EXECUTE.

VARIABLE LABELS ProvinceOfEmployment "27c. Canadian Province of Employment".
MISSING VALUES ProvinceOfEmployment (-99).
ADD VALUE LABELS ProvinceOfEmployment -99 "No Response".
VARIABLE LEVEL ProvinceOfEmployment (NOMINAL).
EXECUTE.

VARIABLE LABELS NationOfEmployment "27d. UK Nation of Employment".
MISSING VALUES NationOfEmployment (-99).
ADD VALUE LABELS NationOfEmployment -99 "No Response".
VARIABLE LEVEL NationOfEmployment (NOMINAL).
* *** one respondent put "other" however they show their employer which equates to England. (SK/MF).
IF (ResponseId="R_1goxfDPomPcu1t3") NationOfEmployment=151.
EXECUTE.


* *** Q28a-d the part of the country.
* *** Some text fields are completely empty (might be an artifact of qualtrics), so delete them.

VARIABLE LABELS AusStateOfBirth "28a. Australian State of Birth".
MISSING VALUES AusStateOfBirth (-99).
ADD VALUE LABELS AusStateOfBirth -99 "No Response".
VARIABLE LEVEL AusStateOfBirth (NOMINAL).
IF (AusStateOfBirth=1000) AusStateOfBirth=AusStateOfEmployment. /* Same as now... so copy over - there were 91 of these.
EXECUTE.

VARIABLE LABELS StateOfBirth "28b. US State of Birth".
MISSING VALUES StateOfBirth (-99).
ADD VALUE LABELS StateOfBirth -99 "No Response".
VARIABLE LEVEL StateOfBirth (NOMINAL).
* *** Note that one person selected "Other"... but there is not other information, so we have to leave it.
IF (StateOfBirth=1000) StateOfBirth=StateOfEmployment. /* Same as now... so copy over - there were 110 of these.
EXECUTE.

VARIABLE LABELS ProvinceOfBirth "28c. Canadian Province of Birth".
MISSING VALUES ProvinceOfBirth (-99).
ADD VALUE LABELS ProvinceOfBirth -99 "No Response".
VARIABLE LEVEL ProvinceOfBirth (NOMINAL).
IF (ProvinceOfBirth=1000) ProvinceOfBirth=ProvinceOfEmployment. /* Same as now... so copy over - there were 16 of these.
EXECUTE.

VARIABLE LABELS NationOfBirth "28d. UK Nation of Birth".
MISSING VALUES NationOfBirth (-99).
ADD VALUE LABELS NationOfBirth -99 "No Response".
VARIABLE LEVEL NationOfBirth (NOMINAL).
* *** one respondent put "other" however they show their employer which equates to England.
IF (NationOfBirth=1000) NationOfBirth=NationOfEmployment. /* Same as now... so copy over - there were 181 of these.
EXECUTE.

* *** Q29 Age (now and when joined).

RENAME VARIABLES AgeRange_1=FirstAgeRangeExtended.
VARIABLE LABELS FirstAgeRangeExtended "29F. First Age Range (extended)".
MISSING VALUES FirstAgeRangeExtended (-99).
ADD VALUE LABELS FirstAgeRangeExtended -99 "No Response".
VARIABLE LEVEL FirstAgeRangeExtended (ORDINAL).
EXECUTE.

RENAME VARIABLES AgeRange_2=AgeRangeExtended.
VARIABLE LABELS AgeRangeExtended "29. Age Range (extended)".
MISSING VALUES AgeRangeExtended (-99).
ADD VALUE LABELS AgeRangeExtended -99 "No Response".
VARIABLE LEVEL AgeRangeExtended (ORDINAL).
EXECUTE.

COMPUTE AgeRange=AgeRangeExtended.
VARIABLE LABELS AgeRange "29r1. Age Range".
MISSING VALUES AgeRange (-99).
VARIABLE LEVEL AgeRange (ORDINAL).
VALUE LABELS AgeRange 4 "24 and under" 5 "25-34" 6 "35-44" 7 "45-54" 8 "55-64" 9 "65 and over" 88 "Prefer not to provide" -99 "No Reponse".
IF AgeRange=10 AgeRange=9. 
* 65-75 --> 65 and over.
IF AgeRange=11 AgeRange=9.
* 75 and over --> 65 and over.
EXECUTE.

* *** Q30 Gender.
RENAME VARIABLES Gender=GenderExtended.
VARIABLE LABELS GenderExtended "30. Gender (extended)".
MISSING VALUES GenderExtended (-99).
VALUE LABELS GenderExtended 4 "Male" 5 "Female" 11 "Non Binary" 88 "Prefer not to provide" -99 "No Response".
VARIABLE LEVEL GenderExtended (NOMINAL).
EXECUTE.

COMPUTE Gender=GenderExtended.
VARIABLE LABELS Gender "30r1. Gender".
MISSING VALUES Gender (-99).
VARIABLE LEVEL Gender (NOMINAL).
VALUE LABELS Gender 4 "Male" 5 "Female" 88 "Prefer not to provide" -99 "No Reponse".
IF Gender=11 Gender=88. 
* Non Binary --> Prefer not to provide, so allow comparisons with RAAAP-1.
EXECUTE.

* *** Q31 Ethic Background - new question for RAAAP-3.
VARIABLE LABELS EthnicBackground "31. Ethnic background".
MISSING VALUES EthnicBackground (-99).
VARIABLE LEVEL EthnicBackground (NOMINAL).
EXECUTE.

RENAME VARIABLES EthnicBackground_99_TEXT=EthnicBackgroundDetails.
VARIABLE LABELS EthnicBackgroundDetails "31a. Ethnic background details".
MISSING VALUES EthnicBackgroundDetails ("").
VALUE LABELS EthnicBackgroundDetails "" "No Response".
VARIABLE LEVEL EthnicBackgroundDetails (NOMINAL).
EXECUTE.
* *** Some respondents (68) put comments in "other" and we have backcoded some of these; to leave just XX as other.
IF EthnicBackgroundDetails="Caribbean, but not black or african" EthnicBackground=3. /* Black / African / Caribbean.
IF EthnicBackgroundDetails="caucasian" EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="Caucasian" EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="Caucasian as white is a color not a ethnic background" EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="Chinese Australian (biracial)" EthnicBackground=6. /* Multiple.
IF EthnicBackgroundDetails="European (white is not an ethnic background :-))" EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="I am white but try to think multicultural..." EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="I believe the correct term in Caucasian." EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="Mixed Arab/White" EthnicBackground=6. /* Multiple.
IF EthnicBackgroundDetails="mixed European" EthnicBackground=6. /* Multiple.
IF EthnicBackgroundDetails="Multiple (Japanese and White) - all surveys that collect racial/ethnic data should allow multiple selections" EthnicBackground=6. /* Multiple.
IF EthnicBackgroundDetails="Mutt" EthnicBackground=6. /* Multiple.
IF EthnicBackgroundDetails="South East Asian" EthnicBackground=2. /* Asian.
IF EthnicBackgroundDetails="What a rude question to ask this! Im white, but I can imagine this question will upset lot of people. Why is this even important to you??" EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="White / Scottish European" EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="White Hispanic" EthnicBackground=6. /* Multiple.
IF EthnicBackgroundDetails="White; I understand the purpose but find the question quite offensive." EthnicBackground=7. /* White.
IF EthnicBackgroundDetails="White/Latino" EthnicBackground=6. /* Multiple.
EXECUTE.
*** * Note that for EthnicBackgroundDetails no anonymising was needed.

* *** Backcoding (second round, where "other" was selected, but text indicated a choice, eg "Caucasian" was written in text, so this was mapped to "white"(7) - some of these duplicate the above, but there are some additionals - SK.
* *** NOTE that the choices here will need to be revisited in ny future iteration - and thee question more carefully worded!.
IF (ResponseId="R_1r67GmESTb9qE8o") EthnicBackground=7.
IF (ResponseId="R_31Kj0G27irK3W9w") EthnicBackground=2.
IF (ResponseId="R_2SkwWosYWWICHhS") EthnicBackground=7.
IF (ResponseId="R_BIZUGvKJujFBlxn") EthnicBackground=7.
IF (ResponseId="R_RkHGQB63MrGLJTz") EthnicBackground=5.
IF (ResponseId="R_p6P45ULUXytDNvj") EthnicBackground=7.
IF (ResponseId="R_3fkjzJYupDKFe3M") EthnicBackground=7.
IF (ResponseId="R_2YWyTRA6qv4ozrK") EthnicBackground=6.
IF (ResponseId="R_3q87bSPYFheeegw") EthnicBackground=7.
IF (ResponseId="R_3M0thxqoIc6drWG") EthnicBackground=2.
IF (ResponseId="R_2AFhXeSwSLRDhno") EthnicBackground=7.
IF (ResponseId="R_2eQZMPRnzFmAxrU") EthnicBackground=7.
IF (ResponseId="R_1LCh3EbQ2doOxjs") EthnicBackground=6.
IF (ResponseId="R_2urOeJvBzZLMV7G") EthnicBackground=7.
IF (ResponseId="R_XiFgWlqq2gMbqIV") EthnicBackground=7.
IF (ResponseId="R_3P6I3qNEPQxwIEA") EthnicBackground=6.
IF (ResponseId="R_33rjic9gz9QkF0O") EthnicBackground=7.
IF (ResponseId="R_3gYPnP1GcPHlVBw") EthnicBackground=6.
IF (ResponseId="R_2xCZ3UP8aYhGArr") EthnicBackground=7.
IF (ResponseId="R_Cljrq5yBM15S6ul") EthnicBackground=7.
IF (ResponseId="R_tZ0FwbfMy8su5Bn") EthnicBackground=7.
IF (ResponseId="R_10V031pskYFcb8N") EthnicBackground=7.
IF (ResponseId="R_55cpIU2hJdw6sxj") EthnicBackground=2.
IF (ResponseId="R_3EgvMcBGAIgpZfz") EthnicBackground=6.
IF (ResponseId="R_9YQK2o1PRY4y8Rb") EthnicBackground=6.
IF (ResponseId="R_27fY0ySAfDclWzM") EthnicBackground=2.
IF (ResponseId="R_1Ffw2gk6ntuc5L0") EthnicBackground=7.
IF (ResponseId="R_1CphqYF97xphijs") EthnicBackground=7.
IF (ResponseId="R_2SuYrS1Xa9nO4Qh") EthnicBackground=7.
IF (ResponseId="R_2VyCyTIVJKMPAeK") EthnicBackground=7.
IF (ResponseId="R_ulywXIS6iHQUAtX") EthnicBackground=7.
IF (ResponseId="R_1NzFjI9Rrhy7PkU") EthnicBackground=6.
IF (ResponseId="R_2bHJFxOSgqAmPBc") EthnicBackground=7.
IF (ResponseId="R_3LXAtttF2qNOzlI") EthnicBackground=7.
IF (ResponseId="R_RwBuZxLt8U8DeLf") EthnicBackground=6.
IF (ResponseId="R_1IhrshLT8AvlkPb") EthnicBackground=7.
IF (ResponseId="R_3FWCDPoiY5ET84N") EthnicBackground=4.
IF (ResponseId="R_1Ean6wCufbRFwVd") EthnicBackground=7.
IF (ResponseId="R_3M0vSuDkCbGtUka") EthnicBackground=7.
IF (ResponseId="R_2rP0L5Ah7qaX3A2") EthnicBackground=7.
EXECUTE.

* *** Part B now done.

* *** BACKHERE ***.
* *** Agreed that if they say this is their first role, then (only if FIRST column is blank) we copy Current info into First role...
* *** And vice versa.

* *** Day 5.
* *** Q32 New for RAAAP-3.
VARIABLE LABELS CurrentJobTitle "32. Current Job Title".
MISSING VALUES CurrentJobTitle ("").
VALUE LABELS CurrentJobTitle "" "No Response".
VARIABLE LEVEL CurrentJobTitle (NOMINAL).
EXECUTE.

* *** CurrentJobTitle anonymising - SK (lead by MD).
IF (ResponseId="R_2b0FovA5slJZHip") CurrentJobTitle="Research Manager School of Clinical Sciences at XXXX Health".
IF (ResponseId="R_3hA8wjAehsm7vfc") CurrentJobTitle="Director del Instituto de Investigación de Tecnologías XXXX".
IF (ResponseId="R_1k0NfstcLl36mo4") CurrentJobTitle="XXXX Science Platform Manager".
IF (ResponseId="R_2Vlor4TdjpJtmSq") CurrentJobTitle="Head: Graduate Studies and Research, College of Economic and Management Sciences, XXXX".
IF (ResponseId="R_Y5IOdkRQPQ3Y1wt") CurrentJobTitle="Directos del Centro de gestión de la Investigación y la Extensión de la Facultad XXXX".
IF (ResponseId="R_bIpQQm2XujkUdFL") CurrentJobTitle="Técnica Superior de Apoyo a la Investigación (Personal de Administración y Servicios) dependiente del Gabinete de Proyectos Institucionales de la Universitat XXXX".
IF (ResponseId="R_3MgKZ8R4c6CD4W1") CurrentJobTitle="XXXX Senior Research Funding Specialist (XXXX)".
IF (ResponseId="R_3GiBhcw3NP3gc0Z") CurrentJobTitle="Coordinadora Core de XXXX ".
IF (ResponseId="R_uqAbvE1qBDisM4p") CurrentJobTitle="Head of XXXX Research Office".
IF (ResponseId="R_2zFRnHOpO7ccniI") CurrentJobTitle="XXXX School for Public Health Research Manager".
IF (ResponseId="R_27IO2kOtPYcGr36") CurrentJobTitle="XXXX Innovation Executive Assistant".
IF (ResponseId="R_233imbivLyO6MQB") CurrentJobTitle="Profesional Especializado Gerencia de XXXX".
IF (ResponseId="R_1HuevhbP7upWRKV") CurrentJobTitle="Assistant Director, XXXX".
IF (ResponseId="R_2fvpymJ9rWF4Muq") CurrentJobTitle="Associate Director of Research, XXXX".
IF (ResponseId="R_1FA2O4b4SpL3Pll") CurrentJobTitle="Research Manager, XXXX".
IF (ResponseId="R_2XclLIg9WuULC4c") CurrentJobTitle="Assistant Director of XXXX Contracts and Partnerships".
IF (ResponseId="R_vuIfPwu5i0erJrH") CurrentJobTitle="auxiliar Administrativa Centro de Investigaciones Facultad de Ciencias XXXX".
IF (ResponseId="R_2VD7WTiuLdEfM3W") CurrentJobTitle="XXXX Research Officer and deputy head of department".
IF (ResponseId="R_1r35dBSlPzLcimi") CurrentJobTitle="XXXX research Management Fellow".
IF (ResponseId="R_2c9OiCraCkmYXRL") CurrentJobTitle="Platform Manager, XXXX Data Analytics Platform".
IF (ResponseId="R_1Nggafyom3ohKVd") CurrentJobTitle="Acting Manager (Maternity Leave Cover), Centre for Research and Analysis XXXX, Department of Economics, XXXX".
IF (ResponseId="R_2frKIdiPlVEpRLk") CurrentJobTitle="Head, Centre for Excellence XXXX  India".
IF (ResponseId="R_55Qzaw0fsZxOpUt") CurrentJobTitle="XXXX Contact point for Horizon Europe".
IF (ResponseId="R_u8hSu2LYU0zWH1D") CurrentJobTitle="XXXX PhD Programme Manager".
IF (ResponseId="R_24hGeKAxTWgPNAh") CurrentJobTitle="Coordinador Ejecutivo XXXX de Ciencia y Tecnología Universidad del XXXX".
IF (ResponseId="R_2VjMIfFPDm0ETzS") CurrentJobTitle="Research Advisor- XXXX".
IF (ResponseId="R_3PcrUBXAkYbIIft") CurrentJobTitle="Vice Director of Collaborative Innovation Center, Executive Board Member of XXXX, XXXX University of China".
IF (ResponseId="R_2zBVjJVSnqJG1uV") CurrentJobTitle="Director, Office of Research Integrity and Ethics, XXXX University ".
IF (ResponseId="R_3nSq5tNnUEPWadq") CurrentJobTitle="Director of Research Services at XXXX University".
IF (ResponseId="R_2QFZ4GdiUjZZIxP") CurrentJobTitle="Coordinator of the Frech National Contact Point for the XXXX".
IF (ResponseId="R_2bHJFxOSgqAmPBc") CurrentJobTitle="XXXX Lawyer - XXXX Contact Point for H2020 & Horizon Europe".
IF (ResponseId="R_yykI0nh77gR5fjP") CurrentJobTitle="Institute Manager, XXXX Institute".
IF (ResponseId="R_3iVEMGW5CqyepDH") CurrentJobTitle="Executive Director, Administration, International XXXX Health Research and Training Centre ".
IF (ResponseId="R_3O33fV1HjZKRHJf") CurrentJobTitle="Docente Investigador de la facultad de ciencias de la salud / responsable de la XXXX".
IF (ResponseId="R_1IpcL7GGXuIVoaB") CurrentJobTitle="Information Specialist Research - XXXX".
IF (ResponseId="R_2Se7cNW8QP9c5mA") CurrentJobTitle="Pesquisador Titular, coordenador da do Laboratório de Referência XXXX do XXXX e coordenador da Rede de Pesquisa Translacional XXXX".
EXECUTE.

* *** Q33 Prev Roles - new for RAAAP-3.
* Previous Employments.

* First the durations
* We will also create the 5year banded version.
RENAME VARIABLES PrevRoles_1_1=PreRMARoleDurationRecent.
RENAME VARIABLES PrevRoles_1_2=PreRMARoleDurationMiddle.
RENAME VARIABLES PrevRoles_1_3=PreRMARoleDurationOldest.

MISSING VALUES PreRMARoleDurationRecent PreRMARoleDurationMiddle PreRMARoleDurationOldest (-99).
VARIABLE LABELS PreRMARoleDurationRecent '33aa. Approx years in most recent pre-RMA role'.
VARIABLE LABELS PreRMARoleDurationMiddle '33ba. Approx years in middle pre-RMA role'.
VARIABLE LABELS PreRMARoleDurationOldest '33ca. Approx years in oldest pre-RMA role'.
VARIABLE LEVEL PreRMARoleDurationRecent PreRMARoleDurationMiddle PreRMARoleDurationOldest (ORDINAL).
FORMATS PreRMARoleDurationRecent PreRMARoleDurationMiddle PreRMARoleDurationOldest (f8.1).
ADD VALUE LABELS PreRMARoleDurationRecent PreRMARoleDurationMiddle PreRMARoleDurationOldest -99 "No Response".
EXECUTE.
* *** note that values need recoding to match other RAAAP variables.
RECODE PreRMARoleDurationRecent PreRMARoleDurationMiddle PreRMARoleDurationOldest 
    (1.0 = 0.0)
    (2.0 = 0.5)
    (3.0 = 1.0)
    (4.0 = 2.0)
    (5.0 = 3.0)
    (6.0 = 4.0)
    (7.0 = 5.0)
    (8.0 = 6.0)
    (9.0 = 7.0)
    (10.0 = 8.0)
    (11.0 = 9.0)
    (12.0 = 12.0)
    (13.0 = 17.0)
    (14.0 = 22.0)
    (15.0 = 27.0)
    (16.0 = 32.0)
    (17.0 = 37.0)
    (18.0 = 40.0)
    (-99=SYSMIS)
    (ELSE=Copy).
VALUE LABELS PreRMARoleDurationRecent PreRMARoleDurationMiddle PreRMARoleDurationOldest
    0 "Never" 0.5 "<1" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6" 7 "7" 8 "8" 9 "9" 12 "10-14" 17 "15-19" 22 "20-24" 27 "25-29" 32 "30-34" 37 "35-39" 40 ">=40" -99 "No Response".
EXECUTE.
* *** created the 5 year banded versions in case they are useful - to match other banded variables.
RECODE PreRMARoleDurationRecent
    (0.0 = 0)
    (0.5, 1.0, 2.0, 3.0, 4.0 = 2)
    (5.0, 6.0, 7.0, 8.0, 9.0 = 7)
    (12.0 = 12)
    (17.0 = 17)
    (22.0 = 22)
    (27.0 = 27)
    (28.0 = 28)
    (32.0 = 32)
    (37.0 = 37)
    (40.0 = 40)
    (-99=SYSMIS)
    (ELSE=Copy)
INTO PreRMARoleDurationRecentGrouped.
RECODE PreRMARoleDurationMiddle
    (0.0 = 0)
    (0.5, 1.0, 2.0, 3.0, 4.0 = 2)
    (5.0, 6.0, 7.0, 8.0, 9.0 = 7)
    (12.0 = 12)
    (17.0 = 17)
    (22.0 = 22)
    (27.0 = 27)
    (28.0 = 28)
    (32.0 = 32)
    (37.0 = 37)
    (40.0 = 40)
    (-99=SYSMIS)
    (ELSE=Copy)
INTO PreRMARoleDurationMiddleGrouped.
RECODE PreRMARoleDurationOldest
    (0.0 = 0)
    (0.5, 1.0, 2.0, 3.0, 4.0 = 2)
    (5.0, 6.0, 7.0, 8.0, 9.0 = 7)
    (12.0 = 12)
    (17.0 = 17)
    (22.0 = 22)
    (27.0 = 27)
    (28.0 = 28)
    (32.0 = 32)
    (37.0 = 37)
    (40.0 = 40)
    (-99=SYSMIS)
    (ELSE=Copy)
INTO PreRMARoleDurationOldestGrouped.
FORMATS PreRMARoleDurationRecentGrouped PreRMARoleDurationMiddleGrouped PreRMARoleDurationOldestGrouped (f8).
VALUE LABELS PreRMARoleDurationRecentGrouped PreRMARoleDurationMiddleGrouped PreRMARoleDurationOldestGrouped  0 "Never" 2 "<5" 7 "5-9" 12 "10-14" 17 "15-19" 22 "20-24" 27 "25-29" 32 "30-34" 37 "35-39" 40 ">=40" -99 "No Response".
VARIABLE LABELS PreRMARoleDurationRecentGrouped "33aab. Approx years (banded) in most recent pre-RMA role".
VARIABLE LABELS PreRMARoleDurationMiddleGrouped "33bab. Approx years (banded) in middle pre-RMA role".
VARIABLE LABELS PreRMARoleDurationOldestGrouped "33cab. Approx years (banded) in oldest pre-RMA role".
VARIABLE LEVEL PreRMARoleDurationRecentGrouped PreRMARoleDurationMiddleGrouped PreRMARoleDurationOldestGrouped  (ORDINAL).
MISSING VALUES PreRMARoleDurationRecentGrouped PreRMARoleDurationMiddleGrouped PreRMARoleDurationOldestGrouped  (-99).
EXECUTE.

RENAME VARIABLES PrevRoles_2_1_1=PreRMARoleDetailsRecent. /* the middle column of the question - "Specific Area".
RENAME VARIABLES PrevRoles_2_2_1=PreRMARoleDetailsMiddle. /* the middle column of the question - "Specific Area".
RENAME VARIABLES PrevRoles_2_3_1=PreRMARoleDetailsOldest. /* the middle column of the question - "Specific Area".
VARIABLE LABELS PreRMARoleDetailsRecent "33ba. Specific area of most recent pre-RMA role".
VARIABLE LABELS PreRMARoleDetailsMiddle "33bb. Specific area of middle pre-RMA role".
VARIABLE LABELS PreRMARoleDetailsOldest "33bc. Specific area of oldest pre-RMA role".
MISSING VALUES PreRMARoleDetailsRecent PreRMARoleDetailsMiddle PreRMARoleDetailsOldest ("").
VALUE LABELS PreRMARoleDetailsRecent PreRMARoleDetailsMiddle PreRMARoleDetailsOldest "" "No Response".
VARIABLE LEVEL PreRMARoleDetailsRecent PreRMARoleDetailsMiddle PreRMARoleDetailsOldest (NOMINAL).
EXECUTE.

RENAME VARIABLES PrevRoles_3_1=PreRMARoleAreaRecent. /* the last column of the question - "Area" from a pick list.
RENAME VARIABLES PrevRoles_3_2=PreRMARoleAreaMiddle.  /* the last column of the question - "Area" from a pick list.
RENAME VARIABLES PrevRoles_3_3=PreRMARoleAreaOldest.  /* the last column of the question - "Area" from a pick list.
VARIABLE LABELS PreRMARoleAreaRecent "33ca. Area of most recent pre-RMA role".
VARIABLE LABELS PreRMARoleAreaMiddle "33cb. Area of middle pre-RMA role".
VARIABLE LABELS PreRMARoleAreaOldest "33cc. Area of oldest pre-RMA role".
* *** now shorten the pick lists to aid output.
VALUE LABELS PreRMARoleAreaRecent PreRMARoleAreaMiddle PreRMARoleAreaOldest
      1 "1. Agriculture"
      2 "2. Mining"
      3 "3. Manufacturing"
      4 "4. Electricity"
      5 "5. Water supply"
      6 "6. Construction"
      7 "7. Retail"
      8 "8. Transportation"
      9 "9. Accommodation"
      10 "10. Information"
      11 "11. Financial"
      12 "12. Real estate"
      13 "13. Scientific"
      14 "14. Administration"
      15 "15. Public administration"
      16 "16. Education"
      17 "17. Health"
      18 "18. Arts"
      19 "19. Other services" 
      20 "20. Homeworking"
      21 "21. Overseas"
      22 "Other".
MISSING VALUES PreRMARoleAreaRecent PreRMARoleAreaMiddle PreRMARoleAreaOldest (-99).
ADD VALUE LABELS PreRMARoleAreaRecent PreRMARoleAreaMiddle PreRMARoleAreaOldest -99 "No Response".
VARIABLE LEVEL PreRMARoleAreaRecent PreRMARoleAreaMiddle PreRMARoleAreaOldest (NOMINAL).
EXECUTE.

* *** Q33 details.
RENAME VARIABLES PrevJobDet=PreRMARoleDetails.
VARIABLE LABELS PreRMARoleDetails "33a. Pre-RMA Role Details".
MISSING VALUES PreRMARoleDetails ("").
VALUE LABELS PreRMARoleDetails "" "No Response".
VARIABLE LEVEL PreRMARoleDetails (NOMINAL).
EXECUTE.

* *** Anonymising PreRMARoleDetailsRecent - MF.
IF (ResponseId="R_3oZm4MrP0o6y9kN") PreRMARoleDetailsRecent="Postdoctoral fellow at XXXX, New Delhi".
IF (ResponseId="R_1lgI9ZXTq1ZA6ZE") PreRMARoleDetailsRecent="EU XXXX project".
IF (ResponseId="R_3IYuDOPHTuLKQBX") PreRMARoleDetailsRecent="Japan XXXX Agency".
IF (ResponseId="R_2uQc9oFlnUDyrPE") PreRMARoleDetailsRecent="Office administrator in a manufacturing plant that made XXXX".
IF (ResponseId="R_xcuQ4n8Wx5K33RD") PreRMARoleDetailsRecent="Public administration - senior advisor in the Norwegian XXXX Agency related to market analysis and statistics".
IF (ResponseId="R_28P5zeoC0gjDXEz") PreRMARoleDetailsRecent="Research programme manager at XXXX".
IF (ResponseId="R_1dMETYhndbSQTuJ") PreRMARoleDetailsRecent="Student and XXXX Ministry".
IF (ResponseId="R_3g1OvUCvnGbGXOC") PreRMARoleDetailsRecent="XXXX".
IF (ResponseId="R_1I47OogsAy3cFKh") PreRMARoleDetailsRecent="Project Officer for the XXXX Learning Team".
IF (ResponseId="R_2CCySw17b1mTRny") PreRMARoleDetailsRecent="XXXX Specialist".
IF (ResponseId="R_29huBBF5AgS24Tq") PreRMARoleDetailsRecent="XXXX".
IF (ResponseId="R_UEB7QzSpE8FRECR") PreRMARoleDetailsRecent="XXXX".
IF (ResponseId="R_2tFnXGGJMIOUeLb") PreRMARoleDetailsRecent="Coordinados de Calidad en Instituto Profesional de XXXX".
IF (ResponseId="R_oXHqWi7nV3KZICR") PreRMARoleDetailsRecent="XXXX zhou".
EXECUTE.

* *** Anonymising PreRMARoleDetailsMiddle - MF.
IF (ResponseId="R_D8CwDAv6SXTJtwl") PreRMARoleDetailsMiddle="Ministry of XXXX, Greenland".
IF (ResponseId="R_XiFgWlqq2gMbqIV") PreRMARoleDetailsMiddle="Czech XXXX Agency".
IF (ResponseId="R_2wzZpOPfAb0mJgX") PreRMARoleDetailsMiddle="Teacher, Undergraduate Courses; Employee, Japanese Board of XXXX".
IF (ResponseId="R_2wmkoIWSYTQ2pD0") PreRMARoleDetailsMiddle="senior advisor in sustainbale XXXX at the city of XXXX (french polynecia)".
EXECUTE.

* *** Anonymising PreRMARoleDetailsOldest - CO.
* *** None.  NB Old jobs tend to be less identifying, also in general less info was given.

* *** Backcoding from PreRMARoleDetailsRecent - SK.
IF (ResponseId="R_1OGYVBDjUpQk8qG") PreRMARoleAreaRecent=18.
IF (ResponseId="R_12f2iCe5cRRJ8CM") PreRMARoleAreaRecent=13.
IF (ResponseId="R_31i6AnEyTSx53gS") PreRMARoleAreaRecent=11.
IF (ResponseId="R_1IWpFdqhqZ2V4jr") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2uHEp1xP3YHqEWV") PreRMARoleAreaRecent=10.
IF (ResponseId="R_Q5pBh8jpJEuLgxb") PreRMARoleAreaRecent=17.
IF (ResponseId="R_2sYIgG54Y94iEDt") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3KOeTZ9XflzcPwL") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1jTVoRUqgGOVe4J") PreRMARoleAreaRecent=10.
IF (ResponseId="R_3esGhtOCEIzgzab") PreRMARoleAreaRecent=16.
IF (ResponseId="R_emxgLX6BtXScPhD") PreRMARoleAreaRecent=16.
IF (ResponseId="R_rqN3J5i9b1brMYN") PreRMARoleAreaRecent=16.
IF (ResponseId="R_urjuS8Kl77pSdB7") PreRMARoleAreaRecent=1.
IF (ResponseId="R_2tr9BzdT5psVfzz") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2R92LSVcHqXJ0rY") PreRMARoleAreaRecent=7.
IF (ResponseId="R_2R2pbK17d6XiVaC") PreRMARoleAreaRecent=18.
IF (ResponseId="R_2QMw5kfeZYYMMKC") PreRMARoleAreaRecent=11.
IF (ResponseId="R_3qOe9q9wSeTMKkN") PreRMARoleAreaRecent=11.
IF (ResponseId="R_3PpJZnB9hjFuu1q") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1BPk3bbrSjjhG0O") PreRMARoleAreaRecent=6.
IF (ResponseId="R_3EGWM5KINMUvygZ") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3RxwEAgWDhlV0H4") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3lxbXZIsnAUc8Bf") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2zOnSKtJGusJLbA") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3JrpNyHjoEj9tS1") PreRMARoleAreaRecent=11.
IF (ResponseId="R_24ecXZ5oDR5h13W") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3HiZIf8Hs5fMPYI") PreRMARoleAreaRecent=17.
IF (ResponseId="R_1dKyWogK1ThAlTs") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1Kwig1Yegxbko3g") PreRMARoleAreaRecent=10.
IF (ResponseId="R_28P5zeoC0gjDXEz") PreRMARoleAreaRecent=13.
IF (ResponseId="R_23ZRak6qaFOX6br") PreRMARoleAreaRecent=16.
IF (ResponseId="R_YRDr50UMURvwxYl") PreRMARoleAreaRecent=13.
IF (ResponseId="R_1CqZIzmwpmcvfLY") PreRMARoleAreaRecent=13.
IF (ResponseId="R_1f2tlKtcmmrArSN") PreRMARoleAreaRecent=7.
IF (ResponseId="R_3lAAdbMmNJlFWiK") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2wsjO9QVQCnS96z") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2fJ2OAIYXDozVtG") PreRMARoleAreaRecent=16.
IF (ResponseId="R_XYe5kdEZnWLdkaJ") PreRMARoleAreaRecent=11.
IF (ResponseId="R_2dRC6frgrSICenz") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1kIhDmbqxaXpoe3") PreRMARoleAreaRecent=18.
IF (ResponseId="R_vSl5x45dY0WUNdD") PreRMARoleAreaRecent=16.
IF (ResponseId="R_30wbLVCI74Qpoqh") PreRMARoleAreaRecent=18.
IF (ResponseId="R_2t9emihpgLG5O2W") PreRMARoleAreaRecent=11.
IF (ResponseId="R_2eQZMPRnzFmAxrU") PreRMARoleAreaRecent=16.
IF (ResponseId="R_VWk6O3hVlgBROWR") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3mIaoA8ILpzUfpn") PreRMARoleAreaRecent=7.
IF (ResponseId="R_2QfXMNDlf8G2Ss5") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3MG37vHsw0h2JLJ") PreRMARoleAreaRecent=14.
IF (ResponseId="R_3qxMrVTxWuWMSXJ") PreRMARoleAreaRecent=14.
IF (ResponseId="R_2fGJY8Av63I9uKI") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3r5S3I3SaE5JnUt") PreRMARoleAreaRecent=7.
IF (ResponseId="R_1pQc3q2aKpZ1CDG") PreRMARoleAreaRecent=14.
IF (ResponseId="R_2cjvm0NDtMSzYHz") PreRMARoleAreaRecent=1.
IF (ResponseId="R_2cB2xJaqS7PsD1L") PreRMARoleAreaRecent=14.
IF (ResponseId="R_3s4CftKBa3K1A95") PreRMARoleAreaRecent=18.
IF (ResponseId="R_2CEwxIYKAdLNm42") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3stuwc4OmCOF9qz") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2ZE4RjwDDbkM2JF") PreRMARoleAreaRecent=11.
IF (ResponseId="R_322VrA3XG9L8vTv") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2feBBwKOo6px2yP") PreRMARoleAreaRecent=13.
IF (ResponseId="R_1mqmi49jyvwCiVN") PreRMARoleAreaRecent=16.
IF (ResponseId="R_231U5VpsWKx0wD6") PreRMARoleAreaRecent=9.
IF (ResponseId="R_3gYPnP1GcPHlVBw") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3fw07eCaftKR5ec") PreRMARoleAreaRecent=16.
IF (ResponseId="R_qJ9U8DcOqzsCwCd") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2SACniNnBQvNd3B") PreRMARoleAreaRecent=13.
IF (ResponseId="R_W1Z4tWskyLvwI4V") PreRMARoleAreaRecent=16.
IF (ResponseId="R_32LsvCkSTDnYwJe") PreRMARoleAreaRecent=11.
IF (ResponseId="R_3h6j5PSfNvunpaJ") PreRMARoleAreaRecent=13.
IF (ResponseId="R_263zbwxFEOIKa1V") PreRMARoleAreaRecent=17.
IF (ResponseId="R_2ckHPlRUfjLzQQ2") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3KBlXf1pDysQbqz") PreRMARoleAreaRecent=10.
IF (ResponseId="R_1FM3eOjQvMhno2O") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3dRZOO3DG0Jt5Z1") PreRMARoleAreaRecent=17.
IF (ResponseId="R_1g7wqPbZK25Tutv") PreRMARoleAreaRecent=13.
IF (ResponseId="R_1P7V6BSJ7uyF4KD") PreRMARoleAreaRecent=16.
IF (ResponseId="R_22YDY7wI8PKMNb3") PreRMARoleAreaRecent=10.
IF (ResponseId="R_2QSuol2xuD66GQa") PreRMARoleAreaRecent=17.
IF (ResponseId="R_2313Qtx9OnjCAuX") PreRMARoleAreaRecent=11.
IF (ResponseId="R_1JL2pNYfBaqEUP4") PreRMARoleAreaRecent=11.
IF (ResponseId="R_1BYua97H96X3Pk3") PreRMARoleAreaRecent=11.
IF (ResponseId="R_2tFnXGGJMIOUeLb") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3HGnoXC1T22cMYT") PreRMARoleAreaRecent=10.
IF (ResponseId="R_2CE4R5cbnt29dNV") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2q1WWVuCw8SgHmd") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3Oi7fOZF83D3Aad") PreRMARoleAreaRecent=16.
IF (ResponseId="R_25AYzZpB7yAyLWK") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3PYPtjBfJbSgvhQ") PreRMARoleAreaRecent=16.
IF (ResponseId="R_RWGWjdzlQYVBr2x") PreRMARoleAreaRecent=7.
IF (ResponseId="R_RLalmXSl1XQxToJ") PreRMARoleAreaRecent=17.
IF (ResponseId="R_2ATj6JnywuiAriD") PreRMARoleAreaRecent=16.
IF (ResponseId="R_10pb3RgLws4q8lC") PreRMARoleAreaRecent=17.
IF (ResponseId="R_1kYssDwNbsuGHyN") PreRMARoleAreaRecent=20.
IF (ResponseId="R_29itI37p13B61gl") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3q7kXEh3XwYAcCc") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3oG5ESWXnnRXCDb") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3FWIDYHawyuw0Qw") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1U4JERKchxGL7W1") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2uINdxZHX9sxLtx") PreRMARoleAreaRecent=17.
IF (ResponseId="R_3KpRoFBQUyoylgt") PreRMARoleAreaRecent=16.
IF (ResponseId="R_QbR57tyraLVStB7") PreRMARoleAreaRecent=11.
IF (ResponseId="R_232ZTb64uYQSqF7") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3EcGtP6UNUcABOP") PreRMARoleAreaRecent=11.
IF (ResponseId="R_3EQYk10uOO6BPln") PreRMARoleAreaRecent=11.
IF (ResponseId="R_1lhh7OaAj3gsJf6") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2RUgnXxRvOHyTUq") PreRMARoleAreaRecent=10.
IF (ResponseId="R_8kP4FjNBY0z4quR") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2VIUyPRmdgbCoNo") PreRMARoleAreaRecent=11.
IF (ResponseId="R_1oiQCH4HDcoZPsO") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2QSV5qBnPFxCCCg") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3qJV14SQCCiQPYe") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2Qm1NYIqYs6jv37") PreRMARoleAreaRecent=15.
IF (ResponseId="R_3Po6PE4gjiarHQv") PreRMARoleAreaRecent=11.
IF (ResponseId="R_2aKncD6eUXJfl3N") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1exzfCI7mafVjiL") PreRMARoleAreaRecent=16.
IF (ResponseId="R_32VK1tc5AJsFNGV") PreRMARoleAreaRecent=15.
IF (ResponseId="R_3rN908rlU94wEYR") PreRMARoleAreaRecent=10.
IF (ResponseId="R_3CE3IBd1DVN1Mub") PreRMARoleAreaRecent=13.
IF (ResponseId="R_124FtV7fruuGsJI") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3EFIL41rM6zWIKh") PreRMARoleAreaRecent=14.
IF (ResponseId="R_DizdQBFibv7mLJL") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2XiCol6w2NAJS7P") PreRMARoleAreaRecent=15.
IF (ResponseId="R_3kEROwIIvilN9os") PreRMARoleAreaRecent=13.
IF (ResponseId="R_bw1sKzDLdTu9iI9") PreRMARoleAreaRecent=17.
IF (ResponseId="R_1dzcS6AzbcPzhnd") PreRMARoleAreaRecent=17.
IF (ResponseId="R_31mzvDjteqQyDNn") PreRMARoleAreaRecent=9.
IF (ResponseId="R_1dFtonqBzFGDU3C") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3NXsLNleXah1ZYq") PreRMARoleAreaRecent=20.
IF (ResponseId="R_3qNJoVxzoLXKYHL") PreRMARoleAreaRecent=13.
IF (ResponseId="R_237VSETBVUGcz2T") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3F5pdRRsODrvJch") PreRMARoleAreaRecent=16.
IF (ResponseId="R_ApaiXusMHk2RSIV") PreRMARoleAreaRecent=18.
IF (ResponseId="R_ZgIOTtPwG6A9MJj") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1r6X6r8dUK1FjfZ") PreRMARoleAreaRecent=9.
IF (ResponseId="R_b29zSYX6qdievGV") PreRMARoleAreaRecent=15.
IF (ResponseId="R_u8hSu2LYU0zWH1D") PreRMARoleAreaRecent=20.
IF (ResponseId="R_3JfQLUV8M0FdHIT") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2scjguV1HY6kAuB") PreRMARoleAreaRecent=9.
IF (ResponseId="R_Wr0vDiQ5kYgNEm5") PreRMARoleAreaRecent=17.
IF (ResponseId="R_2ROJtPpBii4TzLy") PreRMARoleAreaRecent=13.
IF (ResponseId="R_NXsDq9YHpy5Z7H3") PreRMARoleAreaRecent=11.
IF (ResponseId="R_dbwDi1LXQyrX5Kx") PreRMARoleAreaRecent=14.
IF (ResponseId="R_2DOyRMenCu3cLIK") PreRMARoleAreaRecent=17.
IF (ResponseId="R_27jHZCSquzsGQj3") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2R20EnM6SPKn4Ni") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2aOxEuTch8jIFYk") PreRMARoleAreaRecent=14.
IF (ResponseId="R_3n89wyMNHW7ZYjt") PreRMARoleAreaRecent=16.
IF (ResponseId="R_DPrW2auKaqmEebL") PreRMARoleAreaRecent=13.
IF (ResponseId="R_1M09YqxnvTwWUEn") PreRMARoleAreaRecent=16.
IF (ResponseId="R_33C31RQ3ntmZTZi") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3ir8xN7mXMFrZqA") PreRMARoleAreaRecent=13.
IF (ResponseId="R_1kZGaj6hrmwc3KW") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3jTYRSllec1uttB") PreRMARoleAreaRecent=13.
IF (ResponseId="R_dncG6tNli6DeiRj") PreRMARoleAreaRecent=15.
IF (ResponseId="R_OHYhQUIeHQJNnzj") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1LhC28RKl2r39zP") PreRMARoleAreaRecent=10.
IF (ResponseId="R_1QzjAPjqKaHHPvE") PreRMARoleAreaRecent=16.
IF (ResponseId="R_9QDtvRkOuzbG4EN") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1F3ZT6ummeTT7UY") PreRMARoleAreaRecent=17.
IF (ResponseId="R_27DV8dFFXbogKxB") PreRMARoleAreaRecent=16.
IF (ResponseId="R_27BWBAEOSU2Uc9P") PreRMARoleAreaRecent=11.
IF (ResponseId="R_XjLf9ufa1ulzLVL") PreRMARoleAreaRecent=16.
IF (ResponseId="R_20Ms8lkvsXpylXP") PreRMARoleAreaRecent=16.
IF (ResponseId="R_OdHW5xqfgRBWxeF") PreRMARoleAreaRecent=1.
IF (ResponseId="R_qV3rkNNyLax9bRD") PreRMARoleAreaRecent=10.
IF (ResponseId="R_3n1bOSXT50UvibL") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1eRlHGsF55TuAni") PreRMARoleAreaRecent=16.
IF (ResponseId="R_26lh3I8ZlLEE6yK") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2ROGQD2JFY7tr9f") PreRMARoleAreaRecent=17.
IF (ResponseId="R_3PdJn0JPD06QIYV") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1GDLUPj28PGErgB") PreRMARoleAreaRecent=7.
IF (ResponseId="R_3rY4N8rczw05hTq") PreRMARoleAreaRecent=20.
IF (ResponseId="R_3Jt4NEcoi269nIt") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2q8ANE3FTsgJcoh") PreRMARoleAreaRecent=11.
IF (ResponseId="R_PtEUbSqAdcV74Cl") PreRMARoleAreaRecent=8.
IF (ResponseId="R_3D2zZUSxCobf4h3") PreRMARoleAreaRecent=10.
IF (ResponseId="R_3oBKQJjOSHL8oRo") PreRMARoleAreaRecent=16.
IF (ResponseId="R_UEbXuGSEasB5gBj") PreRMARoleAreaRecent=17.
IF (ResponseId="R_CeQ08w2eTWROhsB") PreRMARoleAreaRecent=15.
IF (ResponseId="R_32UZVXl3P4iQmaH") PreRMARoleAreaRecent=4.
IF (ResponseId="R_AFLbnSYC284pkxH") PreRMARoleAreaRecent=18.
IF (ResponseId="R_2Phgb2mhtZsMSwC") PreRMARoleAreaRecent=16.
IF (ResponseId="R_AMzdMasyOreMl2x") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3O33fV1HjZKRHJf") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3D71CfNLYfyodxm") PreRMARoleAreaRecent=11.
IF (ResponseId="R_2fJyME84ynObHtB") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1QGkIb7lNjSmcxL") PreRMARoleAreaRecent=10.
IF (ResponseId="R_2wbrfireJxDZbSy") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3I4YfLiPJJ92ng5") PreRMARoleAreaRecent=16.
IF (ResponseId="R_6SiG3rbgrq8J7QR") PreRMARoleAreaRecent=17.
IF (ResponseId="R_3p3xWTucENQBZnF") PreRMARoleAreaRecent=17.
IF (ResponseId="R_26eADIUAary48ta") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1QLBuk5fkbHMf3X") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2SrwGNygBfnwoUc") PreRMARoleAreaRecent=8.
IF (ResponseId="R_3kncGD3niEKpE37") PreRMARoleAreaRecent=18.
EXECUTE.

* *** Backcoding from PreRMARoleDetailsMiddle - SK.
IF (ResponseId="R_2TZBSjgeZPtUPrm") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2sYIgG54Y94iEDt") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_27Ck1FRgh517Iyp") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_2cq2yygrGhH1aP8") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_2ZPkyFch4QQnJom") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_emxgLX6BtXScPhD") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_3m4xohCFglaXmcy") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_2QMw5kfeZYYMMKC") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_3exiaXRhYpgdsYh") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3HBU2HmMlz41Okw") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3RxwEAgWDhlV0H4") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2zOnSKtJGusJLbA") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3HiZIf8Hs5fMPYI") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_1EXuIVpws7EVteE") PreRMARoleAreaMiddle=7.
IF (ResponseId="R_3phvRwp4ncQuAEW") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_1JJwuUPNKVNZg2k") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_SHqLcdFQlIFkMJr") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_1Kwig1Yegxbko3g") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_3MgKZ8R4c6CD4W1") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_1Fb2KEbfJC5K2Z9") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_1HnKkVGjPfKuh1L") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_YRDr50UMURvwxYl") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2ab1eC1WwhyDv9A") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2s12T6vscPazVII") PreRMARoleAreaMiddle=1.
IF (ResponseId="R_2wsjO9QVQCnS96z") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2eatHOuK89H98G2") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_1i9xXY5iFdZ8xIO") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_9mqxhIiNmhvqjlf") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_VWk6O3hVlgBROWR") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_1nVLZHrRib4e0sR") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2Xp97k4VvYA20Fb") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3IaACWWVeFNjKy0") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_2co6AQYGZatQkQQ") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3gYPnP1GcPHlVBw") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3KUgebMvWg9oS0A") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_ZE0BCMnVrPJ9SxP") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_qJ9U8DcOqzsCwCd") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_24vXwqSplDYMBBp") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2arfDitq8E25x6S") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_1FM3eOjQvMhno2O") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_1g7wqPbZK25Tutv") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_3RpSlbpojVvaGPT") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_3dKuyXh8jXgSZIR") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_1dAFgbFqjNw5CGR") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_1jDn4elm1Sgn3dI") PreRMARoleAreaMiddle=9.
IF (ResponseId="R_2TIa3YfVSiSsVei") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_3IQ7ksGUwvCKbeI") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_3kd00W7iA4s9Sy2") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_1ghcaUJJbn68VHm") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_1era6GM7oD0qu7Z") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2q1WWVuCw8SgHmd") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_22KfMZnUtNlJhmI") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_25AYzZpB7yAyLWK") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_3PYPtjBfJbSgvhQ") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_RLalmXSl1XQxToJ") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_5heOjSYDgQWI2lj") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_3P7uy28mI6ImGbx") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_1kZz7YHpvRzflF0") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_27QBdgT49HN0sjR") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_10SKV0uU2gIYQHF") PreRMARoleAreaMiddle=7.
IF (ResponseId="R_3iR1pZAJQ5MxDkc") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_wLeD9FXi6rIexTH") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_3NKYFuS2LltbExP") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_2BwIHqqbyvvBvqQ") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2QSV5qBnPFxCCCg") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3qJV14SQCCiQPYe") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3Po6PE4gjiarHQv") PreRMARoleAreaMiddle=7.
IF (ResponseId="R_2aKncD6eUXJfl3N") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_9S0GSIj9QmspL45") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3EFIL41rM6zWIKh") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_1dzcS6AzbcPzhnd") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_237VSETBVUGcz2T") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_SP3fcyxcsL4pKpj") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_8vHgzttcX7KWUj7") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_9zv8xBIaaKvpedH") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_27jHZCSquzsGQj3") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2aOxEuTch8jIFYk") PreRMARoleAreaMiddle=9.
IF (ResponseId="R_3n89wyMNHW7ZYjt") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3ir8xN7mXMFrZqA") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_3GycKrtsaM0YfYl") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3jTYRSllec1uttB") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_dncG6tNli6DeiRj") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_1LhC28RKl2r39zP") PreRMARoleAreaMiddle=9.
IF (ResponseId="R_1QzjAPjqKaHHPvE") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_10GVqP9Vf2AMxQp") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_26mv2MQNMcrDdCt") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2Cpk1LXJpckeqaO") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_b8VH6BPYHQ1ZzmF") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3irOtFIvhY9cBEM") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_42QdEnVkC5Zx1QJ") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3nufH5a7K0Yjd4c") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_2tDMpYOptRygR6u") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_2Xd1W2vlMgUecCO") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_XjLf9ufa1ulzLVL") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2vYdPj5U8xVIgxH") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_1Oy4Ve0FzQ7Ntld") PreRMARoleAreaMiddle=7.
IF (ResponseId="R_3pf2GgSIBL037o3") PreRMARoleAreaMiddle=20.
IF (ResponseId="R_1TCvrGYDwDpZacp") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_1mqGSMYd8yrI9ke") PreRMARoleAreaMiddle=20.
IF (ResponseId="R_PLsF6uviJMOwP17") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_e2QBxBmOTKhrKiB") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_bI7NDB8vYFk8ADf") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_RPRmWt5LGSvDT2x") PreRMARoleAreaMiddle=4.
IF (ResponseId="R_3D2zZUSxCobf4h3") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3oGVkVM6DyQJwhV") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_CeQ08w2eTWROhsB") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2Phgb2mhtZsMSwC") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_u4k3zvyKujahAUp") PreRMARoleAreaMiddle=13.
IF (ResponseId="R_AMzdMasyOreMl2x") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_3O33fV1HjZKRHJf") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2fJyME84ynObHtB") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_1QGkIb7lNjSmcxL") PreRMARoleAreaMiddle=10.
IF (ResponseId="R_1LaGmgMRny1AzBf") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_2wbrfireJxDZbSy") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_eVdLf5x0KbhZVu1") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_3hA7WPG352X4IHG") PreRMARoleAreaMiddle=11.
IF (ResponseId="R_3p3xWTucENQBZnF") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_3kncGD3niEKpE37") PreRMARoleAreaMiddle=6.
EXECUTE.

* *** Backcoding from PreRMARoleDetailsOldest - SK.
IF (ResponseId="R_3NVdPyn1VJsMGLY") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3qI6lGFnqqRX708") PreRMARoleAreaOldest=16.
IF (ResponseId="R_1qfgHXb8Luq7jxd") PreRMARoleAreaOldest=11.
IF (ResponseId="R_2zOnSKtJGusJLbA") PreRMARoleAreaOldest=16.
IF (ResponseId="R_Dl8nUCYXhFihqs9") PreRMARoleAreaOldest=7.
IF (ResponseId="R_vObAu147CuWrCMN") PreRMARoleAreaOldest=15.
IF (ResponseId="R_1HnKkVGjPfKuh1L") PreRMARoleAreaOldest=13.
IF (ResponseId="R_1rpIzIbanQ7YoVc") PreRMARoleAreaOldest=4.
IF (ResponseId="R_2AFhXeSwSLRDhno") PreRMARoleAreaOldest=7.
IF (ResponseId="R_3paU0ZJeTDIyIwy") PreRMARoleAreaOldest=9.
IF (ResponseId="R_VWk6O3hVlgBROWR") PreRMARoleAreaOldest=10.
IF (ResponseId="R_2RUJ25aRO8sKhEo") PreRMARoleAreaOldest=15.
IF (ResponseId="R_3fk0Uq37u62EMV9") PreRMARoleAreaOldest=15.
IF (ResponseId="R_etea5RXE8Nceznz") PreRMARoleAreaOldest=10.
IF (ResponseId="R_2cB2xJaqS7PsD1L") PreRMARoleAreaOldest=13.
IF (ResponseId="R_1PcqOTv8IOyrV64") PreRMARoleAreaOldest=11.
IF (ResponseId="R_DIFPlja8Jq7MeCl") PreRMARoleAreaOldest=18.
IF (ResponseId="R_3HjKJdnDccJsJoX") PreRMARoleAreaOldest=17.
IF (ResponseId="R_ZE0BCMnVrPJ9SxP") PreRMARoleAreaOldest=16.
IF (ResponseId="R_2sbzp2wE4n2inq0") PreRMARoleAreaOldest=18.
IF (ResponseId="R_2fjTut2s8vIYIgY") PreRMARoleAreaOldest=10.
IF (ResponseId="R_1dAFgbFqjNw5CGR") PreRMARoleAreaOldest=7.
IF (ResponseId="R_PG0HqGUBoP7qdDb") PreRMARoleAreaOldest=9.
IF (ResponseId="R_2TIa3YfVSiSsVei") PreRMARoleAreaOldest=11.
IF (ResponseId="R_2tFnXGGJMIOUeLb") PreRMARoleAreaOldest=18.
IF (ResponseId="R_2v9bsSWiMKGzWxS") PreRMARoleAreaOldest=13.
IF (ResponseId="R_1ghcaUJJbn68VHm") PreRMARoleAreaOldest=10.
IF (ResponseId="R_2q1WWVuCw8SgHmd") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3qfmEMqZqqyzcss") PreRMARoleAreaOldest=13.
IF (ResponseId="R_5heOjSYDgQWI2lj") PreRMARoleAreaOldest=17.
IF (ResponseId="R_10vbXAbNz0wiPfx") PreRMARoleAreaOldest=16.
IF (ResponseId="R_1kZz7YHpvRzflF0") PreRMARoleAreaOldest=13.
IF (ResponseId="R_217KfswaNtfBU5A") PreRMARoleAreaOldest=16.
IF (ResponseId="R_1lhh7OaAj3gsJf6") PreRMARoleAreaOldest=18.
IF (ResponseId="R_C1bZjh2E1eRkOel") PreRMARoleAreaOldest=16.
IF (ResponseId="R_b1JAX3Skssc0yI1") PreRMARoleAreaOldest=10.
IF (ResponseId="R_2BwIHqqbyvvBvqQ") PreRMARoleAreaOldest=16.
IF (ResponseId="R_2tokcXkfh8nRMWB") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3oKNpScXzrIwCbj") PreRMARoleAreaOldest=13.
IF (ResponseId="R_3EFIL41rM6zWIKh") PreRMARoleAreaOldest=13.
IF (ResponseId="R_2zzEClSO2veTnIg") PreRMARoleAreaOldest=7.
IF (ResponseId="R_ApaiXusMHk2RSIV") PreRMARoleAreaOldest=18.
IF (ResponseId="R_2ROJtPpBii4TzLy") PreRMARoleAreaOldest=13.
IF (ResponseId="R_3n89wyMNHW7ZYjt") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3PoboPNgC2iPEZO") PreRMARoleAreaOldest=11.
IF (ResponseId="R_O2n02BxC6cT7Bvz") PreRMARoleAreaOldest=7.
IF (ResponseId="R_3ir8xN7mXMFrZqA") PreRMARoleAreaOldest=13.
IF (ResponseId="R_dncG6tNli6DeiRj") PreRMARoleAreaOldest=15.
IF (ResponseId="R_21ukLoc1D8bXDTN") PreRMARoleAreaOldest=16.
IF (ResponseId="R_1QzjAPjqKaHHPvE") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3EoOIhHlW8wsfLL") PreRMARoleAreaOldest=13.
IF (ResponseId="R_26mv2MQNMcrDdCt") PreRMARoleAreaOldest=17.
IF (ResponseId="R_2rBje45dGzN8Sew") PreRMARoleAreaOldest=10.
IF (ResponseId="R_20ZPN46QFtpqMMJ") PreRMARoleAreaOldest=16.
IF (ResponseId="R_2Qht5vny471hMgN") PreRMARoleAreaOldest=1.
IF (ResponseId="R_1QsbWag6k5q3xss") PreRMARoleAreaOldest=18.
IF (ResponseId="R_2CrF0D8uxz3nJg9") PreRMARoleAreaOldest=7.
IF (ResponseId="R_PLsF6uviJMOwP17") PreRMARoleAreaOldest=16.
IF (ResponseId="R_BFUNUklykzTNStb") PreRMARoleAreaOldest=7.
IF (ResponseId="R_PtEUbSqAdcV74Cl") PreRMARoleAreaOldest=8.
IF (ResponseId="R_3oGVkVM6DyQJwhV") PreRMARoleAreaOldest=16.
IF (ResponseId="R_CeQ08w2eTWROhsB") PreRMARoleAreaOldest=16.
IF (ResponseId="R_2Phgb2mhtZsMSwC") PreRMARoleAreaOldest=10.
IF (ResponseId="R_1QGkIb7lNjSmcxL") PreRMARoleAreaOldest=16.
IF (ResponseId="R_2SrwGNygBfnwoUc") PreRMARoleAreaOldest=11.
EXECUTE.

* *** Backcoding from PrevJobDet - SK.  Note that some of these might supersede individual responses above.
IF (ResponseId="R_DGdw0Xsyo8vO9ZD") PreRMARoleAreaRecent=15.
IF (ResponseId="R_1ocowEGGnw6WS17") PreRMARoleAreaRecent=11.
IF (ResponseId="R_2xWbOUDcs23xWdA") PreRMARoleAreaRecent=16.
IF (ResponseId="R_21pkObWzrpvfARc") PreRMARoleAreaRecent=11.
IF (ResponseId="R_3IaxH5Zo9bkt2Yg") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1rBmpKpxSz0KqqK") PreRMARoleAreaRecent=17.
IF (ResponseId="R_0eWOuLP4vaJQpyx") PreRMARoleAreaRecent=16.
IF (ResponseId="R_3qsuyTff3HjaCmb") PreRMARoleAreaRecent=16.
IF (ResponseId="R_pJJmbgjAoJJnprb") PreRMARoleAreaRecent=16.
IF (ResponseId="R_32PeBWKva0RgpG4") PreRMARoleAreaRecent=9.
IF (ResponseId="R_3Ljs62FGuuQWqPV") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2cuR8uLHRfJZ7JT") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2PwhAxX3NxrrDmS") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1I5IY88k958oxjV") PreRMARoleAreaRecent=19.
IF (ResponseId="R_2ZOZ6wNfae6qpYJ") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2q4zY0ETW9JETvP") PreRMARoleAreaRecent=9.
IF (ResponseId="R_DCwfT0jsV3aTPEJ") PreRMARoleAreaRecent=9.
IF (ResponseId="R_1o5s7D0cvPTPTtF") PreRMARoleAreaRecent=16.
IF (ResponseId="R_7O6eJj89Q89k7g5") PreRMARoleAreaRecent=9.
IF (ResponseId="R_paf30yu0ndXUL2F") PreRMARoleAreaRecent=17.
IF (ResponseId="R_qXcmhjUF9tGPmsF") PreRMARoleAreaRecent=15.
IF (ResponseId="R_1MQgouDArweuZQR") PreRMARoleAreaRecent=15.
IF (ResponseId="R_2R3na5Caqg4b32u") PreRMARoleAreaRecent=1.
IF (ResponseId="R_12S8x2VYaRu58RR") PreRMARoleAreaRecent=20.
IF (ResponseId="R_1feBCqX6QnjfzJT") PreRMARoleAreaRecent=12.
IF (ResponseId="R_2TpBVkZr4U7Bzoj") PreRMARoleAreaRecent=16.
IF (ResponseId="R_D66c81EeN69XZ5f") PreRMARoleAreaRecent=7.
IF (ResponseId="R_1GKzyoTqhTgOjlC") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2tchnU0EKlxDrQE") PreRMARoleAreaRecent=11.
IF (ResponseId="R_3Gm6rhTG91N4rDf") PreRMARoleAreaRecent=10.
IF (ResponseId="R_1jVq3PnGTVqgzj7") PreRMARoleAreaRecent=7.
IF (ResponseId="R_2nJ0qiuJ4bC3JCx") PreRMARoleAreaRecent=3.
IF (ResponseId="R_2rjQORzohn0jaqZ") PreRMARoleAreaRecent=16.
IF (ResponseId="R_tFkW9CPBGxSXag1") PreRMARoleAreaRecent=19.
IF (ResponseId="R_2qwO1ST9fc86VZP") PreRMARoleAreaRecent=12.
IF (ResponseId="R_2qxsU0ymP0JbHGD") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1CC1npH8mLrRnsg") PreRMARoleAreaRecent=12.
IF (ResponseId="R_YPlbztn9MyC8ck9") PreRMARoleAreaRecent=16.
IF (ResponseId="R_21ALc3WSUdyGGMq") PreRMARoleAreaRecent=3.
IF (ResponseId="R_27HZ60nT80ayCDt") PreRMARoleAreaRecent=19.
IF (ResponseId="R_1dMhBLttqCSnGyo") PreRMARoleAreaRecent=18.
IF (ResponseId="R_e9BjHcgAYawMfVD") PreRMARoleAreaRecent=3.
IF (ResponseId="R_2fwi5V3K290uSmU") PreRMARoleAreaRecent=10.
IF (ResponseId="R_1QFowXNMhoqUeH1") PreRMARoleAreaRecent=16.
IF (ResponseId="R_24CdujaOyvoEVZ8") PreRMARoleAreaRecent=19.
IF (ResponseId="R_2axXhAiOznn1Koc") PreRMARoleAreaRecent=16.
IF (ResponseId="R_9pEHdxsvtLFnndT") PreRMARoleAreaRecent=13.
IF (ResponseId="R_2B9BketGf8GGN2x") PreRMARoleAreaRecent=16.
IF (ResponseId="R_pflzVp3JPINSAEh") PreRMARoleAreaRecent=19.
IF (ResponseId="R_1n2dDzfQ0zmYPdB") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2RVa4vUIU1s72uo") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2QX4sHMC38jwE76") PreRMARoleAreaRecent=1.
IF (ResponseId="R_a90jIQ7kKMHaCFb") PreRMARoleAreaRecent=19.
IF (ResponseId="R_1NsIVc3Qr0ldhzQ") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1l0tXfxv5r7Cicc") PreRMARoleAreaRecent=16.
IF (ResponseId="R_TpFFl9nXl9fnjCp") PreRMARoleAreaRecent=20.
IF (ResponseId="R_Xh2X6BbQqT1po8V") PreRMARoleAreaRecent=17.
IF (ResponseId="R_1mXJtEMh53aZAQV") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2CZcMh3GjVDrFjI") PreRMARoleAreaRecent=13.
IF (ResponseId="R_3j0rurX6XcH60H5") PreRMARoleAreaRecent=10.
IF (ResponseId="R_1k0KNnvF0eNnOSq") PreRMARoleAreaRecent=16.
IF (ResponseId="R_XjQJtqEMrcR0izv") PreRMARoleAreaRecent=16.
IF (ResponseId="R_6mNaKI8KcqUgbXX") PreRMARoleAreaRecent=19.
IF (ResponseId="R_1Oxx0p1ADTge3uk") PreRMARoleAreaRecent=16.
IF (ResponseId="R_1FFChoOfcAf3beh") PreRMARoleAreaRecent=15.
IF (ResponseId="R_11ciM00r4Uyc3vH") PreRMARoleAreaRecent=21.
IF (ResponseId="R_26goGsS0HzV4NHk") PreRMARoleAreaRecent=16.
IF (ResponseId="R_2xWbOUDcs23xWdA") PreRMARoleAreaMiddle=15.
IF (ResponseId="R_3IaxH5Zo9bkt2Yg") PreRMARoleAreaMiddle=17.
IF (ResponseId="R_0eWOuLP4vaJQpyx") PreRMARoleAreaMiddle=16.
IF (ResponseId="R_12S8x2VYaRu58RR") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_1dMhBLttqCSnGyo") PreRMARoleAreaMiddle=18.
IF (ResponseId="R_1ocowEGGnw6WS17") PreRMARoleAreaOldest=15.
IF (ResponseId="R_2xWbOUDcs23xWdA") PreRMARoleAreaOldest=15.
IF (ResponseId="R_3IaxH5Zo9bkt2Yg") PreRMARoleAreaOldest=17.
IF (ResponseId="R_0eWOuLP4vaJQpyx") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3qsuyTff3HjaCmb") PreRMARoleAreaOldest=16.
IF (ResponseId="R_2PwhAxX3NxrrDmS") PreRMARoleAreaOldest=11.
IF (ResponseId="R_paf30yu0ndXUL2F") PreRMARoleAreaOldest=7.
IF (ResponseId="R_12S8x2VYaRu58RR") PreRMARoleAreaOldest=11.
IF (ResponseId="R_1feBCqX6QnjfzJT") PreRMARoleAreaOldest=17.
IF (ResponseId="R_D66c81EeN69XZ5f") PreRMARoleAreaOldest=1.
IF (ResponseId="R_1dMhBLttqCSnGyo") PreRMARoleAreaOldest=10.
IF (ResponseId="R_2fwi5V3K290uSmU") PreRMARoleAreaOldest=15.
IF (ResponseId="R_2axXhAiOznn1Koc") PreRMARoleAreaOldest=16.
IF (ResponseId="R_1n2dDzfQ0zmYPdB") PreRMARoleAreaOldest=16.
IF (ResponseId="R_1mXJtEMh53aZAQV") PreRMARoleAreaOldest=16.
IF (ResponseId="R_3j0rurX6XcH60H5") PreRMARoleAreaOldest=20.
IF (ResponseId="R_11ciM00r4Uyc3vH") PreRMARoleAreaOldest=18.
IF (ResponseId="R_26goGsS0HzV4NHk") PreRMARoleAreaOldest=9.
EXECUTE.    

* *** Anonymising PreRMARoleDetails - CO.
IF (ResponseId="R_XoeES5Lz2HRTKLv") PreRMARoleDetails=CONCAT("most recent: I taught freshman writing at XXXX, in a postdoc position.  longest ago: I provided a mi",
"x of lab management, work as a teaching assistant, proposal development support, and execution/management of funded research.").
IF (ResponseId="R_3g7qvu9akPQXsS6") PreRMARoleDetails=CONCAT("I was a professor of biomedical engineering at XXXX University, then a research scientist and progra",
"m manager at XXXX Pharmaceuticals, then an equity research analyst at a hedge fund / biotech investment firm prior to moving into my current RMA role.").
IF (ResponseId="R_1QopVY5Iuk6gLPV") PreRMARoleDetails="I am working as Research Officer in Ministry of XXXX, Malaysia".
IF (ResponseId="R_1FaibUVDJVHQUXj") PreRMARoleDetails=CONCAT("I worked 2 years in an academic department, supporting the professors and department head, including",
" assisting in proposal development.  The Director of the Sponsored Programs Administration office contacted me and asked if I was interested in working in Research Administration?  I was interviewed t",
"hat afternoon and was offered Research Administrator position that afternoon 2005-2011.  I never looked back.  I moved to a research Center in August 2011 and supported that center in developing propo",
"sals and managing the awards for the Center.  During my time in this center, I started assisting another Research Center located in XXXX, MS.  I continue to support two remote Research Centers for our",
" university, one is located in XXXX and the other is still in XXXX.").
IF (ResponseId="R_1ODK8yo4TlG7xDg") PreRMARoleDetails=CONCAT("5 years at XXXX College in academic department administration (Office Manager/Budget Manager). 1 yea",
"r at XXXX in academic department administration (Office Manager). 2.5 years at XXXX in academic department administration (Administrative Assistant).").
IF (ResponseId="R_2aQ5YCASVXk1lEM") PreRMARoleDetails=CONCAT("From XXXX, Researcher at the University of XXXX, working in Egypt and Vietnam.   From XXXX Biodivers",
"ity coordinator at the XXXX Nature Center of the Province of XXXX (participatory policy formulation and implementation in Nature Conservation; Coordination Citizen Science project for animal/plant dis",
"tribution; Sustainable education)").
IF (ResponseId="R_UEB7QzSpE8FRECR") PreRMARoleDetails="I worked for the National XXXX Association as a Divisions Services Coordinator prior to my current employmer".
EXECUTE.

* *** Q34 Career Plan.
VARIABLE LABELS CareerPlan "34. Career planned before being an RMA".
* *** now shorten the pick lists to aid output.
VALUE LABELS CareerPlan
      1 "1. Agriculture"
      2 "2. Mining"
      3 "3. Manufacturing"
      4 "4. Electricity"
      5 "5. Water supply"
      6 "6. Construction"
      7 "7. Retail"
      8 "8. Transportation"
      9 "9. Accommodation"
      10 "10. Information"
      11 "11. Financial"
      12 "12. Real estate"
      13 "13. Scientific"
      14 "14. Administration"
      15 "15. Public administration"
      16 "16. Education"
      17 "17. Health"
      18 "18. Arts"
      19 "19. Other services" 
      20 "20. Homeworking"
      21 "21. Overseas"
      99 "No plan".
MISSING VALUES CareerPlan (-99).
ADD VALUE LABELS CareerPlan -99 "No Response".
VARIABLE LEVEL CareerPlan (NOMINAL).
EXECUTE.

* *** Q34a details.
VARIABLE LABELS CareerPlanDet "34a. Details of career planned before being an RMA".
MISSING VALUES CareerPlanDet ("").
VALUE LABELS CareerPlanDet "" "No Response".
VARIABLE LEVEL CareerPlanDet (NOMINAL).
EXECUTE.

* *** CareerPlanDet anonymising - SK.
IF (ResponseId="R_1LdhGq94g21KaPE") CareerPlanDet="I was an employee of the Massachusetts State XXXX, and I intended to continue to work in politics and government in some capacity, prior to becoming a research administrator.".
EXECUTE.

* *** backcoding from CurrentEmploymentTD - in three chunks --> FirstEmploymentType, CurrentEmploymentType and CareerPlan - SK.
IF (ResponseId="R_XCam2lxqXIKwybv") FirstEmploymentType=2.
IF (ResponseId="R_263zbwxFEOIKa1V") FirstEmploymentType=1.
IF (ResponseId="R_2aKMWwqL5R7pqW3") FirstEmploymentType=2.
IF (ResponseId="R_1QGw9hB3FSnoNSH") FirstEmploymentType=2.
IF (ResponseId="R_1Sbze3aJDnoMXBL") FirstEmploymentType=2.
IF (ResponseId="R_3dSq9RmeZWzBYNU") FirstEmploymentType=1.
IF (ResponseId="R_3Kp9A4bV4RSZcll") FirstEmploymentType=2.
IF (ResponseId="R_3mejsAXBXOVnxX9") FirstEmploymentType=2.
IF (ResponseId="R_2pJGdvK3bbDil9H") FirstEmploymentType=1.
IF (ResponseId="R_DISYJr8qtHhrAbv") FirstEmploymentType=2.

IF (ResponseId="R_2QmJYirdD1hdVi2") CurrentEmploymentType=2.
IF (ResponseId="R_1k0NfstcLl36mo4") CurrentEmploymentType=1.
IF (ResponseId="R_3PpJZnB9hjFuu1q") CurrentEmploymentType=2.
IF (ResponseId="R_1BPk3bbrSjjhG0O") CurrentEmploymentType=1.
IF (ResponseId="R_W7Lqt7k1h6dhR9D") CurrentEmploymentType=2.
IF (ResponseId="R_XCam2lxqXIKwybv") CurrentEmploymentType=1.
IF (ResponseId="R_1PcqOTv8IOyrV64") CurrentEmploymentType=1.
IF (ResponseId="R_uh2Kn1WtoHbLq6Z") CurrentEmploymentType=2.
IF (ResponseId="R_263zbwxFEOIKa1V") CurrentEmploymentType=1.
IF (ResponseId="R_2qmlwzXMSCuKi5d") CurrentEmploymentType=1.
IF (ResponseId="R_2tKdV9KrCjm7lNs") CurrentEmploymentType=2.
IF (ResponseId="R_1giqLH2DJtmxWB2") CurrentEmploymentType=2.
IF (ResponseId="R_1ewuX7VyCblwxBI") CurrentEmploymentType=2.
IF (ResponseId="R_1QGw9hB3FSnoNSH") CurrentEmploymentType=2.
IF (ResponseId="R_1Sbze3aJDnoMXBL") CurrentEmploymentType=1.
IF (ResponseId="R_3dSq9RmeZWzBYNU") CurrentEmploymentType=2.
IF (ResponseId="R_3Kp9A4bV4RSZcll") CurrentEmploymentType=1.
IF (ResponseId="R_25F5zLXXxnOtaV0") CurrentEmploymentType=2.
IF (ResponseId="R_ZKJflKzKZG0T44x") CurrentEmploymentType=3.
IF (ResponseId="R_2rj8ldrauMQu8mg") CurrentEmploymentType=2.
IF (ResponseId="R_3qDlUdDlW2M9Za8") CurrentEmploymentType=1.
IF (ResponseId="R_33rGKffN1fnnpHE") CurrentEmploymentType=2.
IF (ResponseId="R_30ovYDAQVLneC2X") CurrentEmploymentType=2.
IF (ResponseId="R_2Se7cNW8QP9c5mA") CurrentEmploymentType=1.
IF (ResponseId="R_32Ld70W5i3w8Z30") CurrentEmploymentType=2.
IF (ResponseId="R_00uMLrzodaYIYSd") CurrentEmploymentType=1.
IF (ResponseId="R_2YmELMKI0MriITl") CurrentEmploymentType=1.
IF (ResponseId="R_3PT432I1zjDMfuF") CurrentEmploymentType=4.
IF (ResponseId="R_2CWn1RMn68d0ggK") CurrentEmploymentType=2.

IF (ResponseId="R_2uHEp1xP3YHqEWV") CareerPlan=13.
IF (ResponseId="R_xgYR7YIdpu1YX9D") CareerPlan=13.
IF (ResponseId="R_2tr9BzdT5psVfzz") CareerPlan=13.
IF (ResponseId="R_2Qm4AWDBP855uls") CareerPlan=19.
IF (ResponseId="R_3EExS11Vb7xLFkq") CareerPlan=13.
IF (ResponseId="R_3MMThCBMt4v0A7E") CareerPlan=99.
IF (ResponseId="R_3fuSvw6Vq4T8Ik3") CareerPlan=99.
IF (ResponseId="R_2TBnDbFKdMA2Ft0") CareerPlan=16.
IF (ResponseId="R_1lgI9ZXTq1ZA6ZE") CareerPlan=11.
IF (ResponseId="R_3RgXrIuEP6dGN2V") CareerPlan=99.
IF (ResponseId="R_DT8h92mrUsArOdr") CareerPlan=99.
IF (ResponseId="R_vjL1mH0XdWwg1Xz") CareerPlan=19.
IF (ResponseId="R_1JPFabJYJIRKnG7") CareerPlan=99.
IF (ResponseId="R_2rIa6fENVbhXJzL") CareerPlan=15.
IF (ResponseId="R_UYkaiy0ZcY5fXfb") CareerPlan=16.
IF (ResponseId="R_1OqtZxXbrNCAeXI") CareerPlan=15.
IF (ResponseId="R_5heOjSYDgQWI2lj") CareerPlan=13.
IF (ResponseId="R_2R2nXhJ6K5t09qM") CareerPlan=10.
IF (ResponseId="R_3L7r0xqivwSiytG") CareerPlan=19.
IF (ResponseId="R_1Ckc08EdBZYhhkm") CareerPlan=13.
IF (ResponseId="R_3qebOVt7Zk1bhCX") CareerPlan=13.
IF (ResponseId="R_2uyZyh3iOHYkiRb") CareerPlan=99.
IF (ResponseId="R_8vHgzttcX7KWUj7") CareerPlan=16.
IF (ResponseId="R_O6v264wDouQ0pW1") CareerPlan=99.
IF (ResponseId="R_30rgZB64eSYOgOJ") CareerPlan=99.
IF (ResponseId="R_306JC6S8l1osy7A") CareerPlan=15.
IF (ResponseId="R_PAmvnHJJUYDjx8B") CareerPlan=19.
IF (ResponseId="R_25GTjIh7GEMScAV") CareerPlan=16.
IF (ResponseId="R_2VvGqQbVu363AHI") CareerPlan=11.
IF (ResponseId="R_3C7r7LSQ2oZDjcB") CareerPlan=16.
IF (ResponseId="R_5hH5hT5emKKIr3b") CareerPlan=99.
IF (ResponseId="R_2tmzDPoZpocaAD9") CareerPlan=13.
IF (ResponseId="R_1FmMP2Q9sjgeKQe") CareerPlan=13.
EXECUTE.

* *** More backcoding from CareerPlanDet (where they picked 99 no plan, but then told us what it was!).
IF (ResponseId="R_3qeXq918o2qlD6g") CareerPlan=18.
IF (ResponseId="R_0vmcqonbhTBpAHf") CareerPlan=13.
IF (ResponseId="R_1mQrgFe2kOblUlP") CareerPlan=16.
IF (ResponseId="R_1Fb2KEbfJC5K2Z9") CareerPlan=13.
IF (ResponseId="R_3IAKOgVhxeGflRv") CareerPlan=13.
IF (ResponseId="R_2rko8yfqr5vD8Xq") CareerPlan=21.
IF (ResponseId="R_DCwfT0jsV3aTPEJ") CareerPlan=11.
IF (ResponseId="R_3h6j5PSfNvunpaJ") CareerPlan=13.
IF (ResponseId="R_Wp9lI99DztsC3Kh") CareerPlan=11.
IF (ResponseId="R_232ZTb64uYQSqF7") CareerPlan=13.
IF (ResponseId="R_2bWyIZGtcVgCD9Z") CareerPlan=11.
IF (ResponseId="R_1f7de5Bhk1uMVj1") CareerPlan=13.
IF (ResponseId="R_3U80aPzZdvRJLJ7") CareerPlan=15.
IF (ResponseId="R_79Tsg5oV12l2SMV") CareerPlan=16.
IF (ResponseId="R_3KveEINHRTsTyzA") CareerPlan=13.
EXECUTE.

* *** Q35 Challenges
* *** RMAInitialChallenges_1.
RENAME VARIABLES RMAInitialChallenges_1=ChallengeNoNetwork.
VARIABLE LABELS ChallengeNoNetwork "35a. Challenge of No Network". /* trying to retain Q numbers.
VALUE LABELS ChallengeNoNetwork 1 "Yes" 0 "No".
MISSING VALUES ChallengeNoNetwork (-99).
ADD VALUE LABELS ChallengeNoNetwork -99 "No Response".
VARIABLE LEVEL ChallengeNoNetwork (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_2=ChallengeLackOfKnowledge.
VARIABLE LABELS ChallengeLackOfKnowledge "35b. Challenge of Lack of Knowledge". /* trying to retain Q numbers.
VALUE LABELS ChallengeLackOfKnowledge 1 "Yes" 0 "No".
MISSING VALUES ChallengeLackOfKnowledge (-99).
ADD VALUE LABELS ChallengeLackOfKnowledge -99 "No Response".
VARIABLE LEVEL ChallengeLackOfKnowledge (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_3=ChallengeLackOfTraining.
VARIABLE LABELS ChallengeLackOfTraining "35c. Challenge of Lack of Training". /* trying to retain Q numbers.
VALUE LABELS ChallengeLackOfTraining 1 "Yes" 0 "No".
MISSING VALUES ChallengeLackOfTraining (-99).
ADD VALUE LABELS ChallengeLackOfTraining -99 "No Response".
VARIABLE LEVEL ChallengeLackOfTraining (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_4=ChallengeCulture.
VARIABLE LABELS ChallengeCulture "35d. Challenge of Understanding Culture". /* trying to retain Q numbers.
VALUE LABELS ChallengeCulture 1 "Yes" 0 "No".
MISSING VALUES ChallengeCulture (-99).
ADD VALUE LABELS ChallengeCulture -99 "No Response".
VARIABLE LEVEL ChallengeCulture (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_5=ChallengeNewProfession.
VARIABLE LABELS ChallengeNewProfession "35e. Challenge of New Profession". /* trying to retain Q numbers.
VALUE LABELS ChallengeNewProfession 1 "Yes" 0 "No".
MISSING VALUES ChallengeNewProfession (-99).
ADD VALUE LABELS ChallengeNewProfession -99 "No Response".
VARIABLE LEVEL ChallengeNewProfession (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_6=ChallengeRecognition.
VARIABLE LABELS ChallengeRecognition "35f. Challenge of Professional Recognition". /* trying to retain Q numbers.
VALUE LABELS ChallengeRecognition 1 "Yes" 0 "No".
MISSING VALUES ChallengeRecognition (-99).
ADD VALUE LABELS ChallengeRecognition -99 "No Response".
VARIABLE LEVEL ChallengeRecognition (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_7=ChallengePermanent.
VARIABLE LABELS ChallengePermanent "35g. Challenge of No Permanent Position". /* trying to retain Q numbers.
VALUE LABELS ChallengePermanent 1 "Yes" 0 "No".
MISSING VALUES ChallengePermanent (-99).
ADD VALUE LABELS ChallengePermanent -99 "No Response".
VARIABLE LEVEL ChallengePermanent (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_8=ChallengeCareer.
VARIABLE LABELS ChallengeCareer "35h. Challenge of Unclear Career Framework". /* trying to retain Q numbers.
VALUE LABELS ChallengeCareer 1 "Yes" 0 "No".
MISSING VALUES ChallengeCareer (-99).
ADD VALUE LABELS ChallengeCareer -99 "No Response".
VARIABLE LEVEL ChallengeCareer (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_9=ChallengePolicy.
VARIABLE LABELS ChallengePolicy "35i. Challenge of Lack of Institutional Policies". /* trying to retain Q numbers.
VALUE LABELS ChallengePolicy 1 "Yes" 0 "No".
MISSING VALUES ChallengePolicy (-99).
ADD VALUE LABELS ChallengePolicy -99 "No Response".
VARIABLE LEVEL ChallengePolicy (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_88=ChallengeOther.
VARIABLE LABELS ChallengeOther "35j. Challenge of Other type". /* trying to retain Q numbers.
VALUE LABELS ChallengeOther 1 "Yes" 0 "No".
MISSING VALUES ChallengeOther (-99).
ADD VALUE LABELS ChallengeOther -99 "No Response".
VARIABLE LEVEL ChallengeOther (NOMINAL).
EXECUTE.

RENAME VARIABLES RMAInitialChallenges_77=ChallengeNone.
VARIABLE LABELS ChallengeNone "35x. Challenges - None". /* trying to retain Q numbers.
VALUE LABELS ChallengeNone 1 "Yes" 0 "No".
MISSING VALUES ChallengeNone (-99).
ADD VALUE LABELS ChallengeNone -99 "No Response".
VARIABLE LEVEL ChallengeNone (NOMINAL).
EXECUTE.

* *** Q35a details.
RENAME VARIABLES RMAInitialChallenges_88_TEXT=ChallengeOtherDet.
VARIABLE LABELS ChallengeOtherDet "35. Details of Other Challenges".
MISSING VALUES ChallengeOtherDet ("").
VALUE LABELS ChallengeOtherDet "" "No Response".
VARIABLE LEVEL ChallengeOtherDet (NOMINAL).
EXECUTE.

* *** anonymising ChallengeOtherDet - SK.
IF (ResponseId="R_0vmcqonbhTBpAHf") ChallengeOtherDet="I worked at XXXX and had to learn early on to cultivate a professional network. The institution offered some of the best training, I've had. Yet, and unclear career track. That came much later.".
IF (ResponseId="R_30iuujLG8Xj0vyu") ChallengeOtherDet=CONCAT("I could only get an entry level position because I had no direct experience, so the financial compen",
"sation was challenging. My postdoctoral position at the XXXX paid 50% more than my current RA position.").
IF (ResponseId="R_2CH8MUawoezxvXy") ChallengeOtherDet=CONCAT("Poor institutional regard for, and understanding of, the necessity for quality assurance/curation of",
" research repository data/metadata, and the need to staff and adequately fund resources to allow for these research administration processes to occur.  This leads to a very limited choice of career op",
"tions in my institution, where I would have much more choice at any other Australian institution.  Unfortunately mine is the only research university in XXXX, so options to work elsewhere are almost e",
"ntirely absent.").
EXECUTE.

* *** backcoding from ChallengeOtherDet - SK - lead by MF.
IF (ResponseId="R_DHk8dCmz516eoLv") ChallengeCareer=1.
IF (ResponseId="R_Wvq1MReCP24u6Y1") ChallengeCareer=1.
IF (ResponseId="R_3e5qBucAMgXqumU") ChallengeCareer=1.
IF (ResponseId="R_3rMOkFWtwxJNRhh") ChallengeCareer=1.
IF (ResponseId="R_BrZY84RSuvIEULf") ChallengePolicy=1.
EXECUTE.

RECODE ChallengeNoNetwork ChallengeLackOfKnowledge ChallengeLackOfTraining ChallengeCulture ChallengeNewProfession ChallengeRecognition
    ChallengePermanent ChallengeCareer ChallengePolicy ChallengeOther ChallengeNone (SYSMIS=0).
EXECUTE.
COMPUTE Challenge = ChallengeNoNetwork+ChallengeLackOfKnowledge+ChallengeLackOfTraining+ChallengeCulture+ChallengeNewProfession+ChallengeRecognition+
       ChallengePermanent+ChallengeCareer+ChallengePolicy+ChallengeOther+ChallengeNone.
DO IF (Challenge = 0).
    COMPUTE ChallengeNoNetwork=$SYSMIS.
    COMPUTE ChallengeLackOfKnowledge=$SYSMIS.
    COMPUTE ChallengeLackOfTraining=$SYSMIS.
    COMPUTE ChallengeCulture=$SYSMIS.
    COMPUTE ChallengeNewProfession=$SYSMIS.
    COMPUTE ChallengeRecognition=$SYSMIS.
    COMPUTE ChallengePermanent=$SYSMIS.
    COMPUTE ChallengeCareer=$SYSMIS.
    COMPUTE ChallengePolicy=$SYSMIS.
    COMPUTE ChallengeOther=$SYSMIS.
    COMPUTE ChallengeNone=$SYSMIS.
END IF.
EXECUTE.

* *** Q36 Skills.
* *** SkillsForRMAJob_1.
RENAME VARIABLES SkillsForRMAJob_1=SkillResearch.
VARIABLE LABELS SkillResearch "36a. Research Experience". /* trying to retain Q numbers.
VALUE LABELS SkillResearch 1 "Yes" 0 "No".
MISSING VALUES SkillResearch (-99).
ADD VALUE LABELS SkillResearch -99 "No Response".
VARIABLE LEVEL SkillResearch (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_2=SkillRMA.
VARIABLE LABELS SkillRMA "36b. RMA". /* trying to retain Q numbers.
VALUE LABELS SkillRMA 1 "Yes" 0 "No".
MISSING VALUES SkillRMA (-99).
ADD VALUE LABELS SkillRMA -99 "No Response".
VARIABLE LEVEL SkillRMA (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_3=SkillTraining.
VARIABLE LABELS SkillTraining "36c. Training/Certification". /* trying to retain Q numbers.
VALUE LABELS SkillTraining 1 "Yes" 0 "No".
MISSING VALUES SkillTraining (-99).
ADD VALUE LABELS SkillTraining -99 "No Response".
VARIABLE LEVEL SkillTraining (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_4=SkillMultitasking.
VARIABLE LABELS SkillMultitasking "36d. Multitasking". /* trying to retain Q numbers.
VALUE LABELS SkillMultitasking 1 "Yes" 0 "No".
MISSING VALUES SkillMultitasking (-99).
ADD VALUE LABELS SkillMultitasking -99 "No Response".
VARIABLE LEVEL SkillMultitasking (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_5=SkillDetail.
VARIABLE LABELS SkillDetail "36e. Attention to Detail". /* trying to retain Q numbers.
VALUE LABELS SkillDetail 1 "Yes" 0 "No".
MISSING VALUES SkillDetail (-99).
ADD VALUE LABELS SkillDetail -99 "No Response".
VARIABLE LEVEL SkillDetail (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_6=SkillOrganisational.
VARIABLE LABELS SkillOrganisational "36f. Organisational Skills". /* trying to retain Q numbers.
VALUE LABELS SkillOrganisational 1 "Yes" 0 "No".
MISSING VALUES SkillOrganisational (-99).
ADD VALUE LABELS SkillOrganisational -99 "No Response".
VARIABLE LEVEL SkillOrganisational (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_7=SkillResearchInterest.
VARIABLE LABELS SkillResearchInterest "36g. Interest in Research". /* trying to retain Q numbers.
VALUE LABELS SkillResearchInterest 1 "Yes" 0 "No".
MISSING VALUES SkillResearchInterest (-99).
ADD VALUE LABELS SkillResearchInterest -99 "No Response".
VARIABLE LEVEL SkillResearchInterest (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_8=SkillResearchOrgExp.
VARIABLE LABELS SkillResearchOrgExp "36h. Research Organisation Experience". /* trying to retain Q numbers.
VALUE LABELS SkillResearchOrgExp 1 "Yes" 0 "No".
MISSING VALUES SkillResearchOrgExp (-99).
ADD VALUE LABELS SkillResearchOrgExp -99 "No Response".
VARIABLE LEVEL SkillResearchOrgExp (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_9=SkillTeam.
VARIABLE LABELS SkillTeam "36i. Team Player". /* trying to retain Q numbers.
VALUE LABELS SkillTeam 1 "Yes" 0 "No".
MISSING VALUES SkillTeam (-99).
ADD VALUE LABELS SkillTeam -99 "No Response".
VARIABLE LEVEL SkillTeam (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_10=SkillData.
VARIABLE LABELS SkillData "36j. Data Interpretation". /* trying to retain Q numbers.
VALUE LABELS SkillData 1 "Yes" 0 "No".
MISSING VALUES SkillData (-99).
ADD VALUE LABELS SkillData -99 "No Response".
VARIABLE LEVEL SkillData (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_11=SkillComms.
VARIABLE LABELS SkillComms "36k. Communication Skills". /* trying to retain Q numbers.
VALUE LABELS SkillComms 1 "Yes" 0 "No".
MISSING VALUES SkillComms (-99).
ADD VALUE LABELS SkillComms -99 "No Response".
VARIABLE LEVEL SkillComms (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_12=SkillLearning.
VARIABLE LABELS SkillLearning "36l. Learning New Things". /* trying to retain Q numbers.
VALUE LABELS SkillLearning 1 "Yes" 0 "No".
MISSING VALUES SkillLearning (-99).
ADD VALUE LABELS SkillLearning -99 "No Response".
VARIABLE LEVEL SkillLearning (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_13=SkillInternational.
VARIABLE LABELS SkillInternational "36m. International Skills". /* trying to retain Q numbers.
VALUE LABELS SkillInternational 1 "Yes" 0 "No".
MISSING VALUES SkillInternational (-99).
ADD VALUE LABELS SkillInternational -99 "No Response".
VARIABLE LEVEL SkillInternational (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_14=SkillProblem.
VARIABLE LABELS SkillProblem "36n. Problem Solving". /* trying to retain Q numbers.
VALUE LABELS SkillProblem 1 "Yes" 0 "No".
MISSING VALUES SkillProblem (-99).
ADD VALUE LABELS SkillProblem -99 "No Response".
VARIABLE LEVEL SkillProblem (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_15=SkillIntegrity.
VARIABLE LABELS SkillIntegrity "36o. Integrity". /* trying to retain Q numbers.
VALUE LABELS SkillIntegrity 1 "Yes" 0 "No".
MISSING VALUES SkillIntegrity (-99).
ADD VALUE LABELS SkillIntegrity -99 "No Response".
VARIABLE LEVEL SkillIntegrity (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_16=SkillService.
VARIABLE LABELS SkillService "36p. Service Culture". /* trying to retain Q numbers.
VALUE LABELS SkillService 1 "Yes" 0 "No".
MISSING VALUES SkillService (-99).
ADD VALUE LABELS SkillService -99 "No Response".
VARIABLE LEVEL SkillService (NOMINAL).
EXECUTE.

RENAME VARIABLES SkillsForRMAJob_88=SkillOther.
VARIABLE LABELS SkillOther "36q. Other Skills". /* trying to retain Q numbers.
VALUE LABELS SkillOther 1 "Yes" 0 "No".
MISSING VALUES SkillOther (-99).
ADD VALUE LABELS SkillOther -99 "No Response".
VARIABLE LEVEL SkillOther (NOMINAL).
EXECUTE.

* *** Q36a details.
VARIABLE LABELS SkillsForRMAJobDet "36. Details of Other Skills".
MISSING VALUES SkillsForRMAJobDet ("").
VALUE LABELS SkillsForRMAJobDet "" "No Response".
VARIABLE LEVEL SkillsForRMAJobDet (NOMINAL).
EXECUTE.

* *** backcoding from SkillsForRMAJobDet --> separate skills - MD.
IF (ResponseId="R_Ze3MLsF2BnIUKhX") SkillRMA=1.
IF (ResponseId="R_Ze3MLsF2BnIUKhX") SkillTraining=1.
IF (ResponseId="R_vi8ib2omOU3POmZ") SkillRMA=1.
IF (ResponseId="R_1DV8NObhROXDKzO") SkillOther=1.
IF (ResponseId="R_1K0WHOg7esRP8Je") SkillOther=1.
IF (ResponseId="R_6mU0h464Zury1SV") SkillRMA=1.
IF (ResponseId="R_1BRC8Bifb1mlVfM") SkillRMA=1.
IF (ResponseId="R_1r67GmESTb9qE8o") SkillRMA=1.
IF (ResponseId="R_1F2LBqxhyel8W6j") SkillResearchOrgExp=1.
IF (ResponseId="R_1jTVoRUqgGOVe4J") SkillResearch=1.
IF (ResponseId="R_s7QMcDIbwc9Ojlf") SkillInternational=1.
IF (ResponseId="R_2S2ml5bnwgtVKre") SkillTraining=1.
IF (ResponseId="R_6qULFEYneEE6bF7") SkillOther=1.
IF (ResponseId="R_C77QGR9OcmfctxL") SkillRMA=1.
IF (ResponseId="R_1OoTGUz2YXeCtK1") SkillRMA=1.
IF (ResponseId="R_1LZ3ciVvcQM19r0") SkillRMA=1.
IF (ResponseId="R_3exiaXRhYpgdsYh") SkillRMA=1.
IF (ResponseId="R_3n0JPmwNJGEeL9I") SkillMultitasking=1.
IF (ResponseId="R_2Xdp0fOAWXdyR9v") SkillOther=1.
IF (ResponseId="R_sQXvKosXTKhFKH7") SkillRMA=1.
IF (ResponseId="R_7TZT0WfF8vkC4vL") SkillRMA=1.
IF (ResponseId="R_0qWjLbRGrqcytMJ") SkillRMA=1.
IF (ResponseId="R_3kHft1vSW2mVoTk") SkillRMA=1.
IF (ResponseId="R_3MRrIlKnOEinbGw") SkillRMA=1.
IF (ResponseId="R_3JfvTL98qVFxGZD") SkillOther=1.
IF (ResponseId="R_O0EkYPuLTkn9bCF") SkillRMA=1.
IF (ResponseId="R_3HB4SW98KFDLruz") SkillResearch=1.
IF (ResponseId="R_3HN9kMXYS9CLjpd") SkillRMA=1.
IF (ResponseId="R_3RpSrcXtacKIdES") SkillService=1.
IF (ResponseId="R_27QBC4GxIb8NblY") SkillOther=1.
IF (ResponseId="R_3oYOyHm2lBAwM1b") SkillRMA=1.
IF (ResponseId="R_28P5zeoC0gjDXEz") SkillRMA=1.
IF (ResponseId="R_22VqfgukfLbNcEy") SkillRMA=1.
IF (ResponseId="R_3p9lX1t9YPgY09M") SkillRMA=1.
IF (ResponseId="R_3gRcDORjF3UolVy") SkillRMA=1.
IF (ResponseId="R_vObAu147CuWrCMN") SkillComms=1.
IF (ResponseId="R_1QaBIwwFq6BtGtv") SkillOther=1.
IF (ResponseId="R_1n2zGXMBb6q9Hfd") SkillRMA=1.
IF (ResponseId="R_cHp16p8h0wclpXH") SkillRMA=1.
IF (ResponseId="R_2fCCyr60r0l1SVG") SkillRMA=1.
IF (ResponseId="R_tLjx8IIevtLt4hr") SkillRMA=1.
IF (ResponseId="R_2qf0JzvQMDBFaT4") SkillRMA=1.
IF (ResponseId="R_2s12T6vscPazVII") SkillRMA=1.
IF (ResponseId="R_pJJmbgjAoJJnprb") SkillRMA=1.
IF (ResponseId="R_333lmKg9zgpCQat") SkillIntegrity=1.
IF (ResponseId="R_24wkYFp025LmGRO") SkillData=1.
IF (ResponseId="R_1i9xXY5iFdZ8xIO") SkillRMA=1.
IF (ResponseId="R_296bdcR9SS1Xtno") SkillRMA=1.
IF (ResponseId="R_zef5ufhKDxgJoEF") SkillRMA=1.
IF (ResponseId="R_12F6oeiXglw0Zkj") SkillRMA=1.
IF (ResponseId="R_3IX0JMWhFjf2s0M") SkillRMA=1.
IF (ResponseId="R_2OZ0N04RvfBoK3Y") SkillRMA=1.
IF (ResponseId="R_24qMRcEQxsOsVTm") SkillRMA=1.
IF (ResponseId="R_1eY7EXhVStLmylu") SkillRMA=1.
IF (ResponseId="R_3oO3AyjvxSB0XIS") SkillRMA=1.
IF (ResponseId="R_3Je0m4SaGxcBFfC") SkillRMA=1.
IF (ResponseId="R_2aKzHg1eFkzRcFM") SkillOther=1.
IF (ResponseId="R_3CQ9jJV4T3XA972") SkillOther=1.
IF (ResponseId="R_s5K4qV5sVW63esF") SkillRMA=1.
IF (ResponseId="R_3nIx0SQStLVMM2Z") SkillRMA=1.
IF (ResponseId="R_56DIeQBIFiQGWzv") SkillRMA=1.
IF (ResponseId="R_22LAPG71bLb5rOd") SkillOther=1.
IF (ResponseId="R_31opFOfS2Vj6GQn") SkillRMA=1.
IF (ResponseId="R_2feBBwKOo6px2yP") SkillRMA=1.
IF (ResponseId="R_5iiHwPEuz1Vvkg9") SkillRMA=1.
IF (ResponseId="R_2cdVVA3WatGoePn") SkillResearchOrgExp=1.
IF (ResponseId="R_3KHhcr8JaITkyua") SkillRMA=1.
IF (ResponseId="R_2rONMq9T3mvmWV3") SkillResearch=1.
IF (ResponseId="R_39rcvtgFtcfVvzj") SkillRMA=1.
IF (ResponseId="R_3kh5SB0wY49e8as") SkillRMA=1.
IF (ResponseId="R_3gYPnP1GcPHlVBw") SkillRMA=1.
IF (ResponseId="R_2z75HDt7hxbaw7K") SkillLearning=1.
IF (ResponseId="R_etinYkMpppKzNGp") SkillRMA=1.
IF (ResponseId="R_qXcmhjUF9tGPmsF") SkillRMA=1.
IF (ResponseId="R_qJ9U8DcOqzsCwCd") SkillRMA=1.
IF (ResponseId="R_CmFZGeljTS501DH") SkillRMA=1.
IF (ResponseId="R_2dYYADCWDZLxKcQ") SkillRMA=1.
IF (ResponseId="R_2QSuol2xuD66GQa") SkillRMA=1.
IF (ResponseId="R_2QSuol2xuD66GQa") SkillComms=1.
IF (ResponseId="R_12S8x2VYaRu58RR") SkillRMA=1.
IF (ResponseId="R_tVUYTQkAZuBnUXL") SkillRMA=1.
IF (ResponseId="R_2fvZawDnx4M9p5W") SkillRMA=1.
IF (ResponseId="R_3KTuo9eLeMLTjZm") SkillComms=1.
IF (ResponseId="R_POqvxvmhxRO6F7b") SkillRMA=1.
IF (ResponseId="R_1DA14TQtcj3Rr1D") SkillOther=1.
IF (ResponseId="R_ZazrdxfY3CpDIXv") SkillRMA=1.
IF (ResponseId="R_1N4Hd4Esh76HfaU") SkillRMA=1.
IF (ResponseId="R_UYkaiy0ZcY5fXfb") SkillResearchOrgExp=1.
IF (ResponseId="R_1OqtZxXbrNCAeXI") SkillRMA=1.
IF (ResponseId="R_cSBVzVzdFFFPSJr") SkillRMA=1.
IF (ResponseId="R_9RG9GAv7YyN2RP3") SkillRMA=1.
IF (ResponseId="R_86BTRFHkFTMFsg9") SkillRMA=1.
IF (ResponseId="R_d4fs0bFfXXtJ6tb") SkillRMA=1.
IF (ResponseId="R_2ALjHwZw9wyvvkw") SkillRMA=1.
IF (ResponseId="R_zSBIE8srsCXaDfj") SkillResearchOrgExp=1.
IF (ResponseId="R_z7hhCxB67DqDO9P") SkillRMA=1.
IF (ResponseId="R_Zt9jhMRClOnW8Qp") SkillRMA=1.
IF (ResponseId="R_1luSf2kvbsiU0md") SkillRMA=1.
IF (ResponseId="R_27OuG8NovZvzpoj") SkillRMA=1.
IF (ResponseId="R_2EcxQb8DDoMjX91") SkillRMA=1.
IF (ResponseId="R_YYAwcQqqFbdXZDP") SkillRMA=1.
IF (ResponseId="R_3fTAz0wqwG74DK4") SkillRMA=1.
IF (ResponseId="R_2Sp1BK4Q9CkGVY0") SkillRMA=1.
IF (ResponseId="R_12K0KpCdpiNSbUv") SkillRMA=1.
IF (ResponseId="R_2amBOcqg3Y4ahFM") SkillRMA=1.
IF (ResponseId="R_2toof1SPZhYwBCf") SkillRMA=1.
IF (ResponseId="R_2YFjp0KDtvUY7Qk") SkillRMA=1.
IF (ResponseId="R_1puLp7hNie9V1YL") SkillRMA=1.
IF (ResponseId="R_2Qm1NYIqYs6jv37") SkillRMA=1.
IF (ResponseId="R_elLaRdB1UkCNCsV") SkillRMA=1.
IF (ResponseId="R_2eQoaHcC9MtUwKy") SkillRMA=1.
IF (ResponseId="R_80lxL66kkLIE4Ip") SkillResearchInterest=1.
IF (ResponseId="R_bpE3dpg5d71L7R7") SkillRMA=1.
IF (ResponseId="R_9S0GSIj9QmspL45") SkillRMA=1.
IF (ResponseId="R_3MyzUE885QlpozS") SkillOther=1.
IF (ResponseId="R_1rPspI1ZKXE5gM4") SkillRMA=1.
IF (ResponseId="R_1dzcS6AzbcPzhnd") SkillRMA=1.
IF (ResponseId="R_8vHgzttcX7KWUj7") SkillRMA=1.
IF (ResponseId="R_u8hSu2LYU0zWH1D") SkillOther=1.
IF (ResponseId="R_eWMOQrYByFJZVQJ") SkillRMA=1.
IF (ResponseId="R_1gCrI58a9Ogn1Be") SkillRMA=1.
IF (ResponseId="R_3kClY1mdm8S1pmm") SkillRMA=1.
IF (ResponseId="R_2ymwXT0C6K4ZMPm") SkillTraining=1.
IF (ResponseId="R_3PoboPNgC2iPEZO") SkillRMA=1.
IF (ResponseId="R_1GK4ZOvRzNd3iYA") SkillRMA=1.
IF (ResponseId="R_1M09YqxnvTwWUEn") SkillRMA=1.
IF (ResponseId="R_3TXWUtrXVpobIoF") SkillRMA=1.
IF (ResponseId="R_AtdVRAD7BdtiA25") SkillRMA=1.
IF (ResponseId="R_2BgqUTWWVetbbKF") SkillRMA=1.
IF (ResponseId="R_27eE7PtAyhp0oZ8") SkillComms=1.
IF (ResponseId="R_3Hp13RIVqIIJLmC") SkillRMA=1.
IF (ResponseId="R_3lPUr9SfHhwDib2") SkillRMA=1.
IF (ResponseId="R_1dnvT1AMEdYg0YU") SkillRMA=1.
IF (ResponseId="R_AHThmTriyLSTgop") SkillComms=1.
IF (ResponseId="R_1BY5go7W0PxXaUi") SkillComms=1.
IF (ResponseId="R_OlIRDhMSx9hSnDz") SkillService=1.
IF (ResponseId="R_1H1YCB0HU2BrWvl") SkillRMA=1.
IF (ResponseId="R_2Xd1W2vlMgUecCO") SkillData=1.
IF (ResponseId="R_29g1L1AKchTmsY2") SkillRMA=1.
IF (ResponseId="R_3LYFGLxzPlQbx6y") SkillIntegrity=1.
IF (ResponseId="R_2fJt6R4vKIMO5gh") SkillRMA=1.
IF (ResponseId="R_262ovJcdBgMvYdf") SkillRMA=1.
IF (ResponseId="R_2ROGQD2JFY7tr9f") SkillRMA=1.
IF (ResponseId="R_2CH8MUawoezxvXy") SkillOther=1.
IF (ResponseId="R_3nNvviOIXSzrHug") SkillComms=1.
IF (ResponseId="R_UKpcdT2cYI0ycIF") SkillComms=1.
IF (ResponseId="R_2CZcMh3GjVDrFjI") SkillRMA=1.
IF (ResponseId="R_2rTv1F3vlpCvUgJ") SkillOther=1.
IF (ResponseId="R_3MDlKwHQyt4dZZE") SkillComms=1.
IF (ResponseId="R_2wbMbvpJsQJqyyV") SkillRMA=1.
IF (ResponseId="R_27OU1FoIy2mH4Fi") SkillService=1.
IF (ResponseId="R_OfiLWZmaATck48N") SkillRMA=1.
IF (ResponseId="R_27CB9Ii7MblCkD3") SkillRMA=1.
IF (ResponseId="R_3HBLwPRQiwQIPq1") SkillRMA=1.
IF (ResponseId="R_1KeXWY0nl0Ttsg2") SkillResearch=1.
IF (ResponseId="R_8GlMNhKsQGAwm8F") SkillRMA=1.
IF (ResponseId="R_8vkq0Bvqk18hyRX") SkillResearch=1.
IF (ResponseId="R_2Phgb2mhtZsMSwC") SkillRMA=1.
IF (ResponseId="R_2amfhbxkloRsuZ7") SkillResearch=1.
IF (ResponseId="R_3pbtk42rHeaXj26") SkillResearchOrgExp=1.
IF (ResponseId="R_DwSvyvXy61iTVbH") SkillOther=1.
IF (ResponseId="R_DwSvyvXy61iTVbH") SkillComms=1.
IF (ResponseId="R_eVdLf5x0KbhZVu1") SkillRMA=1.
IF (ResponseId="R_ZL7W18wTaNOZTmV") SkillResearchOrgExp=1.
IF (ResponseId="R_3lvjRxVRpzc6a5P") SkillRMA=1.
IF (ResponseId="R_2Bxm2BKXPVFpYax") SkillTraining=1.
IF (ResponseId="R_vDNeq0j4Y2fzLS9") SkillComms=1.
DO IF (ResponseId="R_Dl8nUCYXhFihqs9").
    COMPUTE SkillLearning=1.
    COMPUTE SkillIntegrity=1.
END IF.
DO IF (ResponseId="R_2uxkJtxbxsPadOu").
    COMPUTE SkillLearning=1.
    COMPUTE SkillService=1.
END IF.
DO IF (ResponseId="R_116Fg4CKzWqFPRR").
    COMPUTE SkillResearch=1.
    COMPUTE SkillRMA=1.
END IF.
DO IF (ResponseId="R_XgCf2qg4MeDaV8Z").
    COMPUTE SkillIntegrity=1.
    COMPUTE SkillResearch=1.
END IF.
DO IF (ResponseId="R_1DChoymAnEbM5il").
    COMPUTE SkillProblem=1.
    COMPUTE SkillTeam=1.
    COMPUTE SkillComms=1.
END IF.
DO IF (ResponseId="R_10N1lFjgcXqFTWp").
    COMPUTE SkillRMA=1.
    COMPUTE SkillIntegrity=1.
END IF.
DO IF (ResponseId="R_24vXwqSplDYMBBp").
    COMPUTE SkillResearch=1.
    COMPUTE SkillIntegrity=1.
END IF.
DO IF (ResponseId="R_2b3gGxKX9xnpkGg").
    COMPUTE SkillComms=1.
    COMPUTE SkillProblem=1.
END IF.
DO IF (ResponseId="R_1kZz7YHpvRzflF0").
    COMPUTE SkillComms=1.
    COMPUTE SkillResearch=1.
END IF.
DO IF (ResponseId="R_vkNv9VSEFWcmywp").
    COMPUTE SkillResearch=1.
END IF.
DO IF (ResponseId="R_1g6fj0EdvKQ5Vyk").
    COMPUTE SkillComms=1.
END IF.
DO IF (ResponseId="R_1FyXEWie3tisXln").
    COMPUTE SkillResearchOrgExp=1.
END IF.
DO IF (ResponseId="R_2dshAXp3KdtVtd3").
    COMPUTE SkillResearchOrgExp=1.
END IF.
DO IF (ResponseId="R_xy02M59P8XsuzJf").
    COMPUTE SkillRMA=1.
    COMPUTE SkillService=1.
END IF.
DO IF (ResponseId="R_dbwDi1LXQyrX5Kx").
    COMPUTE SkillResearchOrgExp=1.
END IF.
DO IF (ResponseId="R_1n2dDzfQ0zmYPdB").
    COMPUTE SkillLearning=1.
    COMPUTE SkillResearch=1.
END IF.
DO IF (ResponseId="R_1goxfDPomPcu1t3").
    COMPUTE SkillTeam=1.
    COMPUTE SkillComms=1.
END IF.
DO IF (ResponseId="R_2OHlPCG3pOtAEMq").
    COMPUTE SkillComms=1.
    COMPUTE SkillTeam=1.
END IF.
DO IF (ResponseId="R_RwBuZxLt8U8DeLf").
    COMPUTE SkillRMA=1.
    COMPUTE SkillComms=1.
END IF.
DO IF (ResponseId="R_rfMixyrtdoVd9CN").
    COMPUTE SkillResearchOrgExp=1.
END IF.
DO IF (ResponseId="R_1ePQogjJwAy1qLj").
    COMPUTE SkillRMA=1.
    COMPUTE SkillComms=1.
END IF.
DO IF (ResponseId="R_bBCaCW8tMlOVxzX").
    COMPUTE SkillRMA=1.
END IF.
DO IF (ResponseId="R_3RyEFJOrgLhJxyP").
    COMPUTE SkillResearchOrgExp=1.
    COMPUTE SkillRMA=1.
END IF.
DO IF (ResponseId="R_26eADIUAary48ta").
    COMPUTE SkillComms=1.
    COMPUTE SkillTeam=1.
END IF.
EXECUTE.

* *** SkillsForRMAJobDet anonymising - SK (lead by MD).
IF (ResponseId="R_3MyzUE885QlpozS") SkillsForRMAJobDet="Experience owning a design XXXX.".
IF (ResponseId="R_2aQ3kW1ntkSOeYB") SkillsForRMAJobDet="Stage au XXXX".
IF (ResponseId="R_3RyEFJOrgLhJxyP") SkillsForRMAJobDet="My educational background from the institution where I applied for my first (study admin) job. Experience/skills from working in a Research Park and in the Norwegian XXXX service.".
IF (ResponseId="R_2Bxm2BKXPVFpYax") SkillsForRMAJobDet="master in healthcare administration from XXXX University and admin internship at XXXX in New York City.".
EXECUTE.

* *** No backcoding from SkillsForRMAJobDet - SK.

RECODE SkillResearch SkillRMA SkillTraining SkillMultitasking SkillDetail SkillOrganisational SkillResearchInterest SkillResearchOrgExp SkillTeam 
    SkillData SkillComms SkillLearning SkillInternational SkillProblem SkillIntegrity SkillService SkillOther (SYSMIS=0).
EXECUTE.
COMPUTE Skills = SkillResearch+SkillRMA+SkillTraining+SkillMultitasking+SkillDetail+SkillOrganisational+SkillResearchInterest+SkillResearchOrgExp+SkillTeam+
    SkillData+SkillComms+SkillLearning+SkillInternational+SkillProblem+SkillIntegrity+SkillService+SkillOther.
DO IF (Skills = 0).
    COMPUTE SkillResearch=$SYSMIS.
    COMPUTE SkillRMA=$SYSMIS.
    COMPUTE SkillTraining=$SYSMIS.
    COMPUTE SkillMultitasking=$SYSMIS.
    COMPUTE SkillDetail=$SYSMIS.
    COMPUTE SkillOrganisational=$SYSMIS.
    COMPUTE SkillResearchInterest=$SYSMIS.
    COMPUTE SkillResearchOrgExp=$SYSMIS.
    COMPUTE SkillTeam=$SYSMIS.
    COMPUTE SkillData=$SYSMIS.
    COMPUTE SkillComms=$SYSMIS.
    COMPUTE SkillLearning=$SYSMIS.
    COMPUTE SkillInternational=$SYSMIS.
    COMPUTE SkillProblem=$SYSMIS.
    COMPUTE SkillIntegrity=$SYSMIS.
    COMPUTE SkillService=$SYSMIS.
    COMPUTE SkillOther=$SYSMIS.
END IF.
EXECUTE.

* *** Q37 Career Satisfaction - new question for RAAAP-3.
RENAME VARIABLES CareerSatisfact=CareerSatisfaction.
VARIABLE LABELS CareerSatisfaction "37. Career Satisfaction".
MISSING VALUES CareerSatisfaction (-99).
VARIABLE LEVEL CareerSatisfaction (NOMINAL).
EXECUTE.

RENAME VARIABLES CareerDet=CareerSatisfactionDetails.
VARIABLE LABELS CareerSatisfactionDetails "37a. Career satisfaction details".
MISSING VALUES CareerSatisfactionDetails ("").
VALUE LABELS CareerSatisfactionDetails "" "No Response".
VARIABLE LEVEL CareerSatisfactionDetails (NOMINAL).
EXECUTE.

* *** Anonymising CareerSatisfactionDetails - CO.
IF (ResponseId="R_2QibIJZYaBvfAAM") CareerSatisfactionDetails=CONCAT("It's been a good career, I've received several awards for my work.  At a University like XXXX, you h",
"ave access to education, the arts, information and the area offers many amenities,   There are good benefits and retirement.  Plus after retirement, I could take my skills anywhere (including remote) ",
"as needed for funds or volunteer services.  My nephew has asked me numerous time to come work at XXXX Clinic, but I still think I want to go back to art, history and travel.  But who knows what the fu",
"ture brings...").
EXECUTE.

* *** backcoding for CareerSatisfactionDetails - where they selected 88 "prefer not to say" - but then gave enough info to back code.
IF (ResponseId="R_2rjQORzohn0jaqZ") CareerSatisfaction=4.
IF (ResponseId="R_2dms39MhownjrEK") CareerSatisfaction=2.
EXECUTE.

* *** Q38 RMA Identity - new question for RAAAP-3.
VARIABLE LABELS IdentityRMA "38. Identify as an RMA?".
MISSING VALUES IdentityRMA (-99).
VARIABLE LEVEL IdentityRMA (NOMINAL).
ADD VALUE LABELS IdentityRMA 4 "Something else" 5 "Not sure".
EXECUTE.

VARIABLE LABELS IdentityName "38a What do you Identify as?".
MISSING VALUES IdentityName (-99).
VARIABLE LEVEL IdentityName (NOMINAL).
EXECUTE.

RENAME VARIABLES IdentityDet=IdentityDetails.
VARIABLE LABELS IdentityDetails "38b. Identity Details".
MISSING VALUES IdentityDetails ("").
VALUE LABELS IdentityDetails "" "No Response".
VARIABLE LEVEL IdentityDetails (NOMINAL).
EXECUTE.

* *** IdentityDetails anonymising - SK.
IF (ResponseId="R_1goxfDPomPcu1t3") IdentityDetails="A 'hybrid' research management professional who is both a researcher (unpaid) and a management professional (1 FTE paid), with a specialism in XXXX and related fields".
EXECUTE.

* *** IdentityDetails backcoding - SK.
IF (ResponseId="R_2aglQ17ImuAyqUO") IdentityName=4.
IF (ResponseId="R_3GE2SyGbT2mDJfk") IdentityName=11.
IF (ResponseId="R_1fiLeCALM5zt1pL") IdentityName=11.
IF (ResponseId="R_CkqVhoPlgQbPrwJ") IdentityName=11.
IF (ResponseId="R_29tUfgiVheABCO8") IdentityName=11.
IF (ResponseId="R_R1SSGsuzckijZoR") IdentityName=11.
EXECUTE.

* *** Q39 Dissatisfaction.
* *** AreasOfDissatisfact_1.
RENAME VARIABLES AreasOfDissatisfact_1=DissatisfactionDemands.
VARIABLE LABELS DissatisfactionDemands "39a. High Demands". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionDemands 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionDemands (-99).
ADD VALUE LABELS DissatisfactionDemands -99 "No Response".
VARIABLE LEVEL DissatisfactionDemands (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_2=DissatisfactionUpdating.
VARIABLE LABELS DissatisfactionUpdating "39b. Keeping Updated". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionUpdating 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionUpdating (-99).
ADD VALUE LABELS DissatisfactionUpdating -99 "No Response".
VARIABLE LEVEL DissatisfactionUpdating (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_3=DissatisfactionMonotony.
VARIABLE LABELS DissatisfactionMonotony "39c. Monotony". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionMonotony 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionMonotony (-99).
ADD VALUE LABELS DissatisfactionMonotony -99 "No Response".
VARIABLE LEVEL DissatisfactionMonotony (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_4=DissatisfactionGranted.
VARIABLE LABELS DissatisfactionGranted "39d. Underappreciated". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionGranted 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionGranted (-99).
ADD VALUE LABELS DissatisfactionGranted -99 "No Response".
VARIABLE LEVEL DissatisfactionGranted (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_5=DissatisfactionPromotion.
VARIABLE LABELS DissatisfactionPromotion "39e. Promotion". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionPromotion 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionPromotion (-99).
ADD VALUE LABELS DissatisfactionPromotion -99 "No Response".
VARIABLE LEVEL DissatisfactionPromotion (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_6=DissatisfactionDevelopment.
VARIABLE LABELS DissatisfactionDevelopment "39f. Professional Development". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionDevelopment 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionDevelopment (-99).
ADD VALUE LABELS DissatisfactionDevelopment -99 "No Response".
VARIABLE LEVEL DissatisfactionDevelopment (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_7=DissatisfactionSalary.
VARIABLE LABELS DissatisfactionSalary "39g. Salary". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionSalary 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionSalary (-99).
ADD VALUE LABELS DissatisfactionSalary -99 "No Response".
VARIABLE LEVEL DissatisfactionSalary (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_8=DissatisfactionBeyond.
VARIABLE LABELS DissatisfactionBeyond "39h. Working Beyond Job". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionBeyond 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionBeyond (-99).
ADD VALUE LABELS DissatisfactionBeyond -99 "No Response".
VARIABLE LEVEL DissatisfactionBeyond (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_9=DissatisfactionHours.
VARIABLE LABELS DissatisfactionHours "39i. After Hours Working". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionHours 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionHours (-99).
ADD VALUE LABELS DissatisfactionHours -99 "No Response".
VARIABLE LEVEL DissatisfactionHours (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_10=DissatisfactionMotivation.
VARIABLE LABELS DissatisfactionMotivation "39j. Lack of Motivation". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionMotivation 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionMotivation (-99).
ADD VALUE LABELS DissatisfactionMotivation -99 "No Response".
VARIABLE LEVEL DissatisfactionMotivation (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_11=DissatisfactionRespect.
VARIABLE LABELS DissatisfactionRespect "39k. Lack of Respect". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionRespect 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionRespect (-99).
ADD VALUE LABELS DissatisfactionRespect -99 "No Response".
VARIABLE LEVEL DissatisfactionRespect (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_12=DissatisfactionGatekeeper.
VARIABLE LABELS DissatisfactionGatekeeper "39l. Seen as Gatekeeper". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionGatekeeper 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionGatekeeper (-99).
ADD VALUE LABELS DissatisfactionGatekeeper -99 "No Response".
VARIABLE LEVEL DissatisfactionGatekeeper (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_13=DissatisfactionIdentity.
VARIABLE LABELS DissatisfactionIdentity "39m. Professional Identity". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionIdentity 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionIdentity (-99).
ADD VALUE LABELS DissatisfactionIdentity -99 "No Response".
VARIABLE LEVEL DissatisfactionIdentity (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_14=DissatisfactionSecurity.
VARIABLE LABELS DissatisfactionSecurity "39n. Low Job Security". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionSecurity 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionSecurity (-99).
ADD VALUE LABELS DissatisfactionSecurity -99 "No Response".
VARIABLE LEVEL DissatisfactionSecurity (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_88=DissatisfactionOther.
VARIABLE LABELS DissatisfactionOther "39o. Other Dissatisfaction". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionOther 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionOther (-99).
ADD VALUE LABELS DissatisfactionOther -99 "No Response".
VARIABLE LEVEL DissatisfactionOther (NOMINAL).
EXECUTE.

RENAME VARIABLES AreasOfDissatisfact_77=DissatisfactionNone.
VARIABLE LABELS DissatisfactionNone "39x. No Dissatisfaction". /* trying to retain Q numbers.
VALUE LABELS DissatisfactionNone 1 "Yes" 0 "No".
MISSING VALUES DissatisfactionNone (-99).
ADD VALUE LABELS DissatisfactionNone -99 "No Response".
VARIABLE LEVEL DissatisfactionNone (NOMINAL).
EXECUTE.

* *** and the details.
RENAME VARIABLES AreasOfDissatisfactD=AreasOfDissatisfactionDetails.
VARIABLE LABELS AreasOfDissatisfactionDetails "39. Details of Areas of Dissatisfaction".
MISSING VALUES AreasOfDissatisfactionDetails ("").
VALUE LABELS AreasOfDissatisfactionDetails "" "No Response".
VARIABLE LEVEL AreasOfDissatisfactionDetails (NOMINAL).
EXECUTE.

* *** NOTE that there could be inconsistenices, eg someone could tick "None" and also some of the others... but no way to know which is incorrect...
* *** so leave as is for others to decide!.
RECODE DissatisfactionDemands DissatisfactionUpdating DissatisfactionMonotony DissatisfactionGranted DissatisfactionPromotion DissatisfactionDevelopment 
    DissatisfactionSalary DissatisfactionBeyond DissatisfactionHours DissatisfactionMotivation DissatisfactionRespect DissatisfactionGatekeeper
    DissatisfactionIdentity DissatisfactionSecurity DissatisfactionOther DissatisfactionNone (SYSMIS=0).
EXECUTE.
COMPUTE Dissatisfaction = DissatisfactionDemands+DissatisfactionUpdating+DissatisfactionMonotony+DissatisfactionGranted+DissatisfactionPromotion+DissatisfactionDevelopment+
    DissatisfactionSalary+DissatisfactionBeyond+DissatisfactionHours+DissatisfactionMotivation+DissatisfactionRespect+DissatisfactionGatekeeper+
    DissatisfactionIdentity+DissatisfactionSecurity+DissatisfactionOther+DissatisfactionNone.
DO IF (Dissatisfaction = 0).
    COMPUTE DissatisfactionDemands=$SYSMIS.
    COMPUTE DissatisfactionUpdating=$SYSMIS.
    COMPUTE DissatisfactionMonotony=$SYSMIS.
    COMPUTE DissatisfactionGranted=$SYSMIS.
    COMPUTE DissatisfactionPromotion=$SYSMIS.
    COMPUTE DissatisfactionDevelopment=$SYSMIS.
    COMPUTE DissatisfactionSalary=$SYSMIS.
    COMPUTE DissatisfactionBeyond=$SYSMIS.
    COMPUTE DissatisfactionHours=$SYSMIS.
    COMPUTE DissatisfactionMotivation=$SYSMIS.
    COMPUTE DissatisfactionRespect=$SYSMIS.
    COMPUTE DissatisfactionGatekeeper=$SYSMIS.
    COMPUTE DissatisfactionIdentity=$SYSMIS.
    COMPUTE DissatisfactionSecurity=$SYSMIS.
    COMPUTE DissatisfactionOther=$SYSMIS.
    COMPUTE DissatisfactionNone=$SYSMIS.
  END IF.
EXECUTE.

* *** Anonymising AreasOfDissatisfactionDetails - MF.
IF (ResponseId="R_2fiX115mjw6dlME") AreasOfDissatisfactionDetails="sorry, so many but it is true throughout XXXX".
EXECUTE.

* *** Backcoding from AreasOfDissatisfactionDetails - SK.
IF (ResponseId="R_2ab1eC1WwhyDv9A") DissatisfactionHours=1.
IF (ResponseId="R_12K0KpCdpiNSbUv") DissatisfactionDevelopment=1.
IF (ResponseId="R_22lYAQl5eVgSrMJ") DissatisfactionPromotion=1.
IF (ResponseId="R_2VjMIfFPDm0ETzS") DissatisfactionDemands=1.
IF (ResponseId="R_2R7GVB8JbuF2UfV") DissatisfactionSecurity=1.
EXECUTE.

* *** Backcoding from AreasOfDissatisfactionDetails where other was selected - MF.
IF (ResponseId="R_2DREzCpBXk4Pm1A") DissatisfactionPromotion=1.
IF (ResponseId="R_2uJ95vyJBw5uXDV") DissatisfactionRespect=1.
IF (ResponseId="R_eboJUyTnq4OKxUJ") DissatisfactionHours=1.
DO IF (ResponseId="R_1rBmpKpxSz0KqqK").
    COMPUTE DissatisfactionGranted=1.    
    COMPUTE DissatisfactionSalary=1.    
    COMPUTE DissatisfactionRespect=1.
END IF.
IF (ResponseId="R_3MG37vHsw0h2JLJ") DissatisfactionHours=1.
IF (ResponseId="R_SBQd4XXg3KNxuwN") DissatisfactionBeyond=1.
IF (ResponseId="R_YSaUOoNHH7qTuYF") DissatisfactionDevelopment=1.
IF (ResponseId="R_PTfsfqQmCwEQtzz") DissatisfactionHours=1.
IF (ResponseId="R_C77yYb41UXEwNW1") DissatisfactionDevelopment=1.
IF (ResponseId="R_tZ0FwbfMy8su5Bn") DissatisfactionHours=1.
IF (ResponseId="R_21v8wU2MS6UkHxe") DissatisfactionSecurity=1.
EXECUTE.

* *** Q40 Mentoring - new question for RAAAP-3.
VARIABLE LABELS HaveBeenMentored "40. Have Been Mentored?".
MISSING VALUES HaveBeenMentored (-99).
VARIABLE LEVEL HaveBeenMentored (NOMINAL).
EXECUTE.

VARIABLE LABELS HaveMentored "40a. Have You Mentored?".
MISSING VALUES HaveMentored (-99).
VARIABLE LEVEL HaveMentored (NOMINAL).
EXECUTE.

VARIABLE LABELS WouldRecommendRMA "41. Would you recommend a career in RMA?".
MISSING VALUES WouldRecommendRMA (-99).
VARIABLE LEVEL WouldRecommendRMA (NOMINAL).
EXECUTE.

VARIABLE LABELS WhyRecommendRMA "41a. Why would you (not) recommend a career in RMA?".
MISSING VALUES WhyRecommendRMA ("").
VALUE LABELS WhyRecommendRMA "" "No Response".
VARIABLE LEVEL WhyRecommendRMA (NOMINAL).
EXECUTE.

* *** Backcoding for WhyRecommendRMA - SK.
IF (ResponseId="R_2qdX3Jw1AXhCgTx") WouldRecommendRMA=3.
IF (ResponseId="R_1THs5DROHIqIkvv") WouldRecommendRMA=1.
* *** Backcoding for WhyRecommendRMA (was 88 “prefer not to say” – then they did). SK.
IF (ResponseId="R_2eWghYQIKHwcaBD") WouldRecommendRMA=3.
IF (ResponseId="R_2wbDaPmha24dMao") WouldRecommendRMA=2.
EXECUTE.

* *** FINAL section.
* *** Q42 - Any Comments.
VARIABLE LABELS AnyComments "42. Any Comments?".
MISSING VALUES AnyComments ("").
VALUE LABELS AnyComments "" "No Response".
VARIABLE LEVEL AnyComments (NOMINAL).
EXECUTE.

* *** anonymise AnyComments - SK.
IF (ResponseId="R_30iuujLG8Xj0vyu") AnyComments=CONCAT("Hi Melinda and Simon! This is XXXX, we met virtually at FRAC 2022. Thank you for putting together th",
"e survey! The soft skills are much more important than the hard skills in being an RA. As I started sending out the link for this RAAAP, I realized many of the RA's I know are rather insulated and res",
"istant to filling it out or spreading the word.").
EXECUTE.

VARIABLE LABELS AnyIssues "43. Any Issues?".
MISSING VALUES AnyIssues ("").
VALUE LABELS AnyIssues "" "No Response".
VARIABLE LEVEL AnyIssues (NOMINAL).
EXECUTE.

* *** anonymise AnyIssues - SK.
IF (ResponseId="R_PLsF6uviJMOwP17") AnyIssues="I wish you a piece of luck in working out the survey's outcomes. If you need anything else, drop me an email at XXXX.cz Have a nice day.".
IF (ResponseId="R_3KveEINHRTsTyzA") AnyIssues="I have answered the survey as the XXXX of a company member of the European Association of Innovation Consultants (EAIC). We would be glad to work with you in the near future. :-)".
EXECUTE.

VARIABLE LABELS CanWeContactYou "44. Can we contact you?".
VALUE LABELS CanWeContactYou 1 "Yes" 2 "No".
MISSING VALUES CanWeContactYou (-99).
VARIABLE LEVEL CanWeContactYou (NOMINAL).
EXECUTE.

* *** Contact details.
RENAME VARIABLES ContactDetails_1=Name.
VARIABLE LABELS Name "45. Name".
MISSING VALUES Name ("").
VALUE LABELS Name "" "No Response".
VARIABLE LEVEL Name (NOMINAL).
EXECUTE.

RENAME VARIABLES ContactDetails_2=Email.
VARIABLE LABELS Email "46. Email".
MISSING VALUES Email ("").
VALUE LABELS Email "" "No Response".
VARIABLE LEVEL Email (NOMINAL).
EXECUTE.

RENAME VARIABLES ContactDetails_3=SocialMedia.
VARIABLE LABELS SocialMedia "47. Social Media".
MISSING VALUES SocialMedia ("").
VALUE LABELS SocialMedia "" "No Response".
VARIABLE LEVEL SocialMedia (NOMINAL).
EXECUTE.

RENAME VARIABLES CurrentEmployer=Employer.
VARIABLE LABELS Employer "48. Current Employer". /* NOTE that this will not be released as part of the anonymised datasets.
MISSING VALUES Employer ("").
VALUE LABELS Employer "" "No Response".
EXECUTE.

* *** However as we have done this we'll put them in here in case useful for future research.
* *** backcoding from Email --> Employer - MD.
IF (ResponseId="R_1kXKszIcsmOEAr9") Employer="University of Witwatersrand".
IF (ResponseId="R_3qQjEfKPjpkT4jP") Employer="University of Texas at San Antonio".
IF (ResponseId="R_1rpK9gAwlIYUugz") Employer="Osaka University".
IF (ResponseId="R_3PNbnsaWZyC4DsI") Employer="Institute of Global Health".
IF (ResponseId="R_2ANIRO5kcbsGyhi") Employer="University of Iceland".
IF (ResponseId="R_2uxkJtxbxsPadOu") Employer="Indiana University of Pennsylvania".
IF (ResponseId="R_3s6vl7jGTTsvZrd") Employer="Klaipeda University".
IF (ResponseId="R_3L0F4dBWqw7ZYOv") Employer="Lithuanian Research Centre for Agriculture and Forestry". 
IF (ResponseId="R_2qr4J0J8mZLxpKt") Employer="International University of Applied Sciences".
IF (ResponseId="R_12SgXPJjKowDeFI") Employer="Statistics Norway".
IF (ResponseId="R_1lgI9ZXTq1ZA6ZE") Employer="University of Koblenz at Landau".
IF (ResponseId="R_1mQQ9lTvgW8ritC") Employer="Instituto Universitario de Lisboa".
IF (ResponseId="R_cwoVeks6vBfDWb7") Employer="Czech Technical University in Prague".
IF (ResponseId="R_UxplX6BupxgLla9") Employer="The University of Virginia".
IF (ResponseId="R_1Ijfjq6CYBwXOl7") Employer="Technology University Wein".
IF (ResponseId="R_3IWYShP9Kgz5c4I") Employer="Queens University".
IF (ResponseId="R_1GIzetWLez9Iwvz") Employer="University of Tokyo".
IF (ResponseId="R_3MoFIr24rKQNdhJ") Employer="Universidad del Valle".
IF (ResponseId="R_Odu4w84k44ZIUUh") Employer="University of Aberdeen".
IF (ResponseId="R_D66c81EeN69XZ5f") Employer="Univeristy of Arkansas Medical Sciences".
IF (ResponseId="R_295udHjP8wJbZHr") Employer="Naturalis Biodiversity Center".
IF (ResponseId="R_1BYl2J6I226fZde") Employer="Erasmus Univeristy, Medical Centre".
IF (ResponseId="R_5zL5iQfPsdW57RD") Employer="Yvonne Morgan Consultancy".
IF (ResponseId="R_3FWIDYHawyuw0Qw") Employer="Indiana University".
IF (ResponseId="R_2tgRNNMfJQXjBPi") Employer="Sina Corporation".
IF (ResponseId="R_71XxLrvhHV6WPAZ") Employer="InnoRenew CoE".
IF (ResponseId="R_1rvLG8O5EtIwTKz") Employer="Universidad de los Andes, Colombia".
IF (ResponseId="R_AcUODIFO94xqRrj") Employer="Tsinghua University".
IF (ResponseId="R_2uKxeiwgbAu1Tip") Employer="University College of Northern Denmark".
IF (ResponseId="R_3jdFCjjMXOZng4B") Employer="Zhejiang University of Technology".
IF (ResponseId="R_3GCaBISBRfy9FYG") Employer="Politecnico di Torino, Italy".
IF (ResponseId="R_25QJmRUnC5e8wDs") Employer="University of Pittsburg".
IF (ResponseId="R_3L7r0xqivwSiytG") Employer="European XFEL".
IF (ResponseId="R_2OI1tJE0cHjNKyc") Employer="Leibniz Universitat Hannover".
IF (ResponseId="R_1hGwxfOKT7MDXlO") Employer="Norwegian Business School".
IF (ResponseId="R_6MddLHmgYmwzZ5v") Employer="University of Torino".
IF (ResponseId="R_2wbDaPmha24dMao") Employer="Bournemouth University".
IF (ResponseId="R_3lFY5ZrNnzWoqdz") Employer="Norwegian Business School".
IF (ResponseId="R_237WOMbxXGt1vbU") Employer="Birmingham City University".
IF (ResponseId="R_Des3vpbaGoYeM7L") Employer="Eastern Michigan University".
IF (ResponseId="R_2frKIdiPlVEpRLk") Employer="The George Institute for Global Health".
IF (ResponseId="R_2fv1kqTguvGxwy9") Employer="The Centre for Mental Health Law & Policy ".
IF (ResponseId="R_1li4RHGbKLydqPx") Employer="University of Melbourne".
IF (ResponseId="R_3NFi5hKRk29gAfg") Employer="Universitat Autonoma de Barcelona".
IF (ResponseId="R_8iYfkzrnQadndER") Employer="Politecnico di Torino, Italy".
IF (ResponseId="R_ByrqXfjAgBtdIwV") Employer="Paderborn University".
IF (ResponseId="R_3DnY0KoCFrFhBkS") Employer="Universite de Lille".
IF (ResponseId="R_126iOimSNsjqcGC") Employer="University of Maine".
IF (ResponseId="R_2bO6GBtB1OR0X93") Employer="Royal Melbourne Institute of Technology".
IF (ResponseId="R_1melr13qnZLDngr") Employer="Leibniz Universitat Hannover".
IF (ResponseId="R_54iRFM5VkLkDm1P") Employer="Syracuse University".
IF (ResponseId="R_XYRqTL2TBWObdF7") Employer="University of Limerick".
IF (ResponseId="R_3JsgLvY4mIkJe0U") Employer="Swinburne University of Technology".
IF (ResponseId="R_2TY1T4YwE2F2V1M") Employer="La Trobe University".
IF (ResponseId="R_C4wsncSQKyboRih") Employer="Binghampton University".
IF (ResponseId="R_27dpJ8Yqfs50BqX") Employer="Yokohama National University".
IF (ResponseId="R_YaZLHodEdJm7iP7") Employer="Deakin University".
IF (ResponseId="R_2S6yXlg5RfRm2h5") Employer="Inter-University Research Institute Corporation ".
IF (ResponseId="R_3m1pbDlNthvsEz2") Employer="Albert Einstein College of Medicine".
IF (ResponseId="R_2tJTFVHYNsLQJmn") Employer="Universita Ca Foscari Venezia".
IF (ResponseId="R_eeNxaRYrhPrPLWN") Employer="Steward Health Care".
EXECUTE.

* *** This section added in v5 ***.
* *** Now the final anonymising (picked up from the final cross-check of previous work.
IF (ResponseId="R_3kH5stvLcVrUlb6") AnyIssues=CONCAT("As I am one the few research officers in Sweden's XXXX context (we are less than 10 nationally) my v",
"oice will be quite easy to detect. And I think I am the only one who XXXX. So I would appreciate if you bear this in mind if quoting. But I do stand for my answers.").

IF (ResponseId="R_86AnaGJ2r51FeCt") CurrentRoleLevelDetails="Manager of the XXXX University Centre for Governance and Public Policy - a research centre within the School of Government and International Relations,.".
IF (ResponseId="R_2D5fFFgqwhsm1Rz") CurrentRoleLevelDetails="Director of Administration for a 3-Center core in a major research institute at the University of XXXX.".

IF (ResponseId="R_3pstzH6ga5umJRh") FirstRoleLevelDetails="Project officer pour la Faculté SH d'Université XXXX".
IF (ResponseId="R_2zBVjJVSnqJG1uV") FirstRoleLevelDetails="Head: Health Research Ethics Offfice,  Faculty of Medicine and Health Sciences, XXXX university".

IF (ResponseId="R_eKviY03SM54zToZ") EmploymentStatusDetails="Management Information Analyst at University of XXXX".
IF (ResponseId="R_1llOY5GFSrFD9nS") EmploymentStatusDetails=CONCAT("Prepare project proposals by determining concept, gathering and formatting information, writing draf",
"ts and obtaining approvals Research grant opportunities from government and non-government agencies Draft Memorandum of Understanding between organizations Craft speeches for Chief Guest (Convocation,",
"ial media and FDA’s website Proof read and edit website and newspaper articles before publication Identify, develop & manage FDA’s contacts with other national universities/institutions to create coll",
"aborative environment Identify and assess future and current training needs through market analysis & consultation with training participants, their managers & human resource department Write training",
" proposals by assembling information including training objectives and outcomes Design capacity building modules along with training schedules & pre and post assessment test Prepare Course Packs/ Doss",
"ier of different training modules Formulate capacity building development plan / training calendar Ensure quality of training contents are in-line with commitment made in the project documents Identif",
"y and select resource persons for training courses Prepare & implement staffing plans, work plans & budget Conduct effective induction and orientation sessions Monitor, review & measure the progress o",
"f trainees through questionnaires, surveys & discussions with managers Develop training invitation package for e-circulation Writing comprehensive reports of training event for sharing with Resource P",
"erson and management Maintain effective communication with trainees regarding the progress & development").
IF (ResponseId="R_2rTw25ib3qpk37K") EmploymentStatusDetails="Full time employee for the Grant office at University of XXXX Italy".
IF (ResponseId="R_3r3fIdp4j3wz6Ku") EmploymentStatusDetails=CONCAT("First I was employed at The XXXX regional authority which is a really rigid organisation and my role",
" was strictly defined in one way. Now I´m working at XXXX University and the range of my RMA responsibilities is widely open.").
IF (ResponseId="R_2uQE97mbtSinGcP") EmploymentStatusDetails=CONCAT("§ Sending information on a daily basis about open calls for proposals in technical-scientific discip",
"lines and all types of research, from basic research to applied research carried out in partnership with higher education institutions and private companies, including SMEs.§ Analyzing the applicatio",
"al writing. § Monitoring all international projects in which the University of XXXX, School of Electrical Engineering is involved. § Monitoring the procedures set by different international programm",
"es, in which XXXX participates (as partner or coordinator), in contracting with other partners, coordinators, donators, third parties, and cooperation with auditing firms.§ Supervision and harmonizat",
"ion of all activities directed towards project realization with national rules and regulations concerning international cooperation § Monitoring of all rules and regulations in accordance with nationa",
"l low important for project implementation.").
IF (ResponseId="R_3HG3FYdR50tgX35") EmploymentStatusDetails=CONCAT("My first role was supporting researchers in the Department of Pediatrics at the University of XXXX (",
"USA) and then XXXX. Now I am full time employed as Director of Pre-Award at the University of XXXX (AUS)").
IF (ResponseId="R_5aKA4slvoJPK86Z") EmploymentStatusDetails=CONCAT("I was the DST-NRF intern first then I received a contract from the University of XXXX after my inter",
"nship.").
IF (ResponseId="R_voSw84irNP4aL5L") EmploymentStatusDetails=CONCAT("I have worked as a full-time RD professional since 1992 in positions supporting interdisciplinary co",
"llaborative bioscience research at XXXX, University XXXX, University of XXXX, XXXX University in XXXX, XXXX University and now University XXXX.").

IF (ResponseId="R_3PcrUBXAkYbIIft") PreRMARoleDetails="Lecturer, Associate Professor at School of Information Engineering, XXXX University of China".
IF (ResponseId="R_2z75HDt7hxbaw7K") PreRMARoleDetails=CONCAT("Doctora en Gobernanza del Conocimiento y la Innovación, XXXX University, Maestría en Investigación e",
"n Documentación, Universidad XXXX, Administradora de Empresas, Pontificia Universidad XXXX, Colombia. Actual Asesora de la Vicerrectoría de Investigación de la XXXX. Ha sido Coordinadora de Publicacio",
"nes Seriadas, Editorial Pontificia Universidad XXXX; Investigadora Económica, revista Dinero, Publicaciones Semana; Docente de la Facultad de Ciencias Económicas y Administrativas de la XXXX; voluntar",
"ia en temas de género equidad para la mujer en la Fundación XXXX, XXXX Community; miembro de la junta directiva del Female Faculty Network, XXXX University, Países Bajos; Directora del Observatorio XX",
"XX, XXXX de Colombia; Coordinadora del proyecto XXXX programa de las cuatro hélices de la Unión Europea H2020 en XXXX. Miembro activo de las Redes de Gobernanza de Ciencia y Tecnología GCTI, Red de ge").
IF (ResponseId="R_1Nggafyom3ohKVd") PreRMARoleDetails="XXXX XXXX of Education University of XXXX".
IF (ResponseId="R_2QyWwe9z7UjxDbX") PreRMARoleDetails=CONCAT("I worked as a video store clerk while getting my associates degree in Information management and des",
"ign (a secretarial degree). I couldn't find an administrative position once I graduated so I worked for a student loan call center for 8 months before finding a front office position at a pediatric of",
"fice which transitioned to me specializing as their medical records clerk. From there I worked as a Secretary at XXXX. My start in research administration came because there was an opening for an Admi",
"nistrative Coordinator and they were seeking someone with administrative, university and medical backgrounds.").
IF (ResponseId="R_2B9BketGf8GGN2x") PreRMARoleDetails="I have always worked at The University of Texas XXXX".

IF (ResponseId="R_vMM7kERlfufJqZX") CareerPlanDet=CONCAT("01/06/2000 - 31/05/2001 Royal Society/NATO Postdoctoral Fellowship. XXXX University of XXXX. School ",
"of Mathematics and Physics. XXXX Simulation Group (UK). Postdoctoral researcher. • Conducted computer simulation of multicomponent ionic liquids by means of molecular dynamic simulations. • Created an",
"d modified software for calculation of the properties of substances using the software product DL_POLY_12.2 for UNIX, LINUX and FORTRAN.• Theoretically processed, analyzed and interpreted data obtain",
"ed,  performed round-up and analysis of scientific publications,  wrote reports on developing issues, prepared scientific publications to scientific conferences and in periodical. 1999-2000 DAAD Post",
"doctoral Fellowship. XXXX-Universität XXXX. Faculty of Natural Sciences. Chair of Technical XXXX (Germany). Postdoctoral researcher. • Planned, designed and conducted experimental research in the fiel",
"d of Raman Spectroscopy of Gases. • Developed and perfected experimental equipment for high-precision determination of concentration of compounds of natural gases (methane, ethane, propane, butane, is",
"obutane, hydrogen, oxygen, and nitrogen) by means of Raman spectroscopy. • Designed and perfected experimental technique for determination of concentration of compounds of gases. Developed software fo",
"r computation of concentration of compounds of gases.  Conducted experimental research of gaseous alkanes and determined the formation mechanism of vibrational bands and processes of molecular relaxat",
"ion in methane, ethane, propane, butane and isobutane. • Theoretically processed, analyzed and interpreted data obtained, performed round-up and analysis of scientific publications, wrote reports on d",
"eveloping issues, prepared scientific publications to scientific conferences and in periodical. 01/04/1997 - 01/04/1997 XXXX University of XXXX. Faculty of Physics. Research Scientist. • Planned, designed,").

IF (ResponseId="R_2zr6Wv7XhMSRI0f") JoinRAMoreDetails=CONCAT("When I was about to finishing my studies at university and was extremely unsure what I would do out ",
"there with a degree in humanities and arts, a friend of mine who has been working as a student assistant at a XXXX Institute recommended that I should send them a speculative application as research a",
"d hired me.").
IF (ResponseId="R_33D73yZxcwsRvoC") JoinRAMoreDetails=CONCAT("While it wasn't a career I grew up wanting, it was RA was something I pursued once I knew about it. ",
" After college, I began skydiving and then was offered a position with a small parachute manufacturer in central Florida.  Some of the duties included proposals for government contracts and negotiatio",
"more about the profession and boost my resume. Shortly thereafter, XXXX University was restructuring their sponsored programs office so my mother (who worked in Housing & Food Service business office)",
" encouraged me to apply so I would move closer to home.  My first position was in preaward services where I thrived.  I moved on to industry sponsored research contract negotiations within XXXX and wh",
"en I got tired of winter again, wanted to stay within the profession but somewhere with a warmer climate.  I worked in the central office at XXXX for almost 6 years, earning my CRA and CPRA, then was ",
"offered a position at the Research Office for our branch campus in XXXX, Qatar where I have lived for the last 14 months.").
IF (ResponseId="R_2QibIJZYaBvfAAM") JoinRAMoreDetails=CONCAT("It was a position and field I was interested in, but was also putting in for other positions at the ",
"University of XXXX at the same time.").
IF (ResponseId="R_0vmcqonbhTBpAHf") JoinRAMoreDetails=CONCAT("I fell into it. I was out of work, and invited to dinner by a friend, who happened to be the HR Dire",
"ctor at a prestigious higher-ed institution. She encouraged me to apply and helped by circulating my resume. This lead to my first position, at XXXX University.").

IF (ResponseId="R_2Ce9ApKUsqYFGb8") EmploymentStatusDetails=CONCAT("First role was at American XXXX Society where research was just one aspect of the role.  Current rol",
"e is full time devoted solely to Research.").
IF (ResponseId="R_10PFeVVGJFYjYZw") EmploymentStatusDetails=CONCAT("Have been full-time research development (RD) since 2004. Started as RD Officer at UC XXXX, led two ",
"large RD offices, now an independent RD consultant with 70+ clients or former clients.").

IF (ResponseId="R_86AnaGJ2r51FeCt") CurrentRoleLevelDetails=CONCAT("Manager of the XXXX University Centre for Governance and Public Policy - a research centre within th",
"e School of Government and International Relations,.").
IF (ResponseId="R_3fcv255jynOPcSd") CurrentRoleLevelDetails=CONCAT("EU Project Leader in charge of developing project management services for EU R&D collaborative proje",
"cts (under Horizon Europe, Digital Europe Programme) for FI Group in France. Also in charge of supporting proposal development. XXXX and active member of the European Association of Innovation Consult",
"ants (EAIC) as well as active member of the French Association of Innovation Consultants.",).
IF (ResponseId="R_1goxfDPomPcu1t3") CurrentRoleLevelDetails=CONCAT("Senior Research Impact and Knowledge Exchange Manager, XXXX University, UK (Research, Enterprise and",
" Scholarship unit, central services)").
IF (ResponseId="R_2D5fFFgqwhsm1Rz") CurrentRoleLevelDetails=CONCAT("Director of Administration for a 3-Center core in a major research institute at the University of XX",
"XX.").

IF (ResponseId="R_yUctdkabBhB4DND") InstitutionCharDet='I work for the XXXX technical university in the country. I believe it belongs to a "top tier" research university.'.

IF (ResponseId="R_3EMzleWVMTrCLfN") InstitutionTypeDet="XXXX Higher Education institute in the Country/National University".
IF (ResponseId="R_31mzvDjteqQyDNn") InstitutionTypeDet="State institution (University of XXX)".

IF (ResponseId="R_1nYHyBmbV6g6bJf") OrgDepartmentDetails="Office of the Cluster Director, XXXX, Technology and Innovation Hub".
IF (ResponseId="R_1HdIaFeNLpM3oDj") OrgDepartmentDetails='So-called XXXX Lab which is a part of the "Prorectorate for Research"'.
IF (ResponseId="R_vZecJ9Jxy0eGezL") OrgDepartmentDetails=CONCAT("Dentro de un centro de investigación perteneciente al XXXX en un grupo de investigación de una línea",
" concreta").
IF (ResponseId="R_3jYTryWR9JkGLQW") OrgDepartmentDetails=CONCAT("Mi primer trabajo relacionado fue en el ministerio de ciencia, tecnología e innovación que financiab",
"a la política de XXXX").
IF (ResponseId="R_vCC2Q7cTHq9KR21") OrgDepartmentDetails="XXXX Research Office".
IF (ResponseId="R_1JQ5u4csvstnF5m") OrgDepartmentDetails=CONCAT("Small organisation with XXXX staff. Part of a team of 2 leading research operations across the chari",
"ty.").
IF (ResponseId="R_21drhm6sWwXqkHS") OrgDepartmentDetails="I worked in a XXXX unit in a larger cancer institute, part of a large academic center.".
IF (ResponseId="R_cACbwOPnP4Pehb3") OrgDepartmentDetails=CONCAT("1st position: XXXX for European Research Programme: a service organization under the Ministry for Re",
"search serving all universities and research organizations in Germany").
IF (ResponseId="R_3G3cI7nZJmK6BVS") OrgDepartmentDetails="My first position was as a Program Officer at the NIH, in the XXXX Division.".
IF (ResponseId="R_3MyzUE885QlpozS") OrgDepartmentDetails=CONCAT("I work with a team of research administrators who serve the needs of primary investigators working w",
"ithin a university-based research institute. In terms of hierarchy: University of XXXX, XXXX School of Geoscience, then the XXXX Geophysics. Under the auspices of the school of geoscience there is the",
" department and then two research institutes, one of which I support.").
IF (ResponseId="R_1gqdvQEO3N8iQi7") OrgDepartmentDetails=CONCAT("1st - Dept. of Computer Science, in XXXX College of Arts & Sciences; 2nd, Current - Div. of General ",
"Internal Medicine, Dept. of Medicine, in School of Medicine").
IF (ResponseId="R_3imx9rSC1XIZpFJ") OrgDepartmentDetails="I have always worked in the Department of Neuroscience and XXXX Therapeutics".
IF (ResponseId="R_2bWyIZGtcVgCD9Z") OrgDepartmentDetails=CONCAT("School of Public Health, Global Health, School of Medicine, Pediatrics, School of Medicine Epidemiol",
"ogy, and National XXXX Center").

IF (ResponseId="R_pRizaw6mkamDRvP") PD_OtherDetails="XXXX offers many management programs, I have taken almost all of them.".
IF (ResponseId="R_3hcnUr8yk0z7BfO") PD_OtherDetails="Took a class with XXXX".

IF (ResponseId="R_3frweedwiOLtOut") PQ_OtherComments="It is considered an important accomplishment at XXXX State.".

* *** A total of 48 items were redacted in the cross-check phase.  It is hoped that we did not miss any.
* *** As the text fields are also disaggregated into separate datafiles we feel confident about our anonymising.

EXECUTE.

* *** AND That is All the variables.
* *** now need to delete the scratch variables.
* *** and then reorder the variables into the questionnaire order.

add files file *
/keep StartDate
EndDate
Progress
ResponseId
UserLanguage
YearsEmployed
YearsEmployedGrouped
FirstRoleLevel
CurrentRoleLevelR3
CurrentRoleLevel
FirstRoleLevelDetails
CurrentRoleLevelDetails
FirstEmploymentStatus
CurrentEmploymentStatus
EmploymentStatusDetails
FirstEmploymentType
CurrentEmploymentType
EmploymentTypeDetails
FirstWorkedInProposalDevelopment
FirstWorkedInProjectSupport
FirstWorkedInTranslation
FirstWorkedInPGR
FirstWorkedInPolicy
FirstWorkedInERA
FirstWorkedInCompliance
FirstWorkedInServiceDelivery
FirstWorkedInTraining
FirstWorkedInOther
WorksInProposalDevelopment
WorksInProjectSupport
WorksInTranslation
WorksInPGR
WorksInPolicy
WorksInERA
WorksInCompliance
WorksInServiceDelivery
WorksInTraining
WorksInOther
WorksInOtherArea
FirstJRespFor_RDP
JRespFor_RDP
FirstJRespFor_RDP_Policy
JRespFor_RDP_Policy
FirstJRespFor_RDP_InstRes
JRespFor_RDP_InstRes
FirstJRespFor_RDP_Strategy
JRespFor_RDP_Strategy
FirstJRespFor_Pre
JRespFor_Pre
FirstJRespFor_Pre_ProjPlan
JRespFor_Pre_ProjPlan
FirstJRespFor_Pre_FundInfo
JRespFor_Pre_FundInfo
FirstJRespFor_Pre_IntNegotiation
JRespFor_Pre_IntNegotiation
FirstJRespFor_Pre_ExtNegotiation
JRespFor_Pre_ExtNegotiation
FirstJRespFor_Pre_AppSupport
JRespFor_Pre_AppSupport
FirstJRespFor_Post
JRespFor_Post
FirstJRespFor_Post_ExtAdjust
JRespFor_Post_ExtAdjust
FirstJRespFor_Post_ProgressMgt
JRespFor_Post_ProgressMgt
FirstJRespFor_Post_Accounting
JRespFor_Post_Accounting
FirstJRespFor_Post_ProjEval
JRespFor_Post_ProjEval
FirstJRespFor_Post_Reporting
JRespFor_Post_Reporting
FirstJRespFor_Other
JRespFor_Other
FirstJRespFor_Other_International
JRespFor_Other_International
FirstJRespFor_Other_Education
JRespFor_Other_Education
FirstJRespFor_Other_Industry
JRespFor_Other_Industry
FirstJRespFor_Other_IP
JRespFor_Other_IP
FirstJRespFor_Other_Branding
JRespFor_Other_Branding
FirstJRespFor_Other_PR
JRespFor_Other_PR
FirstJRespFor_Other_Events
JRespFor_Other_Events
FirstJRespFor_Other_Safety
JRespFor_Other_Safety
FirstJRespFor_Other_Compliance
JRespFor_Other_Compliance
FirstJRespFor_SomethingElse
JRespFor_SomethingElse
JRespFor_SomethingElseD
JobDescriptionMatch
JobDescriptionMatchD
SubjectAreasSupport_Science
SubjectAreasSupport_Medicine
SubjectAreasSupport_Enginering
SubjectAreasSupport_Business
SubjectAreasSupport_SocialScience
SubjectAreasSupport_Humanities
SubjectAreasSupport_Arts
SubjectAreasSupport_General
SubjectAreasSupport_Other
SubjectAreasSupport_OD
EducationAligned
EducationAlignedDet
EducationAlignImp
EducationAlignImpDet
InstitutionCharacter2
InstitutionCharacter
InstitutionCharDet
InstitutionType
InstitutionTypeDet
OrgDepartment_First
OrgDepartment
OrgDepartmentDetails
IE_SupportImpact
IE_UnderstandImpact
IE_ImpactStrategy
IE_ImpactTraining
IE_SupportEngagement
IE_UnderstandEngagement
IE_EngagementStrategy
IE_EngagementTraining
IE_ImpactAtWorkDet
NumRARoles
NumRARolesDetails
NumYearsPUI
NumYearsUniActive
NumYearsUniIntense
NumYearsCollege
NumYearsInstitute
NumYearsFunder
NumYearsCompany
NumYearsHospital
NumYearsCharity
NumYearsOGD
NumYearsOther
NumYearsOtherD
NumYearsWorkedAtDet
JoinRAReason
JoinRAMoreDetails
JoinRAInterested
JoinRASkillsMatch
JoinRATemporary
JoinRAFriend
JoinRAJustApplied
JoinRAResearcher
JoinRAAdmin
JoinRALocal
JoinRAUni
JoinRAOther
JoinRAOtherDet
StayRAGoodPay
StayRANotBoring
StayRAAdvancement
StayRANoOpportunity
StayRACouldntMove
StayRASecurity
StayRAFun
StayRANotWant
StayRAFaculty
StayRAChallenging
StayRANewProfession
StayRATooLate
StayRADontIntend
StayRAWantToMove
StayRAOther
StayRANotStayed
StayRAOtherDet
HighestQualBefore
HighestQualDuring
HighestQualSubjectBefore
HighestQualSubjectDuring
HighestQualSubjectBeforeDet
HighestQualSubjectDuringDet
HighestQualification
HighestQualificationSubject
HighestQualificationSubjectDet
PQ_AU_ARMF
PQ_AU_ARMA
PQ_CA_CRA
PQ_CA_CRM
PQ_EU_CRA
PQ_EU_CRM
PQ_EU_CLRM
PQ_UK_CRA
PQ_UK_CRM
PQ_UK_CLRM
PQ_US_CRA
PQ_US_CPRA
PQ_US_CFRA
PQ_US_CIP
PQ_US_CPIA
PQ_Bachelor
PQ_Master
PQ_Doctor
PQ_Other
PQ_None
PQ_NoneAvailable
PQ_OtherDetails
AnyCRA
PQ_NoDifference
PQ_HelpedPromotion
PQ_DoJobBetter
PQ_MoreConfidence
PQ_Status
PQ_ThinkItWould
PQ_OtherComments
PD_Comms
PD_Collab
PD_Adapt
PD_ProblemSolving
PD_Observation
PD_Coaching
PD_StressManagement
PD_ServiceCulture
PD_InitiativeTaking
PD_EDI
PD_TakingResponsibility
PD_ProjectManagement
PD_MentoringOnly
PD_ConflictResolution
PD_LanguageSkills
PD_Other
PD_Mentoring
PD_None
PD_OtherDetails
LanguagesSpoken
LanguagesUsed
Assoc_ACU_Member
Assoc_ACU_Participated
Assoc_ARMA_Member
Assoc_ARMA_Participated
Assoc_ARMANL_Member
Assoc_ARMANL_Participated
Assoc_ARMS_Member
Assoc_ARMS_Participated
Assoc_AUA_Member
Assoc_AUA_Participated
Assoc_AURAM_Member
Assoc_AURAM_Participated
Assoc_AUTM_Member
Assoc_AUTM_Participated
Assoc_BESTPRAC_Member
Assoc_BESTPRAC_Participated
Assoc_BRAMA_Member
Assoc_BRAMA_Participated
Assoc_CabRIMA_Member
Assoc_CabRIMA_Participated
Assoc_CARA_Member
Assoc_CARA_Participated
Assoc_CARIMA_Member
Assoc_CARIMA_Participated
Assoc_CASSSP_Member
Assoc_CASSSP_Participated
Assoc_CLASP_Member
Assoc_CLASP_Participated
Assoc_CLORA_Member
Assoc_CLORA_Participated
Assoc_COREMA_Member
Assoc_COREMA_Participated
Assoc_COGR_Member
Assoc_COGR_Participated
Assoc_DARMA_Member
Assoc_DARMA_Participated
Assoc_EARIMA_Member
Assoc_EARIMA_Participated
Assoc_EARMA_Member
Assoc_EARMA_Participated
Assoc_FDP_Member
Assoc_FDP_Participated
Assoc_FinnARMA_Member
Assoc_FinnARMA_Participated
Assoc_GARMA_Member
Assoc_GARMA_Participated
Assoc_IceARMA_Member
Assoc_IceARMA_Participated
Assoc_IRMI_Member
Assoc_IRMI_Participated
Assoc_INORMS_Member
Assoc_INORMS_Participated
Assoc_Italy_Member
Assoc_Italy_Participated
Assoc_KOsRISII_Member
Assoc_KOsRISII_Participated
Assoc_MyRMA_Member
Assoc_MyRMA_Participated
Assoc_NARIMA_Member
Assoc_NARIMA_Participated
Assoc_NARMA_Member
Assoc_NARMA_Participated
Assoc_NCURA_Member
Assoc_NCURA_Participated
Assoc_NWM_Member
Assoc_NWM_Participated
Assoc_NORDP_Member
Assoc_NORDP_Participated
Assoc_PIC_Member
Assoc_PIC_Participated
Assoc_PrU_Member
Assoc_PrU_Participated
Assoc_PRISM_Member
Assoc_PRISM_Participated
Assoc_RMANJ_Member
Assoc_RMANJ_Participated
Assoc_SARIMA_Member
Assoc_SARIMA_Participated
Assoc_SRAI_Member
Assoc_SRAI_Participated
Assoc_SWARMA_Member
Assoc_SWARMA_Participated
Assoc_WARIMA_Member
Assoc_WARIMA_Participated
Assoc_ARIS_Member
Assoc_ARIS_Participated
Assoc_AUECO_Member
Assoc_BEARMA_Member
Assoc_CAPANR_Member
Assoc_CASE_Member
Assoc_CURIE_Member
Assoc_CZARMA_Member
Assoc_GPA_Member
Assoc_PMI_Member
Assoc_PRIMR_Member
Assoc_PRIMR_Participated
Assoc_RACC_Member
Assoc_RACC_Participated
Assoc_SOCRA_Member
Assoc_UIDP_Member 
Assoc_UIDP_Participated
Assoc_None_Member
Assoc_None_Participated
Assoc_Other_Member
Assoc_Other_Participated
Assoc_OtherDetails
CountryOfEmployment
AusStateOfEmployment
StateOfEmployment
ProvinceOfEmployment
NationOfEmployment
ContinentOfEmployment
RegionOfEmployment
AnalysisRegionOfEmployment
CountryOfBirth
AusStateOfBirth
StateOfBirth
ProvinceOfBirth
NationOfBirth
FirstAgeRangeExtended
AgeRangeExtended
AgeRange
GenderExtended
Gender
EthnicBackground
EthnicBackgroundDetails
CurrentJobTitle
PreRMARoleDurationRecent
PreRMARoleDurationMiddle
PreRMARoleDurationOldest
PreRMARoleDurationRecentGrouped
PreRMARoleDurationMiddleGrouped
PreRMARoleDurationOldestGrouped
PreRMARoleDetailsRecent
PreRMARoleDetailsMiddle
PreRMARoleDetailsOldest
PreRMARoleAreaRecent
PreRMARoleAreaMiddle
PreRMARoleAreaOldest
PreRMARoleDetails
CareerPlan
CareerPlanDet
ChallengeNoNetwork
ChallengeLackOfKnowledge
ChallengeLackOfTraining
ChallengeCulture
ChallengeNewProfession
ChallengeRecognition
ChallengePermanent
ChallengeCareer
ChallengePolicy
ChallengeOther
ChallengeNone
ChallengeOtherDet
SkillResearch
SkillRMA
SkillTraining
SkillMultitasking
SkillDetail
SkillOrganisational
SkillResearchInterest
SkillResearchOrgExp
SkillTeam
SkillData
SkillComms
SkillLearning
SkillInternational
SkillProblem
SkillIntegrity
SkillService
SkillOther
SkillsForRMAJobDet
CareerSatisfaction
CareerSatisfactionDetails
IdentityRMA
IdentityName
IdentityDetails
DissatisfactionDemands
DissatisfactionUpdating
DissatisfactionMonotony
DissatisfactionGranted
DissatisfactionPromotion
DissatisfactionDevelopment
DissatisfactionSalary
DissatisfactionBeyond
DissatisfactionHours
DissatisfactionMotivation
DissatisfactionRespect
DissatisfactionGatekeeper
DissatisfactionIdentity
DissatisfactionSecurity
DissatisfactionOther
DissatisfactionNone
AreasOfDissatisfactionDetails
HaveBeenMentored
HaveMentored
WouldRecommendRMA
WhyRecommendRMA
AnyComments
AnyIssues
CanWeContactYou
Name
Email
SocialMedia
Employer.
EXECUTE.

* *** and now save our work!.
SAVE OUTFILE='RAAAP-3 All Cleansed Data 20230503.sav'. /* THIS is the file that will go to the next step in the data cleansing process.
* *** ie splitting the file to keep the responses anonymous.
